@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,12 +37,12 @@ namespace BzPNG {
 
   /** Create a PNG image, string starts with "ERROR" if there's an error */
   std::string create(const std::vector<Chunk>& extraChunks,
-		     size_t sx, size_t sy, size_t channels, const void* pixels);
+		     size_t sx, size_t sy, size_t channels, const unsigned char* pixels);
 
   /** Save a PNG image */
   bool save(const std::string& filename,
 	    const std::vector<Chunk>& extraChunks,
-	    size_t sx, size_t sy, size_t channels, const void* pixels);
+	    size_t sx, size_t sy, size_t channels, const unsigned char* pixels);
 }
 
 #endif
