@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -35,7 +35,7 @@ class BzfVisual {
     virtual void	setAccum(int minRed, int minGreen,
 				int minBlue, int minAlpha) = 0;
     virtual void	setStereo(bool) = 0;
-    virtual void	setMultisample(int minSamples) = 0;
+    virtual void	setVerticalSync(bool) {;}
 
     virtual bool	build() = 0;
 
@@ -47,10 +47,9 @@ class BzfVisual {
 #endif // BZF_VISUAL_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
