@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -49,13 +49,17 @@ class BzfWindow {
     virtual void	setMinSize(int width, int height) = 0;
     virtual void	setFullscreen(bool) = 0;
     virtual void	iconify(void) {;};
-    virtual bool	create(void) {return true;};
+    virtual bool	create(void) { return true; };
 
     virtual void	warpMouse(int x, int y) = 0;
     virtual void	getMouse(int& x, int& y) const = 0;
     virtual void	grabMouse() = 0;
     virtual void	ungrabMouse() = 0;
     virtual void	enableGrabMouse(bool) {;};
+    // TODO: Refactor our handling of confining the mouse to the window or
+    // the motionbox to be a bit cleaner.
+    virtual void	disableConfineToMotionbox() {;}
+    virtual void	confineToMotionbox(int x1, int y1, int x2, int y2);
     virtual void	showMouse() = 0;
     virtual void	hideMouse() = 0;
 
@@ -63,6 +67,9 @@ class BzfWindow {
     virtual float	getGamma() const = 0;
     virtual bool	hasGammaControl() const = 0;
 
+    virtual bool	hasVerticalSync() const { return false; }
+    virtual void	setVerticalSync(bool) {;}
+
     virtual void	makeCurrent() = 0;
     virtual void	yieldCurrent();
     virtual void	releaseCurrent();
@@ -85,7 +92,7 @@ class BzfWindow {
 };
 
 
-#endif  /* __BZFWINDOW_H__ */
+#endif /* __BZFWINDOW_H__ */
 
 // Local Variables: ***
 // mode: C++ ***
