@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,8 +31,8 @@ class CacheManager {
       std::string key;
     } CacheRecord;
 
-    bool isCacheFileType(const std::string name) const;
-    std::string getLocalName(const std::string name) const;
+    bool isCacheFileType(const std::string &name) const;
+    std::string getLocalName(const std::string &name) const;
 
     bool loadIndex();
     bool saveIndex();
@@ -49,6 +49,7 @@ class CacheManager {
 
   private:
     std::string indexName;
+    std::string getIndexPath();
     std::vector<CacheRecord> records;
 };
 
@@ -58,7 +59,7 @@ extern CacheManager CACHEMGR;
 
 /*
  * Local Variables: ***
- * mode:C ***
+ * mode: C ***
  * tab-width: 8 ***
  * c-basic-offset: 2 ***
  * indent-tabs-mode: t ***
