@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,7 +24,7 @@
 typedef struct sequenceList {
   float period;
   float offset;
-  char* list;
+  signed char* list;
   unsigned int count;
 } sequenceParams;
 
@@ -68,7 +68,7 @@ class DynamicColor {
 
     int packSize() const;
     void* pack(void*) const;
-    void* unpack(void*);
+    const void* unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -114,7 +114,7 @@ class DynamicColorManager {
 
     int packSize() const;
     void* pack(void*) const;
-    void* unpack(void*);
+    const void* unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -128,10 +128,9 @@ extern DynamicColorManager DYNCOLORMGR;
 #endif //_DYNAMIC_COLOR_H_
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
