@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,10 +13,6 @@
 #ifndef _FONT_MANAGER_H_
 #define _FONT_MANAGER_H_
 
-#ifdef _MSC_VER
-  #pragma warning(disable : 4786)  // Disable warning message
-#endif
-
 #include <map>
 #include <string>
 #include <vector>
@@ -88,8 +84,6 @@ private:
   static void	freeContext(void *data);
   static void	initContext(void *data);
   static GLfloat underlineColor[4];
-
-  bool		canScale;
 };
 
 inline void FontManager::setDimFactor(float newDimFactor)
@@ -111,10 +105,9 @@ inline void FontManager::setDarkness(float newDarkness)
 #endif //_FONT_MANAGER_H_
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
