@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,7 +31,7 @@ namespace GameTime {
 
   int packSize();
   void* pack(void *, float lag);
-  void* unpack(void *);
+  const void* unpack(const void *);
 
   const float startRate = 1.0f;
   const float finalRate = 10.0f;
