@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -46,7 +46,7 @@ class MeshObstacle : public Obstacle {
 		  const std::vector<int>& texcoords,
 		  const BzMaterial* bzMaterial, int physics,
 		  bool noclusters, bool bounce, bool drive, bool shoot,
-		  bool triangulate, bool ricochet);
+		  bool ricochet, bool triangulate);
 
     ~MeshObstacle();
 
@@ -93,26 +93,26 @@ class MeshObstacle : public Obstacle {
 
     const char *getCheckTypes() const;
     const afvec3 *getCheckPoints() const;
-    const afvec3 *getVertices() const;
-    const afvec3 *getNormals() const;
-    const afvec2 *getTexcoords() const;
+    afvec3 *getVertices() const;
+    afvec3 *getNormals() const;
+    afvec2 *getTexcoords() const;
     int getCheckCount() const;
     int getVertexCount() const;
     int getNormalCount() const;
     int getTexcoordCount() const;
     int getFaceCount() const;
-    const MeshFace* getFace(int face) const;
+    MeshFace* getFace(int face) const;
     const float* getPosition() const;
     const float* getSize() const;
     bool useSmoothBounce() const;
     bool noClusters() const;
 
-    const MeshDrawInfo* getDrawInfo() const;
+    MeshDrawInfo* getDrawInfo() const;
     void setDrawInfo(MeshDrawInfo*);
 
     int packSize() const;
     void *pack(void*) const;
-    void *unpack(void*);
+    const void *unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
     void printOBJ(std::ostream& out, const std::string& indent) const;
@@ -158,17 +158,17 @@ inline const afvec3 *MeshObstacle::getCheckPoints() const
   return checkPoints;
 }
 
-inline const afvec3 *MeshObstacle::getVertices() const
+inline afvec3 *MeshObstacle::getVertices() const
 {
   return vertices;
 }
 
-inline const afvec3 *MeshObstacle::getNormals() const
+inline afvec3 *MeshObstacle::getNormals() const
 {
   return normals;
 }
 
-inline const afvec2 *MeshObstacle::getTexcoords() const
+inline afvec2 *MeshObstacle::getTexcoords() const
 {
   return texcoords;
 }
@@ -198,7 +198,7 @@ inline int MeshObstacle::getFaceCount() const
   return faceCount;
 }
 
-inline const MeshFace* MeshObstacle::getFace(int face) const
+inline MeshFace* MeshObstacle::getFace(int face) const
 {
   return faces[face];
 }
@@ -223,7 +223,7 @@ inline bool MeshObstacle::noClusters() const
   return noclusters;
 }
 
-inline const MeshDrawInfo* MeshObstacle::getDrawInfo() const
+inline MeshDrawInfo* MeshObstacle::getDrawInfo() const
 {
   return drawInfo;
 }
@@ -242,10 +242,9 @@ inline void MeshObstacle::setName(const std::string& str)
 #endif // BZF_MESH_OBSTACLE_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
