@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -53,15 +53,15 @@ class Obstacle {
   Obstacle();
 
   /** This function initializes the Obstacle with the given parameters.
-      @param pos	 The position of the obstacle in world coordinates
-      @param rotation    The rotation around the obstacle's Z axis
-      @param hwidth      Half the X size of the obstacle
-      @param hbreadth    Half the Y size of the obstacle
-      @param height      The Z size of the obstacle
-      @param drive       @c true if the obstacle is drivethtrough, i.e. tanks
-			 can pass through it
-      @param shoot       @c true if the obstacle is shootthrough, i.e. bullets
-			 can pass through it
+      @param pos	The position of the obstacle in world coordinates
+      @param rotation   The rotation around the obstacle's Z axis
+      @param hwidth     Half the X size of the obstacle
+      @param hbreadth   Half the Y size of the obstacle
+      @param height     The Z size of the obstacle
+      @param drive      @c true if the obstacle is drivethtrough, i.e. tanks
+			can pass through it
+      @param shoot      @c true if the obstacle is shootthrough, i.e. bullets
+			can pass through it
   */
   Obstacle(const float* pos, float rotation, float hwidth, float hbreadth,
 	   float height, bool drive = false, bool shoot = false, bool rico = false);
@@ -92,7 +92,7 @@ class Obstacle {
   virtual void *pack(void* buf) const = 0;
 
   /** This function unpacks the obstacle from buf */
-  virtual void *unpack(void* buf) = 0;
+  virtual const void *unpack(const void* buf) = 0;
 
   /** This function prints the obstacle to the stream */
   virtual void print(std::ostream& out, const std::string& indent) const = 0;
@@ -152,11 +152,11 @@ class Obstacle {
 
   /** This function checks if a horizontal rectangle crosses the surface of
       this obstacle.
-      @param p	   The position of the centre of the rectangle
-      @param angle       The rotation of the rectangle
-      @param halfWidth   Half the width of the rectangle
+      @param p		 The position of the centre of the rectangle
+      @param angle	 The rotation of the rectangle
+      @param halfWidth	 Half the width of the rectangle
       @param halfBreadth Half the breadth of the rectangle
-      @param plane       The tangent plane of the obstacle where it's
+      @param plane	 The tangent plane of the obstacle where it's
 			 intersected by the rectangle will be stored here
   */
   virtual bool isCrossing(const float* p, float angle,
@@ -166,16 +166,16 @@ class Obstacle {
   /** This function checks if a box moving from @c pos1 to @c pos2 will hit
       this obstacle, and if it does what the surface normal at the hitpoint is.
       @param pos1	 The original position of the box
-      @param azimuth1     The original rotation of the box
+      @param azimuth1	 The original rotation of the box
       @param pos2	 The position of the box at the hit
-      @param azimuth2     The rotation of the box at the hit
-      @param halfWidth    Half the width of the box
-      @param halfBreadth  Half the breadth of the box
-      @param height       The height of the box
-      @param normal       The surface normal of this obstacle at the hit point
-			  will be stored here
+      @param azimuth2	 The rotation of the box at the hit
+      @param halfWidth	 Half the width of the box
+      @param halfBreadth Half the breadth of the box
+      @param height	 The height of the box
+      @param normal	 The surface normal of this obstacle at the hit point
+			 will be stored here
       @returns	    @c true if the box hits this obstacle, @c false
-			  otherwise
+			 otherwise
   */
   virtual bool getHitNormal(const float* pos1, float azimuth1,
 			    const float* pos2, float azimuth2,
@@ -194,7 +194,7 @@ class Obstacle {
       this object, @c false if either can not */
   bool isPassable() const;
 
-  /** This function returns @c true if  bullets will bounce off of this
+  /** This function returns @c true if bullets will bounce off of this
    * object, @c false if they simply die of contact */
   bool canRicochet() const;
 
@@ -244,20 +244,20 @@ class Obstacle {
   /** This function checks if a moving horizontal rectangle will hit a
       box-shaped obstacle, and if it does, computes the obstacle's normal
       at the hitpoint.
-      @param pos1	The original position of the rectangle
-      @param azimuth1    The original rotation of the rectangle
-      @param pos2	The final position of the rectangle
-      @param azimuth2    The final rotation of the rectangle
-      @param halfWidth   Half the width of the rectangle
+      @param pos1	 The original position of the rectangle
+      @param azimuth1	 The original rotation of the rectangle
+      @param pos2	 The final position of the rectangle
+      @param azimuth2	 The final rotation of the rectangle
+      @param halfWidth	 Half the width of the rectangle
       @param halfBreadth Half the breadth of the rectangle
-      @param oPos	The position of the obstacle
-      @param oAzimuth    The rotation of the obstacle
-      @param oWidth      Half the width of the obstacle
-      @param oBreadth    Half the breadth of the obstacle
-      @param oHeight     The height of the obstacle
-      @param normal      The surface normal of the obstacle at the hitpoint
+      @param oPos	 The position of the obstacle
+      @param oAzimuth	 The rotation of the obstacle
+      @param oWidth	 Half the width of the obstacle
+      @param oBreadth	 Half the breadth of the obstacle
+      @param oHeight	 The height of the obstacle
+      @param normal	 The surface normal of the obstacle at the hitpoint
 			 will be stored here
-      @returns	   The time of the hit, where 0 is the time when the
+      @returns		 The time of the hit, where 0 is the time when the
 			 rectangle is at @c pos1 and 1 is the time when it's
 			 at @c pos2, and -1 means "no hit"
   */
@@ -397,10 +397,9 @@ inline void Obstacle::resetObjCounter()
 #endif // BZF_OBSTACLE_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
