@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -49,7 +49,7 @@ class PhysicsDriver {
 
     int packSize() const;
     void* pack(void*) const;
-    void* unpack(void*);
+    const void* unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -118,7 +118,7 @@ class PhysicsDriverManager {
 
     int packSize() const;
     void* pack(void*) const;
-    void* unpack(void*);
+    const void* unpack(const void*);
 
     void print(std::ostream& out, const std::string& indent) const;
 
@@ -142,10 +142,9 @@ extern PhysicsDriverManager PHYDRVMGR;
 #endif //_PHYSICS_DRIVER_H_
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
