@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,13 +20,13 @@ class PlayerState
 {
   public:
     enum PStatus {			// bit masks
-      DeadStatus =      0,		// not alive, not paused, etc.
+      DeadStatus =	0,		// not alive, not paused, etc.
       Alive =		(1 << 0),	// player is alive
       Paused =		(1 << 1),	// player is paused
-      Exploding =       (1 << 2),	// currently blowing up
-      Teleporting =     (1 << 3),	// teleported recently
-      FlagActive =      (1 << 4),	// flag special powers active
-      CrossingWall =    (1 << 5),	// tank crossing building wall
+      Exploding =	(1 << 2),	// currently blowing up
+      Teleporting =	(1 << 3),	// teleported recently
+      FlagActive =	(1 << 4),	// flag special powers active
+      CrossingWall =	(1 << 5),	// tank crossing building wall
       Falling =		(1 << 6),	// tank accel'd by gravity
       OnDriver =	(1 << 7),	// tank is on a physics driver
       UserInputs =	(1 << 8),	// user speed and angvel are sent
@@ -44,7 +44,7 @@ class PlayerState
 
     PlayerState();
     void*	pack(void*, uint16_t& code);
-    void*	unpack(void*, uint16_t code);
+    const void*	unpack(const void*, uint16_t code);
 
     long	order;		// packet ordering
     short	status;		// see PStatus enum
@@ -67,7 +67,7 @@ class PlayerState
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
