@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,12 +39,13 @@ const int		ServerPort = 5154;
 const int		BroadcastPort = 5154;
 
 // URL for default list server
-const char* const	DefaultListServerURL = "http://my.BZFlag.org/db/";
-const char* const	DefaultMasterBanURL = "http://bzflag.org/master-bans.txt";
-const char* const	DefaultMOTDServer = "http://bzflag.org/motd.php";
+const char* const	DefaultListServerURL = "https://my.bzflag.org/db/";
+const char* const	DefaultMasterBanURL = "https://www.bzflag.org/master-bans.txt";
+const char* const	DefaultMOTDServer = "https://www.bzflag.org/motd.php";
 
 // maximum size of any message (including header and length fields)
 const int		MaxPacketLen = 1024;
+const int		MaxUDPPacketLen = 68;
 
 // the banned tag
 const char* const	BanRefusalString = "REFUSED:";
@@ -79,13 +80,11 @@ const uint16_t		MsgGMUpdate = 0x676d;			// 'gm'
 const uint16_t		MsgGetWorld = 0x6777;			// 'gw'
 const uint16_t		MsgGameSettings = 0x6773;		// 'gs'
 const uint16_t		MsgGameTime = 0x6774;			// 'gt'
-const uint16_t	  MsgHandicap = 0x6863;		   // 'hc'
+const uint16_t		MsgHandicap = 0x6863;			// 'hc'
 const uint16_t		MsgKilled = 0x6b6c;			// 'kl'
-const uint16_t		MsgKrbPrincipal = 0x6b70;		// 'kp'
-const uint16_t		MsgKrbTicket    = 0x6b74;		// 'kt'
 const uint16_t		MsgLagState = 0x6c73;			// 'ls'
 const uint16_t		MsgMessage = 0x6d67;			// 'mg'
-const uint16_t	  MsgNearFlag = 0x4e66;		   // 'Nf'
+const uint16_t		MsgNearFlag = 0x4e66;			// 'Nf'
 const uint16_t		MsgNewRabbit = 0x6e52;			// 'nR'
 const uint16_t		MsgNegotiateFlags = 0x6e66;		// 'nf'
 const uint16_t		MsgPause = 0x7061;			// 'pa'
@@ -183,9 +182,6 @@ const uint16_t		PhysicsDriverDeath = 0x7064;		// 'pd'
 const uint16_t		MsgUDPLinkRequest = 0x6f66;		// 'of'
 const uint16_t		MsgUDPLinkEstablished = 0x6f67;		// 'og'
 
-// server control message
-const uint16_t		MsgServerControl = 0x6f69;		// 'oi'
-
 // lag ping sent by server to client and reply from client
 const uint16_t		MsgLagPing = 0x7069;			// 'pi'
 
@@ -248,7 +244,7 @@ player to server messages:
 			<== MsgMessage
   MsgWantWHash		(player wants md5 of world file
 			-->
-  MsgNegotiateFlags     -->flagCount/[flagabbv]
+  MsgNegotiateFlags	-->flagCount/[flagabbv]
   MsgPause		-->true or false
 
 server to player messages:
