@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,10 +39,7 @@ class Ray {
 // Ray
 //
 
-inline Ray::Ray()
-{
-  memset(o, 0, sizeof(float) * 3);
-}
+inline Ray::Ray() { memset(o,0,sizeof(float)*3); memset(d,0,sizeof(float)*3); }
 
 inline Ray::~Ray()
 {
@@ -62,10 +59,9 @@ inline const float*	Ray::getDirection() const
 #endif // BZF_RAY_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
