@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,10 +17,6 @@
 #ifndef	BZF_SCENE_RENDERER_H
 #define	BZF_SCENE_RENDERER_H
 
-#if defined(_MSC_VER)
-#pragma warning(disable: 4786)
-#endif
-
 /* the common header */
 #include "common.h"
 
@@ -79,7 +75,10 @@ public:
   bool		useWireframe() const;
   bool		useHiddenLine() const;
   float		getPanelOpacity() const;
+  float		getRadarOpacity() const;
+  bool		isPanelOpaque() const;
   int		getRadarSize() const;
+  int		getPanelHeight() const;
   int		getMaxMotionFactor() const;
   bool		isLastFrame() const;
   bool		isSameFrame() const;
@@ -93,7 +92,9 @@ public:
   void		setWireframe(bool on);
   void		setHiddenLine(bool on);
   void		setPanelOpacity(float opacity);
+  void		setRadarOpacity(float opacity);
   void		setRadarSize(int size);
+  void		setPanelHeight(int size);
   void		setMaxMotionFactor(int size);
   void		setDim(bool on);
   void		setViewType(ViewType);
@@ -113,8 +114,8 @@ public:
   const ViewFrustum&	getViewFrustum() const;
   ViewFrustum&	getViewFrustum();
 
-  int			getNumLights() const;
-  int			getNumAllLights() const;
+  int		getNumLights() const;
+  int		getNumAllLights() const;
   const OpenGLLight&	getLight(int index) const;
   void		enableLight(int index, bool = true);
   void		clearLights();
@@ -150,11 +151,11 @@ public:
 
   const RenderNodeList& getShadowList() const;
 
-  bool		isFogActive() const { return fogActive; }
+  bool			isFogActive() const { return fogActive; }
   void			setFogActive(bool b) { fogActive = b; }
 
   const fvec4&	getFogColor() const { return fogColor; }
-  void	setFogColor( float *color) { fogColor = color; }
+  void		setFogColor( float *color) { fogColor = color; }
 
 
   void		render(bool lastFrame = true,
@@ -214,10 +215,10 @@ private:
   int			triangleCount;
   static const GLint	SunLight;
 
-  static const float dimDensity;
-  static const GLfloat dimnessColor[4];
-  static const GLfloat blindnessColor[4];
-  float teleporterProximity;
+  static const float	dimDensity;
+  static const GLfloat	dimnessColor[4];
+  static const GLfloat	blindnessColor[4];
+  float			teleporterProximity;
 
   bool		abgr;
   int		useQualityValue;
@@ -225,7 +226,9 @@ private:
   bool		useWireframeOn;
   bool		useHiddenLineOn;
   float		panelOpacity;
+  float		radarOpacity;
   int		radarSize;
+  int		panelHeight;
   int		maxMotionFactor;
   bool		useStencilOn;
   ViewType	viewType;
@@ -313,7 +316,7 @@ inline GLfloat			SceneRenderer::getSunBrightness() const
   return sunBrightness;
 }
 
-inline const GLfloat* SceneRenderer::getAmbientColor() const
+inline const GLfloat*		SceneRenderer::getAmbientColor() const
 {
   return ambientColor;
 }
@@ -348,8 +351,8 @@ inline int			SceneRenderer::useQuality() const
   return useQualityValue;
 }
 
-inline void SceneRenderer::addRenderNode(RenderNode* node,
-					 const OpenGLGState* gstate)
+inline void			SceneRenderer::addRenderNode(RenderNode* node,
+						const OpenGLGState* gstate)
 {
   if (inOrder || gstate->getNeedsSorting()) {
     // nodes will be drawn in the same order received
@@ -360,7 +363,7 @@ inline void SceneRenderer::addRenderNode(RenderNode* node,
   }
 }
 
-inline void SceneRenderer::addShadowNode(RenderNode* node)
+inline void			SceneRenderer::addShadowNode(RenderNode* node)
 {
   shadowList.append(node);
 }
