@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,7 +39,7 @@ class BaseLocalPlayer;
 struct ShotUpdate {
   public:
     void*		pack(void*) const;
-    void*		unpack(void*);
+    const void*		unpack(const void*);
 
   public:
     PlayerId		player;			// who's shot
@@ -56,7 +56,7 @@ struct FiringInfo {
 			FiringInfo(const BaseLocalPlayer&, int id);
 
     void*		pack(void*) const;
-    void*		unpack(void*);
+    const void*		unpack(const void*);
 
   public:
     float	       timeSent;
@@ -68,10 +68,9 @@ struct FiringInfo {
 #endif // BZF_SHOT_UPDATE_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
