@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,12 +27,12 @@ class TankSceneNode;
 class TankDeathOverride
 {
 public:
-	virtual ~TankDeathOverride(){};
+	virtual ~TankDeathOverride() {};
 
 	class DeathParams
 	{
 	public:
-		DeathParams( float param, fvec4 c)
+		DeathParams( float param, fvec4 c): part()
 		{
 			scale = fvec3(1,1,1);
 			explodeParam = param;
@@ -140,12 +140,12 @@ class TankSceneNode : public SceneNode {
 
     static void		setMaxLOD(int maxLevel);
 
-	void		setDeathOverride( TankDeathOverride* o) {deathOverride = o;}
-	TankDeathOverride		*getDeathOverride( void ) {return deathOverride;}
+    void		setDeathOverride( TankDeathOverride* o) { deathOverride = o; }
+    TankDeathOverride	*getDeathOverride( void ) { return deathOverride; }
 
-	fvec3		explodePos;
+    fvec3		explodePos;
   protected:
-	TankDeathOverride *deathOverride;
+    TankDeathOverride	*deathOverride;
 
     class TankRenderNode : public RenderNode {
       public:
@@ -200,25 +200,22 @@ class TankSceneNode : public SceneNode {
     float		leftWheelOffset;
     float		rightWheelOffset;
     bool		useDimensions;
-    bool		useOverride;
     bool		onlyShadows;
     bool		transparent, sort;
-    float		spawnFraction;
     float		explodeFraction;
     bool		clip;
     bool		inTheCockpit;
-    GLfloat		colorOverride[4];
     GLfloat		color[4];
     GLdouble		clipPlane[4];
     OpenGLGState	gstate;
-	OpenGLGState	treadState;
+    OpenGLGState	treadState;
     OpenGLGState	lightsGState;
     TankRenderNode	tankRenderNode;
-	TankRenderNode	treadsRenderNode;
-	TankRenderNode	shadowRenderNode;
+    TankRenderNode	treadsRenderNode;
+    TankRenderNode	shadowRenderNode;
     TankGeometryEnums::TankSize tankSize;
-    GLfloat vel[TankGeometryEnums::LastTankPart][3];
-    GLfloat spin[TankGeometryEnums::LastTankPart][4];
+    GLfloat		vel[TankGeometryEnums::LastTankPart][3];
+    GLfloat		spin[TankGeometryEnums::LastTankPart][4];
     bool		jumpJetsOn;
     GLfloat		jumpJetsScale;
     GLfloat		jumpJetsLengths[4];
@@ -236,10 +233,9 @@ class TankSceneNode : public SceneNode {
 #endif // BZF_TANK_SCENE_NODE_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
