@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -58,6 +58,37 @@ namespace TextUtils {
     return trans;
   }
 
+  inline std::string ltrim(const std::string& s, const char* trim = " ")
+  {
+    if (!trim)
+      return s;
+
+    size_t pos = s.find_first_not_of(trim);
+
+    if (pos == std::string::npos)
+      return s;
+
+    return s.substr(pos, s.length() + 1);
+  }
+
+  inline std::string rtrim(const std::string& s, const char* trim = " ")
+  {
+    if (!trim)
+      return s;
+
+    size_t pos = s.find_last_not_of(trim);
+
+    if (pos == std::string::npos)
+      return s;
+
+    return s.substr(0, pos + 1);
+  }
+
+  inline std::string trim(const std::string& s, const char* trim = " ")
+  {
+    return (rtrim(ltrim(s, trim), trim));
+  }
+
   /** replace all of in in replaceMe with withMe
    */
   std::string replace_all(const std::string& in, const std::string& replaceMe, const std::string& withMe);
@@ -203,10 +234,7 @@ namespace TextUtils {
    */
   inline bool isPrintable(const char c)
   {
-    if (isVisible(c) || isWhitespace(c)) {
-      return false;
-    }
-    return true;
+    return (isVisible(c) || isWhitespace(c));
   }
 
 
@@ -386,7 +414,7 @@ namespace TextUtils {
 
   /** find the first instance of a substring,
   */
-  size_t find_first_substr(const std::string &findin, const std::string findwhat, size_t offset = 0);
+  size_t find_first_substr(const std::string &findin, const std::string &findwhat, size_t offset = 0);
 }
 
 
