@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -35,7 +35,7 @@ class PlayerAddMessage
 public:
 	PlayerAddMessage();
 
-	bool unpack ( void* buf );
+	bool unpack ( const void* buf );
 	void* pack ( void* buf );
 
 	int playerID;
@@ -57,4 +57,3 @@ public:
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
