@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -22,9 +22,6 @@
 #include "common.h"
 
 #ifdef _WIN32
-# if defined(_MSC_VER)
-#   pragma warning(disable: 4786)
-# endif
 # include <winsock2.h>
 # include <ws2tcpip.h>
 #endif
@@ -60,11 +57,7 @@
 #  include <bstring.h>
 #endif
 
-#if defined(__linux__) && !defined(_old_linux_)
-#  define AddrLen		unsigned int
-/* setsockopt incorrectly prototypes the 4th arg without const. */
-#  define SSOType		void*
-#elif defined(BSD) || defined(sun) || defined(__GLIBC__)
+#if defined(BSD) || defined(__sun__) || defined(__GLIBC__)
 #  define AddrLen		socklen_t
 #elif defined (__APPLE__)
 #  include <AvailabilityMacros.h>
@@ -97,12 +90,22 @@ extern "C" {
 
 #else /* !defined(_WIN32) */
 
-#define	MAXHOSTNAMELEN	64
-
+#ifndef EINPROGRESS
 #define EINPROGRESS	WSAEWOULDBLOCK
+#endif
+
+#ifndef EWOULDBLOCK
 #define	EWOULDBLOCK	WSAEWOULDBLOCK
+#endif
+
+#ifndef ECONNRESET
 #define	ECONNRESET	WSAECONNRESET
+#endif
+
+#ifndef EBADMSG
 #define	EBADMSG		WSAECONNRESET	/* not defined by windows */
+#endif
+
 
 /* setsockopt prototypes the 4th arg as const char*. */
 #define SSOType		const char*
