@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,7 +23,6 @@
 
 #include "vectors_old.h" // FIXME -- the crappy old-style vectors
 
-
 //============================================================================//
 
 template <typename T> T typed_cos(T rads);
@@ -265,6 +264,8 @@ class vec3 {
     }
     vec3 normalize() const { vec3 v(*this); normalize(v); return v; }
 
+    static T toRadians(T value) { return value * (T)(M_PI/180.0); }
+
     vec3 rotateX(T radians) const {
       const T cv = typed_cos(radians);
       const T sv = typed_sin(radians);
@@ -376,8 +377,6 @@ class vec4 {
     inline const vec3<T>& xyz() const { return *(new((void*)&x) vec3<T>(false)); }
     inline       vec3<T>& yzw()       { return *(new((void*)&y) vec3<T>(false)); }
     inline const vec3<T>& yzw() const { return *(new((void*)&y) vec3<T>(false)); }
-    inline       vec3<T>& rgb()       { return xyz(); }
-    inline const vec3<T>& rgb() const { return xyz(); }
 
     vec4& operator+=(const vec4& v) { x += v.x; y += v.y; z += v.z; w += v.w; return *this; }
     vec4& operator-=(const vec4& v) { x -= v.x; y -= v.y; z -= v.z; w -= v.w; return *this; }
