@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -15,11 +15,6 @@
 #ifndef __VERSION_H__
 #define __VERSION_H__
 
-#ifndef BZ_BUILD_DATE
-extern int getBuildDate();
-#define BZ_BUILD_DATE		getBuildDate()
-#endif
-
 #ifndef BZ_CONFIG_DIR_VERSION
 #define BZ_CONFIG_DIR_VERSION	"2.4"
 #endif
@@ -29,7 +24,7 @@ extern int getBuildDate();
 #endif
 
 #ifndef BZ_CONFIG_FILE_VERSION
-#define BZ_CONFIG_FILE_VERSION	4
+#define BZ_CONFIG_FILE_VERSION	5
 #endif
 
 #define BZ_CONNECT_HEADER	"BZFLAG\r\n\r\n"
@@ -46,7 +41,7 @@ extern const char* getAppVersion();
 #endif //__VERSION_H__
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
