@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,24 +13,24 @@
 // logDetail.cpp : Plugin module for logging server events to stdout
 //
 
+#include "bzfsAPI.h"
 #include <iostream>
 #include <sstream>
-#include <cstring>
-#include "bzfsAPI.h"
 
-enum action { join , auth , part };
+enum action { join, auth, part };
 
 class LogDetail : public bz_Plugin
 {
 public:
-  virtual const char* Name (){return "Log Detail";}
-  virtual void Init ( const char* config);
+  virtual const char* Name () {return "Log Detail";}
+  virtual void Init ( const char* config );
   virtual void Cleanup ();
   virtual void Event ( bz_EventData *eventData );
 private:
   std::string displayPlayerPrivs( int playerID );
   std::string displayCallsign( bz_ApiString callsign );
   std::string displayCallsign( int playerID );
+  std::string displayMotto( int playerID );
   std::string displayBZid( int playerID );
   std::string displayTeam( bz_eTeamType team );
   virtual void listPlayers( action act, bz_PlayerJoinPartEventData_V1 *data );
@@ -50,13 +50,14 @@ void LogDetail::Init ( const char* /*commandLine*/ )
 
   bz_debugMessage(0, "SERVER-STATUS Running");
   bz_debugMessagef(0, "SERVER-MAPNAME %s", bz_getPublicDescription().c_str());
-  listPlayers( join , NULL );
+  listPlayers( join, NULL );
 }
 
 void LogDetail::Cleanup()
 {
-  listPlayers( part , NULL );
+  listPlayers( part, NULL );
   bz_debugMessage(0, "SERVER-STATUS Stopped");
+  Flush();
 }
 
 void LogDetail::Event( bz_EventData *eventData )
@@ -67,16 +68,16 @@ void LogDetail::Event( bz_EventData *eventData )
   bz_PlayerJoinPartEventData_V1 *joinPartData = (bz_PlayerJoinPartEventData_V1 *) eventData;
   bz_PlayerAuthEventData_V1 *authData = (bz_PlayerAuthEventData_V1 *) eventData;
   bz_MessageFilteredEventData_V1 *filteredData = (bz_MessageFilteredEventData_V1 *) eventData;
-  char temp[9] = {0};
 
   if (eventData) {
     switch (eventData->eventType) {
-      case bz_eSlashCommandEvent:
+      case bz_eSlashCommandEvent: {
 	// Slash commands are case insensitive
 	// Tokenize the stream and check the first word
 	// /report -> MSG-REPORT
 	// anything -> MSG-COMMAND
 
+	char temp[9] = {0};
 	strncpy(temp, cmdData->message.c_str(), 8);
 
 	if (strcasecmp( temp, "/REPORT ") == 0) {
@@ -89,6 +90,7 @@ void LogDetail::Event( bz_EventData *eventData )
 			   cmdData->message.c_str()+1);
 	}
 	break;
+      }
       case bz_eRawChatMessageEvent:
 	if ((chatData->to == BZ_ALLUSERS) && (chatData->team == eNoTeam)) {
 	  bz_debugMessagef(0, "MSG-BROADCAST %s %s",
@@ -145,6 +147,11 @@ void LogDetail::Event( bz_EventData *eventData )
 			     displayBZid( joinPartData->playerID ).c_str(),
 			     displayTeam( joinPartData->record->team ).c_str(),
 			     displayPlayerPrivs( joinPartData->playerID ).c_str());
+	    bz_debugMessagef(0, "PLAYER-MOTTO %s #%d%s %s",
+			     displayCallsign( joinPartData->playerID).c_str(),
+			     joinPartData->playerID,
+			     displayBZid( joinPartData->playerID ).c_str(),
+			     displayMotto( joinPartData->playerID).c_str());
 	    listPlayers( join, joinPartData);
 	  }
 	}
@@ -225,6 +232,20 @@ std::string LogDetail::displayCallsign( int playerID )
   return callsign.str();
 }
 
+std::string LogDetail::displayMotto( int playerID )
+{
+  std::ostringstream motto;
+  bz_PlayerRecordV2 *player = (bz_PlayerRecordV2*)bz_getPlayerByIndex( playerID );
+  if (player) {
+    motto << strlen( player->motto.c_str() ) << ":";
+    motto << player->motto.c_str();
+    bz_freePlayerRecord( player );
+  } else {
+    motto << "7:UNKNOWN";
+  }
+  return motto.str();
+}
+
 
 std::string LogDetail::displayTeam( bz_eTeamType team )
 {
@@ -251,7 +272,7 @@ std::string LogDetail::displayTeam( bz_eTeamType team )
   }
 }
 
-void LogDetail::listPlayers( action act , bz_PlayerJoinPartEventData_V1 *data )
+void LogDetail::listPlayers( action act, bz_PlayerJoinPartEventData_V1 *data )
 {
   bz_APIIntList *playerList = bz_newIntList();
   bz_BasePlayerRecord *player = NULL;
@@ -261,7 +282,7 @@ void LogDetail::listPlayers( action act , bz_PlayerJoinPartEventData_V1 *data )
 
   bz_getPlayerIndexList( playerList );
 
-  bz_debugMessage( 4 , "Players:" );
+  bz_debugMessage( 4, "Players:" );
   //
   // Count number of players
   //
@@ -290,7 +311,7 @@ void LogDetail::listPlayers( action act , bz_PlayerJoinPartEventData_V1 *data )
   // PLAYERS (2) [@]7:Thumper(16:me@somewhere.net) [ ]3:xxx()
   //
   msg.str("");
-  msg << "PLAYERS (" << numPlayers << ") ";
+  msg << "PLAYERS (" << numPlayers << ")";
   for ( unsigned int i = 0; i < playerList->size(); i++ ) {
     player = bz_getPlayerByIndex( playerList->get(i));
     if (player) {
@@ -299,9 +320,9 @@ void LogDetail::listPlayers( action act , bz_PlayerJoinPartEventData_V1 *data )
 	if (player->globalUser) playerStatus = '+';
 	if (player->verified) playerStatus = '+';
 	if (player->admin && !bz_hasPerm(player->playerID, bz_perm_hideAdmin)) playerStatus = '@';
-	msg << "[" << playerStatus << "]";
+	msg << " [" << playerStatus << "]";
 	msg << player->callsign.size() << ':';
-	msg << player->callsign.c_str();
+	msg << player->callsign.c_str() << "(" << bz_getPlayerMotto(player->playerID) << ")";
       }
     }
   }
@@ -311,10 +332,9 @@ void LogDetail::listPlayers( action act , bz_PlayerJoinPartEventData_V1 *data )
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
