@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,26 +13,25 @@
 // ServerControl.cpp : Server shutdown and ban file control
 //
 
-#include <string>
+#include "bzfsAPI.h"
+#include "plugin_utils.h"
 #include <fstream>
 #include <sstream>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include "bzfsAPI.h"
-#include "plugin_utils.h"
 
 using namespace std;
 
-enum action { join , part };
+enum action { join, part };
 
 class ServerControl : public bz_Plugin
 {
 public:
-  virtual const char* Name (){return "Server Control";}
-  virtual void Init ( const char* config);
+  virtual const char* Name () {return "Server Control";}
+  virtual void Init ( const char* config );
 
   virtual void Event( bz_EventData *eventData );
-  int loadConfig(const char *cmdLine);
+  int loadConfig( const char *cmdLine );
 private:
   void countPlayers( action act, bz_PlayerJoinPartEventData_V1 *data );
   void checkShutdown( void );
@@ -76,9 +75,9 @@ int ServerControl::loadConfig(const char *cmdLine)
   if (config.errors) return -1;
 
   serverActive = false;
-  countPlayers( join , NULL );
+  countPlayers( join, NULL );
 
-  lastTime = 0.0f;
+  lastTime = 0.0;
 
   /*
    * Set up options from the configuration file
@@ -190,15 +189,13 @@ void ServerControl::checkShutdown( void ) {
 
 void ServerControl::Event( bz_EventData *eventData )
 {
-  ostringstream msg;
   bz_PlayerJoinPartEventData_V1 *data = (bz_PlayerJoinPartEventData_V1 *) eventData;
-  double now;
 
   if (eventData) {
     switch (eventData->eventType) {
-      case bz_eTickEvent:
-	now = bz_getCurrentTime();
-	if ((now - lastTime) < 3.0f) return;
+      case bz_eTickEvent: {
+	double now = bz_getCurrentTime();
+	if ((now - lastTime) < 3.0) return;
 	lastTime = now;
 	checkShutdown();
 	if (banFilename != "" )
@@ -206,16 +203,17 @@ void ServerControl::Event( bz_EventData *eventData )
 	if (masterBanFilename != "")
 	  checkMasterBanChanges();
 	break;
+      }
       case bz_ePlayerJoinEvent:
 	if (data->record->team >= eRogueTeam &&
 	    data->record->team <= eHunterTeam &&
 	    data->record->callsign != "")  {
 	  serverActive = true;
 	}
-	countPlayers( join , data );
+	countPlayers( join, data );
 	break;
       case bz_ePlayerPartEvent:
-	countPlayers( part , data );
+	countPlayers( part, data );
 	checkShutdown();
 	break;
       default :
@@ -224,19 +222,16 @@ void ServerControl::Event( bz_EventData *eventData )
   }
 }
 
-void ServerControl::countPlayers(action act , bz_PlayerJoinPartEventData_V1 *data)
+void ServerControl::countPlayers(action act, bz_PlayerJoinPartEventData_V1 *data)
 {
   bz_APIIntList *playerList = bz_newIntList();
-  bz_BasePlayerRecord *player;
-  ostringstream msg;
-  string str;
   int numLines = 0;
   int numObs = 0;
 
   bz_getPlayerIndexList( playerList );
 
   for ( unsigned int i = 0; i < playerList->size(); i++ ) {
-    player = bz_getPlayerByIndex( playerList->get(i));
+    bz_BasePlayerRecord *player = bz_getPlayerByIndex( playerList->get(i));
     if (player) {
       if (act == join || (data && (player->playerID != data->playerID) &&
 			  (player->callsign != ""))) {
@@ -281,7 +276,7 @@ void ServerControl::checkMasterBanChanges( void )
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
