@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,6 +20,7 @@
 #include <math.h>
 #include <string>
 #include <string.h>
+#include <sstream>
 
 // Global implementation headers
 #include "bzfgl.h"
@@ -33,7 +34,6 @@
 
 // Local implementation headers
 #include "ImageFont.h"
-#include "BitmapFont.h"
 #include "TextureFont.h"
 
 // initialize the singleton
@@ -119,9 +119,9 @@ void FontManager::clear(void)	// clear all the lists
     FontSizeMap::iterator itr = faceItr->begin();
     while (itr != faceItr->end()) {
       delete(itr->second);
-      itr++;
+      ++itr;
     }
-    faceItr++;
+    ++faceItr;
   }
   fontFaces.clear();
   return;
@@ -140,9 +140,6 @@ void FontManager::loadAll(std::string directory)
   if (directory.size() == 0)
     return;
 
-  const bool bitmapRenderer = BZDB.isTrue("useBitmapFontRenderer");
-  canScale = !bitmapRenderer;
-
   // save this in case we have to rebuild
   fontDirectory = directory;
 
@@ -154,11 +151,7 @@ void FontManager::loadAll(std::string directory)
     std::string ext = file.getExtension();
 
     if (TextUtils::compare_nocase(ext, "fmt") == 0) {
-      ImageFont *pFont;
-      if (bitmapRenderer)
-	pFont = new BitmapFont;
-      else
-	pFont = new TextureFont;
+      ImageFont *pFont = new TextureFont;
       if (pFont) {
 	if (pFont->load(file)) {
 	  std::string  str = TextUtils::toupper(pFont->getFaceName());
@@ -195,7 +188,6 @@ int FontManager::getFaceID(std::string faceName)
 
   FontFaceMap::iterator faceItr = faceNames.find(faceName);
 
-  int faceID = 0;
   if (faceItr == faceNames.end()) {
     // see if there is a default
     logDebugMessage(4,"Requested font %s not found, trying Default\n", faceName.c_str());
@@ -218,7 +210,7 @@ int FontManager::getFaceID(std::string faceName)
     }
   }
 
-  return faceID = faceItr->second;
+  return faceItr->second;
 }
 
 int FontManager::getNumFaces(void)
@@ -302,9 +294,6 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 				   opacity };
   underlineColor[3] = opacity;
 
-  // FIXME - this should not be necessary, but the bitmap font renderer needs it
-  //  OpenGLGState::resetState();
-
   /*
    * ANSI code interpretation is somewhat limited, we only accept values
    * which have been defined in AnsiCodes.h
@@ -339,9 +328,7 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
       glDepthMask(0);
       pFont->drawString(scale, color, &tmpText[startSend], len);
       if (underline) {
-	if (canScale) {
-	  glDisable(GL_TEXTURE_2D);
-	}
+	glDisable(GL_TEXTURE_2D);
 	glEnable(GL_BLEND);
 	if (bright && underlineColor[0] >= 0) {
 	  glColor4fv(underlineColor);
@@ -356,9 +343,7 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 	glVertex2f(0.0f, 0.0f);
 	glVertex2f(width, 0.0f);
 	glEnd();
-	if (canScale) {
-	  glEnable(GL_TEXTURE_2D);
-	}
+	glEnable(GL_TEXTURE_2D);
       }
       glDepthMask(depthMask);
       glPopMatrix();
@@ -391,7 +376,7 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
       }
       // didn't find a matching color
       if (!tookCareOfANSICode) {
-	// settings other than color
+	// settings other than a hardcoded color
 	if (tmpText == ANSI_STR_RESET) {
 	  bright = true;
 	  pulsating = false;
@@ -418,6 +403,23 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 	  underline = false;
 	} else if (tmpText == ANSI_STR_NO_PULSATE) {
 	  pulsating = false;
+	} else if (tmpText.substr(0, strlen(ANSI_STR_FG_RGB)) == ANSI_STR_FG_RGB) {
+	  // 24-bit foreground RGB (ISO-8613-3)
+	  // format: \033[38;2;<r>;<g>;<b>m
+	  std::istringstream rgb(tmpText.substr(strlen(ANSI_STR_FG_RGB) + 1, tmpText.size() - strlen(ANSI_STR_FG_RGB) - 2));
+	  for (int i = 0; i <= 2; i++) {
+	    short value = 0;
+	    rgb >> value;
+
+	    if (bright) {
+	      color[i] = value * darkness / 255.0f;
+	    } else {
+	      color[i] = value * darkDim / 255.0f;
+	    }
+
+	    // jump over the ; delimiter
+	    rgb.ignore();
+	  }
 	} else {
 	  logDebugMessage(2,"ANSI Code %s not supported\n", tmpText.c_str());
 	}
@@ -506,9 +508,9 @@ void FontManager::unloadAll(void)
     FontSizeMap::iterator itr = faceItr->begin();
     while (itr != faceItr->end()) {
       itr->second->free();
-      itr++;
+      ++itr;
     }
-    faceItr++;
+    ++faceItr;
   }
 }
 
@@ -523,10 +525,10 @@ ImageFont* FontManager::getClosestSize(int faceID, float size, bool bigger)
   FontSizeMap::const_iterator itr = sizes.lower_bound(rsize);
   if (bigger) {
     if (itr == sizes.end())
-      itr--;
+      --itr;
   } else {
     if (itr != sizes.begin() && itr->first != rsize)
-      itr--;
+      --itr;
   }
 
   return itr->second;
@@ -539,8 +541,8 @@ ImageFont*    FontManager::getClosestRealSize(int faceID, float desiredSize, flo
    * if the font is too tiny to scale, and a scaled size if it's big enough.
    */
 
-  ImageFont* font = getClosestSize(faceID, desiredSize, canScale ? true : false);
-  if (!canScale || desiredSize < 14.0f) {
+  ImageFont* font = getClosestSize(faceID, desiredSize, true);
+  if (desiredSize < 14.0f) {
     // get the next biggest font size from requested
     if (!font) {
       logDebugMessage(2,"Could not find applicable font size for sizing; font face ID %d, "
