@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,8 @@
 #else
 #  include <math.h>
 #endif
+#include <stdio.h>
+#include <string.h>
 #include <iostream>
 #include <sstream>
 
@@ -31,6 +33,7 @@
 #include "ServerList.h"
 #include "ErrorHandler.h"
 #include "cURLManager.h"
+#include "TimeKeeper.h"
 
 StartupInfo startupInfo;
 
@@ -41,7 +44,8 @@ BZAdminClient::BZAdminClient(BZAdminUI* bzInterface)
     switch (sLink.getState()) {
       case ServerLink::BadVersion: {
 	static char versionError[] = "Incompatible server version XXXXXXXX";
-	strncpy(versionError + strlen(versionError) - 8,
+	// Flawfinder: ignore
+	strncpy(versionError + sizeof(versionError) - 8 - 1,
 	    sLink.getVersion(), 8);
 	std::cout << versionError;
 	break;
@@ -135,15 +139,13 @@ PlayerId BZAdminClient::getMyId() {
 BZAdminClient::ServerCode BZAdminClient::checkMessage() {
   uint16_t code, len;
   char inbuf[MaxPacketLen];
-  std::string dstName, srcName;
-  int i = 0;
   PlayerIdMap::iterator iter;
 
   // read until we have a package, or until we have waited 100 ms
   if (sLink.read(code, len, inbuf, 100) == 1) {
     lastMessage.first = "";
     lastMessage.second = Default;
-    void* vbuf = inbuf;
+    const void* vbuf = inbuf;
     PlayerId p;
     PlayerIdMap::const_iterator it;
     std::string victimName, killerName;
@@ -188,8 +190,11 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       uint16_t numVars;
       uint8_t nameLen, valueLen;
 
+      // Flawfinder: ignore
       char name[MaxPacketLen];
+      // Flawfinder: ignore
       char value[MaxPacketLen];
+      int i;
 
       vbuf = nboUnpackUShort(vbuf, numVars);
       for (i = 0; i < numVars; i++) {
@@ -214,7 +219,9 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
 
     case MsgAddPlayer:
       uint16_t team, type, wins, losses, tks;
+      // Flawfinder: ignore
       char callsign[CallSignLen];
+      // Flawfinder: ignore
       char motto[MottoLen];
       vbuf = nboUnpackUByte(vbuf, p);
       vbuf = nboUnpackUShort(vbuf, type);
@@ -272,26 +279,26 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       uint8_t numIPs;
       uint8_t tmp;
       vbuf = nboUnpackUByte(vbuf, numIPs);
-      if(numIPs > 1){
+      if (numIPs > 1) {
 	for (i = 0; i < numIPs; ++i) {
 	  vbuf = nboUnpackUByte(vbuf, tmp);
 	  vbuf = nboUnpackUByte(vbuf, p);
 	  vbuf = a.unpack(vbuf);
 	  players[p].ip = a.getDotNotation();
-	  if ((ui != NULL) && messageMask[MsgAdminInfo]){
+	  if ((ui != NULL) && messageMask[MsgAdminInfo]) {
 	    ui->outputMessage("*** IPINFO: " + players[p].name + " from "  +
 	      players[p].ip, Default);
 	  }
 	}
       }
       //Alternative to the MsgAddPlayer message
-      else if(numIPs == 1){
+      else if (numIPs == 1) {
 	vbuf = nboUnpackUByte(vbuf, tmp);
 	vbuf = nboUnpackUByte(vbuf, p);
 	vbuf = a.unpack(vbuf);
 	players[p].ip = a.getDotNotation();
 	Team temp;
-	if (messageMask[MsgAdminInfo]){
+	if (messageMask[MsgAdminInfo]) {
 	  std::string joinMsg = std::string("*** \'") + players[p].name + "\' joined the game as " +
 	    temp.getName(players[p].team) + " from " + players[p].ip + ".";
 	  lastMessage.first = joinMsg;
@@ -405,7 +412,7 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
       TeamColor dstTeam = (LastRealPlayer < dst && dst <= FirstTeam ?
 			   TeamColor(FirstTeam - dst) : NoTeam);
       if (messageMask[MsgMessage]) {
-	lastMessage.first = formatMessage((char*)vbuf, MessageType(mtype),
+	lastMessage.first = formatMessage((const char*)vbuf, MessageType(mtype),
 					  src, dst, dstTeam, me);
 	PlayerIdMap::const_iterator iterator = players.find(src);
 	lastMessage.second = (iterator == players.end() ?
@@ -473,7 +480,7 @@ void BZAdminClient::outputServerList() const {
     std::vector<ServerItem> servers = serverList.getServers();
     for (std::vector<ServerItem>::const_iterator server = servers.begin();
 	 server != servers.end();
-	 server++) {
+	 ++server) {
       ui->outputMessage(std::string("  ") + server->description, Yellow);
     }
     ui->outputMessage(std::string("End Server List."), Yellow);
@@ -484,7 +491,6 @@ void BZAdminClient::outputServerList() const {
 
 void BZAdminClient::runLoop() {
   std::string cmd;
-  std::map<std::string, uint16_t>::iterator iter;
   ServerCode what(NoMessage);
   while (true) {
     what = checkMessage();
@@ -494,7 +500,7 @@ void BZAdminClient::runLoop() {
       if (cmd == "/quit")
 	break;
       else if (cmd.substr(0, 6) == "/show ") {
-	if ((iter = msgTypeMap.find(cmd.substr(6))) == msgTypeMap.end()) {
+	if (msgTypeMap.find(cmd.substr(6)) == msgTypeMap.end()) {
 	  ui->outputMessage(std::string("--- ERROR: ") + cmd.substr(6) +
 			    " is an unknown message type", Red);
 	}
@@ -505,7 +511,7 @@ void BZAdminClient::runLoop() {
 	}
       }
       else if (cmd.substr(0, 6) == "/hide ") {
-	if ((iter = msgTypeMap.find(cmd.substr(6))) == msgTypeMap.end()) {
+	if (msgTypeMap.find(cmd.substr(6)) == msgTypeMap.end()) {
 	  ui->outputMessage(std::string("--- ERROR: ") + cmd.substr(6) +
 			    " is an unknown message type", Red);
 	}
@@ -549,13 +555,16 @@ void BZAdminClient::sendMessage(const std::string& msg,
     return;
   }
 
+  // Flawfinder: ignore
   char buffer[MessageLen];
+  // Flawfinder: ignore
   char buffer2[1 + MessageLen];
   void* buf = buffer2;
 
   buf = nboPackUByte(buf, target);
-  memset(buffer, 0, MessageLen);
+  // Flawfinder: ignore
   strncpy(buffer, msg.c_str(), MessageLen - 1);
+  buffer[MessageLen - 1] = '\0';
   nboPackString(buffer2 + 1, buffer, MessageLen);
   sLink.send(MsgMessage, sizeof(buffer2), buffer2);
 }
@@ -579,13 +588,13 @@ std::string BZAdminClient::formatMessage(const std::string& msg,
     if (!(src == me && dst == me)) {
       if (src == me) {
 	if (type == ActionMessage) {
-	  formatted += "[->" + msg + "]";
+	  formatted += "[->" + dstName + "][" + srcName + " " + msg + "]";
 	} else {
 	  formatted += "[->" + dstName + "] " + msg;
 	}
       } else {
 	if (type == ActionMessage) {
-	  formatted += "[" + msg + "->]";
+	  formatted += "[" + srcName + " " + msg + "]";
 	} else {
 	  formatted += "[" + srcName + "->] " + msg;
 	}
@@ -629,7 +638,6 @@ void BZAdminClient::waitForServer() {
     sendMessage("bzadminping", me);
     std::string expected = formatMessage("bzadminping", ChatMessage, me, me, NoTeam, me);
     std::string noTalk = formatMessage("We're sorry, you are not allowed to talk!", ChatMessage, ServerPlayer, me, NoTeam, me);
-    std::string str;
     BZAdminUI* tmpUI = ui;
     ui = NULL;
     do {
@@ -662,9 +670,11 @@ void BZAdminClient::showMessageType(std::string type) {
 
 
 void BZAdminClient::listSetVars(const std::string& name, void* thisObject) {
+  //Flawfinder: ignore
   char message[MessageLen];
   if (BZDB.getPermission(name) == StateDatabase::Locked) {
-    sprintf(message, "/set %s %f", name.c_str(), BZDB.eval(name));
+    // Flawfinder: ignore
+    snprintf(message, sizeof(message), "/set %s %f", name.c_str(), BZDB.eval(name));
     ((BZAdminClient*)thisObject)->ui->outputMessage(message, Default);
   }
 }
@@ -685,7 +695,7 @@ bool BZAdminClient::getFilterStatus(uint16_t msgType) const {
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
