@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -9,12 +9,10 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
-#if defined(_MSC_VER)
-  #pragma warning(disable: 4786)
-#endif
 
 // interface header
 #include "ServerLink.h"
+// #include "MsgStrings.h"
 
 #if defined(DEBUG)
 #define NETWORK_STATS
@@ -69,7 +67,7 @@ TConnect conn;
 DWORD WINAPI ThreadConnect(LPVOID params)
 {
   TConnect *conn = (TConnect*)params;
-  if(connect(conn->query, conn->addr, conn->saddr) >= 0) {
+  if (connect(conn->query, conn->addr, conn->saddr) >= 0) {
     SetEvent(hConnected); // Connect successful
   }
   ExitThread(0);
@@ -89,7 +87,9 @@ ServerLink*		ServerLink::server = NULL;
 ServerLink::ServerLink(const Address& serverAddress, int port) :
 				state(SocketError),	// assume failure
 				fd(-1),			// assume failure
-				udpLength(0)
+				udpLength(0),
+				udpBufferPtr(),
+				ubuf()
 {
   int i;
 
@@ -127,17 +127,20 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
   // for UDP, used later
   memcpy((unsigned char *)&usendaddr,(unsigned char *)&addr, sizeof(addr));
 
-#if !defined(_WIN32)
-  const bool okay = true;
+  bool okay = true;
   int fdMax = query;
-  if (BzfNetwork::setNonBlocking(query) < 0) {
-    close(query);
-    return;
-  }
   struct timeval timeout;
   fd_set write_set;
   fd_set read_set;
   int nfound;
+
+#if !defined(_WIN32)
+  okay = true;
+  fdMax = query;
+  if (BzfNetwork::setNonBlocking(query) < 0) {
+    close(query);
+    return;
+  }
   if (connect(query, (CNCTType*)&addr, sizeof(addr)) < 0) {
     if (getErrno() != EINPROGRESS) {
       close(query);
@@ -175,9 +178,9 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
   hConnected = CreateEvent(NULL, FALSE, FALSE, "Connected Event");
 
   hThread = CreateThread(NULL, 0, ThreadConnect, &conn, 0, &ThreadID);
-  const bool okay = (WaitForSingleObject(hConnected, 5000) == WAIT_OBJECT_0);
-  if(!okay)
-    TerminateThread(hThread ,1);
+  okay = (WaitForSingleObject(hConnected, 5000) == WAIT_OBJECT_0);
+  if (!okay)
+    TerminateThread(hThread, 1);
 
   // Do some cleanup
   CloseHandle(hConnected);
@@ -185,30 +188,92 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
 
 #endif // !defined(_WIN32)
   if (!okay)
-    goto done;
-
-  // get server version and verify
-#if !defined(_WIN32)
-  FD_ZERO(&read_set);
-  FD_SET((unsigned int)query, &read_set);
-  timeout.tv_sec = long(5);
-  timeout.tv_usec = 0;
-  nfound = select(fdMax + 1, (fd_set*)&read_set, NULL, NULL, &timeout);
-  if (nfound <= 0) {
+  {
     close(query);
     return;
   }
-#endif // !defined(_WIN32)
-  i = recv(query, (char*)version, 8, 0);
-  if (i < 8)
-    goto done;
 
-  if (debugLevel >= 1) {
-    char cServerVersion[128];
-    sprintf(cServerVersion,"Server version: '%8s'",version);
-    printError(cServerVersion);
+  // send out the connect header
+  // this will let the server know we are BZFS protocol.
+  // after the server gets this it will send back a version for us to check
+  int sendRepply = ::send(query,BZ_CONNECT_HEADER,(int)strlen(BZ_CONNECT_HEADER),0);
+
+  logDebugMessage(2,"CONNECT:send in connect returned %d\n",sendRepply);
+
+  // wait to get data back. we are still blocking so these
+  // calls should be sync.
+
+  FD_ZERO(&read_set);
+  FD_ZERO(&write_set);
+  FD_SET((unsigned int)query, &read_set);
+  FD_SET((unsigned int)query, &write_set);
+
+  timeout.tv_sec = long(10);
+  timeout.tv_usec = 0;
+
+  // pick some limit to time out on ( in seconds )
+  double thisStartTime = TimeKeeper::getCurrent().getSeconds();
+  double connectTimeout = 30.0;
+  if (BZDB.isSet("connectionTimeout"))
+    connectTimeout = BZDB.eval("connectionTimeout")  ;
+
+  bool gotNetData = false;
+
+  // loop calling select untill we read some data back.
+  // its only 8 bytes so it better come back in one packet.
+  int loopCount = 0;
+  while (!gotNetData) {
+    loopCount++;
+    nfound = select(fdMax + 1, (fd_set*)&read_set, (fd_set*)&write_set, NULL, &timeout);
+
+    // there has to be at least one socket active, or we are screwed
+    if (nfound <= 0) {
+      logDebugMessage(1,"CONNECT:select in connect failed, nfound = %d\n",nfound);
+      close(query);
+      return;
+    }
+
+    // try and get data back from the server
+    i = recv(query, (char*)version, 8, 0);
+
+    // if we got some, then we are done
+    if (i > 0) {
+      logDebugMessage(2,"CONNECT:got net data in connect, bytes read = %d\n",i);
+      logDebugMessage(2,"CONNECT:Time To Connect = %f\n",(TimeKeeper::getCurrent().getSeconds() - thisStartTime));
+      gotNetData = true;
+    } else {
+      // if we have waited too long, then bail
+      if ((TimeKeeper::getCurrent().getSeconds() - thisStartTime) > connectTimeout) {
+	logDebugMessage(1,"CONNECT:connect time out failed\n");
+	logDebugMessage(2,"CONNECT:connect loop count = %d\n",loopCount);
+	close(query);
+	return;
+      }
+
+      TimeKeeper::sleep(0.25f);
+    }
   }
 
+  logDebugMessage(2,"CONNECT:connect loop count = %d\n",loopCount);
+
+  // if we got back less than the expected connect response (BZFSXXXX)
+  // then something went bad, and we are done.
+  if (i < 8) {
+    close(query);
+    return;
+  }
+
+  // since we are connected, we can go non blocking
+  // on BSD sockets systems
+  // all other messages after this are handled via the normal
+  // message system
+#if !defined(_WIN32)
+  if (BzfNetwork::setNonBlocking(query) < 0) {
+    close(query);
+    return;
+  }
+#endif
+
   // FIXME is it ok to try UDP always?
   server_abilities |= CanDoUDP;
   if (strcmp(version, getServerVersion()) != 0) {
@@ -226,7 +291,8 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
       rejectionMessage = message;
     }
 
-    goto done;
+    close(query);
+    return;
   }
 
   // read local player's id
@@ -246,7 +312,8 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
     return;
   if (id == 0xff) {
     state = Rejected;
-    goto done;
+    close(query);
+    return;
   }
 
 #if !defined(_WIN32)
@@ -278,8 +345,6 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
   }
   return;
 
-done:
-  close(query);
 }
 
 ServerLink::~ServerLink()
@@ -294,26 +359,29 @@ ServerLink::~ServerLink()
   urecvfd = -1;
   ulinkup = false;
 
-// FIXME -- packet recording
-if (packetStream) {
-  long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
-  fwrite(&endPacket, sizeof(endPacket), 1, packetStream);
-  fwrite(&dt, sizeof(dt), 1, packetStream);
-  fclose(packetStream);
-}
+  // FIXME -- packet recording
+  if (packetStream) {
+    long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
+    size_t items_written = fwrite(&endPacket, sizeof(endPacket), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(&dt, sizeof(dt), 1, packetStream);
+    if (items_written != 1)
+      printError("Error writing on packetStream");
+    fclose(packetStream);
+  }
 
 #if defined(NETWORK_STATS)
   const float dt = float(TimeKeeper::getCurrent() - startTime);
-  DEBUG1("Server network statistics:\n");
-  DEBUG1("  elapsed time    : %f\n", dt);
-  DEBUG1("  bytes sent      : %d (%f/sec)\n", bytesSent, (float)bytesSent / dt);
-  DEBUG1("  packets sent    : %d (%f/sec)\n", packetsSent, (float)packetsSent / dt);
+  logDebugMessage(1,"Server network statistics:\n");
+  logDebugMessage(1,"  elapsed time    : %f\n", dt);
+  logDebugMessage(1,"  bytes sent      : %d (%f/sec)\n", bytesSent, (float)bytesSent / dt);
+  logDebugMessage(1,"  packets sent    : %d (%f/sec)\n", packetsSent, (float)packetsSent / dt);
   if (packetsSent != 0)
-    DEBUG1("  bytes/packet    : %f\n", (float)bytesSent / (float)packetsSent);
-  DEBUG1("  bytes recieved  : %d (%f/sec)\n", bytesReceived, (float)bytesReceived / dt);
-  DEBUG1("  packets received: %d (%f/sec)\n", packetsReceived, (float)packetsReceived / dt);
+    logDebugMessage(1,"  bytes/packet    : %f\n", (float)bytesSent / (float)packetsSent);
+  logDebugMessage(1,"  bytes recieved  : %d (%f/sec)\n", bytesReceived, (float)bytesReceived / dt);
+  logDebugMessage(1,"  packets received: %d (%f/sec)\n", packetsReceived, (float)packetsReceived / dt);
   if (packetsReceived != 0)
-    DEBUG1("  bytes/packet    : %f\n", (float)bytesReceived / (float)packetsReceived);
+    logDebugMessage(1,"  bytes/packet    : %f\n", (float)bytesReceived / (float)packetsReceived);
 #endif
 }
 
@@ -332,6 +400,8 @@ void			ServerLink::send(uint16_t code, uint16_t len,
 {
   bool needForSpeed=false;
   if (state != Okay) return;
+//  if (code != MsgPlayerUpdateSmall && code != MsgPlayerUpdate)
+//    logDebugMessage(1,"send %s len %d\n",MsgStrings::strMsgCode(code),len);
   char msgbuf[MaxPacketLen];
   void* buf = msgbuf;
   buf = nboPackUShort(buf, len);
@@ -405,12 +475,11 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
   if (state != Okay) return -1;
 
   if ((urecvfd >= 0) /* && ulinkup */) {
-    int n;
 
     if (!udpLength) {
       AddrLen recvlen = sizeof(urecvaddr);
-      n = recvfrom(urecvfd, ubuf, MaxPacketLen, 0, &urecvaddr,
-		   (socklen_t*) &recvlen);
+      int n = recvfrom(urecvfd, ubuf, MaxPacketLen, 0,
+		       &urecvaddr, (socklen_t*) &recvlen);
       if (n > 0) {
 	udpLength    = n;
 	udpBufferPtr = ubuf;
@@ -423,8 +492,10 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
 	udpLength = 0;
 	return -1;
       }
-      udpBufferPtr = (char *)nboUnpackUShort(udpBufferPtr, len);
-      udpBufferPtr = (char *)nboUnpackUShort(udpBufferPtr, code);
+      udpBufferPtr = (const char *)nboUnpackUShort(udpBufferPtr, len);
+      udpBufferPtr = (const char *)nboUnpackUShort(udpBufferPtr, code);
+//      if (code != MsgPlayerUpdateSmall && code != MsgPlayerUpdate && code != MsgGameTime)
+//	logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
       UDEBUG("<** UDP Packet Code %x Len %x\n",code, len);
       if (len > udpLength) {
 	udpLength = 0;
@@ -487,12 +558,12 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
 #endif
 
   // unpack header and get message
-  void* buf = headerBuffer;
+  const void* buf = headerBuffer;
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
 
-  //printError("Code is %02x",code);
-  if (len > MaxPacketLen)
+//  logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
+  if (len > MaxPacketLen - 4)
     return -1;
   if (len > 0)
     rlen = recv(fd, (char*)msg, int(len), 0);
@@ -501,52 +572,58 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
 #if defined(NETWORK_STATS)
   if (rlen >= 0) bytesReceived += rlen;
 #endif
-  if (rlen == int(len)) goto success;	// got whole thing
-
-  // keep reading until we get the whole message
-  tlen = rlen;
-  while (rlen >= 1 && tlen < int(len)) {
-    FD_ZERO(&read_set);
-    FD_SET((unsigned int)fd, &read_set);
-    nfound = select(fd+1, (fd_set*)&read_set, 0, 0, NULL);
-    if (nfound == 0) continue;
-    if (nfound < 0) return -1;
-    rlen = recv(fd, (char*)msg + tlen, int(len) - tlen, 0);
-    if (rlen >= 0) tlen += rlen;
-#if defined(NETWORK_STATS)
-  if (rlen >= 0) bytesReceived += rlen;
-#endif
+  if (rlen != int(len))
+  {
+    // keep reading until we get the whole message
+    tlen = rlen;
+    while (rlen >= 1 && tlen < int(len))
+    {
+	FD_ZERO(&read_set);
+	FD_SET((unsigned int)fd, &read_set);
+	nfound = select(fd+1, (fd_set*)&read_set, 0, 0, NULL);
+	if (nfound == 0) continue;
+	if (nfound < 0) return -1;
+	rlen = recv(fd, (char*)msg + tlen, int(len) - tlen, 0);
+	if (rlen >= 0) tlen += rlen;
+    #if defined(NETWORK_STATS)
+      if (rlen >= 0) bytesReceived += rlen;
+    #endif
+    }
+    if (tlen < int(len)) return -1;
   }
-  if (tlen < int(len)) return -1;
 
-success:
-// FIXME -- packet recording
-if (packetStream) {
-  long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
-  fwrite(&serverPacket, sizeof(serverPacket), 1, packetStream);
-  fwrite(&dt, sizeof(dt), 1, packetStream);
-  fwrite(headerBuffer, 4, 1, packetStream);
-  fwrite(msg, len, 1, packetStream);
-}
+  // FIXME -- packet recording
+  if (packetStream) {
+    long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
+    size_t items_written = fwrite(&serverPacket, sizeof(serverPacket), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(&dt, sizeof(dt), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(headerBuffer, 4, 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(msg, len, 1, packetStream);
+    if (items_written != 1)
+      printError("Error writing on packetStream");
+  }
   return 1;
 }
 
 void			ServerLink::sendEnter(PlayerType type,
 						TeamColor team,
 						const char* name,
-						const char* email,
+						const char* motto,
 						const char* token)
 {
   if (state != Okay) return;
-  char msg[PlayerIdPLen + 4 + CallSignLen + EmailLen + TokenLen + VersionLen];
+  char msg[PlayerIdPLen + 4 + CallSignLen + MottoLen + TokenLen + VersionLen];
   ::memset(msg, 0, sizeof(msg));
   void* buf = msg;
   buf = nboPackUShort(buf, uint16_t(type));
   buf = nboPackUShort(buf, uint16_t(team));
   ::memcpy(buf, name, ::strlen(name));
   buf = (void*)((char*)buf + CallSignLen);
-  ::memcpy(buf, email, ::strlen(email));
-  buf = (void*)((char*)buf + EmailLen);
+  ::memcpy(buf, motto, ::strlen(motto));
+  buf = (void*)((char*)buf + MottoLen);
   ::memcpy(buf, token, ::strlen(token));
   buf = (void*)((char*)buf + TokenLen);
   ::memcpy(buf, getAppVersion(), ::strlen(getAppVersion()) + 1);
@@ -554,8 +631,8 @@ void			ServerLink::sendEnter(PlayerType type,
   send(MsgEnter, sizeof(msg), msg);
 }
 
-bool ServerLink::readEnter (std::string& reason,
-			    uint16_t& code, uint16_t& rejcode)
+bool ServerLink::readEnter(std::string& reason,
+			   uint16_t& code, uint16_t& rejcode)
 {
   // wait for response
   uint16_t len;
@@ -575,7 +652,7 @@ bool ServerLink::readEnter (std::string& reason,
       return false;
     }
     else if (code == MsgReject) {
-      void *buf;
+      const void *buf;
       char buffer[MessageLen];
       buf = nboUnpackUShort (msg, rejcode); // filler for now
       buf = nboUnpackString (buf, buffer, MessageLen);
@@ -591,219 +668,8 @@ bool ServerLink::readEnter (std::string& reason,
   return true;
 }
 
-void			ServerLink::sendCaptureFlag(TeamColor team)
-{
-  char msg[2];
-  nboPackUShort(msg, uint16_t(team));
-  send(MsgCaptureFlag, sizeof(msg), msg);
-}
-
-void			ServerLink::sendGrabFlag(int flagIndex)
-{
-  char msg[2];
-  nboPackUShort(msg, uint16_t(flagIndex));
-  send(MsgGrabFlag, sizeof(msg), msg);
-}
-
-void			ServerLink::sendDropFlag(const float* position)
-{
-  char msg[12];
-  void* buf = msg;
-  buf = nboPackVector(buf, position);
-  send(MsgDropFlag, sizeof(msg), msg);
-}
-
-void			ServerLink::sendKilled(const PlayerId& killer,
-					       int reason, int shotId,
-					       const FlagType* flagType,
-					       int phydrv)
-{
-  char msg[PlayerIdPLen + 2 + 2 + FlagPackSize + 4];
-  void* buf = msg;
-
-  buf = nboPackUByte(buf, killer);
-  buf = nboPackUShort(buf, int16_t(reason));
-  buf = nboPackShort(buf, int16_t(shotId));
-  buf = flagType->pack(buf);
-
-  if (reason == PhysicsDriverDeath) {
-    buf = nboPackInt(buf, phydrv);
-  }
-
-  send(MsgKilled, (char*)buf - (char*)msg, msg);
-}
-
-
-#ifndef BUILDING_BZADMIN
-void			ServerLink::sendPlayerUpdate(Player* player)
-{
-  char msg[PlayerUpdatePLenMax];
-  // Send the time frozen at each start of scene iteration, as all
-  // dead reckoning use that
-  const float timeStamp = float(TimeKeeper::getTick() - TimeKeeper::getNullTime());
-  void* buf = msg;
-  uint16_t code;
-  buf = nboPackFloat(buf, timeStamp);
-  buf = nboPackUByte(buf, player->getId());
-
-  // code will be MsgPlayerUpdate or MsgPlayerUpdateSmall
-  buf = player->pack(buf, code);
-
-  // variable length
-  const int len = (char*)buf - (char*)msg;
-
-  send(code, len, msg);
-}
-#endif
-
-void			ServerLink::sendBeginShot(const FiringInfo& info)
-{
-  char msg[FiringInfoPLen];
-  void* buf = msg;
-  buf = info.pack(buf);
-  send(MsgShotBegin, sizeof(msg), msg);
-}
-
-void			ServerLink::sendEndShot(const PlayerId& source,
-							int shotId, int reason)
-{
-  char msg[PlayerIdPLen + 4];
-  void* buf = msg;
-  buf = nboPackUByte(buf, source);
-  buf = nboPackShort(buf, int16_t(shotId));
-  buf = nboPackUShort(buf, uint16_t(reason));
-  send(MsgShotEnd, sizeof(msg), msg);
-}
-
-void			ServerLink::sendAlive()
-{
-  send(MsgAlive, 0, NULL);
-}
-
-void			ServerLink::sendTeleport(int from, int to)
-{
-  char msg[4];
-  void* buf = msg;
-  buf = nboPackUShort(buf, uint16_t(from));
-  buf = nboPackUShort(buf, uint16_t(to));
-  send(MsgTeleport, sizeof(msg), msg);
-}
-
-void			ServerLink::sendTransferFlag(const PlayerId& from, const PlayerId& to)
-{
-  char msg[PlayerIdPLen*2];
-  void* buf = msg;
-  buf = nboPackUByte(buf, from);
-  buf = nboPackUByte(buf, to);
-  send(MsgTransferFlag, sizeof(msg), msg);
-}
-
-void			ServerLink::sendNewRabbit()
-{
-  send(MsgNewRabbit, 0, NULL);
-}
-
-void			ServerLink::sendPaused(bool paused)
-{
-  uint8_t p = paused;
-  send(MsgPause, 1, &p);
-}
-
-void			ServerLink::sendAutoPilot(bool autopilot)
-{
-  uint8_t p = autopilot;
-  send(MsgAutoPilot, 1, &p);
-}
-
-void			ServerLink::sendUDPlinkRequest()
-{
-  if ((server_abilities & CanDoUDP) != CanDoUDP)
-    return; // server does not support udp (future list server test)
-
-  char msg[1];
-  unsigned short localPort;
-  void* buf = msg;
-
-  struct sockaddr_in serv_addr;
-
-  if ((urecvfd = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
-    return; // we cannot comply
-  }
-#if 1
-  AddrLen addr_len = sizeof(serv_addr);
-  if (getsockname(fd, (struct sockaddr*)&serv_addr, (socklen_t*) &addr_len) < 0) {
-    printError("Error: getsockname() failed, cannot get TCP port?");
-    return;
-  }
-  if (bind(urecvfd, (struct sockaddr *) &serv_addr, sizeof(serv_addr)) != 0) {
-    printError("Error: getsockname() failed, cannot get TCP port?");
-    return;  // we cannot get udp connection, bail out
-  }
-
-#else
-  // TODO if nobody complains kill this old port 17200 code
-  for (int port=17200; port < 65000; port++) {
-    ::memset((unsigned char *)&serv_addr, 0, sizeof(serv_addr));
-    serv_addr.sin_family = AF_INET;
-    serv_addr.sin_addr.s_addr = htonl(INADDR_ANY);
-    serv_addr.sin_port = htons(port);
-    if (bind(urecvfd, (struct sockaddr *) &serv_addr, sizeof(serv_addr)) == 0) {
-      break;
-    }
-  }
-#endif
-  localPort = ntohs(serv_addr.sin_port);
-  memcpy((char *)&urecvaddr,(char *)&serv_addr, sizeof(serv_addr));
-
-  if (debugLevel >= 1) {
-    std::vector<std::string> args;
-    char lps[10];
-    sprintf(lps, "%d", localPort);
-    args.push_back(lps);
-    printError("Network: Created local UDP downlink port {1}", &args);
-  }
-
-  buf = nboPackUByte(buf, id);
-
-  if (BzfNetwork::setNonBlocking(urecvfd) < 0) {
-    printError("Error: Unable to set NonBlocking for UDP receive socket");
-  }
-
-  send(MsgUDPLinkRequest, sizeof(msg), msg);
-}
-
-// heard back from server that we can send udp
-void			ServerLink::enableOutboundUDP()
-{
-  ulinkup = true;
-  if (debugLevel >= 1)
-    printError("Server got our UDP, using UDP to server");
-}
-// confirm that server can send us UDP
-void			ServerLink::confirmIncomingUDP()
-{
-  // This is really a hack. enableOutboundUDP will be setting this
-  // but frequently the udp handshake will finish first so might as
-  // well start with udp as soon as we can
-  ulinkup = true;
-
-  if (debugLevel >= 1)
-    printError("Got server's UDP packet back, server using UDP");
-  send(MsgUDPLinkEstablished, 0, NULL);
-}
-
-#ifdef HAVE_KRB5
-void ServerLink::sendKerberosTicket(const char      *principal,
-				    const krb5_data *ticket)
-{
-  DEBUG3("Sent authentication ticket to server : \n");
-  send(MsgKrbPrincipal, strlen(principal), principal);
-  send(MsgKrbTicket, ticket->length, ticket->data);
-}
-#endif
-
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
