@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786)
-#endif
-
 #include "common.h"
 
 /* system headers */
@@ -39,11 +35,6 @@
 
 int debugLevel = 0;
 
-#ifdef _WIN32
-void Player::setDeadReckoning()
-{
-}
-#endif
 /** @file
     This is the main file for bzadmin, the bzflag text client.
 */
@@ -144,18 +135,24 @@ int main(int argc, char** argv) {
     startupInfo.serverPort = ServerPort;
     int cPos = serverName.find(':');
     if (cPos != -1) {
-      startupInfo.serverPort = atoi(serverName.substr(cPos + 1).c_str());
+      long int serverPort = strtol(serverName.substr(cPos + 1).c_str(), (char **)NULL, 10);
+      if (serverPort > 0 && serverPort < 65536)
+	startupInfo.serverPort = (int) serverPort;
       serverName = serverName.substr(0, cPos);
     }
+    // Flawfinder: ignore
     strncpy(startupInfo.callsign, callsign.c_str(), sizeof(startupInfo.callsign) - 1);
+    // Flawfinder: ignore
     strncpy(startupInfo.password, password.c_str(), sizeof(startupInfo.password) - 1);
+    // Flawfinder: ignore
     strncpy(startupInfo.serverName, serverName.c_str(), sizeof(startupInfo.serverName) - 1);
   }
   std::cerr << "Connecting to " <<
     startupInfo.callsign << "@" <<
     startupInfo.serverName << ":" <<
     startupInfo.serverPort;
-  if (strlen(startupInfo.password)) {
+  // Check if password is not empty
+  if (startupInfo.password[0]) {
     std::cerr << " using central login";
   }
   std::cerr << std::endl;
@@ -207,7 +204,7 @@ int main(int argc, char** argv) {
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
