@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -85,6 +85,8 @@ ActionBinding::ActionBinding() {
   wayToBindActions.insert(std::make_pair(std::string("addhunt"), press));
   wayToBindActions.insert(std::make_pair(std::string("restart"), release));
   wayToBindActions.insert(std::make_pair(std::string("autopilot"), press));
+  wayToBindActions.insert(std::make_pair(std::string("cycleRadar"), press));
+  wayToBindActions.insert(std::make_pair(std::string("cyclePanel"), press));
 
   wayToBindActions.insert(std::make_pair(std::string("messagepanel all"), press));
   wayToBindActions.insert(std::make_pair(std::string("messagepanel chat"), press));
@@ -265,7 +267,7 @@ void ActionBinding::unbind(std::string action, std::string key) {
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
