@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -59,14 +59,14 @@ class ActionBinding : public Singleton<ActionBinding> {
   //~ActionBinding();
   void bind(std::string action, std::string key);
   void unbind(std::string action, std::string key);
-  static void onScanCB(const std::string& name, bool press,
-		       const std::string& cmd, void* userData);
+  static void onScanCB(const std::string& name, bool,
+		       const std::string& cmd, void*);
 };
 
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
