@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -34,8 +34,6 @@ AudioMenu::AudioMenu()
 {
   // add controls
   std::vector<HUDuiControl*>& listHUD = getControls();
-  std::string currentDriver = BZDB.get("audioDriver");
-  std::string currentDevice = BZDB.get("audioDevice");
 
   HUDuiLabel* label = new HUDuiLabel;
   label->setFontFace(MainMenu::getFontFace());
@@ -51,7 +49,7 @@ AudioMenu::AudioMenu()
   option = new HUDuiList;
   option->setFontFace(MainMenu::getFontFace());
   option->setLabel("Sound Volume:");
-  option->setCallback(callback, (void*)"s");
+  option->setCallback(callback, "s");
   options = &option->getList();
   if (isSoundOpen()) {
     options->push_back(std::string("Off"));
@@ -67,20 +65,18 @@ AudioMenu::AudioMenu()
    and can screw things up if you switch from non-SDL to SDL build.
    If more platforms get setDriver functions, they can be added. */
 
-  // Driver
 #ifdef HAVE_SDL
+  // Driver
+  std::string currentDriver = BZDB.get("audioDriver");
   driver = new HUDuiTypeIn;
   driver->setFontFace(MainMenu::getFontFace());
   driver->setLabel("Driver:");
   driver->setMaxLength(10);
   driver->setString(currentDriver);
   listHUD.push_back(driver);
-#else
-  driver = NULL;
-#endif // HAVE_SDL
 
   // Device
-#ifdef HAVE_SDL
+  std::string currentDevice = BZDB.get("audioDevice");
   device = new HUDuiTypeIn;
   device->setFontFace(MainMenu::getFontFace());
   device->setLabel("Device:");
@@ -88,6 +84,7 @@ AudioMenu::AudioMenu()
   device->setString(currentDevice);
   listHUD.push_back(device);
 #else
+  driver = NULL;
   device = NULL;
 #endif // HAVE_SDL
 
@@ -95,7 +92,7 @@ AudioMenu::AudioMenu()
   option = new HUDuiList;
   option->setFontFace(MainMenu::getFontFace());
   option->setLabel("Remote Sounds:");
-  option->setCallback(callback, (void*)"r");
+  option->setCallback(callback, "r");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -161,10 +158,8 @@ void			AudioMenu::resize(int _width, int _height)
   ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("remoteSounds") ? 1 : 0);
 }
 
-void			AudioMenu::callback(HUDuiControl* w, void* data) {
+void			AudioMenu::callback(HUDuiControl* w, const void* data) {
   HUDuiList* list = (HUDuiList*)w;
-  std::vector<std::string> *options = &list->getList();
-  std::string selectedOption = (*options)[list->getIndex()];
   switch (((const char*)data)[0]) {
     case 's':
       BZDB.set("volume", TextUtils::format("%d", list->getIndex()));
