@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,6 +25,9 @@
 #include "playing.h"
 #include "Plan.h"
 
+/* system implementation headers */
+#include <algorithm>
+
 typedef std::map<FlagType*, std::pair<int,int> > FlagSuccessMap;
 
 static FlagSuccessMap	flagSuccess;
@@ -723,3 +726,10 @@ void	doAutoPilot(float &rotation, float &speed)
 }
 
 
+// Local Variables: ***
+// mode: C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
