@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -81,8 +81,6 @@ BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
   OpenGLMaterial defaultMaterial(black, black, 0.0f);
   OpenGLMaterial rainMaterial(white, white, 0.0f);
 
-  int i;
-
   sunList = INVALID_GL_LIST_ID;
   moonList = INVALID_GL_LIST_ID;
   starList = INVALID_GL_LIST_ID;
@@ -131,7 +129,7 @@ BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
 
  /* useMoonTexture = BZDBCache::texture && (BZDB.eval("useQuality")>2);
   int moonTexture = -1;
-  if (useMoonTexture){
+  if (useMoonTexture) {
     moonTexture = tm.getTextureID( "moon" );
     useMoonTexture = moonTexture>= 0;
   }*/
@@ -179,24 +177,20 @@ BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
   // make mountain stuff
   mountainsAvailable = false;
   {
-    int mountainTexture = -1;
-    int width = 0;
+    int mountainTexture;
     int height = 0;
+    int i;
+
     numMountainTextures = 0;
-    bool done = false;
-    while (!done) {
+    while (1) {
       char text[256];
       sprintf (text, "mountain%d", numMountainTextures + 1);
       mountainTexture = tm.getTextureID (text, false);
-      if (mountainTexture >= 0) {
-	const ImageInfo & info = tm.getInfo (mountainTexture);
-	height = info.y;
-	width += info.x;
-	numMountainTextures++;
-      }
-      else {
-	done = true;
-      }
+      if (mountainTexture < 0)
+	break;
+      const ImageInfo & info = tm.getInfo (mountainTexture);
+      height = info.y;
+      numMountainTextures++;
     }
 
     if (numMountainTextures > 0) {
@@ -209,9 +203,6 @@ BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
       gstate.setMaterial (defaultMaterial);
       gstate.setAlphaFunc ();
 
-      if (numMountainTextures > 1) {
-	width -= 2 * numMountainTextures;
-      }
       // find power of two at least as large as height
       int scaledHeight = 1;
       while (scaledHeight < height) {
@@ -288,7 +279,7 @@ void BackgroundRenderer::setupGroundMaterials()
   }
   else {
     // map specified material
-    ((BzMaterial*)bzmat)->setReference();
+    bzmat->setReference();
     for (int i = 0; i < 4; i++) {
       memcpy (groundColor[i], bzmat->getDiffuse(), sizeof(GLfloat[4]));
     }
@@ -356,7 +347,7 @@ void BackgroundRenderer::setupGroundMaterials()
 }
 
 
-void			BackgroundRenderer::notifyStyleChange()
+void BackgroundRenderer::notifyStyleChange()
 {
   if (BZDBCache::texture) {
     if (BZDBCache::lighting)
@@ -387,7 +378,7 @@ void			BackgroundRenderer::notifyStyleChange()
 }
 
 
-void		BackgroundRenderer::resize() {
+void BackgroundRenderer::resize() {
   resizeSky();
   doFreeDisplayLists();
   doInitDisplayLists();
@@ -491,7 +482,7 @@ void BackgroundRenderer::makeCelestialLists(const SceneRenderer& renderer)
   sun2[2] = sunDirection[2] * cosf(moonAltitude) - sun2[0] * sinf(moonAltitude);
   const float limbAngle = atan2f(sun2[2], sun2[1]);
 
-  int moonSegements = (int)BZDB.eval("moonSegments");
+  const int moonSegements = BZDB.evalInt("moonSegments");
   moonList = glGenLists(1);
   glNewList(moonList, GL_COMPILE);
   {
@@ -779,7 +770,7 @@ void BackgroundRenderer::setupSkybox()
 
   // reference map specified materials
   for (i = 0; i < 6; i++) {
-    ((BzMaterial*)bzmats[i])->setReference();
+    bzmats[i]->setReference();
   }
 
   // setup the wrap mode
@@ -1120,8 +1111,8 @@ void BackgroundRenderer::drawGroundCentered()
 }
 
 
-void			BackgroundRenderer::drawGroundGrid(
-						SceneRenderer& renderer)
+void BackgroundRenderer::drawGroundGrid(
+					SceneRenderer& renderer)
 {
   const GLfloat* pos = renderer.getViewFrustum().getEye();
   const GLfloat xhalf = gridSpacing * (gridCount + floorf(pos[2] / 4.0f));
@@ -1153,8 +1144,8 @@ void			BackgroundRenderer::drawGroundGrid(
   glEnd();
 }
 
-void			BackgroundRenderer::drawGroundShadows(
-						SceneRenderer& renderer)
+void BackgroundRenderer::drawGroundShadows(
+					   SceneRenderer& renderer)
 {
   // draw sun shadows -- always stippled so overlapping shadows don't
   // accumulate darkness.  make and multiply by shadow projection matrix.
@@ -1644,16 +1635,11 @@ void BackgroundRenderer::doInitDisplayLists()
   //
 
   const GLfloat groundSize = 10.0f * worldSize;
-  const GLfloat gameSize = 0.5f * worldSize;
   GLfloat groundPlane[4][3];
-  GLfloat gameArea[4][3];
   for (i = 0; i < 4; i++) {
     groundPlane[i][0] = groundSize * squareShape[i][0];
     groundPlane[i][1] = groundSize * squareShape[i][1];
     groundPlane[i][2] = 0.0f;
-    gameArea[i][0] = gameSize * squareShape[i][0];
-    gameArea[i][1] = gameSize * squareShape[i][1];
-    gameArea[i][2] = 0.0f;
   }
 
   {
@@ -1914,10 +1900,9 @@ const GLfloat*	BackgroundRenderer::getSunDirection() const
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
