@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,7 +38,7 @@ class CacheMenu : public HUDDialog {
     void execute();
     void resize(int width, int height);
     void setFailedMessage(const char* msg);
-    static void callback(HUDuiControl* w, void* data);
+    static void callback(HUDuiControl* w, const void* data);
 
   private:
     float center;
