@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -152,12 +152,12 @@ static SetCommand	  setCommand;
 static DiffCommand	  diffCommand;
 static LocalSetCommand    localSetCommand;
 static QuitCommand	  quitCommand;
-static RoamPosCommand     RoamPosCommand;
+static RoamPosCommand     roamPosCommand;
 static ReTextureCommand   reTextureCommand;
 static SaveMsgsCommand	  saveMsgsCommand;
 static SaveWorldCommand   saveWorldCommand;
 static ForceRadarCommand  forceRadarCommand;
-static DebugLevelCommand  DebugLevelCommand;
+static DebugLevelCommand  debugLevelCommand;
 
 
 // class constructors
@@ -191,7 +191,7 @@ bool CommandList::operator() (const char * UNUSED(cmdLine))
   std::vector<const std::string*> cmds;
   MapOfCommands::iterator it;
   MapOfCommands& commandMap = *mapOfCommands;
-  for (it = commandMap.begin(); it != commandMap.end(); it++) {
+  for (it = commandMap.begin(); it != commandMap.end(); ++it) {
     const std::string& cmd = it->first;
     cmds.push_back(&cmd);
   }
@@ -302,33 +302,57 @@ bool BindCommand::operator() (const char *commandLine)
 
 bool SilenceCommand::operator() (const char *commandLine)
 {
-  Player *loudmouth = getPlayerByName(commandLine + 9);
-  if (loudmouth) {
-    silencePlayers.push_back(commandLine + 9);
-    std::string silenceMessage = "Silenced";
-    silenceMessage += (commandLine + 8);
-    addMessage(NULL, silenceMessage);
-  }
-  else {
-    std::string silenceMessage = "no such callsign:";
-    silenceMessage += (commandLine + 8);
-    addMessage(NULL, silenceMessage);
+  const char* name = commandLine + 9;
+  if (name != NULL && strlen(name) > 0) {
+
+    Player *loudmouth = getPlayerByName(name);
+    if (loudmouth) {
+      // we know this person exists
+      silencePlayers.push_back(name);
+      std::string silenceMessage = "Silenced ";
+      silenceMessage += (name);
+      addMessage(NULL, silenceMessage);
+    } else {
+      if (strcmp (name,"*") == 0) {
+	// check for * case
+	silencePlayers.push_back(name);
+	std::string silenceMessage = "Silenced All Msgs";
+	addMessage(NULL, silenceMessage);
+      } else if (strcmp(name, "-") == 0) {
+	// check for - case
+	silencePlayers.push_back(name);
+	std::string silenceMessage = "Silenced Unregistered Players";
+	addMessage(NULL, silenceMessage);
+      } else {
+	std::string silenceMessage = name;
+	silenceMessage += (" Does not exist");
+	addMessage(NULL, silenceMessage);
+      }
+    }
   }
+
   return true;
 }
 
 
 bool UnsilenceCommand::operator() (const char *commandLine)
 {
-  Player *loudmouth = getPlayerByName(commandLine + 11);
-  if (loudmouth) {
+  const char* name = commandLine + 11;
+  if (name != NULL && strlen(name) > 0) {
     std::vector<std::string>::iterator it = silencePlayers.begin();
-    for (; it != silencePlayers.end(); it++) {
-      if (*it == commandLine + 10) {
+    for (; it != silencePlayers.end(); ++it) {
+      if (*it == name) {
 	silencePlayers.erase(it);
-	std::string unsilenceMessage = "Unsilenced ";
-	unsilenceMessage += (commandLine + 10);
-	addMessage(NULL, unsilenceMessage);
+	std::string silenceMessage = "Unsilenced ";
+	silenceMessage += (name);
+	if (strcmp (name, "*") == 0) {
+	  // to make msg fancier
+	  silenceMessage = "Unblocked Msgs";
+	}
+	else if (strcmp(name, "-") == 0) {
+	  silenceMessage = "Unsilenced Unregistered Players";
+	}
+	addMessage(NULL, silenceMessage);
 	break;
       }
     }
@@ -355,7 +379,6 @@ bool ClientQueryCommand::operator() (const char *commandLine)
   if (strlen(commandLine) != 11)
     return false;
   char messageBuffer[MessageLen];
-  memset(messageBuffer, 0, MessageLen);
   strncpy(messageBuffer, "/clientquery", MessageLen);
   nboPackString(messageMessage + PlayerIdPLen, messageBuffer, MessageLen);
   serverLink->send(MsgMessage, sizeof(messageMessage), messageMessage);
@@ -591,7 +614,6 @@ bool LocalSetCommand::operator() (const char *commandLine)
 bool QuitCommand::operator() (const char *commandLine)
 {
   char messageBuffer[MessageLen]; // send message
-  memset(messageBuffer, 0, MessageLen);
   strncpy(messageBuffer, commandLine, MessageLen);
   nboPackString(messageMessage + PlayerIdPLen, messageBuffer, MessageLen);
   serverLink->send(MsgMessage, sizeof(messageMessage), messageMessage);
@@ -686,18 +708,30 @@ bool SaveMsgsCommand::operator() (const char *commandLine)
     return true;
   }
 
+  bool stripAnsi = false;
+  bool timestamp = false;
+
   std::vector<std::string> args;
   args = TextUtils::tokenize(commandLine, " ");
   const int argCount = (int)args.size();
 
-  bool stripAnsi = false;
-  if ((argCount > 1) && (args[1] == "-s")) {
-    stripAnsi = true;
+  for (int pos = 1; pos < argCount; pos++) {
+    if (args[pos] == "-s") {
+      stripAnsi = true;
+    }
+    else if (args[pos] == "-t") {
+      timestamp = true;
+    }
   }
 
-  std::string filename = getConfigDirName() + "msglog.txt";
+  int year, month, day, hour, minute, second;
+  TimeKeeper::localTime(&year, &month, &day, &hour, &minute, &second, NULL);
 
-  controlPanel->saveMessages(filename, stripAnsi);
+  std::string filename = getConfigDirName() + "msglog-";
+  filename += TextUtils::format("%04d-%02d-%02d_%02d-%02d-%02d", year, month, day, hour, minute, second);
+  filename += ".txt";
+
+  controlPanel->saveMessages(filename, stripAnsi, timestamp);
 
   std::string msg = "Saved messages to: " + filename;
   addMessage(NULL, msg);
@@ -721,7 +755,6 @@ bool SaveWorldCommand::operator() (const char *commandLine)
   bool ungrouped = false;
   bool wavefront = false;
 
-  std::string cmdLine = commandLine;
   std::vector<std::string> args;
   args = TextUtils::tokenize(commandLine, " ");
   const int argCount = (int)args.size();
@@ -820,7 +853,7 @@ bool DebugLevelCommand::operator() (const char* cmdLine)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
