@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,10 +30,14 @@
 #include "TextUtils.h"
 #include "ErrorHandler.h"
 #include "global.h"
+#ifdef _WIN32
+#  include <DirectoryNames.h>
+#endif
 
 /* local implementation headers */
 #include "SceneRenderer.h"
 #include "RadarRenderer.h"
+#include "TimeKeeper.h"
 #include "bzflag.h"
 
 //
@@ -41,20 +45,42 @@
 //
 
 ControlPanelMessage::ControlPanelMessage(const std::string& _string) :
-  string(_string), numlines(0)
+  numlines(0), string(_string), year(0), month(0), day(0), hour(0), min(0), sec(0)
 {
+  TimeKeeper::localTime(&year, &month, &day, &hour, &min, &sec);
+}
+
+std::string ControlPanelMessage::getString() const {
+  return formatTimestamp(BZDBCache::controlPanelTimestamp) + string;
+}
+
+std::string ControlPanelMessage::getString(bool withTimeDate) const {
+  return formatTimestamp(withTimeDate?2:0) + string;
+}
+
+std::string ControlPanelMessage::formatTimestamp(int mode) const {
+  // Just the date
+  if (mode == 1)
+    return TextUtils::format("[%02d:%02d:%02d] ", hour, min, sec);
+
+  if (mode == 2)
+    return TextUtils::format("[%04d-%02d-%02d %02d:%02d:%02d] ", year, month, day, hour, min, sec);
+
+  return "";
 }
 
 void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSize)
 {
   FontManager &fm = FontManager::instance();
 
+  std::string _string = getString();
+
   // get message and its length
-  const char* msg = string.c_str();
-  int lineLen     = (int)string.length();
+  const char* msg = _string.c_str();
+  int lineLen     = (int)_string.length();
 
   // if there are tabs in the message, find the last one
-  int lastTab = (int)string.rfind('\t');
+  int lastTab = (int)_string.rfind('\t');
 
   lines.clear();
   numlines=0;
@@ -62,6 +88,7 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
   // in order for the new font engine to draw successive lines in the right
   // color, it needs to be fed the right ansi codes at the beginning of each
   // line.
+  std::string previousANSICodes = "";
   std::string cumulativeANSICodes = "";
 
   // break lines
@@ -76,7 +103,7 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
     } else {
       n = 0;
       while ((n < lineLen) &&
-	     (fm.getStrLength(fontFace, fontSize, std::string(msg, n+1)) < maxLength)) {
+	     (fm.getStrLength(fontFace, fontSize, std::string(msg, n)) < maxLength)) {
 	if (msg[n] == ESC_CHAR) {
 	  // clear the cumulative codes when we hit a reset
 	  // the reset itself will start the new cumulative string.
@@ -117,7 +144,10 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
       n = lastWhitespace;
 
     // message
-    lines.push_back(cumulativeANSICodes + std::string(msg,n));
+    lines.push_back(previousANSICodes + std::string(msg,n));
+
+    // Store cumulative ANSI codes to be prepended to the next line
+    previousANSICodes = cumulativeANSICodes;
 
     if (msg[n] != '\t')
       numlines++;
@@ -170,7 +200,8 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
 				dimming(1.0f),
 				du(0),
 				dv(0),
-				messageMode(MessageAll)
+				messageMode(MessageAll),
+				paused(false)
 {
   setControlColor();
 
@@ -179,6 +210,7 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
   window.getWindow()->addExposeCallback(exposeCallback, this);
   BZDB.addCallback("displayRadar", bzdbCallback, this);
   BZDB.addCallback(StateDatabase::BZDB_RADARLIMIT, bzdbCallback, this);
+  BZDB.addCallback("controlPanelTimestamp", bzdbCallback, this);
 
   // other initialization
   radarAreaPixels[0] = 0;
@@ -210,7 +242,6 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
 
   // construct critical section for threadsafe messages
 #if defined(HAVE_PTHREADS)
-  pthread_mutex_init(&controlpanel_mutex, NULL);
 #elif defined(_WIN32)
   InitializeCriticalSection(&controlpanel_critical);
 #endif
@@ -225,10 +256,10 @@ ControlPanel::~ControlPanel()
   window.getWindow()->removeExposeCallback(exposeCallback, this);
   BZDB.removeCallback("displayRadar", bzdbCallback, this);
   BZDB.removeCallback(StateDatabase::BZDB_RADARLIMIT, bzdbCallback, this);
+  BZDB.removeCallback("controlPanelTimestamp", bzdbCallback, this);
 
   // destroy critical section for threadsafe messages
 #if defined(HAVE_PTHREADS)
-  pthread_mutex_destroy(&controlpanel_mutex);
 #elif defined(_WIN32)
   DeleteCriticalSection(&controlpanel_critical);
 #endif
@@ -284,7 +315,7 @@ void			ControlPanel::render(SceneRenderer& _renderer)
   const int x = window.getOriginX();
   const int y = window.getOriginY();
   const int w = window.getWidth();
-  const int tabStyle = (int)BZDB.eval("showtabs");
+  const int tabStyle = BZDB.evalInt("showtabs");
   const bool showTabs = (tabStyle > 0);
   tabsOnRight = (tabStyle == 2);
 
@@ -526,11 +557,8 @@ void			ControlPanel::render(SceneRenderer& _renderer)
   OpenGLGState::resetState();
 
   // draw the lines around the console panel
-  long xpos;
-  long ypos;
-
   float outlineOpacity = RENDERER.getPanelOpacity();
-  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this manybe?
+  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this maybe?
   if ( outlineOpacity < 1.0f )
 	outlineOpacity = (outlineOpacity*fudgeFactor) + (1.0f - fudgeFactor);
 
@@ -539,7 +567,11 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 
   // nice border
   glColor4f(teamColor[0], teamColor[1], teamColor[2],outlineOpacity );
-  glBegin(GL_LINE_LOOP); {
+  glBegin(GL_LINE_LOOP);
+  {
+    long xpos;
+    long ypos;
+
     // bottom left
     xpos = x + messageAreaPixels[0] - 1;
     ypos = y + messageAreaPixels[1] - 1;
@@ -560,7 +592,6 @@ void			ControlPanel::render(SceneRenderer& _renderer)
     }
 
     // across the top from right to left
-    long int drawnTabWidth = 0;
     for (int tab = (int)tabs->size() - 1; tab >= 0; tab--) {
 
       if (messageMode == MessageModes(tab)) {
@@ -576,7 +607,6 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 	xpos -= long(tabTextWidth[tab]);
 	glVertex2f((float) xpos, (float) ypos);
       }
-      drawnTabWidth += long(tabTextWidth[tab]);
     }
 
     // over from panel on right
@@ -587,7 +617,7 @@ void			ControlPanel::render(SceneRenderer& _renderer)
 
   } glEnd();
 
-  if (0){
+  if (0) {
     // some engines miss the corners
     glBegin(GL_POINTS); {
       glVertex2f((float) (x + messageAreaPixels[0] - 1),
@@ -630,29 +660,36 @@ glColor4f(teamColor[0], teamColor[1], teamColor[2],1.0f );
 
 void			ControlPanel::resize()
 {
-  float radarSpace, radarSize;
+  float radarSpace, radarSize, panelHeight;
   // get important metrics
   const float w = (float)window.getWidth();
   const float h = (float)window.getHeight();
   const float opacity = RENDERER.getPanelOpacity();
-  radarSize = float(window.getHeight() - window.getViewHeight());
   if (opacity == 1.0f) {
     radarSize = float(window.getHeight() - window.getViewHeight());
+    panelHeight = radarSize;
     radarSpace = 0.0f;
   } else {
     radarSize = h * (14 + RENDERER.getRadarSize()) / 60.0f;
+    panelHeight = h * (14 + RENDERER.getPanelHeight()) / 60.0f;
     radarSpace = 3.0f * w / MinY;
   }
 
   // compute areas in pixels x,y,w,h
   // leave off 1 pixel for the border
-  radarAreaPixels[0] = radarAreaPixels[1] = (int)radarSpace + 1;
+  radarAreaPixels[1] = (int)radarSpace + 1;
   radarAreaPixels[2] = radarAreaPixels[3] = (int)(radarSize - (radarSpace * 2.0f)) - 2;
+  if (BZDB.get("radarPosition") == "1") {	//radar on right
+    radarAreaPixels[0] = (int)(w - radarSize + radarSpace); // radar X coord
+    messageAreaPixels[0] = (int)radarSpace + 1;	// message box X coord
+  } else {					//radar on left
+    radarAreaPixels[0] = radarAreaPixels[1];	// radar X coord
+    messageAreaPixels[0] = (int)radarSize + 1;	// message box X coord
+  }
+  messageAreaPixels[1] = radarAreaPixels[1];			// Y coord
+  messageAreaPixels[2] = (int)(w - radarSize - radarSpace) - 2;	// Width
+  messageAreaPixels[3] = (int)(panelHeight - (radarSpace * 2.0f)) - 2; // Height
 
-  messageAreaPixels[0] = (int)radarSize + 1;		    // X coord
-  messageAreaPixels[1] = radarAreaPixels[1];		    // Y coord
-  messageAreaPixels[2] = (int)(w - radarSize - radarSpace) - 2; // Width
-  messageAreaPixels[3] = radarAreaPixels[3];		    // Height
   if (!BZDB.isTrue("displayRadar") || (BZDBCache::radarLimit <= 0.0f)) {
     messageAreaPixels[0] = (int)radarSpace + 1;
     messageAreaPixels[2] = (int)(w - (radarSpace * 2.0f)) - 2;
@@ -664,23 +701,23 @@ void			ControlPanel::resize()
 			    radarAreaPixels[2], radarAreaPixels[3]);
 
   switch (static_cast<int>(BZDB.eval("cpanelfontsize"))) {
-  case 0: { // auto
-    const bool useBigFont = (messageAreaPixels[2] / 100.0f) > 10.0f;
-    fontSize = useBigFont ? 12.0f : 8.0f;
-    break;
-    }
-  case 1: // tiny
-    fontSize = 6;
-    break;
-  case 2: // small
-    fontSize = 8;
-    break;
-  case 3: // medium
-    fontSize = 12;
-    break;
-  case 4: // big
-    fontSize = 16;
-    break;
+    case 0: { // auto
+      const bool useBigFont = (messageAreaPixels[2] / 100.0f) > 10.0f;
+      fontSize = useBigFont ? 12.0f : 8.0f;
+      break;
+      }
+    case 1: // tiny
+      fontSize = 6;
+      break;
+    case 2: // small
+      fontSize = 8;
+      break;
+    case 3: // medium
+      fontSize = 12;
+      break;
+    case 4: // big
+      fontSize = 16;
+      break;
   }
 
   FontManager &fm = FontManager::instance();
@@ -839,6 +876,12 @@ void			ControlPanel::addMessage(const std::string& line,
 
       // visible changes, force a console refresh
       if (messageMode == tab) {
+	// Don't scroll the messages unless we're at the bottom
+	if ((BZDB.isTrue("pauseConsole") && messagesOffset > 0 && messageMode >= 0) ||
+	    paused) {
+	  setMessagesOffset(1, 1 /* current */, false);
+	}
+
 	invalidate();
       }
 
@@ -850,11 +893,12 @@ void			ControlPanel::addMessage(const std::string& line,
     }
   }
 
-  if (echoToConsole){
+  if (echoToConsole) {
 #ifdef _WIN32
     // this is cheap but it will work on windows
-    FILE *fp = fopen ("stdout.txt","a+");
-    if (fp){
+    std::string filename = getConfigDirName() + "stdout.txt";
+    FILE *fp = fopen (filename.c_str(), "a+");
+    if (fp) {
       fprintf(fp,"%s\n", stripAnsiCodes(line).c_str());
       fclose(fp);
     }
@@ -871,7 +915,7 @@ void			ControlPanel::addMessage(const std::string& line,
 
 
 void ControlPanel::saveMessages(const std::string& filename,
-				bool stripAnsi) const
+				bool stripAnsi, bool timestamp) const
 {
   FILE* file = fopen(filename.c_str(), "a+");
   if (!file) {
@@ -883,10 +927,10 @@ void ControlPanel::saveMessages(const std::string& filename,
   fprintf(file, "Messages saved: %s", ctime(&nowTime));
   fprintf(file, "----------------------------------------\n\n");
 
-  // add to the appropriate tabs
+  // Iterate through the 'All' tab messages
   std::deque<ControlPanelMessage>::const_iterator msg = messages[MessageAll].begin()++;
   for (; msg != messages[MessageAll].end(); ++msg) {
-    const std::string& line = msg->string;
+    const std::string line = msg->getString(timestamp);
     if (stripAnsi) {
       fprintf(file, "%s\n", stripAnsiCodes(line).c_str());
     } else {
