@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,7 @@
 #include "FontManager.h"
 #include "BZDBCache.h"
 #include "TextureManager.h"
+#include "OpenGLUtils.h"
 
 /* local implementation headers */
 #include "MainMenu.h"
@@ -45,7 +46,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Dithering:");
-  option->setCallback(callback, (void*)"1");
+  option->setCallback(callback, "1");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -55,7 +56,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Blending:");
-  option->setCallback(callback, (void*)"2");
+  option->setCallback(callback, "2");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -65,7 +66,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Smoothing:");
-  option->setCallback(callback, (void*)"3");
+  option->setCallback(callback, "3");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -75,7 +76,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Lighting:");
-  option->setCallback(callback, (void*)"4");
+  option->setCallback(callback, "4");
   options = &option->getList();
   options->push_back(std::string("None"));
   options->push_back(std::string("Fast"));
@@ -86,7 +87,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Texturing:");
-  option->setCallback(callback, (void*)"5");
+  option->setCallback(callback, "5");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("Nearest"));
@@ -101,45 +102,37 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("AntiFlicker:");
-  option->setCallback(callback, (void*)"R");
+  option->setCallback(callback, "R");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
   option->update();
   listHUD.push_back(option);
 
-  option = new HUDuiList;
-  option->setFontFace(fontFace);
-  option->setLabel("Anisotropic:");
-  option->setCallback(callback, (void*)"A");
-  options = &option->getList();
-#ifdef HAVE_GLEW
-  if (GLEW_EXT_texture_filter_anisotropic) {
+  if (OpenGLGState::hasAnisotropicFiltering) {
     static GLint maxAnisotropy = 1;
     glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
     if (maxAnisotropy > 1) {
+      option = new HUDuiList;
+      option->setFontFace(fontFace);
+      option->setLabel("Anisotropic:");
+      option->setCallback(callback, "A");
+      options = &option->getList();
       options->push_back(std::string("Off"));
       for (int i = 1; i < maxAnisotropy; i++) {
 	char buffer[16];
 	snprintf(buffer, 16, "%i/%i", i + 1, maxAnisotropy);
 	options->push_back(std::string(buffer));
       }
-    } else {
-      options->push_back(std::string("Unavailable"));
+      option->update();
+      listHUD.push_back(option);
     }
-  } else {
-    options->push_back(std::string("Unavailable"));
   }
-#else
-  options->push_back(std::string("Unavailable"));
-#endif
-  option->update();
-  listHUD.push_back(option);
 
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Quality:");
-  option->setCallback(callback, (void*)"6");
+  option->setCallback(callback, "6");
   options = &option->getList();
   options->push_back(std::string("Low"));
   options->push_back(std::string("Medium"));
@@ -151,7 +144,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Shadows:");
-  option->setCallback(callback, (void*)"7");
+  option->setCallback(callback, "7");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("Stipple"));
@@ -159,13 +152,11 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
   option->update();
   listHUD.push_back(option);
 
-#if !defined(DEBUG_RENDERING)
-  if (debugLevel > 0) {
-#endif
+#if defined(DEBUG_RENDERING)
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Hidden Line:");
-    option->setCallback(callback, (void*)"a");
+    option->setCallback(callback, "a");
     options = &option->getList();
     options->push_back(std::string("Off"));
     options->push_back(std::string("On"));
@@ -175,7 +166,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Wireframe:");
-    option->setCallback(callback, (void*)"b");
+    option->setCallback(callback, "b");
     options = &option->getList();
     options->push_back(std::string("Off"));
     options->push_back(std::string("On"));
@@ -185,7 +176,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Depth Complexity:");
-    option->setCallback(callback, (void*)"c");
+    option->setCallback(callback, "c");
     options = &option->getList();
     options->push_back(std::string("Off"));
     options->push_back(std::string("On"));
@@ -195,7 +186,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Culling Tree:");
-    option->setCallback(callback, (void*)"d");
+    option->setCallback(callback, "d");
     options = &option->getList();
     options->push_back(std::string("Off"));
     options->push_back(std::string("On"));
@@ -205,39 +196,57 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Collision Tree:");
-    option->setCallback(callback, (void*)"e");
+    option->setCallback(callback, "e");
     options = &option->getList();
     options->push_back(std::string("Off"));
     options->push_back(std::string("On"));
     option->update();
     listHUD.push_back(option);
-#if !defined(DEBUG_RENDERING)
-  }
 #endif
 
-  BzfWindow* window = getMainWindow()->getWindow();
+  if (((BzfWindow*) getMainWindow()->getWindow())->hasGammaControl()) {
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Brightness:");
+    option->setCallback(callback, "g");
+    option->createSlider(15);
+    option->update();
+    listHUD.push_back(option);
+  }
+
   option = new HUDuiList;
   option->setFontFace(fontFace);
-  option->setLabel("Brightness:");
-  option->setCallback(callback, (void*)"g");
-  if (window->hasGammaControl()) {
-    option->createSlider(15);
-  } else {
-    options = &option->getList();
-    options->push_back(std::string("Unavailable"));
+
+#if (defined(HAVE_SDL) && !defined(HAVE_SDL2))	// only SDL 2 can make live changes
+    option->setLabel("(restart required) Energy Saver:");
+#else
+    option->setLabel("Energy Saver:");
+#endif
+  option->setCallback(callback, "s");
+  options = &option->getList();
+  options->push_back(std::string("Off"));
+  options->push_back(std::string("FPS Limit"));
+  if (getMainWindow()->getWindow()->hasVerticalSync()) {
+    options->push_back(std::string("Vertical Sync"));
   }
   option->update();
   listHUD.push_back(option);
 
-  option = new HUDuiList;
-  option->setFontFace(fontFace);
-  option->setLabel("Energy Saver:");
-  option->setCallback(callback, (void*)"s");
-  options = &option->getList();
-  options->push_back(std::string("Off"));
-  options->push_back(std::string("On"));
-  option->update();
-  listHUD.push_back(option);
+  if (OpenGLGState::getMaxSamples() > 1) {
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Anti Aliasing:");
+    option->setCallback(callback, "m");
+    options = &option->getList();
+    options->push_back(std::string("Off"));
+    for (int i = 2; i <= OpenGLGState::getMaxSamples(); ++i) {
+      char msaaText[11];
+      snprintf(msaaText, 11, "%i", i);
+      options->push_back(std::string(msaaText) + "x MSAA");
+    }
+    option->update();
+    listHUD.push_back(option);
+  }
 
   BzfDisplay* display = getDisplay();
   int numFormats = display->getNumResolutions();
@@ -319,9 +328,15 @@ void			DisplayMenu::resize(int _width, int _height)
     }
     ((HUDuiList*)listHUD[i++])->setIndex(tm.getMaxFilter());
     ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("remapTexCoords") ? 1 : 0);
-    int aniso = BZDB.evalInt("aniso");
-    aniso = (aniso < 1) ? 1 : aniso;
-    ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("aniso") - 1);
+    if (OpenGLGState::hasAnisotropicFiltering) {
+      static GLint maxAnisotropy = 1;
+      glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
+      if (maxAnisotropy > 1) {
+	int aniso = BZDB.evalInt("aniso");
+	aniso = (aniso < 1) ? 1 : aniso;
+	((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("aniso") - 1);
+      }
+    }
     ((HUDuiList*)listHUD[i++])->setIndex(renderer->useQuality());
     int shadowVal = 0;
     if (BZDBCache::shadows) {
@@ -331,9 +346,7 @@ void			DisplayMenu::resize(int _width, int _height)
       }
     }
     ((HUDuiList*)listHUD[i++])->setIndex(shadowVal);
-#if !defined(DEBUG_RENDERING)
-    if (debugLevel > 0) {
-#endif
+#if defined(DEBUG_RENDERING)
       ((HUDuiList*)listHUD[i++])->setIndex(renderer->useHiddenLine() ? 1 : 0);
       ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("wireframe") ? 1 : 0);
       ((HUDuiList*)listHUD[i++])->setIndex(renderer->useDepthComplexity() ? 1
@@ -341,19 +354,21 @@ void			DisplayMenu::resize(int _width, int _height)
       ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::showCullingGrid ? 1 : 0);
       ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::showCollisionGrid ? 1
 					   : 0);
-#if !defined(DEBUG_RENDERING)
-    }
 #endif
   }
 
   // brightness
   BzfWindow* window = getMainWindow()->getWindow();
   if (window->hasGammaControl())
-    ((HUDuiList*)listHUD[i])->setIndex(gammaToIndex(window->getGamma()));
-  i++;
+    ((HUDuiList*)listHUD[i++])->setIndex(gammaToIndex(window->getGamma()));
 
   // energy saver
-  ((HUDuiList*)listHUD[i])->setIndex((int)BZDB.eval("saveEnergy"));
+  ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("saveEnergy"));
+
+  if (OpenGLGState::getMaxSamples() > 1) {
+    // multisampling
+    ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("multisample") - 1);
+  }
 }
 
 int DisplayMenu::gammaToIndex(float gamma)
@@ -367,7 +382,7 @@ float DisplayMenu::indexToGamma(int index)
   return powf(2.0f, (float)index / 5.0f - 1.0f);
 }
 
-void			DisplayMenu::callback(HUDuiControl* w, void* data) {
+void			DisplayMenu::callback(HUDuiControl* w, const void* data) {
   HUDuiList* list = (HUDuiList*)w;
   SceneRenderer* sceneRenderer = getSceneRenderer();
   switch (((const char*)data)[0]) {
@@ -449,7 +464,11 @@ void			DisplayMenu::callback(HUDuiControl* w, void* data) {
     BZDB.setBool("showCollisionGrid", list->getIndex() != 0);
     break;
   case 's':
-    BZDB.setBool("saveEnergy", list->getIndex() != 0);
+    BZDB.setInt("saveEnergy", list->getIndex());
+    getMainWindow()->getWindow()->setVerticalSync(list->getIndex() == 2);
+    break;
+  case 'm':
+    BZDB.setInt("multisample", list->getIndex() + 1);
     break;
   case 'g':
     BzfWindow* window = getMainWindow()->getWindow();
