@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -35,7 +35,7 @@ public:
   }
   void execute();
   void resize(int width, int height);
-  static void callback(HUDuiControl* w, void* data);
+  static void callback(HUDuiControl* w, const void* data);
 private:
   FormatMenu*	formatMenu;
   HUDuiControl*	videoFormat;
@@ -43,8 +43,6 @@ private:
   static float	indexToGamma(int);
 };
 
-extern void setSceneDatabase();
-
 #endif /* __DISPLAYMENU_H__ */
 
 // Local Variables: ***
