@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -44,7 +44,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   HUDuiList* option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Radar Style:");
-  option->setCallback(callback, (void*)"e");
+  option->setCallback(callback, "e");
   std::vector<std::string>* options = &option->getList();
   options->push_back(std::string("Normal"));
   options->push_back(std::string("Fast"));
@@ -56,7 +56,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Scoreboard Sort:");
-  option->setCallback(callback, (void*)"p");
+  option->setCallback(callback, "p");
   options = &option->getList();
   const char **sortLabels = ScoreboardRenderer::getSortLabels();
   while ( *sortLabels != NULL)
@@ -67,7 +67,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Always Show Team Scores:");
-  option->setCallback(callback, (void*)"q");
+  option->setCallback(callback, "q");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -77,7 +77,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Scoreboard Font Size:");
-  option->setCallback(callback, (void*)"S");
+  option->setCallback(callback, "S");
   options = &option->getList();
   options->push_back(std::string("Auto"));
   option->createSlider(4);
@@ -87,7 +87,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("ControlPanel Font Size:");
-  option->setCallback(callback, (void*)"C");
+  option->setCallback(callback, "C");
   options = &option->getList();
   options->push_back(std::string("Auto"));
   option->createSlider(4);
@@ -98,7 +98,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Extended Observer Info:");
-  option->setCallback(callback, (void*)"O");
+  option->setCallback(callback, "O");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -107,11 +107,20 @@ GUIOptionsMenu::GUIOptionsMenu()
   option->update();
   listHUD.push_back(option);
 
+  // set Panel Translucency
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("Panel Opacity:");
+  option->setCallback(callback, "y");
+  option->createSlider(11);
+  option->update();
+  listHUD.push_back(option);
+
   // set Radar Translucency
   option = new HUDuiList;
   option->setFontFace(fontFace);
-  option->setLabel("Radar & Panel Opacity:");
-  option->setCallback(callback, (void*)"y");
+  option->setLabel("Radar Opacity:");
+  option->setCallback(callback, "Y");
   option->createSlider(11);
   option->update();
   listHUD.push_back(option);
@@ -120,7 +129,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Colored shots on radar:");
-  option->setCallback(callback, (void*)"z");
+  option->setCallback(callback, "z");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -131,7 +140,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Radar Shot Length:");
-  option->setCallback(callback, (void*)"l");
+  option->setCallback(callback, "l");
   option->createSlider(11);
   option->update();
   listHUD.push_back(option);
@@ -140,7 +149,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Radar Shot Size:");
-  option->setCallback(callback, (void*)"s");
+  option->setCallback(callback, "s");
   option->createSlider(11);
   option->update();
   listHUD.push_back(option);
@@ -149,18 +158,39 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Radar Shot Line:");
-  option->setCallback(callback, (void*)"F");
+  option->setCallback(callback, "F");
   options = &option->getList();
   options->push_back(std::string("Lagging"));
   options->push_back(std::string("Leading"));
+  options->push_back(std::string("Leading & Lagging"));
+  option->update();
+  listHUD.push_back(option);
+
+  // set radar position
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("Radar Position:");
+  option->setCallback(callback, "P");
+  options = &option->getList();
+  options->push_back(std::string("Left"));
+  options->push_back(std::string("Right"));
   option->update();
   listHUD.push_back(option);
 
   // set radar size
   option = new HUDuiList;
   option->setFontFace(fontFace);
-  option->setLabel("Radar & Panel Size:");
-  option->setCallback(callback, (void*)"R");
+  option->setLabel("Radar Size:");
+  option->setCallback(callback, "R");
+  option->createSlider(maxRadarSize+1);
+  option->update();
+  listHUD.push_back(option);
+
+  // set panel size
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("Panel Height:");
+  option->setCallback(callback, "a");
   option->createSlider(maxRadarSize+1);
   option->update();
   listHUD.push_back(option);
@@ -169,7 +199,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Mouse Box Size:");
-  option->setCallback(callback, (void*)"M");
+  option->setCallback(callback, "M");
   option->createSlider(22);
   option->update();
   listHUD.push_back(option);
@@ -178,7 +208,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Locale:");
-  option->setCallback(callback, (void*)"L");
+  option->setCallback(callback, "L");
   options = &option->getList();
   std::vector<std::string> locales;
   if (BundleMgr::getLocaleList(&locales) == true) {
@@ -207,18 +237,28 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Control panel tabs:");
-  option->setCallback(callback, (void*)"t");
+  option->setCallback(callback, "t");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("Left"));
   options->push_back(std::string("Right"));
   option->update();
   listHUD.push_back(option);
+  // Automatic pausing of the console
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("Automatically pause the control panel:");
+  option->setCallback(callback, "o");
+  options = &option->getList();
+  options->push_back(std::string("Off"));
+  options->push_back(std::string("On"));
+  option->update();
+  listHUD.push_back(option);
   // GUI coloring
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Control panel coloring:");
-  option->setCallback(callback, (void*)"c");
+  option->setCallback(callback, "c");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -228,7 +268,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Underline color:");
-  option->setCallback(callback, (void*)"u");
+  option->setCallback(callback, "u");
   options = &option->getList();
   options->push_back(std::string("Cyan"));
   options->push_back(std::string("Grey"));
@@ -239,7 +279,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Killer Highlight:");
-  option->setCallback(callback, (void*)"k");
+  option->setCallback(callback, "k");
   options = &option->getList();
   options->push_back(std::string("None"));
   options->push_back(std::string("Pulsating"));
@@ -250,7 +290,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Pulsation Rate:");
-  option->setCallback(callback, (void*)"r");
+  option->setCallback(callback, "r");
   option->createSlider(9);
   option->update();
   listHUD.push_back(option);
@@ -258,7 +298,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Pulsation Depth:");
-  option->setCallback(callback, (void*)"d");
+  option->setCallback(callback, "d");
   option->createSlider(9);
   option->update();
   listHUD.push_back(option);
@@ -266,18 +306,31 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Time / Date Display:");
-  option->setCallback(callback, (void*)"h");
+  option->setCallback(callback, "h");
   options = &option->getList();
-  options->push_back(std::string("time"));
-  options->push_back(std::string("date"));
-  options->push_back(std::string("both"));
+  options->push_back(std::string("Time"));
+  options->push_back(std::string("Date"));
+  options->push_back(std::string("Date and Time"));
   option->update();
   listHUD.push_back(option);
+
+  // Time/date display settings
+  option = new HUDuiList;
+  option->setFontFace(fontFace);
+  option->setLabel("Timestamps in console:");
+  option->setCallback(callback, "Z");
+  options = &option->getList();
+  options->push_back(std::string("Off"));
+  options->push_back(std::string("Time"));
+  options->push_back(std::string("Date and Time"));
+  option->update();
+  listHUD.push_back(option);
+
   // HUD Reload timer
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Reload timer on HUD:");
-  option->setCallback(callback, (void*)"T");
+  option->setCallback(callback, "T");
   options = &option->getList();
   options->push_back(std::string("Off"));
   options->push_back(std::string("On"));
@@ -288,7 +341,7 @@ GUIOptionsMenu::GUIOptionsMenu()
   option = new HUDuiList;
   option->setFontFace(fontFace);
   option->setLabel("Motto Display Length:");
-  option->setCallback(callback, (void*)"E");
+  option->setCallback(callback, "E");
   option->createSlider(32+1);
   option->update();
   listHUD.push_back(option);
@@ -349,18 +402,23 @@ void			GUIOptionsMenu::resize(int _width, int _height)
 		("showVelocities")));
    ((HUDuiList*)listHUD[i++])->setIndex((int)(10.0f * renderer
 					       ->getPanelOpacity() + 0.5));
+   ((HUDuiList*)listHUD[i++])->setIndex((int)(10.0f * renderer
+						  ->getRadarOpacity() + 0.5));
     ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("coloredradarshots") ? 1
 					 : 0);
     ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>
 					 (BZDB.eval("linedradarshots")));
     ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>
 					 (BZDB.eval("sizedradarshots")));
-    ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::leadingShotLine ? 1 : 0);
+    ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>(BZDB.eval("leadingShotLine")));
+    ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>(BZDB.eval("radarPosition")));
     ((HUDuiList*)listHUD[i++])->setIndex(renderer->getRadarSize());
+    ((HUDuiList*)listHUD[i++])->setIndex(renderer->getPanelHeight());
     ((HUDuiList*)listHUD[i++])->setIndex(renderer->getMaxMotionFactor() + 11);
     i++; // locale
     ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>(BZDB.eval
 							  ("showtabs")));
+	((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("pauseConsole") ? 1 : 0);
     ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("colorful") ? 1 : 0);
 
     // underline color - find index of mode string in options
@@ -377,16 +435,17 @@ void			GUIOptionsMenu::resize(int _width, int _height)
 					 (BZDB.eval("pulseDepth") * 10) - 1);
     ((HUDuiList*)listHUD[i++])->setIndex(static_cast<int>(BZDB.eval
 							  ("timedate")));
+    ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("controlPanelTimestamp"));
     ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("displayReloadTimer") ? 1
 					 : 0);
     if (BZDB.isTrue("hideMottos"))
       ((HUDuiList*)listHUD[i++])->setIndex(0);
     else
-      ((HUDuiList*)listHUD[i++])->setIndex((int)BZDB.eval("mottoDispLen") / 4);
+      ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("mottoDispLen") / 4);
   }
 }
 
-void			GUIOptionsMenu::callback(HUDuiControl* w, void* data)
+void			GUIOptionsMenu::callback(HUDuiControl* w, const void* data)
 {
   HUDuiList* list = (HUDuiList*)w;
 
@@ -409,6 +468,12 @@ void			GUIOptionsMenu::callback(HUDuiControl* w, void* data)
 	break;
       }
 
+    case 'Z':
+      {
+	BZDB.setInt("controlPanelTimestamp", list->getIndex());
+	break;
+      }
+
     case 'S':
       {
 	BZDB.setInt("scorefontsize", list->getIndex());
@@ -425,7 +490,19 @@ void			GUIOptionsMenu::callback(HUDuiControl* w, void* data)
 
     case 'y':
       {
-	sceneRenderer->setPanelOpacity(((float)list->getIndex()) / 10.0f);
+	const float newOpacity = (float)list->getIndex() / 10.0f;
+	if (newOpacity == 1.0f || sceneRenderer->getRadarOpacity() == 1.0f)
+	  sceneRenderer->setRadarOpacity(newOpacity);
+	sceneRenderer->setPanelOpacity(newOpacity);
+	break;
+      }
+
+    case 'Y':
+      {
+	const float newOpacity = (float)list->getIndex() / 10.0f;
+	sceneRenderer->setRadarOpacity(newOpacity);
+	if (newOpacity == 1.0f || sceneRenderer->getPanelOpacity() == 1.0f)
+	  sceneRenderer->setPanelOpacity(newOpacity);
 	break;
       }
 
@@ -442,7 +519,12 @@ void			GUIOptionsMenu::callback(HUDuiControl* w, void* data)
       break;
 
     case 'F':
-      BZDB.set("leadingShotLine", list->getIndex() ? "1" : "0");
+      BZDB.setInt("leadingShotLine", list->getIndex());
+      break;
+
+    case 'P':
+      BZDB.setInt("radarPosition", list->getIndex());
+      controlPanel->resize();
       break;
 
     case 'R':
@@ -451,12 +533,24 @@ void			GUIOptionsMenu::callback(HUDuiControl* w, void* data)
 	break;
       }
 
+    case 'a':
+      {
+	sceneRenderer->setPanelHeight(list->getIndex());
+	break;
+      }
+
     case 'M':
       {
 	sceneRenderer->setMaxMotionFactor(list->getIndex() - 11);
 	break;
       }
 
+    case 'o':
+      {
+	BZDB.set("pauseConsole", list->getIndex() ? "1" : "0");
+	break;
+      }
+
     case 'c':
       {
 	BZDB.set("colorful", list->getIndex() ? "1" : "0");
