@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,10 +16,6 @@
 /* common */
 #include "common.h"
 
-#if defined(_MSC_VER)
-	#pragma warning(disable: 4786)
-#endif
-
 /* system headers */
 #include <vector>
 
@@ -39,9 +35,9 @@ class HUDDialog {
     void			render();
 
     virtual HUDuiDefaultKey*	getDefaultKey() = 0;
-    virtual void		show() { }
+    virtual void		show() {}
     virtual void		execute() = 0;
-    virtual void		dismiss() { }
+    virtual void		dismiss() {}
     virtual void		resize(int _width, int _height);
     virtual void		setFailedMessage(const char *) {;};
 
@@ -71,10 +67,9 @@ class HUDDialog {
 #endif /* __HUDDIALOG_H__ */
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
