@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -75,7 +75,6 @@ HUDRenderer::HUDRenderer(const BzfDisplay* _display,
     dater = false;
   else if (BZDB.eval("timedate") == 1) //just the date
     dater = true;
-  int i;
 
   // initialize colors
   hudColor[0] = 1.0f;
@@ -93,10 +92,9 @@ HUDRenderer::HUDRenderer(const BzfDisplay* _display,
 
   // initialize heading and altitude labels
   if (headingLabel[0].length() == 0) {
-    char buf[10];
+    int i;
     for (i = 0; i < 36; i++) {
-      sprintf(buf, "%d", i * 10);
-      headingLabel[i] = std::string(buf);
+      headingLabel[i] = TextUtils::format("%d", i * 10);
     }
   }
 
@@ -113,8 +111,6 @@ HUDRenderer::HUDRenderer(const BzfDisplay* _display,
   // create scoreboard renderer
   scoreboard = new ScoreboardRenderer();
 
-  friendlyMarkerList = DisplayListSystem::Instance().newList(this);
-
   // initialize fonts
   resize(true);
 }
@@ -174,6 +170,24 @@ void			HUDRenderer::resize(bool firstTime)
   const float sby = window.getViewHeight() - majorFontHeight - alertFontHeight * 2.0f;
   scoreboard->setWindowSize (0.01f * window.getWidth(), sby,
 	0.98f * window.getWidth(), sby);
+
+  // resize the input prompt
+  if (showCompose) {
+    int cFontFace = composeTypeIn->getFontFace();
+    float cFontSize = composeTypeIn->getFontSize();
+    if (cFontFace >= 0) {
+      FontManager &fm = FontManager::instance();
+      const float x = fm.getStrLength(cFontFace, cFontSize, composeTypeIn->getLabel()) +
+		    fm.getStrLength(cFontFace, cFontSize, "99");
+      const float y = 1.0f;
+      composeTypeIn->setLabelWidth(x);
+      composeTypeIn->setPosition(x, y);
+    }
+  }
+
+  // resize cracks
+  if (showCracks)
+    initCracks();
 }
 
 int			HUDRenderer::getNoMotionSize() const
@@ -217,7 +231,7 @@ void			HUDRenderer::setMajorFontSize(int, int height)
 {
   const float s = (float)height / 36.0f;
   FontManager &fm = FontManager::instance();
-  majorFontFace = fm.getFaceID(BZDB.get("serifFont"));
+  majorFontFace = fm.getFaceID(BZDB.get("sansSerifFont"));
   majorFontSize = floorf(s);
   majorFontHeight = fm.getStrHeight(majorFontFace, majorFontSize, " ");
 }
@@ -338,7 +352,15 @@ void			HUDRenderer::setFPS(float _fps)
 
 void			HUDRenderer::setDrawTime(float drawTimeInseconds)
 {
+  if (drawTime < 0.) {
+     minDrawTime = drawTimeInseconds;
+     maxDrawTime = drawTimeInseconds;
+  }
   drawTime = drawTimeInseconds;
+  if (drawTime < minDrawTime)
+     minDrawTime = drawTime;
+  else if (drawTime > maxDrawTime)
+     maxDrawTime = drawTime;
 }
 
 void			HUDRenderer::setFrameTriangleCount(int tpf)
@@ -513,9 +535,7 @@ void HUDRenderer::AddLockOnMarker(const fvec3& pos, std::string name,
 
 void			HUDRenderer::setRestartKeyLabel(const std::string& label)
 {
-  char buffer[250];
-  sprintf(buffer, BundleMgr::getCurrentBundle()->getLocalString(restartLabelFormat).c_str(), label.c_str());
-  restartLabel = buffer;
+  restartLabel = TextUtils::format(BundleMgr::getCurrentBundle()->getLocalString(restartLabelFormat).c_str(), label.c_str());
   FontManager &fm = FontManager::instance();
   restartLabelWidth = fm.getStrLength(bigFontFace, bigFontSize, restartLabel);
 }
@@ -634,7 +654,7 @@ void			HUDRenderer::hudColor3fv(const GLfloat* c)
 
 void HUDRenderer::hudColor3Afv(const float * c, const float a)
 {
-  if( dim )
+  if ( dim )
     glColor4f( dimFactor *c[0], dimFactor *c[1], dimFactor *c[2], a );
   else
     glColor4f( c[0],c[1],c[2],a );
@@ -657,61 +677,54 @@ void			HUDRenderer::hudColor4fv(const GLfloat* c)
 }
 
 
-void HUDRenderer::buildGeometry ( GLDisplayList displayList )
+void			HUDRenderer::drawGeometry()
 {
-  if (displayList == friendlyMarkerList) {
-    float lockonSize = 40;
+  float lockonSize = 40;
 
-    float segmentation = 32.0f/360.0f;
-    float rad = lockonSize * 0.125f;
+  float segmentation = 360.0f/32.0f;
+  float rad = lockonSize * 0.25f;
 
-    // white outline
-    hudColor4f( 1,1,1, 0.85f );
-    glLineWidth(4.0f);
-    glBegin(GL_LINES);
-    glVertex3f(-rad,rad+rad,0.03f);
-    glVertex3f(rad,-rad+rad,0.02f);
-    // glVertex3f(-lockonSize*xFactor,lockonSize,0.02f);
-    // glVertex3f(lockonSize*xFactor,0,0.02f);
-    glEnd();
+  // white outline
+  hudColor4f( 1,1,1, 0.85f );
+  glLineWidth(4.0f);
+  glBegin(GL_LINES);
+  glVertex3f(-rad,rad,0.03f);
+  glVertex3f(rad,-rad,0.02f);
+  // glVertex3f(-lockonSize*xFactor,lockonSize,0.02f);
+  // glVertex3f(lockonSize*xFactor,0,0.02f);
+  glEnd();
 
-    glBegin(GL_LINE_LOOP);
-    for (float t = 0; t < 360; t += segmentation) {
-      if (t != 0) {
-	const float s = (t - segmentation);
-	const float tRads = t * DEG2RADf;
-	const float sRads = s * DEG2RADf;
-	glVertex3f(sinf(sRads) * rad, (cosf(sRads) * rad) + rad, 0.02f);
-	glVertex3f(sinf(tRads) * rad, (cosf(tRads) * rad) + rad, 0.02f);
-      }
-    }
-    glEnd();
-
-    // red X
-    hudColor4f( 1,0,0, 0.85f );
-    glLineWidth(2.0f);
-    glBegin(GL_LINES);
-    glVertex3f(-rad,rad+rad,0.03f);
-    glVertex3f(rad,-rad+rad,0.02f);
-    // glVertex3f(-lockonSize*xFactor,lockonSize,0.03f);
-    //  glVertex3f(lockonSize*xFactor,0,0.02f);
-    glEnd();
-
-    glBegin(GL_LINE_LOOP);
-    for (float t = 0; t < 360; t += segmentation) {
-      if (t != 0) {
-	const float s = (t - segmentation);
-	const float tRads = t * DEG2RADf;
-	const float sRads = s * DEG2RADf;
-	glVertex3f(sinf(sRads) * rad, (cosf(sRads) * rad) + rad, 0.02f);
-	glVertex3f(sinf(tRads) * rad, (cosf(tRads) * rad) + rad, 0.02f);
-      }
-    }
-    glEnd();
-
-    glLineWidth(2.0f);
+  glBegin(GL_LINES);
+  for (float t = 0; t < 360; t += segmentation) {
+    const float s = (t - segmentation);
+    const float tRads = t * DEG2RADf;
+    const float sRads = s * DEG2RADf;
+    glVertex3f(sinf(sRads) * rad, cosf(sRads) * rad, 0.02f);
+    glVertex3f(sinf(tRads) * rad, cosf(tRads) * rad, 0.02f);
   }
+  glEnd();
 
+  // red X
+  hudColor4f( 1,0,0, 0.85f );
+  glLineWidth(2.0f);
+  glBegin(GL_LINES);
+  glVertex3f(-rad,rad,0.03f);
+  glVertex3f(rad,-rad,0.02f);
+  // glVertex3f(-lockonSize*xFactor,lockonSize,0.03f);
+  //  glVertex3f(lockonSize*xFactor,0,0.02f);
+  glEnd();
+
+  glBegin(GL_LINES);
+  for (float t = 0; t < 360; t += segmentation) {
+    const float s = (t - segmentation);
+    const float tRads = t * DEG2RADf;
+    const float sRads = s * DEG2RADf;
+    glVertex3f(sinf(sRads) * rad, cosf(sRads) * rad, 0.02f);
+    glVertex3f(sinf(tRads) * rad, cosf(tRads) * rad, 0.02f);
+  }
+  glEnd();
+
+  glLineWidth(2.0f);
 }
 
 void			HUDRenderer::render(SceneRenderer& renderer)
@@ -805,29 +818,28 @@ void			HUDRenderer::renderStatus(void)
 
   FontManager &fm = FontManager::instance();
 
-  char buffer[80];
   const float h = fm.getStrHeight(majorFontFace, majorFontSize, " ");
   float x = 0.25f * h;
   float y = (float)window.getViewHeight() - h;
   TeamColor teamIndex = myTank->getTeam();
   FlagType* flag = myTank->getFlag();
 
-  // print player name and score in upper left corner in team (radar) color
+  // print player name and score in upper left corner in team (tank) color
   if (!roaming && (!playerHasHighScore || scoreClock.isOn())) {
-    sprintf(buffer, "%s: %d", myTank->getCallSign(), myTank->getScore());
-    hudColor3fv(Team::getRadarColor(teamIndex));
-    fm.drawString(x, y, 0, majorFontFace, majorFontSize, buffer);
+    hudColor3fv(Team::getTankColor(teamIndex));
+    fm.drawString(x, y, 0, majorFontFace, majorFontSize,
+      TextUtils::format("%s: %d", myTank->getCallSign(), myTank->getScore()));
   }
 
   // print flag if player has one in upper right
   if (flag != Flags::Null) {
-    sprintf(buffer, "%s", BundleMgr::getCurrentBundle()->getLocalString(flag->flagName).c_str());
-    x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, buffer);
+    const std::string flagname = bdl->getLocalString(flag->flagName);
+    x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, flagname);
     if (flag->endurance == FlagSticky)
       hudColor3fv(warningColor);
     else
       hudColor3fv(messageColor);
-    fm.drawString(x, y, 0, majorFontFace, majorFontSize, buffer);
+    fm.drawString(x, y, 0, majorFontFace, majorFontSize, flagname);
   } else {
     time_t timeNow;
     struct tm userTime;
@@ -845,25 +857,24 @@ void			HUDRenderer::renderStatus(void)
     }
 
     // print time or date
-    if (dater)
-      sprintf(buffer, "%4d.%02d.%02d", 1900 + userTime.tm_year, userTime.tm_mon + 1, userTime.tm_mday);
-    else
-      sprintf(buffer, "%2d:%2.2d", userTime.tm_hour, userTime.tm_min);
-    x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, buffer);
+    const std::string datetime = (dater) ?
+      TextUtils::format("%4d.%02d.%02d", 1900 + userTime.tm_year, userTime.tm_mon + 1, userTime.tm_mday) :
+      TextUtils::format("%2d:%2.2d", userTime.tm_hour, userTime.tm_min);
+    x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, datetime);
     hudColor3fv(messageColor);
-    fm.drawString(x, y, 0, majorFontFace, majorFontSize, buffer);
+    fm.drawString(x, y, 0, majorFontFace, majorFontSize, datetime);
   }
 
   // print current position of tank
   if (BZDB.isTrue("showCoordinates")) {
-	Player *target = ROAM.getTargetTank();
-	if(!target){
-      sprintf(buffer, "[%d %d %d]", (int)myTank->getPosition()[0],
-	      (int)myTank->getPosition()[1], (int)myTank->getPosition()[2]);
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, buffer);
-      fm.drawString(x, (y - h), 0, majorFontFace, majorFontSize, buffer);
-	}
-   }
+    Player *target = ROAM.getTargetTank();
+    if (!target) {
+      const std::string pos = TextUtils::format("[%d %d %d]", (int)myTank->getPosition()[0],
+	(int)myTank->getPosition()[1], (int)myTank->getPosition()[2]);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(majorFontFace, majorFontSize, pos);
+      fm.drawString(x, (y - h), 0, majorFontFace, majorFontSize, pos);
+    }
+  }
 
   if (roaming && BZDB.isTrue("showVelocities"))
   {
@@ -893,55 +904,57 @@ void			HUDRenderer::renderStatus(void)
 	maxApparentLinTime = TimeKeeper::getTick();
       }
 
-      float smallZHeight = fm.getStrHeight(minorFontFace,minorFontSize,std::string("X"))*1.125f;
+      std::string msg = "X";
+      float smallZHeight = fm.getStrHeight(minorFontFace, minorFontSize, msg) * 1.125f;
       float drawY = y - smallZHeight;
       // draw header
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, "Target Info");
-      fm.drawString(x, drawY, 0, minorFontFace, minorFontSize, "Target Info");
+      msg = "Target Info";
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x, drawY, 0, minorFontFace, minorFontSize, msg);
 
       // draw the postion
-      sprintf(buffer, "Position [%d %d %d]", (int)myTank->getPosition()[0], (int)myTank->getPosition()[1], (int)myTank->getPosition()[2]);
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-      fm.drawString(x,drawY-smallZHeight, 0, minorFontFace, minorFontSize, buffer);
+      msg = TextUtils::format("Position [%d %d %d]", (int)target->getPosition()[0], (int)target->getPosition()[1], (int)target->getPosition()[2]);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x,drawY-smallZHeight, 0, minorFontFace, minorFontSize, msg);
 
-      std::string label = "Linear Speed:";
+      msg = "Linear Speed:";
       if ( linSpeed > target->getMaxSpeed() )
-	label += "!";
+	msg += "!";
 
-      sprintf(buffer,"%s%5.2f",label.c_str(),linSpeed);
+      msg += TextUtils::format("%5.2f", linSpeed);
       if (BZDB.evalInt("showVelocities") > 1)
-	sprintf(buffer,"%s%5.2f(%5.2f)",label.c_str(),linSpeed,apparentLinSpeed);
+	msg += TextUtils::format("(%5.2f)", apparentLinSpeed);
 
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-      fm.drawString(x,drawY-smallZHeight*2.0f, 0, minorFontFace, minorFontSize, buffer);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x,drawY-smallZHeight*2.0f, 0, minorFontFace, minorFontSize, msg);
 
-      sprintf(buffer,"Vertical Speed:%5.2f",vertSpeed);
+      msg = TextUtils::format("Vertical Speed:%5.2f", vertSpeed);
       if (BZDB.evalInt("showVelocities") > 1)
-	sprintf(buffer,"Vertical Speed:%5.2f(%5.2f)",vertSpeed,apparentVel[2]);
+	msg += TextUtils::format("(%5.2f)", apparentVel[2]);
 
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-      fm.drawString(x, drawY-smallZHeight*3.0f, 0, minorFontFace, minorFontSize, buffer);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x, drawY-smallZHeight*3.0f, 0, minorFontFace, minorFontSize, msg);
 
-      label = "Angular Speed:";
+      msg = "Angular Speed:";
       if (rotSpeed > BZDB.eval(StateDatabase::BZDB_TANKANGVEL))
-	label += "!";
-      sprintf(buffer,"%s%5.2f",label.c_str(),rotSpeed);
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-      fm.drawString(x,drawY-smallZHeight*4.0f, 0, minorFontFace, minorFontSize, buffer);
+	msg += "!";
+      msg += TextUtils::format("%5.2f", rotSpeed);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x,drawY-smallZHeight*4.0f, 0, minorFontFace, minorFontSize, msg);
 
       float shotTime = (float)target->getShotStatistics()->getLastShotTimeDelta();
       float shotDeviation = (float)target->getShotStatistics()->getLastShotDeviation();
 
-      sprintf(buffer,"Last Shot Info  Time:%6.4f  Deviation:%6.3f", shotTime, shotDeviation);
-      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-      fm.drawString(x,drawY-smallZHeight*5.0f, 0, minorFontFace, minorFontSize, buffer);
+      msg = TextUtils::format("Last Shot Info  Time:%6.4f  Deviation:%6.3f", shotTime, shotDeviation);
+      x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+      fm.drawString(x,drawY-smallZHeight*5.0f, 0, minorFontFace, minorFontSize, msg);
 
       float offset = 6.0f;
       if (BZDB.evalInt("showVelocities") > 2) {
 	offset += 1.0f;
-	sprintf(buffer,"ReportedHits %d ComputedHits %d ratio %f", target->reportedHits, target->computedHits,(float)target->reportedHits/(float)target->computedHits);
-	x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize,buffer);
-	fm.drawString(x,drawY-smallZHeight*offset, 0, minorFontFace, minorFontSize, buffer);
+	msg = TextUtils::format("ReportedHits %d ComputedHits %d ratio %.2f", target->reportedHits, target->computedHits, target->computedHits == 0 ? 0.0f : (float)target->reportedHits/(float)target->computedHits);
+	x = (float)window.getWidth() - 0.25f * h - fm.getStrLength(minorFontFace, minorFontSize, msg);
+	fm.drawString(x,drawY-smallZHeight*offset, 0, minorFontFace, minorFontSize, msg);
       }
 
       offset += 1.5f;
@@ -959,24 +972,25 @@ void			HUDRenderer::renderStatus(void)
   static const GLfloat yellowColor[3] = { 1.0f, 1.0f, 0.0f };
   static const GLfloat greenColor[3] = { 0.0f, 1.0f, 0.0f };
   const GLfloat* statusColor = warningColor;
+  std::string msg;
   // TODO: the upper 4 values of timeLeft (~0u-3 to ~0u)
   // are reserved for future use as timer flags (e.g. paused)
   if ((timeLeft == 0) || (timeLeft >= (~0u - 3))) {
-    strcpy(buffer, "");
+    msg = "";
   } else {
     int t = timeLeft - (int)(TimeKeeper::getTick() - timeSet);
     if (t < 0) t = 0;
     if (t >= 3600)
-      sprintf(buffer, "%d:%02d:%02d   ", t / 3600, (t / 60) % 60, t % 60);
+      msg = TextUtils::format("%d:%02d:%02d   ", t / 3600, (t / 60) % 60, t % 60);
     else if (t >= 60)
-      sprintf(buffer, "%d:%02d   ", t / 60, t % 60);
+      msg = TextUtils::format("%d:%02d   ", t / 60, t % 60);
     else
-      sprintf(buffer, "0:%02d   ", t);
+      msg = TextUtils::format("0:%02d   ", t);
   }
   if (!roaming) {
     switch (myTank->getFiringStatus()) {
       case LocalPlayer::Deceased:
-	strcat(buffer, bdl->getLocalString("Dead").c_str());
+	msg += bdl->getLocalString("Dead");
 	break;
 
       case LocalPlayer::Ready:
@@ -984,10 +998,10 @@ void			HUDRenderer::renderStatus(void)
 	    World::getWorld()->allowShakeTimeout()) {
 	  /* have a bad flag -- show time left 'til we shake it */
 	  statusColor = yellowColor;
-	  sprintf(buffer, bdl->getLocalString("%.1f").c_str(), myTank->getFlagShakingTime());
+	  msg = TextUtils::format(bdl->getLocalString("%.1f").c_str(), myTank->getFlagShakingTime());
 	} else {
 	  statusColor = greenColor;
-	  strcat(buffer, bdl->getLocalString("Ready").c_str());
+	  msg += bdl->getLocalString("Ready");
 	}
 	break;
 
@@ -995,29 +1009,29 @@ void			HUDRenderer::renderStatus(void)
 
     if (World::getWorld()->getMaxShots() != 0) {
 	  statusColor = redColor;
-	  sprintf(buffer, bdl->getLocalString("Reloaded in %.1f").c_str(), myTank->getReloadTime());
+	  msg = TextUtils::format(bdl->getLocalString("Reloaded in %.1f").c_str(), myTank->getReloadTime());
 	}
 	break;
 
       case LocalPlayer::Sealed:
-	strcat(buffer, bdl->getLocalString("Sealed").c_str());
+	msg += bdl->getLocalString("Sealed");
 	break;
 
       case LocalPlayer::Zoned:
-	strcat(buffer, bdl->getLocalString("Zoned").c_str());
+	msg += bdl->getLocalString("Zoned");
 	break;
     }
   }
 
   if (roaming) {
     statusColor = messageColor;
-    if (dim) strcat(buffer, ColorStrings[DimColor].c_str());
-    strcat(buffer, ROAM.getRoamingLabel().c_str());
+    if (dim) msg += ColorStrings[DimColor];
+    msg += ROAM.getRoamingLabel();
   }
 
-  x = 0.5f * ((float)window.getWidth() - fm.getStrLength(majorFontFace, majorFontSize, buffer));
+  x = 0.5f * ((float)window.getWidth() - fm.getStrLength(majorFontFace, majorFontSize, msg));
   hudColor3fv(statusColor);
-  fm.drawString(x, y, 0, majorFontFace, majorFontSize, buffer);
+  fm.drawString(x, y, 0, majorFontFace, majorFontSize, msg);
 }
 
 void			HUDRenderer::renderTankLabels(SceneRenderer& renderer)
@@ -1041,7 +1055,7 @@ void			HUDRenderer::renderTankLabels(SceneRenderer& renderer)
   for (int i = 0; i < curMaxPlayers; i++) {
     RemotePlayer *pl = World::getWorld()->getPlayer(i);
     if (pl && pl->isAlive()) {
-      const char *name = pl->getCallSign();
+      const std::string name = pl->getCallSign();
       double x, y, z;
       hudSColor3fv(Team::getRadarColor(pl->getTeam()));
       gluProject(pl->getPosition()[0], pl->getPosition()[1],
@@ -1056,11 +1070,10 @@ void			HUDRenderer::renderTankLabels(SceneRenderer& renderer)
 	  std::string flagStr = "(";
 	  flagStr += flag->endurance == FlagNormal ? flag->flagName : flag->flagAbbv;
 	  flagStr += ")";
-	  const char *fname = flagStr.c_str();
-	  fm.drawString(float(x) - fm.getStrLength(labelsFontFace, labelsFontSize, fname) / 2.0f,
+	  fm.drawString(float(x) - fm.getStrLength(labelsFontFace, labelsFontSize, flagStr) / 2.0f,
 			float(y) + offset -
-			(2.0f * fm.getStrHeight(labelsFontFace, labelsFontSize, fname)),
-			0, labelsFontFace, labelsFontSize, fname);
+			(2.0f * fm.getStrHeight(labelsFontFace, labelsFontSize, flagStr)),
+			0, labelsFontFace, labelsFontSize, flagStr);
 	}
 
 		if (roaming && BZDB.isTrue("showVelocities"))
@@ -1123,34 +1136,30 @@ void			HUDRenderer::renderTimes(void)
 
   // draw frames per second
   if (fps > 0.0f) {
-    char buf[20];
-    sprintf(buf, "FPS: %d", int(fps));
     hudColor3f(1.0f, 1.0f, 1.0f);
     fm.drawString((float)(centerx - maxMotionSize), (float)centery + (float)maxMotionSize +
 		3.0f * fm.getStrHeight(headingFontFace, headingFontSize, "0"), 0,
-		headingFontFace, headingFontSize, buf);
+		headingFontFace, headingFontSize, TextUtils::format("FPS: %d", int(fps)));
   }
   float triCountYOffset = 4.5f;
   if (radarTriangleCount > 0) {
-    char buf[20];
-    sprintf(buf, "rtris: %i", radarTriangleCount);
     hudColor3f(1.0f, 1.0f, 1.0f);
     fm.drawString((float)(centerx - maxMotionSize), (float)centery + (float)maxMotionSize +
 		triCountYOffset * fm.getStrHeight(headingFontFace, headingFontSize, "0"), 0,
-		headingFontFace, headingFontSize, buf);
+		headingFontFace, headingFontSize, TextUtils::format("rtris: %d", radarTriangleCount));
     triCountYOffset += 1.5f;
   }
   if (triangleCount > 0) {
-    char buf[20];
-    sprintf(buf, "tris: %i", triangleCount);
     hudColor3f(1.0f, 1.0f, 1.0f);
     fm.drawString((float)(centerx - maxMotionSize), (float)centery + (float)maxMotionSize +
 		triCountYOffset * fm.getStrHeight(headingFontFace, headingFontSize, "0"), 0,
-		headingFontFace, headingFontSize, buf);
+		headingFontFace, headingFontSize, TextUtils::format("tris: %d", triangleCount));
   }
   if (drawTime > 0.0f) {
-    char buf[20];
-    sprintf(buf, "time: %dms", (int)(drawTime * 1000.0f));
+    const std::string buf = TextUtils::format("time: %d/%d/%dms",
+          int(minDrawTime * 1000.0f),
+          int(drawTime * 1000.0f),
+          int(maxDrawTime * 1000.0f));
     hudColor3f(1.0f, 1.0f, 1.0f);
     fm.drawString((float)(centerx + maxMotionSize) - fm.getStrLength(headingFontFace, headingFontSize, buf),
 		  (float)centery + (float)maxMotionSize +
@@ -1161,7 +1170,7 @@ void			HUDRenderer::renderTimes(void)
 void HUDRenderer::saveMatrixes(const float *mm, const float *pm )
 {
   // ssave off the stuff before we reset it
-  for(int i = 0; i < 16; i++) {
+  for (int i = 0; i < 16; i++) {
     modelMatrix[i] = mm[i];
     projMatrix[i] = pm[i];
   }
@@ -1186,7 +1195,7 @@ void HUDRenderer::drawWaypointMarker(float* color, float alpha, float* object,
     (GLint*)viewport, &map[0], &map[1], &map[2]);
   glPopMatrix();
 
-  float halfWidth = window.getWidth( )* 0.5f;
+  float halfWidth = window.getWidth() * 0.5f;
   float halfHeight = window.getHeight() * 0.5f;
 
   // comp us back to the view
@@ -1260,7 +1269,7 @@ void HUDRenderer::drawWaypointMarker(float* color, float alpha, float* object,
   glEnd();
 
   if (friendly)
-    DisplayListSystem::Instance().callList(friendlyMarkerList);
+    drawGeometry();
 
   glPopMatrix();
 
@@ -1269,7 +1278,7 @@ void HUDRenderer::drawWaypointMarker(float* color, float alpha, float* object,
     float textOffset = 5.0f;
     float width = FontManager::instance().getStrLength(headingFontFace, headingFontSize, name);
     glEnable(GL_TEXTURE_2D);
-    FontManager::instance().drawString(-width * 0.5f , textOffset + triangleSize,
+    FontManager::instance().drawString(-width * 0.5f, textOffset + triangleSize,
       0, headingFontFace, headingFontSize, name);
     glDisable(GL_TEXTURE_2D);
   }
@@ -1282,9 +1291,9 @@ void HUDRenderer::drawWaypointMarker(float* color, float alpha, float* object,
 // HUDRenderer::drawLockonMarker
 //-------------------------------------------------------------------------
 
-void HUDRenderer::drawLockonMarker(float* color ,float alpha, float* object,
+void HUDRenderer::drawLockonMarker(float* color, float alpha, float* object,
 				   const float *viewPos, std::string name,
-				   bool friendly )
+				   bool friendly)
 {
   double map[3] = {0,0,0};
   double o[3];
@@ -1299,7 +1308,7 @@ void HUDRenderer::drawLockonMarker(float* color ,float alpha, float* object,
     (GLint*)viewport, &map[0], &map[1], &map[2]);
   glPopMatrix();
 
-  float halfWidth = window.getWidth( )* 0.5f;
+  float halfWidth = window.getWidth() * 0.5f;
   float halfHeight = window.getHeight() * 0.5f;
 
   // comp us back to the view
@@ -1357,7 +1366,7 @@ void HUDRenderer::drawLockonMarker(float* color ,float alpha, float* object,
   glEnd();
 
   if (friendly)
-    DisplayListSystem::Instance().callList(friendlyMarkerList);
+    drawGeometry();
 
   glLineWidth(1.0f);
 
@@ -1402,7 +1411,7 @@ void			HUDRenderer::renderBox(SceneRenderer&)
     glVertex2i(centerx + noMotionSize, centery + noMotionSize);
     glVertex2i(centerx - noMotionSize, centery + noMotionSize);
   } glEnd();
-  if (0){
+  if (0) {
       glBegin(GL_POINTS); {
       glVertex2i(centerx - noMotionSize, centery - noMotionSize);
       glVertex2i(centerx + noMotionSize, centery - noMotionSize);
@@ -1416,7 +1425,7 @@ void			HUDRenderer::renderBox(SceneRenderer&)
     glVertex2i(centerx + maxMotionSize, centery + maxMotionSize);
     glVertex2i(centerx - maxMotionSize, centery + maxMotionSize);
   } glEnd();
-  if (0){
+  if (0) {
       glBegin(GL_POINTS); {
       glVertex2i(centerx - maxMotionSize, centery - maxMotionSize);
       glVertex2i(centerx + maxMotionSize, centery - maxMotionSize);
@@ -1594,10 +1603,8 @@ void			HUDRenderer::renderBox(SceneRenderer&)
       y -= 0.5f;
       hudColor4f(hudColor[0], hudColor[1], hudColor[2], basey - floorf(basey));
     }
-    char buf[10];
     for (i = minMark; i <= maxMark; i++) {
-      sprintf(buf, "%d", i * 5);
-      fm.drawString(x, y, 0, headingFontFace, headingFontSize, std::string(buf));
+      fm.drawString(x, y, 0, headingFontFace, headingFontSize, TextUtils::format("%d", i * 5));
       y += altitudeMarkSpacing;
     }
     if (smoothLabel) {
@@ -1606,8 +1613,7 @@ void			HUDRenderer::renderBox(SceneRenderer&)
       basey -= floorf(basey);
       hudColor4f(hudColor[0], hudColor[1], hudColor[2], 1.0f - basey);
       for (i = minMark; i <= maxMark; i++) {
-	sprintf(buf, "%d", i * 5);
-	fm.drawString(x, y, 0, headingFontFace, headingFontSize, std::string(buf));
+	fm.drawString(x, y, 0, headingFontFace, headingFontSize, TextUtils::format("%d", i * 5));
 	y += altitudeMarkSpacing;
       }
     }
@@ -1661,8 +1667,6 @@ void			HUDRenderer::renderPlaying(SceneRenderer& renderer)
   const int oy = window.getOriginY();
   const int centerx = width >> 1;
   const int centery = viewHeight >> 1;
-  int i;
-  float y;
 
   FontManager &fm = FontManager::instance();
 
@@ -1695,7 +1699,6 @@ void			HUDRenderer::renderPlaying(SceneRenderer& renderer)
   const bool  experimental = (RENDERER.useQuality() >= 3);
 
   if (!BZDB.isTrue("_forbidMarkers") && experimental) {
-      bool enableTex = glIsEnabled(GL_TEXTURE_2D) != 0;
       glDisable(GL_TEXTURE_2D);
 
       drawMarkersInView(centerx,centery,myTank);
@@ -1716,6 +1719,8 @@ void			HUDRenderer::renderPlaying(SceneRenderer& renderer)
 
   // draw flag help
   if (flagHelpClock.isOn()) {
+    int i;
+    float y;
     hudColor3fv(messageColor);
     flagHelpY = (float) ((window.getViewHeight() >> 1) - maxMotionSize);
     y = flagHelpY;
@@ -1893,7 +1898,7 @@ void			HUDRenderer::renderRoaming(SceneRenderer& renderer)
 
 
 
-static int compare_float (const void* a, const void* b)
+static int		compare_float(const void* a, const void* b)
 {
   const float fa = *((const float*)a);
   const float fb = *((const float*)b);
@@ -1965,7 +1970,7 @@ void			HUDRenderer::renderShots(const Player* target)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
