@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -54,10 +54,12 @@ public:
   EnhancedHUDMarker()
     : pos(0.0f, 0.0f, 0.0f)
     , color(0.0f, 0.0f, 0.0f, 1.0f)
+    , friendly(false)
   {}
   EnhancedHUDMarker(const fvec3& p, const fvec4& c)
     : pos(p)
     , color(c)
+    , friendly(false)
   {}
   fvec3 pos;
   fvec4 color;
@@ -71,12 +73,12 @@ typedef std::vector<EnhancedHUDMarker> EnhancedMarkerList;
  * HUDRenderer:
  *	Encapsulates information about rendering the heads-up display.
  */
-class HUDRenderer : public GLDisplayListCreator {
+class HUDRenderer {
 public:
   HUDRenderer(const BzfDisplay*, const SceneRenderer&);
   ~HUDRenderer();
 
-  virtual void buildGeometry(GLDisplayList displayList);
+  void drawGeometry();
 
   int			getNoMotionSize() const;
   int			getMaxMotionSize() const;
@@ -162,8 +164,6 @@ private:
   void		resize(bool firstTime);
   static void	resizeCallback(void*);
 
-  GLDisplayList	friendlyMarkerList;
-private:
   const BzfDisplay*	display;
   ScoreboardRenderer* scoreboard;
   MainWindow&		window;
@@ -204,7 +204,9 @@ private:
   float		altitude;
   bool		altitudeTape;
   float		fps;
+  float		minDrawTime;
   float		drawTime;
+  float		maxDrawTime;
   float		headingMarkSpacing;
   float		headingLabelWidth[36];
   float		altitudeMarkSpacing;
