@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,7 +24,7 @@
 // HUDuiTextureLabel
 //
 
-HUDuiTextureLabel::HUDuiTextureLabel() : HUDuiLabel()
+HUDuiTextureLabel::HUDuiTextureLabel() : HUDuiLabel(), texture()
 {
 }
 
@@ -74,10 +74,9 @@ void			HUDuiTextureLabel::doRender()
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
