@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -123,7 +123,7 @@ void HelpMenu::resize(int _width, int _height)
 class Help1Menu : public HelpMenu {
 public:
   Help1Menu();
-  ~Help1Menu() { }
+  ~Help1Menu() {}
 
   void		resize(int width, int height);
 
@@ -156,6 +156,8 @@ Help1Menu::Help1Menu() : HelpMenu("Controls")
   listHUD.push_back(createLabel(NULL, "Short Radar Range:"));
   listHUD.push_back(createLabel(NULL, "Medium Radar Range:"));
   listHUD.push_back(createLabel(NULL, "Long Radar Range:"));
+  listHUD.push_back(createLabel(NULL, "Zoom Radar In:"));
+  listHUD.push_back(createLabel(NULL, "Zoom Radar Out:"));
   listHUD.push_back(createLabel(NULL, "Send Message to Everybody:"));
   listHUD.push_back(createLabel(NULL, "Send Message to Teammates:"));
   listHUD.push_back(createLabel(NULL, "Send Message to Nemesis:"));
@@ -191,33 +193,35 @@ Help1Menu::Help1Menu() : HelpMenu("Controls")
   initKeymap("set displayRadarRange 0.25", 6);
   initKeymap("set displayRadarRange 0.5", 7);
   initKeymap("set displayRadarRange 1.0", 8);
-  initKeymap("send all", 9);
-  initKeymap("send team", 10);
-  initKeymap("send nemesis", 11);
-  initKeymap("send recipient", 12);
-  initKeymap("jump", 13);
-  initKeymap("viewZoom toggle", 14);
-  initKeymap("toggle displayScore", 15);
-  initKeymap("toggle displayLabels", 16);
-  initKeymap("toggle displayFlagHelp", 17);
-  initKeymap("time backward", 18);
-  initKeymap("time forward", 19);
-  initKeymap("pause", 20);
-  initKeymap("destruct", 21);
-  initKeymap("quit", 22);
-  initKeymap("scrollpanel up_page", 23);
-  initKeymap("scrollpanel down_page", 24);
-  initKeymap("toggle slowKeyboard", 25);
-  initKeymap("toggleFlags radar", 26);
-  initKeymap("toggleFlags main", 27);
-  initKeymap("silence", 28);
-  initKeymap("servercommand", 29);
-  initKeymap("hunt", 30);
-  initKeymap("autopilot", 31);
-  initKeymap("messagepanel all", 32);
-  initKeymap("messagepanel chat", 33);
-  initKeymap("messagepanel server", 34);
-  initKeymap("messagepanel misc", 35);
+  initKeymap("radarZoom in", 9);
+  initKeymap("radarZoom out", 10);
+  initKeymap("send all", 11);
+  initKeymap("send team", 12);
+  initKeymap("send nemesis", 13);
+  initKeymap("send recipient", 14);
+  initKeymap("jump", 15);
+  initKeymap("viewZoom toggle", 16);
+  initKeymap("toggle displayScore", 17);
+  initKeymap("toggle displayLabels", 18);
+  initKeymap("toggle displayFlagHelp", 19);
+  initKeymap("time backward", 20);
+  initKeymap("time forward", 21);
+  initKeymap("pause", 22);
+  initKeymap("destruct", 23);
+  initKeymap("quit", 24);
+  initKeymap("scrollpanel up_page", 25);
+  initKeymap("scrollpanel down_page", 26);
+  initKeymap("toggle slowKeyboard", 27);
+  initKeymap("toggleFlags radar", 28);
+  initKeymap("toggleFlags main", 29);
+  initKeymap("silence", 30);
+  initKeymap("servercommand", 31);
+  initKeymap("hunt", 32);
+  initKeymap("autopilot", 33);
+  initKeymap("messagepanel all", 34);
+  initKeymap("messagepanel chat", 35);
+  initKeymap("messagepanel server", 36);
+  initKeymap("messagepanel misc", 37);
 }
 
 void Help1Menu::onScan(const std::string& name, bool press,
@@ -257,14 +261,14 @@ void Help1Menu::resize(int _width, int _height)
   // get current key mapping and set strings appropriately
   KeyKeyMap::iterator it;
   // clear
-  for (it = mappable.begin(); it != mappable.end(); it++) {
+  for (it = mappable.begin(); it != mappable.end(); ++it) {
     it->second.key1 = "";
     it->second.key2 = "";
   }
   // load current settings
   KEYMGR.iterate(&onScanCB, this);
   std::vector<HUDuiControl*>& listHUD = getControls();
-  for (it = mappable.begin(); it != mappable.end(); it++) {
+  for (it = mappable.begin(); it != mappable.end(); ++it) {
     std::string value = "";
     if (it->second.key1.empty()) {
       value = "<not mapped>";
@@ -287,7 +291,7 @@ void Help1Menu::resize(int _width, int _height)
 class Help2Menu : public HelpMenu {
 public:
   Help2Menu();
-  ~Help2Menu() { }
+  ~Help2Menu() {}
 };
 
 Help2Menu::Help2Menu() : HelpMenu("General")
@@ -323,7 +327,7 @@ Help2Menu::Help2Menu() : HelpMenu("General")
 class Help3Menu : public HelpMenu {
 public:
   Help3Menu();
-  ~Help3Menu() { }
+  ~Help3Menu() {}
 };
 
 Help3Menu::Help3Menu() : HelpMenu("Environment")
@@ -356,7 +360,7 @@ Help3Menu::Help3Menu() : HelpMenu("Environment")
 class Help4Menu : public HelpMenu {
 public:
   Help4Menu();
-  ~Help4Menu() { }
+  ~Help4Menu() {}
 };
 
 Help4Menu::Help4Menu() : HelpMenu("Flags")
@@ -390,7 +394,7 @@ Help4Menu::Help4Menu() : HelpMenu("Flags")
 class Help5Menu : public HelpMenu {
 public:
   Help5Menu();
-  ~Help5Menu() { }
+  ~Help5Menu() {}
 
 protected:
   float getLeftSide(int width, int height);
@@ -402,7 +406,7 @@ Help5Menu::Help5Menu() : HelpMenu("Good Flags")
   listHUD.push_back(createLabel("", "Good Flags:"));
 
   FlagSet fs = Flag::getGoodFlags();
-  for (FlagSet::iterator it = fs.begin(); it != fs.end(); it++) {
+  for (FlagSet::iterator it = fs.begin(); it != fs.end(); ++it) {
 
     if (((*it)->flagQuality != FlagGood) ||
 	((*it)->flagTeam != NoTeam) ||
@@ -426,7 +430,7 @@ float			Help5Menu::getLeftSide(int _width, int)
 class Help6Menu : public HelpMenu {
 public:
   Help6Menu();
-  ~Help6Menu() { }
+  ~Help6Menu() {}
 
 protected:
   float		getLeftSide(int width, int height);
@@ -438,7 +442,7 @@ Help6Menu::Help6Menu() : HelpMenu("Bad Flags")
   listHUD.push_back(createLabel("", "Bad Flags:"));
 
   FlagSet fs = Flag::getBadFlags();
-  for (FlagSet::iterator it = fs.begin(); it != fs.end(); it++) {
+  for (FlagSet::iterator it = fs.begin(); it != fs.end(); ++it) {
 
     if (((*it)->flagQuality != FlagBad) ||
 	((*it)->flagTeam != NoTeam) ||
@@ -462,7 +466,7 @@ float Help6Menu::getLeftSide(int _width, int)
 class Help7Menu : public HelpMenu {
 public:
   Help7Menu();
-  ~Help7Menu() { }
+  ~Help7Menu() {}
 };
 
 Help7Menu::Help7Menu() : HelpMenu("Readouts I")
@@ -496,7 +500,7 @@ Help7Menu::Help7Menu() : HelpMenu("Readouts I")
 class Help8Menu : public HelpMenu {
 public:
   Help8Menu();
-  ~Help8Menu() { }
+  ~Help8Menu() {}
 };
 
 Help8Menu::Help8Menu() : HelpMenu("Readouts II")
@@ -523,58 +527,11 @@ Help8Menu::Help8Menu() : HelpMenu("Readouts II")
   listHUD.push_back(createLabel("Other informational messages may occasionally flash on the HUD."));
 }
 
-//
-// Help9Menu
-//
-
-class Help9Menu : public HelpMenu {
-public:
-  Help9Menu();
-  ~Help9Menu() { }
-
-protected:
-  float getLeftSide(int width, int height);
-};
-
-Help9Menu::Help9Menu() : HelpMenu("Credits")
-{
-  // add controls
-  std::vector<HUDuiControl*>& listHUD = getControls();
-  listHUD.push_back(createLabel("Tim Riker", "Maintainer:"));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("Chris Schoeneman", "Original Author:"));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("David Hoeferlin, Tom Hubina", "Code Contributors:"));
-  listHUD.push_back(createLabel("Dan Kartch, Jed Lengyel", ""));
-  listHUD.push_back(createLabel("Jeff Myers, Tim Olson", ""));
-  listHUD.push_back(createLabel("Brian Smits, Greg Spencer", ""));
-  listHUD.push_back(createLabel("Daryll Strauss, Frank Thilo", ""));
-  listHUD.push_back(createLabel("Dave Brosius, David Trowbridge", ""));
-  listHUD.push_back(createLabel("Sean Morrison, Tupone Alfredo", ""));
-  listHUD.push_back(createLabel("Lars Luthman, Nils McCarthy", ""));
-  listHUD.push_back(createLabel("Daniel Remenak", ""));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("Tamar Cohen", "Tank Models:"));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("Kevin Novins, Rick Pasetto", "Special Thanks:"));
-  listHUD.push_back(createLabel("Adam Rosen, Erin Shaw", ""));
-  listHUD.push_back(createLabel("Ben Trumbore, Don Greenberg", ""));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("http://BZFlag.org/", "BZFlag Home Page:"));
-  listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("Tim Riker", "Copyright (c) 1993-2011"));
-}
-
-float Help9Menu::getLeftSide(int _width, int _height)
-{
-  return 0.5f * _width - _height / 20.0f;
-}
-
 //
 // help menu getter
 //
 
-static const int numHelpMenus = 9;
+static const int numHelpMenus = 8;
 HelpMenu** HelpMenu::helpMenus = NULL;
 
 HelpMenu* HelpMenu::getHelpMenu(HUDDialog* dialog, bool next)
@@ -589,7 +546,6 @@ HelpMenu* HelpMenu::getHelpMenu(HUDDialog* dialog, bool next)
     helpMenus[5] = new Help6Menu;
     helpMenus[6] = new Help7Menu;
     helpMenus[7] = new Help8Menu;
-    helpMenus[8] = new Help9Menu;
   }
   for (int i = 0; i < numHelpMenus; i++) {
     if (dialog == helpMenus[i]) {
