@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -29,6 +29,9 @@
 #include "ForceFeedback.h"
 #include "effectsRenderer.h"
 
+/* system implementation headers */
+#include <algorithm>
+
 LocalPlayer*		LocalPlayer::mainPlayer = NULL;
 
 LocalPlayer::LocalPlayer(const PlayerId& _id,
@@ -1149,15 +1152,14 @@ void			LocalPlayer::setPause(bool pause)
 
 void			LocalPlayer::activateAutoPilot(bool autopilot)
 {
-  if (autopilot && !isAutoPilot()) {
-    setAutoPilot();
-    server->sendAutoPilot(true);
-  }
-  else if (!autopilot && isAutoPilot()) {
-    setAutoPilot(false);
-    server->sendAutoPilot(false);
+  // If desired and actual state is the same, ignore the request
+  if (autopilot == isAutoPilot())
+    return;
+
+  setAutoPilot(autopilot);
+  server->sendAutoPilot(autopilot);
+  if (!autopilot)
     setTarget(NULL);
-  }
 }
 
 bool			LocalPlayer::fireShot()
@@ -1444,16 +1446,15 @@ void			LocalPlayer::explodeTank()
   setExplode(TimeKeeper::getTick());
   const float* oldVelocity = getVelocity();
   float newVelocity[3];
-  float maxSpeed;
   newVelocity[0] = oldVelocity[0];
   newVelocity[1] = oldVelocity[1];
   if (gravity < 0) {
     // comparing 2 speed:
-    //   to have a simmetric path (ending at same height as starting)
-    //   to reach the acme of parabola, under the max height established
+    //   to have a symmetric path (ending at same height as starting)
+    //   to reach the apex of parabola, under the max height established
     // take the less
     newVelocity[2] = - 0.5f * gravity * explodeTim;
-    maxSpeed       = sqrtf(- 2.0f * zMax * gravity);
+    float maxSpeed = sqrtf(- 2.0f * zMax * gravity);
     if (newVelocity[2] > maxSpeed)
       newVelocity[2] = maxSpeed;
   } else {
@@ -1463,7 +1464,7 @@ void			LocalPlayer::explodeTank()
   if (death)
   {
 	  fvec3 v(newVelocity[0],newVelocity[1],newVelocity[2]);
-	  if(death->GetDeathVector(v))
+	  if (death->GetDeathVector(v))
 	  {
 		  newVelocity[0] = v.x;
 		  newVelocity[1] = v.y;
@@ -1605,7 +1606,12 @@ void			LocalPlayer::setFlag(FlagType* flag)
     if (World::getWorld()->allowAntidote()) {
       float tankRadius = BZDBCache::tankRadius;
       float baseSize = BZDB.eval(StateDatabase::BZDB_BASESIZE);
+      int tryCount = 0;
       do {
+	tryCount++;
+	if (tryCount > 100) // if it takes this long, just screw it.
+	  break;
+
 	if (World::getWorld()->allowTeamFlags()) {
 	  flagAntidotePos[0] = 0.5f * worldSize * ((float)bzfrand() - 0.5f);
 	  flagAntidotePos[1] = 0.5f * worldSize * ((float)bzfrand() - 0.5f);
@@ -1685,10 +1691,9 @@ void LocalPlayer::setKey(int button, bool pressed) {
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
