@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -50,7 +50,7 @@ class MainWindow {
     int			getWidth() const;
     int			getHeight() const;
     int			getViewHeight() const;
-    bool		getFullscreen();
+    bool		getFullscreen() const;
     bool		getFullView() const;
 
     void		setPosition(int x, int y);
@@ -62,7 +62,6 @@ class MainWindow {
     void		iconify(void);
     void		setNoMouseGrab();
 
-    void		setZoomFactor(int);
     void		setQuadrant(Quadrant);
 
     void		showWindow(bool = true);
@@ -70,9 +69,11 @@ class MainWindow {
     void		warpMouse(int mx, int my);
     void		warpMouseCenterX();
     void		warpMouseCenterY();
+    void		disableConfineToMotionbox();
+    void		confineToMotionbox(int x1, int y1, int x2, int y2);
     void		grabMouse();
     void		enableGrabMouse(bool on);
-    bool		isGrabEnabled(void);
+    bool		isGrabEnabled(void) const;
     void		ungrabMouse();
 
     void		resize();
@@ -85,14 +86,16 @@ class MainWindow {
     // for these values that we need every frame.
     void		getMousePosition(int& mx, int& my) const;
     void		getJoyPosition(int& mx, int& my) const;
+    int			getNumHats() const;
+    void		getJoyHat(int hat, float &hatX, float &hatY) const;
     unsigned long	getJoyButtonSet() const;
     void		getJoyDevices(std::vector<std::string> &list) const;
     void		getJoyDeviceAxes(std::vector<std::string> &list) const;
-    void		setJoyXAxis(const std::string axis);
-    void		setJoyYAxis(const std::string axis);
+    void		setJoyXAxis(const std::string &axis);
+    void		setJoyYAxis(const std::string &axis);
     void		initJoystick(std::string &joystickName);
 
-    bool		isInFault() { return faulting; };
+    bool		isInFault() const { return faulting; };
 
   private:
     // no copying
@@ -112,7 +115,6 @@ class MainWindow {
     bool		isFullView;
     bool		allowMouseGrab;
     bool		grabEnabled;
-    int			zoomFactor;
     int			trueWidth, trueHeight;
     int			xOrigin, yOrigin;
     int			width;
