@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -65,10 +65,15 @@ Player::Player(const PlayerId& _id, TeamColor _team,
   wins(0),
   losses(0),
   tks(0),
+  selfKills(0),
   localWins(0),
   localLosses(0),
   localTks(0),
   autoPilot(false),
+  relativeSpeed(),
+  relativeAngVel(),
+  inputRelVel(),
+  inputRelSpeed(),
   deltaTime(0.0),
   offset(0.0),
   deadReckoningState(0),
@@ -664,6 +669,10 @@ void Player::changeScore(short deltaWins, short deltaLosses, short deltaTeamKill
   tks += deltaTeamKills;
 }
 
+void Player::changeSelfKills(short delta)
+{
+  selfKills += delta;
+}
 
 void Player::changeLocalScore(short dWins, short dLosses, short dTeamKills)
 {
@@ -1030,7 +1039,7 @@ void Player::addShots(SceneDatabase* scene, bool colorblind) const
 }
 
 
-void* Player::unpack(void* buf, uint16_t code)
+const void* Player::unpack(const void* buf, uint16_t code)
 {
   float timestamp;
   PlayerId ident;
@@ -1337,8 +1346,6 @@ void Player::doDeadReckoning()
 
 
 // How long does the filter takes to be considered "initialized"
-const int   DRStateStable      = 100;
-const float maxToleratedJitter = 1.0f;
 
 void Player::setDeadReckoning(float timestamp)
 {
@@ -1434,7 +1441,7 @@ void Player::setHandicap(float _handicap)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
