@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -103,6 +103,7 @@ public:
   }
 #endif
   short		getRabbitScore() const;
+  short		getSelfKills() const;
   short		getLocalWins() const;
   short		getLocalLosses() const;
   short		getLocalTeamKills() const;
@@ -174,21 +175,23 @@ public:
   void		changeTeam(TeamColor);
   virtual void	setFlag(FlagType*);
   virtual void	changeScore(short deltaWins, short deltaLosses, short deltaTeamKills);
+  void		changeSelfKills(short delta);
   void		changeLocalScore(short deltaWins, short deltaLosses, short deltaTeamKills);
-  void	  setHandicap(float handicap);
+  void		setHandicap(float handicap);
   void		setStatus(short);
   void		setExplode(const TimeKeeper&);
   void		setTeleport(const TimeKeeper&, short from, short to);
   void		endShot(int index, bool isHit = false,
 			bool showExplosion = false);
+  void		addHitToStats(FlagType* flag);
 
   void*		pack(void*, uint16_t& code);
-  void*		unpack(void*, uint16_t code);
+  const void*	unpack(const void*, uint16_t code);
 
   void		setDeadReckoning();
   void		setDeadReckoning(float timestamp);
 
-  void		setUserTexture ( const char *tex ) { if(tex) userTexture = tex;}
+  void		setUserTexture ( const char *tex ) { if (tex) userTexture = tex;}
 
   void		renderRadar() const;
 
@@ -294,6 +297,7 @@ private:
   short			wins;			// number of kills
   short			losses;			// number of deaths
   short			tks;			// number of teamkills
+  short			selfKills;			// number of self-destructions
 
   // score of local player against this player
   short			localWins;		// local player won this many
@@ -452,6 +456,11 @@ inline short		Player::getTeamKills() const
   return tks;
 }
 
+inline short		Player::getSelfKills() const
+{
+  return selfKills;
+}
+
 inline short		Player::getLocalWins() const
 {
   return localWins;
@@ -617,6 +626,11 @@ inline void		Player::setPlayerList(bool _playerList)
   playerList = _playerList;
 }
 
+inline void		Player::addHitToStats(FlagType* flag)
+{
+  shotStatistics.recordHit(flag);
+}
+
 inline void*		Player::pack(void* buf, uint16_t& code)
 {
   setDeadReckoning();
