@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -47,18 +47,17 @@ RadarRenderer::RadarRenderer(const SceneRenderer&, World* _world)
     w(0),
     h(0),
     dimming(0.0f),
+    ps(),
+    range(),
     decay(0.01f),
+    smooth(false),
     jammed(false),
-    multiSampled(false)
+    useTankModels(false),
+    useTankDimensions(false),
+    triangleCount()
 {
 
   setControlColor();
-
-#if defined(GLX_SAMPLES_SGIS) && defined(GLX_SGIS_multisample)
-  GLint bits;
-  glGetIntergerv(GL_SAMPLES_SGIS, &bits);
-  if (bits > 0) multiSampled = true;
-#endif
 }
 
 void RadarRenderer::setWorld(World* _world)
@@ -105,8 +104,56 @@ void RadarRenderer::drawShot(const ShotPath* shot)
   glEnd();
 }
 
+void RadarRenderer::setTankColor(const Player* player)
+{
+  //The height box also uses the tank color
 
-void RadarRenderer::drawTank(const float pos[3], const Player* player)
+  const LocalPlayer *myTank = LocalPlayer::getMyTank();
+
+  //my tank
+  if (player->getId() == myTank->getId() ) {
+    glColor3f(1.0f, 1.0f, 1.0f);
+    return;
+  }
+
+  //remote player
+  if (player->isPaused() || player->isNotResponding()) {
+    const float dimfactor = 0.4f;
+
+    const float *color;
+    if (myTank->getFlag() == Flags::Colorblindness) {
+      color = Team::getRadarColor(RogueTeam);
+    } else {
+      color = Team::getRadarColor(player->getTeam());
+    }
+
+    float dimmedcolor[3];
+    dimmedcolor[0] = color[0] * dimfactor;
+    dimmedcolor[1] = color[1] * dimfactor;
+    dimmedcolor[2] = color[2] * dimfactor;
+    glColor3fv(dimmedcolor);
+    } else {
+    glColor3fv(Team::getRadarColor(myTank->getFlag() ==
+			 Flags::Colorblindness ? RogueTeam : player->getTeam()));
+    }
+    // If this tank is hunted flash it on the radar
+    if (player->isHunted() && myTank->getFlag() != Flags::Colorblindness) {
+    if (flashTank.isOn()) {
+      if (!toggleTank) {
+	float flashcolor[3];
+	flashcolor[0] = 0.0f;
+	flashcolor[1] = 0.8f;
+	flashcolor[2] = 0.9f;
+	glColor3fv(flashcolor);
+      }
+    } else {
+      toggleTank = !toggleTank;
+      flashTank.setClock(0.2f);
+    }
+  }
+}
+
+void RadarRenderer::drawTank(const float pos[3], const Player* player, bool useSquares)
 {
   glPushMatrix();
 
@@ -130,7 +177,8 @@ void RadarRenderer::drawTank(const float pos[3], const Player* player)
   glTranslatef(pos[0], pos[1], 0.0f);
 
   // draw the tank
-  if ((player == NULL) || !useTankDimensions) {
+  if (useSquares || !useTankDimensions) {
+    setTankColor(player);
     // align to the screen axes
     glRotatef(float(myAngle * 180.0 / M_PI), 0.0f, 0.0f, 1.0f);
     glRectf(-size, -size, +size, +size);
@@ -139,9 +187,11 @@ void RadarRenderer::drawTank(const float pos[3], const Player* player)
     const float tankAngle = player->getAngle();
     glPushMatrix();
     glRotatef(float(tankAngle * 180.0 / M_PI), 0.0f, 0.0f, 1.0f);
-    if (0/*useTankModels*/) { // TODO fix the fancy drawing
+    if (useTankModels) {
       drawFancyTank(player);
+      setTankColor(player);
     } else {
+      setTankColor(player);
       const float* dims = player->getDimensions();
       glRectf(-dims[0], -dims[1], +dims[0], +dims[1]);
     }
@@ -188,7 +238,6 @@ void RadarRenderer::drawFancyTank(const Player* player)
   player->renderRadar(); // draws at (0,0,0)
 
   RENDERER.enableSun(false);
-  glColor4f(1.0f, 1.0f, 1.0f, 1.0f); // FIXME - height box color
   OpenGLGState::resetState();
 
   if (BZDBCache::zbuffer) {
@@ -197,6 +246,7 @@ void RadarRenderer::drawFancyTank(const Player* player)
 
   if (smooth) {
     glEnable(GL_BLEND);
+    glEnable(GL_POINT_SMOOTH);
   }
 
   return;
@@ -269,8 +319,8 @@ void RadarRenderer::renderFrame(SceneRenderer& renderer)
   const float top = float(oy + y) - 0.5f;
   const float bottom = float(oy + y + h) + 0.5f;
 
-  float outlineOpacity = RENDERER.getPanelOpacity();
-  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this manybe?
+  float outlineOpacity = RENDERER.getRadarOpacity();
+  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this maybe?
   if ( outlineOpacity < 1.0f )
 	  outlineOpacity = (outlineOpacity*fudgeFactor) + (1.0f - fudgeFactor);
 
@@ -286,7 +336,7 @@ void RadarRenderer::renderFrame(SceneRenderer& renderer)
     glVertex2f(left, bottom);
   } glEnd();
 
-  if (0){
+  if (0) {
 	  glBegin(GL_POINTS); {
 		glVertex2f(left, top);
 		glVertex2f(right, top);
@@ -300,7 +350,7 @@ void RadarRenderer::renderFrame(SceneRenderer& renderer)
 
   glColor4f(teamColor[0],teamColor[1],teamColor[2],1.0f);
 
-  const float opacity = renderer.getPanelOpacity();
+  const float opacity = renderer.getRadarOpacity();
   if ((opacity < 1.0f) && (opacity > 0.0f)) {
     glScissor(ox + x - 2, oy + y - 2, w + 4, h + 4);
     // draw nice blended background
@@ -351,7 +401,7 @@ void RadarRenderer::render(SceneRenderer& renderer, bool blank, bool observer)
     return;
   }
 
-  smooth = !multiSampled && BZDBCache::smooth;
+  smooth = BZDBCache::smooth;
   const bool fastRadar = ((BZDBCache::radarStyle == 1) ||
 			  (BZDBCache::radarStyle == 2)) && BZDBCache::zbuffer;
   const LocalPlayer *myTank = LocalPlayer::getMyTank();
@@ -538,8 +588,6 @@ void RadarRenderer::render(SceneRenderer& renderer, bool blank, bool observer)
     // draw the buildings
     renderObstacles(fastRadar, radarRange);
 
-    // antialiasing on for lines and points unless we're multisampling,
-    // in which case it's automatic and smoothing makes them look worse.
     if (smooth) {
       glEnable(GL_BLEND);
       glEnable(GL_LINE_SMOOTH);
@@ -594,48 +642,14 @@ void RadarRenderer::render(SceneRenderer& renderer, bool blank, bool observer)
       const float* position = player->getPosition();
 
       if (player->getFlag() != Flags::Null) {
-	glColor3fv(player->getFlag()->getColor());
+	glColor3fv(player->getFlag()->getRadarColor());
 	drawFlagOnTank(position);
       }
 
-      if (player->isPaused() || player->isNotResponding()) {
-	const float dimfactor = 0.4f;
-
-	const float *color;
-	if (myTank->getFlag() == Flags::Colorblindness) {
-	  color = Team::getRadarColor(RogueTeam);
-	} else {
-	  color = Team::getRadarColor(player->getTeam());
-	}
-
-	float dimmedcolor[3];
-	dimmedcolor[0] = color[0] * dimfactor;
-	dimmedcolor[1] = color[1] * dimfactor;
-	dimmedcolor[2] = color[2] * dimfactor;
-	glColor3fv(dimmedcolor);
-      } else {
-	glColor3fv(Team::getRadarColor(myTank->getFlag() ==
-			     Flags::Colorblindness ? RogueTeam : player->getTeam()));
-      }
-      // If this tank is hunted flash it on the radar
-      if (player->isHunted() && myTank->getFlag() != Flags::Colorblindness) {
-	if (flashTank.isOn()) {
-	  if (!toggleTank) {
-	    float flashcolor[3];
-	    flashcolor[0] = 0.0f;
-	    flashcolor[1] = 0.8f;
-	    flashcolor[2] = 0.9f;
-	    glColor3fv(flashcolor);
-	  }
-	} else {
-	  toggleTank = !toggleTank;
-	  flashTank.setClock(0.2f);
-	}
-      }
       if (!observer) {
-	drawTank(position, NULL);
+	drawTank(position, player, true);
       } else {
-	drawTank(position, player);
+	drawTank(position, player, false);
       }
     }
 
@@ -690,7 +704,7 @@ void RadarRenderer::render(SceneRenderer& renderer, bool blank, bool observer)
       }
       // Flags change color by height
       const float cs = colorScale(flag.position[2], muzzleHeight);
-      const float *flagcolor = flag.type->getColor();
+      const float *flagcolor = flag.type->getRadarColor();
       glColor3f(flagcolor[0] * cs, flagcolor[1] * cs, flagcolor[2] * cs);
       drawFlag(flag.position);
     }
@@ -731,13 +745,17 @@ void RadarRenderer::render(SceneRenderer& renderer, bool blank, bool observer)
 
       // my flag
       if (myTank->getFlag() != Flags::Null) {
-	glColor3fv(myTank->getFlag()->getColor());
+	glColor3fv(myTank->getFlag()->getRadarColor());
 	drawFlagOnTank(myPos);
       }
 
       // my tank
-      glColor3f(1.0f, 1.0f, 1.0f);
-      drawTank(myPos, myTank);
+      drawTank(myPos, myTank, false);
+
+      // re-setup the blending function
+      // (was changed by drawing jump jets)
+      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+      glPopMatrix();
     }
 
     if (dimming > 0.0f) {
@@ -1134,8 +1152,8 @@ void RadarRenderer::renderBasesAndTeles()
   int i;
 
   // draw team bases
-  if(world->allowTeamFlags()) {
-    for(i = 1; i < NumTeams; i++) {
+  if (world->allowTeamFlags()) {
+    for (i = 1; i < NumTeams; i++) {
       for (int j = 0;;j++) {
 	const float *base = world->getBase(i, j);
 	if (base == NULL)
@@ -1222,10 +1240,9 @@ int RadarRenderer::getFrameTriangleCount() const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
