@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -62,8 +62,10 @@ class RadarRenderer {
     RadarRenderer&	operator=(const RadarRenderer&);
 
     void		drawShot(const ShotPath*);
+    void		setTankColor(const class Player* player);
     void		drawTank(const float pos[3],
-				 const class Player* player);
+				 const class Player* player,
+				 bool useSquares);
     void		drawFancyTank(const class Player* player);
     void		drawFlag(const float pos[3]);
     void		drawFlagOnTank(const float pos[3]);
@@ -82,7 +84,6 @@ class RadarRenderer {
     GLfloat		teamColor[3];
     bool		smooth;
     bool		jammed;
-    bool		multiSampled;
     bool		useTankModels;
     bool		useTankDimensions;
     int			triangleCount;
@@ -116,10 +117,9 @@ inline int		RadarRenderer::getHeight() const
 #endif // BZF_RADAR_RENDERER_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
