@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,6 +41,9 @@ void			RemotePlayer::addShot(const FiringInfo& info)
   const float *f = getForward();
   RemoteShotPath* newShot = new RemoteShotPath(info);
   int shotNum = int(newShot->getShotId() & 255);
+
+  if (shotNum >= numShots)
+	  return;
   if (shots[shotNum]) delete shots[shotNum];
   shots[shotNum] = newShot;
   // Update tanks position and set dead reckoning for better lag handling
@@ -129,10 +132,9 @@ void			RemotePlayer::updateShots(float dt)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
