@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -139,7 +139,7 @@ void			RobotPlayer::doUpdate(float dt)
   bool	shoot   = false;
   const float azimuth = getAngle();
   // Allow shooting only if angle is near and timer has elapsed
-  if ((int)path.size() != 0 && timerForShot <= 0.0f) {
+  if ((!path.empty()) && timerForShot <= 0.0f) {
     float p1[3];
     getProjectedPosition(target, p1);
     const float* p2     = getPosition();
@@ -507,10 +507,9 @@ void			RobotPlayer::findPath(RegionPriorityQueue& queue,
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
