@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,7 +38,9 @@ typedef std::vector<std::string> NameList;
 
 extern int curMaxPlayers;
 extern RemotePlayer** remotePlayers;
+#ifdef ROBOT
 extern RobotPlayer* robots[MAX_ROBOTS];
+#endif
 extern int numRobots;
 
 extern NameList silencePlayers;
