@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -158,10 +158,12 @@ const GLfloat		SceneDatabaseBuilder::teleporterLightedModulateColors[3][4] = {
 
 SceneDatabaseBuilder::SceneDatabaseBuilder(const SceneRenderer* _renderer) :
 				renderer(_renderer),
-				wallMaterial(black, black, 0.0f),
-				boxMaterial(black, black, 0.0f),
-				pyramidMaterial(black, black, 0.0f),
-				teleporterMaterial(black, black, 0.0f)
+				wallMaterial(black, black, 0.0f), wallLOD(),
+				boxMaterial(black, black, 0.0f), boxLOD(),
+				pyramidMaterial(black, black, 0.0f), pyramidLOD(),
+				baseLOD(),
+				teleporterMaterial(black, black, 0.0f),
+				teleporterLOD()
 {
   // FIXME -- should get texture heights from resources
 
@@ -401,11 +403,11 @@ void SceneDatabaseBuilder::addBox(SceneDatabase* db, BoxBuilding& o)
     node->setLightedColor(boxLightedColors[part]);
     node->setLightedModulateColor(boxLightedModulateColors[part]);
     node->setMaterial(boxMaterial);
-    if (part < 4){
+    if (part < 4) {
       node->setTexture(boxTexture);
       node->setUseColorTexture(useColorTexture[0]);
     }
-    else{
+    else {
       node->setTexture(boxTopTexture);
       node->setUseColorTexture(useColorTexture[1]);
     }
@@ -535,7 +537,7 @@ void SceneDatabaseBuilder::addBase(SceneDatabase *db, BaseBuilding &o)
     useColorTexture[1] = baseTopTexture >= 0;
 
   // this assumes bases have 6 parts - if they don't, it still works
-  int part = 0;
+  unsigned int part = 0;
   // repeat the textue once for the top and bottom, else use the old messed up way
   // There are 3 cases for the texture ordering:
   // 1. getNextNode() only returns the top texture
@@ -546,15 +548,16 @@ void SceneDatabaseBuilder::addBase(SceneDatabase *db, BaseBuilding &o)
 							   o.getHeight(),
 							   boxLOD)))) {
     if ((part % 5) != 0) {
-      node->setColor(boxColors[part - 2]);
-      node->setModulateColor(boxModulateColors[part - 2]);
-      node->setLightedColor(boxLightedColors[part - 2]);
-      node->setLightedModulateColor(boxLightedModulateColors[part - 2]);
+      const unsigned int colorIndex = (part % 5) - 1;
+      node->setColor(boxColors[colorIndex]);
+      node->setModulateColor(boxModulateColors[colorIndex]);
+      node->setLightedColor(boxLightedColors[colorIndex]);
+      node->setLightedModulateColor(boxLightedModulateColors[colorIndex]);
       node->setMaterial(boxMaterial);
       node->setTexture(boxTexture);
       node->setUseColorTexture(useColorTexture[0]);
     }
-    else{
+    else {
       if (useColorTexture[1]) {  // only set the texture if we have one and are using it
 	node->setTexture(baseTopTexture);
 	node->setUseColorTexture(useColorTexture[1]);
@@ -662,10 +665,9 @@ void SceneDatabaseBuilder::addTeleporter(SceneDatabase* db,
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
