@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -101,7 +101,9 @@ SceneRenderer::SceneRenderer() :
 				useWireframeOn(false),
 				useHiddenLineOn(false),
 				panelOpacity(0.3f),
+				radarOpacity(0.3f),
 				radarSize(4),
+				panelHeight(4),
 				maxMotionFactor(5),
 				viewType(Normal),
 				inOrder(false),
@@ -136,7 +138,7 @@ void SceneRenderer::setWindow(MainWindow* _window) {
   window->getWindow()->makeCurrent();
   GLint bits;
   if (!BZDB.isSet("zbuffer")) {
-//	  glGetIntegerv(GL_DEPTH_BITS, &bits);
+//  glGetIntegerv(GL_DEPTH_BITS, &bits);
     BZDB.set("zbuffer", "1");
   }
   glGetIntegerv(GL_STENCIL_BITS, &bits);
@@ -252,8 +254,8 @@ void SceneRenderer::setQuality(int value)
 
   if (value < 0) {
     value = 0;
-  } else if (value > BZDB.eval("maxQuality")) {
-    value = (int)BZDB.eval("maxQuality");
+  } else if (value > BZDB.evalInt("maxQuality")) {
+    value = BZDB.evalInt("maxQuality");
   }
   if (useQualityValue != value) {
     rebuildTanks = true;
@@ -404,12 +406,24 @@ void SceneRenderer::setPanelOpacity(float opacity)
 }
 
 
+void SceneRenderer::setRadarOpacity(float opacity)
+{
+  radarOpacity = opacity;
+}
+
+
 float SceneRenderer::getPanelOpacity() const
 {
   return panelOpacity;
 }
 
 
+float SceneRenderer::getRadarOpacity() const
+{
+  return radarOpacity;
+}
+
+
 void SceneRenderer::setRadarSize(int size)
 {
   radarSize = size;
@@ -420,12 +434,28 @@ void SceneRenderer::setRadarSize(int size)
 }
 
 
+void SceneRenderer::setPanelHeight(int size)
+{
+  panelHeight = size;
+  notifyStyleChange();
+  if (window) {
+    window->getWindow()->callResizeCallbacks();
+  }
+}
+
+
 int SceneRenderer::getRadarSize() const
 {
   return radarSize;
 }
 
 
+int SceneRenderer::getPanelHeight() const
+{
+  return panelHeight;
+}
+
+
 void SceneRenderer::setMaxMotionFactor(int factor)
 {
   if (factor < -11)
@@ -503,11 +533,11 @@ void SceneRenderer::setBackground(BackgroundRenderer* br)
 void SceneRenderer::getGroundUV(const float p[2], float uv[2]) const
 {
   float repeat = 0.01f;
-    if (BZDB.isSet("groundTexRepeat"))
-      repeat = BZDB.eval("groundTexRepeat");
+  if (BZDB.isSet("groundTexRepeat"))
+    repeat = BZDB.eval("groundTexRepeat");
 
-    if (useQualityValue >= 3)
-      repeat = BZDB.eval("groundHighResTexRepeat");
+  if (useQualityValue >= 3)
+    repeat = BZDB.eval("groundHighResTexRepeat");
 
   uv[0] = repeat * p[0];
   uv[1] = repeat * p[1];
@@ -636,8 +666,8 @@ void SceneRenderer::setTimeOfDay(double julianDay)
 static int sortLights (const void* a, const void* b)
 {
   // the higher getImportance(), the closer it is to the beginning
-  const OpenGLLight* lightA = *((const OpenGLLight**) a);
-  const OpenGLLight* lightB = *((const OpenGLLight**) b);
+  const OpenGLLight* lightA = *((const OpenGLLight* const *) a);
+  const OpenGLLight* lightB = *((const OpenGLLight* const *) b);
   const float valA = lightA->getImportance();
   const float valB = lightB->getImportance();
 
@@ -1088,7 +1118,6 @@ void SceneRenderer::doRender()
 static bool setupMapFog()
 {
   RENDERER.setFogActive(false);
-  std::string fogModeStr;
   if (BZDB.get(StateDatabase::BZDB_FOGMODE) == "none")
   {
     glDisable(GL_FOG);
