@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -44,6 +44,7 @@ std::string ScoreboardRenderer::playerLabel("Player");
 const char* ScoreboardRenderer::sortLabels[] = {
   "[Score]",
   "[Normalized Score]",
+  "[Reverse Score]",
   "[Callsign]",
   "[Team Kills]",
   "[TK ratio]",
@@ -58,9 +59,11 @@ bool ScoreboardRenderer::alwaysShowTeamScore = 0;
 
 
 ScoreboardRenderer::ScoreboardRenderer() :
+				winX(),
+				winY(),
 				winWidth (0.0),
+				winHeight(),
 				dim(false),
-				huntIndicator(false),
 				huntPosition(0),
 				huntSelectEvent(false),
 				huntPositionEvent(0),
@@ -68,6 +71,18 @@ ScoreboardRenderer::ScoreboardRenderer() :
 	huntAddMode(false),
 	teamScoreYVal(0.0f),
 	roaming(false),
+	minorFontFace(),
+	minorFontSize(),
+	labelsFontFace(),
+	labelsFontSize(),
+	scoreLabelWidth(),
+	killsLabelWidth(),
+	teamScoreLabelWidth(),
+	teamCountLabelWidth(),
+	huntArrowWidth(),
+	huntPlusesWidth(),
+	huntedArrowWidth(),
+	tkWarnRatio(),
 	numHunted(0)
 {
   // initialize message color (white)
@@ -194,7 +209,7 @@ void ScoreboardRenderer::hudColor3fv(const GLfloat* c)
 
 
 
-void    ScoreboardRenderer::exitSelectState (void){
+void    ScoreboardRenderer::exitSelectState (void) {
   playLocalSound(SFX_HUNT_SELECT);
   if (numHunted > 0) {
     setHuntState(HUNT_ENABLED);
@@ -213,14 +228,14 @@ void ScoreboardRenderer::render(bool forceDisplay)
     fm.setOpacity(dimFactor);
   }
 
-  if (BZDB.isTrue("displayScore") || forceDisplay){
+  if (BZDB.isTrue("displayScore") || forceDisplay) {
     OpenGLGState::resetState();
     renderScoreboard();
   } else {
-    if (getHuntState() == HUNT_SELECTING){      // 'S' pressed while selecting ...
+    if (getHuntState() == HUNT_SELECTING) {	// 'S' pressed while selecting ...
       exitSelectState ();
     }
-    if (BZDB.isTrue("alwaysShowTeamScores") && World::getWorld()->allowTeams()){
+    if (BZDB.isTrue("alwaysShowTeamScores") && World::getWorld()->allowTeams()) {
       OpenGLGState::resetState();
       renderTeamScores(winWidth, winY,
 	    FontManager::instance().getStrHeight(minorFontFace, minorFontSize, " "));
@@ -235,8 +250,8 @@ void ScoreboardRenderer::render(bool forceDisplay)
 
 int ScoreboardRenderer::teamScoreCompare(const void* _c, const void* _d)
 {
-  Team* c = World::getWorld()->getTeams()+*(int*)_c;
-  Team* d = World::getWorld()->getTeams()+*(int*)_d;
+  Team* c = World::getWorld()->getTeams()+*(const int*)_c;
+  Team* d = World::getWorld()->getTeams()+*(const int*)_d;
   return (d->getWins()-d->getLosses()) - (c->getWins()-c->getLosses());
 }
 
@@ -292,7 +307,7 @@ void ScoreboardRenderer::setHuntState (int _huntState)
     return;
   if (_huntState != HUNT_SELECTING)
     huntAddMode = false;
-  if (_huntState==HUNT_NONE){
+  if (_huntState==HUNT_NONE) {
     clearHuntedTanks();
   } else if (_huntState==HUNT_SELECTING) {
     huntPosition = 0;
@@ -314,7 +329,7 @@ void ScoreboardRenderer::huntReset()
     numHunted = 0;
 }
 
-void ScoreboardRenderer::renderTeamScores (float x, float y, float dy){
+void ScoreboardRenderer::renderTeamScores (float x, float y, float dy) {
   // print teams sorted by score
   int teams[NumTeams];
   int teamCount = 0;
@@ -333,7 +348,7 @@ void ScoreboardRenderer::renderTeamScores (float x, float y, float dy){
   hudColor3fv(messageColor);
 
   label = bdl->getLocalString("Team Score");
-  xl = xn = x - teamScoreLabelWidth;
+  xl = xn = x - teamScoreLabelWidth - teamCountLabelWidth;
   fm.drawString(xl, y, 0, minorFontFace, minorFontSize, label);
 
   for (i = RedTeam; i < NumTeams; i++) {
@@ -346,10 +361,10 @@ void ScoreboardRenderer::renderTeamScores (float x, float y, float dy){
   y -= dy;
 
   char score[44];
-  for (i = 0 ; i < teamCount; i++){
+  for (i = 0 ; i < teamCount; i++) {
     Team& team = World::getWorld()->getTeam(teams[i]);
     sprintf(score, "%3d (%3d-%-3d) %3d", team.getWins() - team.getLosses(), team.getWins(), team.getLosses(), team.size);
-    hudColor3fv(Team::getRadarColor((TeamColor)teams[i]));
+    hudColor3fv(Team::getTankColor((TeamColor)teams[i]));
     fm.drawString(xn, y, 0, minorFontFace, minorFontSize, score);
     y -= dy;
   }
@@ -357,7 +372,7 @@ void ScoreboardRenderer::renderTeamScores (float x, float y, float dy){
 
 
 // not used yet - new feature coming
-void ScoreboardRenderer::renderCtfFlags (){
+void ScoreboardRenderer::renderCtfFlags () {
   int i;
   RemotePlayer* player;
   const int curMaxPlayers = World::getWorld()->getCurMaxPlayers();
@@ -378,11 +393,11 @@ void ScoreboardRenderer::renderCtfFlags (){
     if ((player = World::getWorld()->getPlayer(i))) {
       FlagType* flagd = player->getFlag();
       TeamColor teamIndex = player->getTeam();
-      if (flagd!=Flags::Null && flagd->flagTeam != NoTeam) {   // if player has team flag ...
-	std::string playerInfo = ColorStrings[flagd->flagTeam];
+      if (flagd!=Flags::Null && flagd->flagTeam != NoTeam) {	// if player has team flag ...
+	std::string playerInfo = Team::getAnsiCode(flagd->flagTeam);
 	snprintf(flagColor, 200, "%-12s", flagd->flagName.c_str());
 	playerInfo += flagColor;
-	playerInfo += ColorStrings[teamIndex];
+	playerInfo += Team::getAnsiCode(teamIndex);
 	playerInfo += player->getCallSign();
 
 	fm.drawString(x, y0, 0, minorFontFace, minorFontSize, playerInfo);
@@ -432,7 +447,7 @@ void ScoreboardRenderer::renderScoreboard(void)
   hudColor3fv(messageColor);
 
   std::string psLabel = bdl->getLocalString(playerLabel);
-  if (sortMode != SORT_SCORE){
+  if (sortMode != SORT_SCORE) {
     psLabel += "  ";
     psLabel += sortLabels[sortMode];
   }
@@ -445,7 +460,7 @@ void ScoreboardRenderer::renderScoreboard(void)
   // make room for the status marker
   const float xs = x3 - fm.getStrLength(minorFontFace, minorFontSize, "+|");
 
-  if (huntState == HUNT_SELECTING){
+  if (huntState == HUNT_SELECTING) {
     std::string huntStr = ColorStrings[YellowColor];
     huntStr += ColorStrings[PulsatingColor];
     huntStr += " *SEL*";
@@ -455,28 +470,34 @@ void ScoreboardRenderer::renderScoreboard(void)
   // grab the tk warning ratio
   tkWarnRatio = BZDB.eval("tkwarnratio");
 
-  if (huntState == HUNT_SELECTING){
-    if (numPlayers<1 || (numPlayers==1 && players[0]==myTank)){
+  if (huntState == HUNT_SELECTING) {
+    if (numPlayers<1 || (numPlayers==1 && players[0]==myTank)) {
       setHuntState (HUNT_NONE);
     } else {
-      if (players[huntPosition] == myTank){
+      if (players[huntPosition] == myTank) {
 	if (huntPositionEvent < 0)
 	  --huntPosition;
 	else
 	  ++huntPosition;
       }
-      if (huntPosition>=numPlayers)
-	huntPosition = 0;
-      if (huntPosition<0)
+      if (huntPosition>=numPlayers) {
+	  huntPosition = 0;
+	if (players[0] == myTank)
+	  huntPosition = 1;
+      }
+      if (huntPosition<0) {
 	huntPosition = numPlayers-1;
-      if (huntSelectEvent){	     // if 'fire' was pressed ...
+	if (players[huntPosition] == myTank)
+	  --huntPosition;
+      }
+      if (huntSelectEvent) {	// if 'fire' was pressed ...
 	if (!huntAddMode)
 	  clearHuntedTanks ();
-	if (huntAddMode && players[huntPosition]->isHunted()) {   // UNselect
+	if (huntAddMode && players[huntPosition]->isHunted()) {	// UNselect
 	      players[huntPosition]->setHunted(false);
 	  if (--numHunted != 0)
 		playLocalSound(SFX_HUNT_SELECT);
-	} else {						  // else select
+	} else {						// else select
 	      players[huntPosition]->setHunted(true);
 	  if (++numHunted == 1)
 		playLocalSound(SFX_HUNT);
@@ -504,7 +525,7 @@ void ScoreboardRenderer::renderScoreboard(void)
       if (player->isHunted()) {
 	++numHunted;
       }
-      if (player->getTeam()==ObserverTeam && !haveObs){
+      if (player->getTeam()==ObserverTeam && !haveObs) {
 	y -= dy;
 	haveObs = true;
       }
@@ -558,8 +579,18 @@ void ScoreboardRenderer::drawRoamTarget(float _x0, float _y0,
   const float x1 = floorf(_x1) + 0.5f;
   const float y1 = y0 + 1.0f;
 
-  const float black[4] = { 0.0f, 0.0f, 0.0f, 1.0f };
-  const float white[4] = { 1.0f, 1.0f, 1.0f, 1.0f };
+  const float black[4] = {
+      0.0f * (dim ? dimFactor : 1.0f),
+      0.0f * (dim ? dimFactor : 1.0f),
+      0.0f * (dim ? dimFactor : 1.0f),
+      1.0f
+    };
+  const float white[4] = {
+      1.0f * (dim ? dimFactor : 1.0f),
+      1.0f * (dim ? dimFactor : 1.0f),
+      1.0f * (dim ? dimFactor : 1.0f),
+      1.0f
+    };
   const float* c0 = black;
   const float* c1 = white;
 
@@ -616,20 +647,17 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
   if (LocalPlayer::getMyTank() != player) {
     sprintf(kills, "%3d~%-3d", player->getLocalWins(), player->getLocalLosses());
   } else {
-    kills[0] = '\0';
+    sprintf(kills, "%4d", player->getSelfKills());
   }
 
 
   // team color
   TeamColor teamIndex = player->getTeam();
-  if (teamIndex < RogueTeam) {
-    teamIndex = RogueTeam;
-  }
   std::string teamColor;
   if (player->getId() < 200) {
-    teamColor = ColorStrings[teamIndex];
+    teamColor = Team::getAnsiCode(teamIndex);
   } else {
-    teamColor = ColorStrings[CyanColor]; // replay observers
+    teamColor = ColorStrings[CyanColor];	// replay observers
   }
 
   // authentication status
@@ -646,7 +674,7 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
   } else if (player->isRegistered()) {
     statusInfo += '-';
   } else {
-    statusInfo = ""; // don't print
+    statusInfo = "";	// don't print
   }
 
   std::string playerInfo;
@@ -703,7 +731,7 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
 	      playerInfo += ColorStrings[WhiteColor];
       } else if (flagd->flagTeam != NoTeam) {
 	// use team color for team flags
-	playerInfo += ColorStrings[flagd->flagTeam];
+	playerInfo += Team::getAnsiCode(flagd->flagTeam);
       }
       coloredFlag = true;
     }
@@ -724,12 +752,14 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
     playerInfo += "[auto]";
 
 #if DEBUG_SHOWRATIOS
-  if (sortMode == SORT_NORMALIZED)
-    stringAppendNormalized (&playerInfo, player->getNormalizedScore());
-  else if (sortMode == SORT_MYRATIO)
-    stringAppendNormalized (&playerInfo, player->getLocalNormalizedScore());
-  else if (sortMode == SORT_TKRATIO)
-    stringAppendNormalized (&playerInfo, player->getTKRatio());
+  if (player->getTeam() != ObserverTeam) {
+    if (sortMode == SORT_NORMALIZED)
+      stringAppendNormalized (&playerInfo, player->getNormalizedScore());
+    else if (sortMode == SORT_MYRATIO && LocalPlayer::getMyTank() != player)
+      stringAppendNormalized (&playerInfo, player->getLocalNormalizedScore());
+    else if (sortMode == SORT_TKRATIO)
+      stringAppendNormalized (&playerInfo, player->getTKRatio());
+  }
 #endif
 
   FontManager &fm = FontManager::instance();
@@ -743,9 +773,9 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
 
   // draw
   if (player->getTeam() != ObserverTeam) {
-    hudColor3fv(Team::getRadarColor(teamIndex));
+    hudColor3fv(Team::getTankColor(teamIndex));
     fm.drawString(x1, y, 0, minorFontFace, minorFontSize, score);
-    hudColor3fv(Team::getRadarColor(teamIndex));
+    hudColor3fv(Team::getTankColor(teamIndex));
     fm.drawString(x2, y, 0, minorFontFace, minorFontSize, kills);
   }
   fm.drawString(x3, y, 0, minorFontFace, minorFontSize, playerInfo);
@@ -753,7 +783,7 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
     fm.drawString(xs, y, 0, minorFontFace, minorFontSize, statusInfo);
   }
   if (BZDB.isTrue("debugHud")) {
-    printf ("playerInfo: %s\n", playerInfo.c_str()); //FIXME
+    printf ("playerInfo: %s\n", playerInfo.c_str());	// FIXME
   }
 
   // draw huntEnabled status
@@ -783,10 +813,10 @@ void ScoreboardRenderer::drawPlayerScore(const Player* player,
 Player*   ScoreboardRenderer::getLeader(std::string *label) {
   int sortType=sortMode;
 
-  if (sortMode==SORT_CALLSIGN || sortMode==SORT_MYRATIO || sortMode==SORT_TEAM){
+  if (sortMode==SORT_CALLSIGN || sortMode==SORT_MYRATIO || sortMode==SORT_TEAM) {
     sortType = SORT_SCORE;
   }
-  if (label != NULL){
+  if (label != NULL) {
     if (sortMode==SORT_TKS)
       *label = "TK Leader ";
     else if (sortMode==SORT_TKRATIO)
@@ -823,16 +853,16 @@ typedef struct st_playersort sortEntry;
 
 int       ScoreboardRenderer::sortCompareCp(const void* _a, const void* _b)
 {
-  sortEntry *a = (sortEntry *)_a;
-  sortEntry *b = (sortEntry *)_b;
+  const sortEntry *a = (const sortEntry *)_a;
+  const sortEntry *b = (const sortEntry *)_b;
   return strcasecmp (a->cp, b->cp);
 }
 
 
 int       ScoreboardRenderer::sortCompareI2(const void* _a, const void* _b)
 {
-  const sortEntry *a = (sortEntry *)_a;
-  const sortEntry *b = (sortEntry *)_b;
+  const sortEntry *a = (const sortEntry *)_a;
+  const sortEntry *b = (const sortEntry *)_b;
   if (a->i1 != b->i1 ) {
     return b->i1 - a->i1;
   }
@@ -858,7 +888,7 @@ Player **  ScoreboardRenderer::newSortedList (int sortType, bool obsLast, int *_
 
   // fill the array with remote players
   for (i=0; i<curMaxPlayers-1; i++) {
-    if ((p = world->getPlayer(i))){
+    if ((p = world->getPlayer(i))) {
       if (obsLast && p->getTeam()==ObserverTeam)
 	sorter[curMaxPlayers - (++numObs)].player = p;
       else
@@ -872,10 +902,10 @@ Player **  ScoreboardRenderer::newSortedList (int sortType, bool obsLast, int *_
     sorter[numPlayers++].player = myTank;
 
   // sort players ...
-  if (numPlayers > 0){
-    for (i=0; i<numPlayers; i++){
+  if (numPlayers > 0) {
+    for (i=0; i<numPlayers; i++) {
       p = sorter[i].player;
-      switch (sortType){
+      switch (sortType) {
 	case SORT_TKS:
 	  sorter[i].i1 = p->getTeamKills();
 	  sorter[i].i2 = 0 - (int)(p->getNormalizedScore() * 100000);
@@ -908,6 +938,8 @@ Player **  ScoreboardRenderer::newSortedList (int sortType, bool obsLast, int *_
 	  else
 	    sorter[i].i1 = p->getScore();
 	  sorter[i].i2 = 0;
+	  if (sortType == SORT_REVERSE)
+	    sorter[i].i1 *= -1;
       }
     }
     if (sortType == SORT_CALLSIGN)
@@ -953,7 +985,7 @@ void ScoreboardRenderer::getPlayerList(std::vector<Player*>& players)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
