@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -26,7 +26,7 @@ const ServerCommandKey::Mode ServerCommandKey::nonAdminModes [6] = {LagStats, Id
 /* FIXME - note the important numModes and numNonAdminModes values inited here
  * when new commands are added, the indices need to be adjusted here.
  */
-ServerCommandKey::ServerCommandKey(): mode(LagStats), startIndex(-1), numModes(35), numNonAdminModes(6)
+ServerCommandKey::ServerCommandKey(): mode(LagStats), numModes(35), numNonAdminModes(6)
 {
   return;
 }
@@ -58,7 +58,7 @@ void			ServerCommandKey::init()
 
 void			ServerCommandKey::updatePrompt()
 {
-  std::string composePrompt, banPattern;
+  std::string composePrompt;
   // decide what should be on the composing prompt
 
   LocalPlayer *myTank = LocalPlayer::getMyTank();
@@ -67,7 +67,7 @@ void			ServerCommandKey::updatePrompt()
     return;
   }
   const Player * recipient = myTank->getRecipient();
-  if (mode >= Kick && mode <= Ghost) { // more complicated modes here
+  if (mode >= Kick && mode <= Removegroup) { // more complicated modes here
     if (recipient) {
 
       switch (mode) {
@@ -100,10 +100,6 @@ void			ServerCommandKey::updatePrompt()
 	composePrompt = composePrompt +  " -> " + recipient->getCallSign() + " :";
 	hud->setComposing(composePrompt, true);
 	break;
-      case Ghost: composePrompt = "Ghost player [enter your pass] ";
-	composePrompt = composePrompt +  " -> " + recipient->getCallSign() + " :";
-	hud->setComposing(composePrompt, true);
-	break;
       case Showgroup: composePrompt = "Show player's groups ";
 	composePrompt = composePrompt +  " -> " + recipient->getCallSign();
 	hud->setComposing(composePrompt, false);
@@ -129,9 +125,6 @@ void			ServerCommandKey::updatePrompt()
       case Removegroup: composePrompt = "Remove player from group :";
 	hud->setComposing(composePrompt, true);
 	break;
-      case Ghost: composePrompt = "Ghost :";
-	hud->setComposing(composePrompt, true);
-	break;
       case Showgroup: composePrompt = "Show players group :";
 	hud->setComposing(composePrompt, true);
 	break;
@@ -235,10 +228,10 @@ bool			ServerCommandKey::keyPress(const BzfKeyEvent& key)
 
   if (sendIt) {
     std::string message = hud->getComposeString();
-    std::string banPattern, sendMsg, displayMsg, name;
+    std::string sendMsg, displayMsg, name;
 
     const Player * troll = myTank->getRecipient();
-    if (mode >= Kick && mode <=Ghost){ // handle more complicated modes
+    if (mode >= Kick && mode <= Removegroup) { // handle more complicated modes
       if (troll) { // cases where we select recipient with keys
 
 	name = troll->getCallSign();
@@ -268,7 +261,7 @@ bool			ServerCommandKey::keyPress(const BzfKeyEvent& key)
 	   banPattern = makePattern(troll->id.serverHost);
 	   sendMsg="/ban " + banPattern;
 
-	   if (message != ""){ // add ban length if something is there
+	   if (message != "") { // add ban length if something is there
 	     sendMsg = sendMsg + " " + message;
 	   }
 	  */
@@ -282,10 +275,6 @@ bool			ServerCommandKey::keyPress(const BzfKeyEvent& key)
 	  sendMsg = "/removegroup";
 	  sendMsg = sendMsg + " \"" + name + "\"" +" " + message;
 	  break;
-	case Ghost:
-	  sendMsg = "/ghost";
-	  sendMsg = sendMsg + " \"" + name + "\"" +" " + message;
-	  break;
 	case Showgroup:
 	  sendMsg = "/showgroup";
 	  sendMsg = sendMsg + " \"" + name + "\"";
@@ -303,7 +292,6 @@ bool			ServerCommandKey::keyPress(const BzfKeyEvent& key)
 	case BanIp: sendMsg = "/ban"; break;
 	case Setgroup: sendMsg = "/setgroup"; break;
 	case Removegroup: sendMsg = "/removegroup"; break;
-	case Ghost: sendMsg = "/ghost"; break;
 	case Showgroup: sendMsg = "/showgroup"; break;
 	default: /* shouldn't happen */ break;
 	}
@@ -352,8 +340,8 @@ bool			ServerCommandKey::keyPress(const BzfKeyEvent& key)
       buf = nboPackUByte(buf, ServerPlayer);
 
       char messageBuffer[MessageLen];
-      memset(messageBuffer, 0, MessageLen);
-      strncpy(messageBuffer, sendMsg.c_str(), MessageLen);
+      strncpy(messageBuffer, sendMsg.c_str(), MessageLen - 1);
+      messageBuffer[MessageLen - 1] = '\0';
       buf = nboPackString(buf, messageBuffer, MessageLen);
       serverLink->send(MsgMessage, sizeof(messageMessage), messageMessage);
     }
@@ -434,3 +422,11 @@ bool			ServerCommandKey::keyRelease(const BzfKeyEvent& key)
   }
   return keyPress(key);
 }
+
+// Local Variables: ***
+// mode: C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
