@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -42,7 +42,6 @@ private:
     Showgroup,
     Setgroup,
     Removegroup,
-    Ghost,
     Unban,
     Banlist,
     Playerlist,
@@ -70,21 +69,17 @@ private:
   };
 
   Mode mode;
-  int startIndex;
   const int numModes;
   const int numNonAdminModes;
   static const Mode nonAdminModes[6];
-
-
 };
 
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
