@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -9,9 +9,6 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
-#if defined(_MSC_VER)
-  #pragma warning(disable: 4786)
-#endif
 
 // interface header
 #include "ServerLink.h"
@@ -70,7 +67,7 @@ TConnect conn;
 DWORD WINAPI ThreadConnect(LPVOID params)
 {
   TConnect *conn = (TConnect*)params;
-  if(connect(conn->query, conn->addr, conn->saddr) >= 0) {
+  if (connect(conn->query, conn->addr, conn->saddr) >= 0) {
     SetEvent(hConnected); // Connect successful
   }
   ExitThread(0);
@@ -90,7 +87,9 @@ ServerLink*		ServerLink::server = NULL;
 ServerLink::ServerLink(const Address& serverAddress, int port) :
 				state(SocketError),	// assume failure
 				fd(-1),			// assume failure
-				udpLength(0)
+				udpLength(0),
+				udpBufferPtr(),
+				ubuf()
 {
   int i;
 
@@ -180,8 +179,8 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
 
   hThread = CreateThread(NULL, 0, ThreadConnect, &conn, 0, &ThreadID);
   okay = (WaitForSingleObject(hConnected, 5000) == WAIT_OBJECT_0);
-  if(!okay)
-    TerminateThread(hThread ,1);
+  if (!okay)
+    TerminateThread(hThread, 1);
 
   // Do some cleanup
   CloseHandle(hConnected);
@@ -223,7 +222,7 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
   // loop calling select untill we read some data back.
   // its only 8 bytes so it better come back in one packet.
   int loopCount = 0;
-  while(!gotNetData) {
+  while (!gotNetData) {
     loopCount++;
     nfound = select(fdMax + 1, (fd_set*)&read_set, (fd_set*)&write_set, NULL, &timeout);
 
@@ -257,7 +256,7 @@ ServerLink::ServerLink(const Address& serverAddress, int port) :
 
   logDebugMessage(2,"CONNECT:connect loop count = %d\n",loopCount);
 
-  // if we got back less then the expected connect responce (BZFSXXXX)
+  // if we got back less than the expected connect response (BZFSXXXX)
   // then something went bad, and we are done.
   if (i < 8) {
     close(query);
@@ -360,13 +359,16 @@ ServerLink::~ServerLink()
   urecvfd = -1;
   ulinkup = false;
 
-// FIXME -- packet recording
-if (packetStream) {
-  long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
-  fwrite(&endPacket, sizeof(endPacket), 1, packetStream);
-  fwrite(&dt, sizeof(dt), 1, packetStream);
-  fclose(packetStream);
-}
+  // FIXME -- packet recording
+  if (packetStream) {
+    long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
+    size_t items_written = fwrite(&endPacket, sizeof(endPacket), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(&dt, sizeof(dt), 1, packetStream);
+    if (items_written != 1)
+      printError("Error writing on packetStream");
+    fclose(packetStream);
+  }
 
 #if defined(NETWORK_STATS)
   const float dt = float(TimeKeeper::getCurrent() - startTime);
@@ -473,12 +475,11 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
   if (state != Okay) return -1;
 
   if ((urecvfd >= 0) /* && ulinkup */) {
-    int n;
 
     if (!udpLength) {
       AddrLen recvlen = sizeof(urecvaddr);
-      n = recvfrom(urecvfd, ubuf, MaxPacketLen, 0, &urecvaddr,
-		   (socklen_t*) &recvlen);
+      int n = recvfrom(urecvfd, ubuf, MaxPacketLen, 0,
+		       &urecvaddr, (socklen_t*) &recvlen);
       if (n > 0) {
 	udpLength    = n;
 	udpBufferPtr = ubuf;
@@ -491,8 +492,8 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
 	udpLength = 0;
 	return -1;
       }
-      udpBufferPtr = (char *)nboUnpackUShort(udpBufferPtr, len);
-      udpBufferPtr = (char *)nboUnpackUShort(udpBufferPtr, code);
+      udpBufferPtr = (const char *)nboUnpackUShort(udpBufferPtr, len);
+      udpBufferPtr = (const char *)nboUnpackUShort(udpBufferPtr, code);
 //      if (code != MsgPlayerUpdateSmall && code != MsgPlayerUpdate && code != MsgGameTime)
 //	logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
       UDEBUG("<** UDP Packet Code %x Len %x\n",code, len);
@@ -557,12 +558,12 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
 #endif
 
   // unpack header and get message
-  void* buf = headerBuffer;
+  const void* buf = headerBuffer;
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
 
 //  logDebugMessage(1,"rcvd %s len %d\n",MsgStrings::strMsgCode(code),len);
-  if (len > MaxPacketLen)
+  if (len > MaxPacketLen - 4)
     return -1;
   if (len > 0)
     rlen = recv(fd, (char*)msg, int(len), 0);
@@ -591,14 +592,19 @@ int			ServerLink::read(uint16_t& code, uint16_t& len,
     if (tlen < int(len)) return -1;
   }
 
-// FIXME -- packet recording
-if (packetStream) {
-  long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
-  fwrite(&serverPacket, sizeof(serverPacket), 1, packetStream);
-  fwrite(&dt, sizeof(dt), 1, packetStream);
-  fwrite(headerBuffer, 4, 1, packetStream);
-  fwrite(msg, len, 1, packetStream);
-}
+  // FIXME -- packet recording
+  if (packetStream) {
+    long dt = (long)((TimeKeeper::getCurrent() - packetStartTime) * 10000.0f);
+    size_t items_written = fwrite(&serverPacket, sizeof(serverPacket), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(&dt, sizeof(dt), 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(headerBuffer, 4, 1, packetStream);
+    if (items_written == 1)
+      items_written = fwrite(msg, len, 1, packetStream);
+    if (items_written != 1)
+      printError("Error writing on packetStream");
+  }
   return 1;
 }
 
@@ -625,8 +631,8 @@ void			ServerLink::sendEnter(PlayerType type,
   send(MsgEnter, sizeof(msg), msg);
 }
 
-bool ServerLink::readEnter (std::string& reason,
-			    uint16_t& code, uint16_t& rejcode)
+bool ServerLink::readEnter(std::string& reason,
+			   uint16_t& code, uint16_t& rejcode)
 {
   // wait for response
   uint16_t len;
@@ -646,7 +652,7 @@ bool ServerLink::readEnter (std::string& reason,
       return false;
     }
     else if (code == MsgReject) {
-      void *buf;
+      const void *buf;
       char buffer[MessageLen];
       buf = nboUnpackUShort (msg, rejcode); // filler for now
       buf = nboUnpackString (buf, buffer, MessageLen);
@@ -705,7 +711,6 @@ void			ServerLink::sendKilled(const PlayerId& killer,
 }
 
 
-#ifndef BUILDING_BZADMIN
 void			ServerLink::sendPlayerUpdate(Player* player)
 {
   char msg[PlayerUpdatePLenMax];
@@ -725,7 +730,6 @@ void			ServerLink::sendPlayerUpdate(Player* player)
 
   send(code, len, msg);
 }
-#endif
 
 void			ServerLink::sendBeginShot(const FiringInfo& info)
 {
@@ -864,7 +868,7 @@ void			ServerLink::confirmIncomingUDP()
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
