@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -103,7 +103,7 @@ class RemoteShotPath : public ShotPath {
 
     void		update(float dt);
     void		update(const ShotUpdate& shot,
-				uint16_t code, void* msg);
+				uint16_t code, const void* msg);
 };
 
 //
