@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,17 +30,23 @@ public:
 
   HUDuiDefaultKey* getDefaultKey();
   void resize(int width, int height);
-  void execute(void);
-  void addStats(Player* player, std::vector<HUDuiControl*>& list);
+  void execute();
+  void dismiss();
+  void show();
+
+  void refresh();
 
   static int getFontFace();
 
 private:
 
+  void addStats(Player* player, std::vector<HUDuiControl*>& list);
   void createLabel(const std::string &str, std::vector<HUDuiControl*>& list);
 
+  int staticLabelCount;
   int rows;
   int columns;
+  bool visible;
 
 };
 
