@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,7 +41,7 @@ void ShotStrategy::sendUpdate(const FiringInfo&) const
   // do nothing by default -- normal shots don't need updates
 }
 
-void ShotStrategy::readUpdate(uint16_t, void*)
+void ShotStrategy::readUpdate(uint16_t, const void*)
 {
   // do nothing by default -- normal shots don't need updates
 }
