@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,7 +23,7 @@ Weapon::Weapon()
 }
 
 
-void* Weapon::unpack(void* buf)
+const void* Weapon::unpack(const void* buf)
 {
   uint16_t delayCount;
 
