@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -22,7 +22,7 @@
 class Weapon {
   public:
     Weapon();
-    void* unpack(void*);
+    const void* unpack(const void*);
 
   public:
     FlagType *type;
