@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -473,15 +473,13 @@ void WeatherRenderer::update(void)
 void WeatherRenderer::draw(const SceneRenderer& sr)
 {
   if (!_CULLING_RAIN) {
-    if (!raindrops.size())
+    if (raindrops.empty())
       return;
   } else {
     if (!rainCount)
       return;
   }
 
-  int visibleChunks = 0;
-
   glDisable(GL_CULL_FACE);
   glMatrixMode(GL_MODELVIEW);
   glColor4f(1, 1, 1, 1.0f);
@@ -514,7 +512,6 @@ void WeatherRenderer::draw(const SceneRenderer& sr)
 	// block the Extents copy constructor to avoid passing by value.
 	exts.set(itr->second.bbox.mins, itr->second.bbox.maxs);
 	if (testAxisBoxInFrustum(exts, frustum) != Outside) {
-	  visibleChunks++;
 	  std::vector<rain>::iterator dropItr = itr->second.drops.begin();
 	  while (dropItr != itr->second.drops.end()) {
 	    drawDrop(*dropItr, sr);
@@ -880,7 +877,7 @@ void WeatherRenderer::addDrop(rain& drop)
 }
 
 
-int WeatherRenderer::keyFromPos(float x, float y)
+int WeatherRenderer::keyFromPos(float x, float y) const
 {
   union {
     short pos[2];
@@ -919,10 +916,9 @@ bool WeatherRenderer::dbItemSet(const char *name)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
