@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -112,7 +112,7 @@ protected:
 	// some kinda culling
 	void addDrop(rain &drop);
 
-	int keyFromPos(float x, float y);
+	int keyFromPos(float x, float y) const;
 
 	float			gridSize;
 	float			keyFactor;
@@ -142,10 +142,9 @@ protected:
 #endif // BZF_WEATHER_RENDERER_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
