@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -54,10 +54,15 @@ World::World() :
   curMaxPlayers(0),
   maxShots(1),
   maxFlags(0),
+  shakeTimeout(),
+  shakeWins(),
   players(NULL),
   flags(NULL),
   flagNodes(NULL),
-  flagWarpNodes(NULL)
+  flagWarpNodes(NULL),
+  wind(),
+  oldFogEffect(),
+  oldUseDrawInfo()
 {
   worldWeapons = new WorldPlayer();
   waterLevel = -1.0f;
@@ -164,9 +169,11 @@ int World::getTeleporter(const Teleporter* teleporter, int face) const
 const Teleporter* World::getTeleporter(int source, int& face) const
 {
   const ObstacleList& teleporters = OBSTACLEMGR.getTeles();
-  assert(source >= 0 && source < (int)(2 * teleporters.size()));
-  face = (source & 1);
-  return ((const Teleporter*) teleporters[source / 2]);
+  if (source >= 0 && source < (int)(2 * teleporters.size())) {
+    face = (source & 1);
+    return ((const Teleporter*) teleporters[source / 2]);
+  }
+  return NULL;
 }
 
 
@@ -181,11 +188,11 @@ TeamColor		World::whoseBase(const float* pos) const
       float ny = pos[1] - it->p[1];
       float rx = (float) (cosf(atanf(ny / nx) - it->p[3]) * sqrt((ny * ny) + (nx * nx)));
       float ry = (float) (sinf(atanf(ny / nx) - it->p[3]) * sqrt((ny * ny) + (nx * nx)));
-      if(fabsf(rx) < it->p[4] &&
+      if (fabsf(rx) < it->p[4] &&
 	 fabsf(ry) < it->p[5]) {
 	float nz = it->p[2] + it->p[6];
 	float rz = pos[2] - nz;
-	if(fabsf(rz) < 0.1) { // epsilon kludge
+	if (fabsf(rz) < 0.1) { // epsilon kludge
 	  return TeamColor(i);
 	}
       }
@@ -269,8 +276,8 @@ static int compareObstacles(const void* a, const void* b)
   // - normal object come first (from lowest to highest)
   // - then come the mesh face (highest to lowest)
   // - and finally, the mesh objects (checkpoints really)
-  const Obstacle* obsA = *((const Obstacle**)a);
-  const Obstacle* obsB = *((const Obstacle**)b);
+  const Obstacle* obsA = *((const Obstacle* const *)a);
+  const Obstacle* obsB = *((const Obstacle* const *)b);
   const char* typeA = obsA->getType();
   const char* typeB = obsB->getType();
 
@@ -317,8 +324,8 @@ static int compareObstacles(const void* a, const void* b)
 
 static int compareHitNormal (const void* a, const void* b)
 {
-  const MeshFace* faceA = *((const MeshFace**) a);
-  const MeshFace* faceB = *((const MeshFace**) b);
+  const MeshFace* faceA = *((const MeshFace* const *) a);
+  const MeshFace* faceB = *((const MeshFace* const *) b);
 
   // Up Planes come first
   if (faceA->isUpPlane() && !faceB->isUpPlane()) {
@@ -396,7 +403,7 @@ const Obstacle* World::hitBuilding(const float* oldPos, float oldAngle,
 
   // check mesh faces
   for (/* do nothing */; i < olist->count; i++) {
-    const Obstacle* obs = olist->list[i];
+    Obstacle* obs = olist->list[i];
     const char* type = obs->getType();
     if (type == MeshObstacle::getClassName()) {
       break;
@@ -414,7 +421,7 @@ const Obstacle* World::hitBuilding(const float* oldPos, float oldAngle,
       }
       else {
 	// add the face to the hitlist
-	olist->list[hitCount] = (Obstacle*) obs;
+	olist->list[hitCount] = obs;
 	hitCount++;
 	// compute its dot product and stick it in the scratchPad
 	const float* p = face->getPlane();
@@ -537,7 +544,7 @@ void			World::makeMeshDrawMgrs()
   drawInfoArray = new MeshDrawInfo*[count];
   drawInfoCount = 0;
   for (unsigned int i = 0; i < count; i++) {
-    MeshDrawInfo* di = (MeshDrawInfo*) sourceMeshes[i]->getDrawInfo();
+    MeshDrawInfo* di = sourceMeshes[i]->getDrawInfo();
     if ((di != NULL) && !di->isCopy()) {
       MeshDrawMgr* dm = new MeshDrawMgr(di);
       di->setDrawMgr(dm);
@@ -669,6 +676,9 @@ void		World::makeLinkMaterial()
 
 void			World::initFlag(int index)
 {
+  // make sure the server has not sent us a bogus value.
+  if (index >= maxFlags || index < 0)
+    return;
   // set color of flag (opaque)
   const float* color = flags[index].type->getColor();
   flagNodes[index]->setColor(color[0], color[1], color[2]);
@@ -1144,7 +1154,7 @@ bool World::writeWorld(const std::string& filename, std::string& fullname)
 			   << weapon.pos[2] << std::endl;
       out << indent << "  rotation " << ((weapon.dir * 180.0) / M_PI) << std::endl;
       out << indent << "  initdelay " << weapon.initDelay << std::endl;
-      if (weapon.delay.size() > 0) {
+      if (!weapon.delay.empty()) {
 	out << indent << "  delay";
 	for (std::vector<float>::iterator dit = weapon.delay.begin();
 	     dit != weapon.delay.end(); ++dit) {
@@ -1167,7 +1177,7 @@ bool World::writeWorld(const std::string& filename, std::string& fullname)
       out << indent << "  size " << zone.size[0] << " " << zone.size[1] << " "
 		       << zone.size[2] << std::endl;
       out << indent << "  rotation " << ((zone.rot * 180.0) / M_PI) << std::endl;
-      if (zone.flags.size() > 0) {
+      if (!zone.flags.empty()) {
 	out << indent << "  flag";
 	std::vector<FlagType*>::iterator fit;
 	for (fit = zone.flags.begin(); fit != zone.flags.end(); ++fit) {
@@ -1175,7 +1185,7 @@ bool World::writeWorld(const std::string& filename, std::string& fullname)
 	}
 	out << std::endl;
       }
-      if (zone.teams.size() > 0) {
+      if (!zone.teams.empty()) {
 	out << indent << "  team";
 	std::vector<TeamColor>::iterator tit;
 	for (tit = zone.teams.begin(); tit != zone.teams.end(); ++tit) {
@@ -1183,7 +1193,7 @@ bool World::writeWorld(const std::string& filename, std::string& fullname)
 	}
 	out << std::endl;
       }
-      if (zone.safety.size() > 0) {
+      if (!zone.safety.empty()) {
 	out << indent << "  safety";
 	std::vector<TeamColor>::iterator sit;
 	for (sit = zone.safety.begin(); sit != zone.safety.end(); ++sit) {
