@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -55,7 +55,6 @@
 #include "KeyManager.h"
 #include "OSFile.h"
 #include "OpenGLGState.h"
-#include "ParseColor.h"
 #include "PlatformFactory.h"
 #include "Protocol.h"
 #include "ServerListCache.h"
@@ -120,22 +119,6 @@ int bail ( int returnCode )
 	return returnCode;
 }
 
-static void		setTeamColor(TeamColor team, const std::string& str)
-{
-  float color[4];
-  parseColorString(str, color);
-  // don't worry about alpha, Team::setColors() doesn't use it
-  Team::setColors(team, color, Team::getRadarColor(team));
-}
-
-static void		setRadarColor(TeamColor team, const std::string& str)
-{
-  float color[4];
-  parseColorString(str, color);
-  // don't worry about alpha, Team::setColors() doesn't use it
-  Team::setColors(team, Team::getTankColor(team), color);
-}
-
 static void		setVisual(BzfVisual* visual)
 {
   // sine qua non
@@ -160,12 +143,11 @@ static void		setVisual(BzfVisual* visual)
 #else
   visual->setStencil(1);
 #endif
-  if (BZDB.isTrue("multisample"))
-    visual->setMultisample(4);
 #ifdef USE_GL_STEREO
   if (BZDB.isSet("view") && BZDB.get("view") == configViewValues[1])
     visual->setStereo(true);
 #endif
+  visual->setVerticalSync(BZDB.evalInt("saveEnergy") == 2);
 }
 
 static void		usage()
@@ -175,10 +157,14 @@ static void		usage()
 	" [-config <configfile>]"
 	" [-configdir <config dir name>]"
 	" [-d | -debug]"
+#ifdef DEBUG
 	" [-date mm/dd/yyyy]"
+#endif
 	" [{-dir | -directory} <data-directory>]"
 	" [-e | -echo]"
 	" [-ea | -echoAnsi]"
+	" [-eyesep separation]"
+	" [-focal distance]"
 	" [-h | -help | --help]"
 	" [-latitude <latitude>] [-longitude <longitude>]"
 	" [-list <list-server-url>] [-nolist]"
@@ -194,7 +180,7 @@ static void		usage()
 	" [-v | -version | --version]"
 	" [-view {normal|stereo|stacked|three|anaglyph|interlaced}]"
 	" [-window <geometry-spec>]"
-	" [-zoom <zoom-factor>]"
+	" [-zbuffer {on|off}]"
 	" [callsign[:password]@]server[:port]\n\nExiting.", argv0);
   if (display != NULL) {
     delete display;
@@ -292,7 +278,7 @@ static void		parse(int argc, char** argv)
       BZDB.set("list", "");
     }
     else if (strcmp(argv[i], "-m") == 0 ||
-		strcmp(argv[i], "-mute") == 0) {
+	     strcmp(argv[i], "-mute") == 0) {
       noAudio = true;
     }
     else if (strcmp(argv[i], "-multisample") == 0) {
@@ -331,8 +317,8 @@ static void		parse(int argc, char** argv)
 	usage();
       }
     } else if (strcmp(argv[i], "-v") == 0 ||
-	     strcmp(argv[i], "-version") == 0 ||
-	     strcmp(argv[i], "--version") == 0) {
+	       strcmp(argv[i], "-version") == 0 ||
+	       strcmp(argv[i], "--version") == 0) {
       printFatalError("BZFlag client %s (protocol %s) http://BZFlag.org/\n%s",
 		getAppVersion(),
 		getProtocolVersion(),
@@ -385,15 +371,6 @@ static void		parse(int argc, char** argv)
       checkArgc(i, argc, argv[i]);
       BZDB.set("view", argv[i]);
     }
-    else if (strcmp(argv[i], "-zoom") == 0) {
-      checkArgc(i, argc, argv[i]);
-      const int zoom = atoi(argv[i]);
-      if (zoom < 1 || zoom > 8) {
-	printFatalError("Invalid argument for %s.", argv[i-1]);
-	usage();
-      }
-      BZDB.set("displayZoom", argv[i]);
-    }
     else if (strcmp(argv[i], "-zbuffer") == 0) {
       checkArgc(i, argc, argv[i]);
       if (strcmp(argv[i], "on") == 0) {
@@ -425,54 +402,87 @@ static void		parse(int argc, char** argv)
     }
     else if (argv[i][0] != '-') {
       if (i == (argc - 1)) {
-	// find the beginning of the server name, parse the callsign
-	char *serverName;
-	if ((serverName = strchr(argv[i], '@')) != NULL) {
-	  char *password;
-	  *serverName = '\0';
-	  if (strlen(argv[i]) >= sizeof(startupInfo.callsign)) {
-	    printFatalError("Callsign truncated.");
-	  }
-	  strncpy(startupInfo.callsign, argv[i],
-		  sizeof(startupInfo.callsign) - 1);
-	  startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-	  if ((password = strchr(startupInfo.callsign, ':')) != NULL) {
-	    *(strchr(startupInfo.callsign, ':')) = '\0';
-	    *password = '\0', ++password;
-	    if (strlen(argv[i]) >= sizeof(startupInfo.password)) {
-	      printFatalError("Password truncated.");
+	// argv[i] = username:password@server:port
+	// variables to store
+	std::string serverName, callsign, password;
+	int port;
+
+	// start splitting stuff
+	const std::string argument = std::string(argv[i]);
+	const size_t atSplit = argument.find("@");
+	const size_t portSplit = argument.rfind(":");
+	const size_t passSplit = argument.find(":");
+
+	if (atSplit != std::string::npos) { // we found an "@"
+	  if (portSplit != std::string::npos) { // we have a port
+	    serverName = argument.substr(atSplit + 1, portSplit - atSplit - 1);
+	    port = atoi(argument.substr(portSplit + 1, argument.length() - portSplit).c_str());
+
+	    if (port < 1 || port > 65535) { // invalid port
+	      printFatalError("Bad port, using default %d.", ServerPort);
+	      port = ServerPort;
 	    }
-	    strncpy(startupInfo.password, password,
-		    sizeof(startupInfo.password) - 1);
-	    startupInfo.password[sizeof(startupInfo.password) - 1] = '\0';
 	  }
-	  ++serverName;
+	  else { //we don't have a port
+	    serverName = argument.substr(atSplit + 1, argument.length() - atSplit);
+	    port = ServerPort;
+	  }
+
+	  if (portSplit != passSplit) { // there's a password to parse
+	    callsign = argument.substr(0, passSplit);
+	    password = argument.substr(passSplit + 1, atSplit - passSplit - 1);
+	  }
+	  else { // just a username
+	    callsign = argument.substr(0, atSplit);
+	    password = "";
+	  }
+
+	  // length checks and always truncate everything after the max length
+	  if (callsign.length() > sizeof(startupInfo.callsign)) {
+	    callsign.erase(sizeof(startupInfo.callsign) - 1, std::string::npos);
+	    printFatalError("Callsign truncated after %d characters.", sizeof(startupInfo.callsign));
+	  }
+	  if (password.length() > sizeof(startupInfo.password)) {
+	    password.erase(sizeof(startupInfo.password) - 1, std::string::npos);
+	    printFatalError("Password truncated after %d characters.", sizeof(startupInfo.password));
+	  }
+	  if (serverName.length() > sizeof(startupInfo.serverName)) {
+	    serverName.erase(sizeof(startupInfo.serverName) - 1, std::string::npos);
+	    printFatalError("Server name truncated after %d characters.", sizeof(startupInfo.serverName));
+	  }
+
+	  // assign variables with strcpy because char[] can't be assigned
+	  strcpy(startupInfo.callsign, callsign.c_str());
+	  strcpy(startupInfo.password, password.c_str());
+	  strcpy(startupInfo.serverName, serverName.c_str());
+	  startupInfo.serverPort = port;
 	}
-	else {
-	  serverName = argv[i];
+	else { // there is no callsign/password so only a destination
+	  if (portSplit != std::string::npos) { // we have a port
+	    serverName = argument.substr(atSplit + 1, portSplit - atSplit - 1);
+	    port = atoi(argument.substr(portSplit + 1, argument.length() - portSplit).c_str());
+
+	    if (port < 1 || port > 65535) { // invalid port
+	      printFatalError("Bad port, using default %d.", ServerPort);
+	      port = ServerPort;
+	    }
+	  }
+	  else { //we don't have a port
+	    serverName = argument.substr(atSplit + 1, argument.length() - atSplit);
+	    port = ServerPort;
+	  }
+
+	  // sanity check for length
+	  if (serverName.length() > sizeof(startupInfo.serverName)) {
+	    serverName.erase(sizeof(startupInfo.serverName) - 1, std::string::npos);
+	    printFatalError("Server name truncated after %d characters.", sizeof(startupInfo.serverName));
+	  }
+
+	  strcpy(startupInfo.serverName, serverName.c_str());
+	  startupInfo.serverPort = port;
 	}
 
-	// find the beginning of the port number, parse it
-	char *portNumber;
-	if ((portNumber = strchr(serverName, ':')) == NULL) {
-	  startupInfo.serverPort = ServerPort;  // use the default
-	}
-	else {
-	  *portNumber = '\0';
-	  ++portNumber;
-	  startupInfo.serverPort = atoi(portNumber);
-	  if (startupInfo.serverPort < 1 || startupInfo.serverPort > 65535) {
-	    startupInfo.serverPort = ServerPort;
-	    printFatalError("Bad port, using default %d.", startupInfo.serverPort);
-	  }
-	}
-	if (strlen(serverName) >= sizeof(startupInfo.serverName)) {
-	  printFatalError("Server name too long.  Ignoring.");
-	}
-	else {
-	  strcpy(startupInfo.serverName, serverName);
-	  startupInfo.autoConnect = true;
-	}
+	startupInfo.autoConnect = true; // automatically connect on start up
       }
       else {
 	printFatalError("Unexpected: %s. Server must go after all options.", argv[i]);
@@ -512,7 +522,6 @@ static void parseConfigName(int argc, char** argv)
     if (strcmp(argv[i], "-configdir") == 0) {
       checkArgc(i, argc, argv[i]);
       setCustomConfigDir(argv[i]);
-      alternateConfig += argv[i];
     }
   }
   for (int i = 1; i < argc; i++) {
@@ -571,8 +580,12 @@ void dumpResources()
 
   BZDB.set("panelopacity", TextUtils::format("%f", RENDERER.getPanelOpacity()));
 
+  BZDB.set("radaropacity", TextUtils::format("%f", RENDERER.getRadarOpacity()));
+
   BZDB.set("radarsize", TextUtils::format("%d", RENDERER.getRadarSize()));
 
+  BZDB.set("panelheight", TextUtils::format("%d", RENDERER.getPanelHeight()));
+
   BZDB.set("mouseboxsize", TextUtils::format("%d", RENDERER.getMaxMotionFactor()));
 
   // don't save these configurations
@@ -635,8 +648,8 @@ static void createCacheSignature ()
   cacheTagName += "CACHEDIR.TAG";
   std::ostream* cacheTag = FILEMGR.createDataOutStream(cacheTagName, true, true);
   if (cacheTag != NULL) {
-    cacheTag->write(cacheSignature, strlen(cacheSignature));
-    cacheTag->write(cacheComment, strlen(cacheComment));
+    cacheTag->write(cacheSignature, strlen(cacheSignature)); // Flawfinder: ignore
+    cacheTag->write(cacheComment, strlen(cacheComment)); // Flawfinder: ignore
   }
   delete cacheTag;
 
@@ -693,35 +706,6 @@ int			main(int argc, char** argv)
     exit(0);
   }
 
-#if defined(_WIN32)
-  {
-    /* write HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath with the
-     * current path.  this lets Xfire know that this bzflag.exe running from
-     * here really is bzflag, not some imposter.
-     * since it may be useful to someone else, it's not protected by USE_XFIRE
-     */
-
-    // get our path
-    char temppath[MAX_PATH], temppath2[MAX_PATH];
-    char tempdrive[10];
-    GetModuleFileName(NULL, temppath, MAX_PATH);
-    // strip filename/extension
-    _splitpath(temppath, tempdrive, temppath2, NULL, NULL);
-    _makepath(temppath, tempdrive, temppath2, NULL, NULL);
-
-    // write the registry key in question
-    HKEY key = NULL;
-    if (RegCreateKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
-	0, NULL, REG_OPTION_VOLATILE, KEY_ALL_ACCESS, NULL,
-	&key, NULL) == ERROR_SUCCESS) {
-      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)temppath,
-		   (DWORD)strlen(temppath));
-    }
-  }
-#endif
-
-  createCacheSignature();
-
   // initialize global objects and classes
   bzfsrand((unsigned int)time(0));
 
@@ -741,17 +725,6 @@ int			main(int argc, char** argv)
 
   Flags::init();
 
-  if (getenv("BZFLAGID")) {
-    BZDB.set("callsign", getenv("BZFLAGID"));
-    strncpy(startupInfo.callsign, getenv("BZFLAGID"),
-					sizeof(startupInfo.callsign) - 1);
-    startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-  } else if (getenv("BZID")) {
-    BZDB.set("callsign", getenv("BZID"));
-    strncpy(startupInfo.callsign, getenv("BZID"),
-					sizeof(startupInfo.callsign) - 1);
-    startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
-  }
   time_t timeNow;
   time(&timeNow);
   userTime = *localtime(&timeNow);
@@ -781,6 +754,9 @@ int			main(int argc, char** argv)
     }
   }
 
+  // Create the cache signature
+  createCacheSignature();
+
   if (startupInfo.hasConfiguration)
     ActionBinding::instance().getFromBindings();
   else
@@ -792,11 +768,13 @@ int			main(int argc, char** argv)
   // restore some configuration (command line overrides these)
   if (startupInfo.hasConfiguration) {
     if (BZDB.isSet("callsign")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.callsign, BZDB.get("callsign").c_str(),
 					sizeof(startupInfo.callsign) - 1);
       startupInfo.callsign[sizeof(startupInfo.callsign) - 1] = '\0';
     }
     if (BZDB.isSet("password")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.password, BZDB.get("password").c_str(),
 					sizeof(startupInfo.password) - 1);
       startupInfo.password[sizeof(startupInfo.password) - 1] = '\0';
@@ -807,6 +785,7 @@ int			main(int argc, char** argv)
       startupInfo.team = Team::getTeam(value);
     }
     if (BZDB.isSet("server")) {
+      // Flawfinder: ignore
       strncpy(startupInfo.serverName, BZDB.get("server").c_str(),
 					sizeof(startupInfo.serverName) - 1);
       startupInfo.serverName[sizeof(startupInfo.serverName) - 1] = '\0';
@@ -815,31 +794,6 @@ int			main(int argc, char** argv)
       startupInfo.serverPort = atoi(BZDB.get("port").c_str());
     }
 
-    // check for reassigned team colors
-    if (BZDB.isSet("roguecolor"))
-      setTeamColor(RogueTeam, BZDB.get("roguecolor"));
-    if (BZDB.isSet("redcolor"))
-      setTeamColor(RedTeam, BZDB.get("redcolor"));
-    if (BZDB.isSet("greencolor"))
-      setTeamColor(GreenTeam, BZDB.get("greencolor"));
-    if (BZDB.isSet("bluecolor"))
-      setTeamColor(BlueTeam, BZDB.get("bluecolor"));
-    if (BZDB.isSet("purplecolor"))
-      setTeamColor(PurpleTeam, BZDB.get("purplecolor"));
-
-    // check for reassigned radar colors
-    if (BZDB.isSet("rogueradar"))
-      setRadarColor(RogueTeam, BZDB.get("rogueradar"));
-    if (BZDB.isSet("redradar"))
-      setRadarColor(RedTeam, BZDB.get("redradar"));
-    if (BZDB.isSet("greenradar"))
-      setRadarColor(GreenTeam, BZDB.get("greenradar"));
-    if (BZDB.isSet("blueradar"))
-      setRadarColor(BlueTeam, BZDB.get("blueradar"));
-    if (BZDB.isSet("purpleradar"))
-      setRadarColor(PurpleTeam, BZDB.get("purpleradar"));
-
-
     // ignore window name in config file (it's used internally)
     BZDB.unset("_window");
     BZDB.unset("_multisample");
@@ -860,12 +814,13 @@ int			main(int argc, char** argv)
 #ifdef _WIN32
   // this is cheap but it will work on windows
   // clear out the stdout file
-  if (echoToConsole){
-	  FILE	*fp = fopen ("stdout.txt","w");
-	  if (fp) {
-		  fprintf(fp,"stdout started\r\n" );
-		  fclose(fp);
-	  }
+  if (echoToConsole) {
+    std::string filename = getConfigDirName() + "stdout.txt";
+    FILE *fp = fopen (filename.c_str(), "w");
+    if (fp) {
+      fprintf(fp,"stdout started\r\n" );
+      fclose(fp);
+    }
   }
 #endif
 
@@ -883,7 +838,9 @@ int			main(int argc, char** argv)
   if (BZDB.isSet("fixedTime")) {
     int hours, minutes, seconds;
     char dbTime[256];
+    // Flawfinder: ignore
     strncpy(dbTime, BZDB.get("fixedTime").c_str(), sizeof(dbTime) - 1);
+    dbTime[sizeof(dbTime) - 1] = '\0';
     if (sscanf(dbTime, "%d:%d:%d", &hours, &minutes, &seconds) != 3 ||
 	hours < 0 || hours > 23 ||
 	minutes < 0 || minutes > 59 ||
@@ -941,8 +898,12 @@ int			main(int argc, char** argv)
   // use empty motto string unless previously set
   std::string motto = BZDB.get("motto");
   motto = motto.substr(0, sizeof(startupInfo.motto) - 1);
+  //Flawfinder: ignore
   strcpy(startupInfo.motto, motto.c_str());
 
+  // load the default values for shot colors
+  Team::updateShotColors();
+
   // make platform factory
   PlatformFactory* platformFactory = PlatformFactory::getInstance();
 
@@ -965,11 +926,8 @@ int			main(int argc, char** argv)
   }
   window->setTitle("bzflag");
 
-  // create & initialize the joystick
+  // create the joystick
   BzfJoystick* joystick = platformFactory->createJoystick();
-  joystick->initJoystick(BZDB.get("joystickname").c_str());
-  joystick->setXAxis(BZDB.get("jsXAxis"));
-  joystick->setYAxis(BZDB.get("jsYAxis"));
 
   // Change audio driver if requested
   if (BZDB.isSet("audioDriver"))
@@ -1141,10 +1099,18 @@ int			main(int argc, char** argv)
       setSoundVolume(static_cast<int>(BZDB.eval("volume")));
   }
 
+  // Initialize the joystick
+  joystick->initJoystick(BZDB.get("joystickname").c_str());
+  joystick->setXAxis(BZDB.get("jsXAxis"));
+  joystick->setYAxis(BZDB.get("jsYAxis"));
+
   // set main window's minimum size (arbitrary but should be big enough
   // to see stuff in control panel)
   pmainWindow->setMinSize(256, 192);
 
+  // enable vsync if needed
+  pmainWindow->getWindow()->setVerticalSync(BZDB.evalInt("saveEnergy") == 2);
+
   // initialize graphics state
   pmainWindow->getWindow()->makeCurrent();
   glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
@@ -1173,7 +1139,7 @@ int			main(int argc, char** argv)
   // there's no sense in continuing.
   const char* const glRenderer = (const char*)glGetString(GL_RENDERER);
   if (!glRenderer) {
-    // bad code, no donut for you
+    // bad code, no doughnut for you
 
     GLenum error = GL_NO_ERROR;
     while ((error = glGetError()) != GL_NO_ERROR) {
@@ -1228,7 +1194,7 @@ int			main(int argc, char** argv)
   //add a fake cursor. Let the defaults file override this, though.
   if (!BZDB.isSet("fakecursor")) {
     // check that the glrenderer is Mesa Glide
-    if ((glRenderer != NULL) && (strncmp(glRenderer, "Mesa Glide", 10) == 0)){
+    if ((glRenderer != NULL) && (strncmp(glRenderer, "Mesa Glide", 10) == 0)) {
       BZDB.set("fakecursor", "1");
     }
   }
@@ -1282,9 +1248,15 @@ int			main(int argc, char** argv)
     if (BZDB.isSet("panelopacity"))
       RENDERER.setPanelOpacity(BZDB.eval("panelopacity"));
 
+    if (BZDB.isSet("radaropacity"))
+	  RENDERER.setRadarOpacity(BZDB.eval("radaropacity"));
+
     if (BZDB.isSet("radarsize"))
       RENDERER.setRadarSize(BZDB.getIntClamped("radarsize", 0, GUIOptionsMenu::maxRadarSize));
 
+    if (BZDB.isSet("panelheight"))
+      RENDERER.setPanelHeight(BZDB.getIntClamped("panelheight", 0, GUIOptionsMenu::maxRadarSize));
+
     if (BZDB.isSet("mouseboxsize"))
       RENDERER.setMaxMotionFactor(atoi(BZDB.get("mouseboxsize").c_str()));
   }
@@ -1381,18 +1353,6 @@ int			main(int argc, char** argv)
   delete bm;
   Flags::kill();
 
-#if defined(_WIN32)
-  {
-    /* clear HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath if it
-     * exists */
-    HKEY key = NULL;
-    if (RegOpenKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
-	0, KEY_ALL_ACCESS, &key) == ERROR_SUCCESS) {
-      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)"\0", 1);
-    }
-  }
-#endif
-
 #ifdef _WIN32
   // clean up
   WSACleanup();
