@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,6 +20,7 @@
 #endif
 #include <string>
 #include <vector>
+#include <cstdlib>
 
 /* common implementation headers */
 #include "BZDBCache.h"
@@ -178,36 +179,47 @@ static std::string cmdMouseGrab(const std::string&,
 static std::string cmdToggleFS(const std::string&,
 			       const CommandManager::ArgList& args, bool*);
 
+/** cycle to the next radar zoom level
+ */
+static std::string cmdCycleRadar(const std::string&,
+				  const CommandManager::ArgList& args, bool*);
+
+/** cycle to the next panel tab
+ */
+static std::string cmdCyclePanel(const std::string&,
+				  const CommandManager::ArgList& args, bool*);
+
 
 const struct CommandListItem commandList[] = {
-  { "fire",	&cmdFire,	"fire:  fire a shot" },
-  { "jump",	&cmdJump,	"jump:  make player jump" },
-  { "drop",	&cmdDrop,	"drop:  drop the current flag" },
-  { "identify",	&cmdIdentify,	"identify:  identify/lock-on-to player in view" },
-  { "restart",	&cmdRestart,	"restart:  restart playing" },
-  { "destruct", &cmdDestruct,	"destruct:  self destruct" },
-  { "pause",	&cmdPause,	"pause:  pause/resume" },
-  { "send",	&cmdSend,	"send {all|team|nemesis|recipient|admin}:  start composing a message" },
-  { "screenshot", &cmdScreenshot, "screenshot:  take a screenshot" },
-  { "time",	&cmdTime,	"time {forward|backward}:  adjust the current time" },
-  { "roam",	&cmdRoam,	"roam {zoom|cycle} <args>:  roam around" },
-  { "silence",	&cmdSilence,	"silence:  silence/unsilence a player" },
+  { "fire",		&cmdFire,		"fire:  fire a shot" },
+  { "jump",		&cmdJump,		"jump:  make player jump" },
+  { "drop",		&cmdDrop,		"drop:  drop the current flag" },
+  { "identify",		&cmdIdentify,		"identify:  identify/lock-on-to player in view" },
+  { "restart",		&cmdRestart,		"restart:  restart playing" },
+  { "destruct",		&cmdDestruct,		"destruct:  self destruct" },
+  { "pause",		&cmdPause,		"pause:  pause/resume" },
+  { "send",		&cmdSend,		"send {all|team|nemesis|recipient|admin}:  start composing a message" },
+  { "screenshot",	&cmdScreenshot,		"screenshot:  take a screenshot" },
+  { "time",		&cmdTime,		"time {forward|backward}:  adjust the current time" },
+  { "roam",		&cmdRoam,		"roam {zoom|cycle} <args>:  roam around" },
+  { "silence",		&cmdSilence,		"silence:  silence/unsilence a player" },
   { "servercommand",	&cmdServerCommand,	"servercommand:  quick admin" },
   { "scrollpanel",	&cmdScrollPanel,	"scrollpanel {up|down}:  scroll message panel" },
-  { "hunt",	&cmdHunt,	"hunt:  hunt a specific player" },
-  { "addhunt",	&cmdAddHunt,	"addhunt:  add/modify hunted player(s)" },
-  { "iconify",  &cmdIconify,	"iconify: iconify & pause bzflag" },
-  { "mousebox", &cmdMouseBox, "mousebox <size>:  change the mousebox size"},
-  { "mousegrab", &cmdMouseGrab, "mousegrab: toggle exclusive mouse mode" },
-  { "fullscreen", &cmdToggleFS, "fullscreen: toggle fullscreen mode" },
-  { "autopilot",&cmdAutoPilot,	"autopilot:  set/unset autopilot bot code" },
-  { "radarZoom", &cmdRadarZoom, "radarZoom {in/out}: change maxRadar range"},
-  { "viewZoom",  &cmdViewZoom,  "viewZoom {in/out/toggle}: change view angle"},
-  { "messagepanel", &cmdMessagePanel,
-    "messagepanel {all|chat|server|misc}:  set message tab" },
-  { "toggleRadar", &cmdToggleRadar, "toggleRadar:  toggle radar visibility"},
-  { "toggleConsole", &cmdToggleConsole, "toggleConsole:  toggle console visibility"},
-  { "toggleFlags", &cmdToggleFlags, "toggleFlags {main|radar}:  turn off/on field radar flags"}
+  { "hunt",		&cmdHunt,		"hunt:  hunt a specific player" },
+  { "addhunt",		&cmdAddHunt,		"addhunt:  add/modify hunted player(s)" },
+  { "iconify",		&cmdIconify,		"iconify: iconify & pause bzflag" },
+  { "mousebox",		&cmdMouseBox,		"mousebox <size>:  change the mousebox size"},
+  { "mousegrab",	&cmdMouseGrab,		"mousegrab: toggle exclusive mouse mode" },
+  { "fullscreen",	&cmdToggleFS,		"fullscreen: toggle fullscreen mode" },
+  { "autopilot",	&cmdAutoPilot,		"autopilot:  set/unset autopilot bot code" },
+  { "radarZoom",	&cmdRadarZoom,		"radarZoom {in/out}: change maxRadar range"},
+  { "viewZoom",		&cmdViewZoom,		"viewZoom {in/out/toggle}: change view angle" },
+  { "messagepanel",	&cmdMessagePanel,	"messagepanel {all|chat|server|misc}:  set message tab" },
+  { "toggleRadar",	&cmdToggleRadar,	"toggleRadar:  toggle radar visibility" },
+  { "toggleConsole",	&cmdToggleConsole,	"toggleConsole:  toggle console visibility" },
+  { "toggleFlags",	&cmdToggleFlags,	"toggleFlags {main|radar}:  turn off/on field radar flags" },
+  { "cycleRadar",	&cmdCycleRadar,		"cycleRadar {level1 [level2 ...] [off]}:  cycle to the next radar zoom level" },
+  { "cyclePanel",	&cmdCyclePanel,		"cyclePanel {left[_off]|right[_off]}:  cycle to the previous or next message panel tab" }
 };
 
 
@@ -255,7 +267,7 @@ static std::string cmdIconify(const std::string&,
     return "usage: iconify";
 
   if (!BZDB.isTrue("Win32NoMin"))
-	 mainWindow->iconify();
+    mainWindow->iconify();
   return std::string();
 }
 
@@ -470,13 +482,10 @@ static std::string cmdAutoPilot(const std::string&,
   if (!BZDB.isTrue(StateDatabase::BZDB_TANKWIDTH))
     return std::string();
 
-  if (BZDB.isTrue(StateDatabase::BZDB_DISABLEBOTS) && ! myTank->isAutoPilot()) {
-    hud->setAlert(0, "autopilot not allowed on this server", 1.0f, true);
+  if ((myTank == NULL) || (myTank->getTeam() == ObserverTeam))
     return std::string();
-  }
 
-  if (myTank != NULL && myTank->getTeam() != ObserverTeam) {
-    if (myTank->isAutoPilot()) {
+  if (myTank->isAutoPilot()) {
 
       myTank->activateAutoPilot(false);
       hud->setAlert(0, "autopilot disabled", 1.0f, true);
@@ -484,7 +493,9 @@ static std::string cmdAutoPilot(const std::string&,
       // grab mouse
       if (shouldGrabMouse()) mainWindow->grabMouse();
 
-    } else {
+  } else if (BZDB.isTrue(StateDatabase::BZDB_DISABLEBOTS)) {
+    hud->setAlert(0, "autopilot not allowed on this server", 1.0f, true);
+  } else {
 
       // don't enable the AutoPilot if you have within the last 5 secs
       static TimeKeeper LastAutoPilotEnable = TimeKeeper::getSunGenesisTime();
@@ -500,10 +511,8 @@ static std::string cmdAutoPilot(const std::string&,
 	mainWindow->ungrabMouse();
       } else {
 	controlPanel->addMessage("You may not enable the Autopilot more than once every five seconds.");
-	return std::string();
       }
 
-    }
   }
 
   return std::string();
@@ -618,7 +627,7 @@ static std::string cmdSend(const std::string&,
     buf = nboPackUByte(buf, AllPlayers);
     composePrompt = "Send to all: ";
   } else if (args[0] == "team") {
-    if (World::getWorld()->allowTeams())
+    if (World::getWorld()->allowTeams() || myTank->getTeam() == ObserverTeam)
     {
       void* buf = messageMessage;
       buf = nboPackUByte(buf, TeamToPlayerId(myTank->getTeam()));
@@ -659,7 +668,7 @@ static std::string cmdSend(const std::string&,
   } else if (args[0] == "admin") {
     void* buf = messageMessage;
     buf = nboPackUByte(buf, AdminPlayers);
-    composePrompt = "Send to Admin : ";
+    composePrompt = "Send to Admin: ";
 
   } else {
     return "usage: send {all|team|nemesis|recipient|admin}";
@@ -808,7 +817,12 @@ static std::string cmdScreenshot(const std::string&, const CommandManager::ArgLi
 
 #if defined(HAVE_PTHREADS)
   pthread_t thread;
-  pthread_create(&thread, NULL, writeScreenshot, (void *) ssdata);
+  pthread_attr_t attr;
+
+  pthread_attr_init(&attr);
+  pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
+  pthread_create(&thread, &attr, writeScreenshot, (void *) ssdata);
+  pthread_attr_destroy(&attr);
 #elif defined(_WIN32)
   CreateThread(
 	    NULL, // Security attributes
@@ -949,6 +963,8 @@ static std::string cmdScrollPanel(const std::string&,
     controlPanel->setMessagesOffset(123456789, 0 /* set */, false);
   } else if (args[0] == "bottom") {
     controlPanel->setMessagesOffset(0, 0 /* set */, false);
+  } else if (args[0] == "pause") {
+    controlPanel->togglePaused();
   }
   return std::string();
 }
@@ -959,7 +975,7 @@ static std::string cmdHunt(const std::string&,
 {
   if (args.size() != 0)
     return "usage: hunt";
-   hud->getScoreboard()->huntKeyEvent (false);
+  hud->getScoreboard()->huntKeyEvent (false);
   return std::string();
 }
 
@@ -968,7 +984,101 @@ static std::string cmdAddHunt(const std::string&,
 {
   if (args.size() != 0)
     return "usage: addhunt";
-   hud->getScoreboard()->huntKeyEvent (true);
+  hud->getScoreboard()->huntKeyEvent (true);
+  return std::string();
+}
+
+static std::string cmdCycleRadar(const std::string&,
+				  const CommandManager::ArgList& args, bool*)
+{
+  const std::string usageText = "usage: cycleRadar {level1 [level2 ...] [off]}:  cycle to the next radar zoom level";
+
+  if (args.size() == 0)
+    return usageText;
+
+  std::vector<float> radarLevels;
+
+  for (size_t i = 0; i < args.size(); ++i)
+    if (args[i] == "off")
+      radarLevels.push_back(0.0f);
+    else if (atof(args[i].c_str()) > 0.0f)
+      radarLevels.push_back((float)atof(args[i].c_str()));
+    else
+      return usageText;
+
+  if (radarLevels.size() == 0)
+    return usageText;
+
+  if (radarLevels.size() == 1) {
+    // only one specified... just set it
+    BZDB.set("displayRadar", radarLevels[0] > 0.0f ? "1" : "0");
+
+    if (radarLevels[0] > 0.0f)
+      BZDB.setFloat("displayRadarRange", radarLevels[0]);
+
+    return std::string();
+  }
+
+  static size_t radarLevelIndex = radarLevels.size() - 1;
+
+  // if it's off and the current level is some form of on, turn it back on and set it
+  if (BZDB.get("displayRadar") == "0" && radarLevels[radarLevelIndex] > 0.0f) {
+    BZDB.set("displayRadar", "1");
+    BZDB.setFloat("displayRadarRange", radarLevels[radarLevelIndex]);
+
+    return std::string();
+  }
+
+  ++radarLevelIndex;
+  if (radarLevelIndex >= radarLevels.size())
+    radarLevelIndex = 0;
+
+  if (radarLevels[radarLevelIndex] == 0.0f) {
+    BZDB.set("displayRadar", "0");
+  } else {
+    BZDB.setFloat("displayRadarRange", radarLevels[radarLevelIndex]);
+    BZDB.set("displayRadar", "1");
+  }
+
+  return std::string();
+}
+
+static std::string cmdCyclePanel(const std::string&,
+				  const CommandManager::ArgList& args, bool*)
+{
+  if (args.size() != 1)
+    return "usage: cyclePanel {left[_off]|right[_off]}\n";
+
+  bool forward = args[0] == "right" || args[0] == "right_off";
+  bool includeOff = args[0] == "left_off" || args[0] == "right_off";
+
+  if (! BZDB.isTrue("displayConsole")) {
+    if (forward && includeOff && controlPanel->getMessagesMode() == 3)
+      // reversed directions... put it back at beginning
+      controlPanel->setMessagesMode(0);
+    else if (! forward && includeOff && controlPanel->getMessagesMode() == 0)
+      // reversed directions... put it back at end
+      controlPanel->setMessagesMode(3);
+
+    BZDB.setBool("displayConsole", true);
+  } else {
+    if (controlPanel->getMessagesMode() == 0) {
+      controlPanel->setMessagesMode(forward ? 1 : 3);
+
+      if (! forward && includeOff)
+	BZDB.setBool("displayConsole", false);
+    } else if (controlPanel->getMessagesMode() == 1) {
+      controlPanel->setMessagesMode(forward ? 2 : 0);
+    } else if (controlPanel->getMessagesMode() == 2) {
+      controlPanel->setMessagesMode(forward ? 3 : 1);
+    } else {
+      controlPanel->setMessagesMode(forward ? 0 : 2);
+
+      if (forward && includeOff)
+	BZDB.setBool("displayConsole", false);
+    }
+  }
+
   return std::string();
 }
 
