@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,20 +10,11 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786)
-#endif
-
 // interface header
 #include "motd.h"
 
 // system headers
 #include <vector>
-#if defined(BUILD_REGEX)
-#  include "bzregex.h"
-#elif defined(HAVE_REGEX_H)
-#  include <regex.h>
-#endif
 
 // common implementation headers
 #include "TextUtils.h"
@@ -77,7 +68,7 @@ void MessageOfTheDay::finalization(char *_data, unsigned int length, bool good)
 	messages.push_back(msg);
       }
     }
-    if (messages.size() == 0) {
+    if (messages.empty()) {
       MOTD_message msg;
       msg.text = data;
       messages.push_back(msg);
@@ -92,7 +83,7 @@ void MessageOfTheDay::finalization(char *_data, unsigned int length, bool good)
   regex_t re;
 
   std::vector<std::string> msgs;
-  for (i = 0; i < messages.size(); ++i)
+  for (i = 0; i < messages.size(); ++i) {
     if (regcomp(&re, messages[i].version.c_str(), REG_EXTENDED | REG_ICASE) == 0) {
       if (regexec(&re, getAppVersion(), 0, NULL, 0) == 0) {
 	if (messages[i].title.substr(0, 9) == "UPGRADE: ") {
@@ -105,9 +96,9 @@ void MessageOfTheDay::finalization(char *_data, unsigned int length, bool good)
 	  msgs.push_back(messages[i].text);
 	}
       }
+      regfree(&re);
     }
-
-  regfree(&re);
+  }
   controlPanel->addMessage(ColorStrings[UnderlineColor]
 			   + ColorStrings[WhiteColor]
 			   + "Message of the day: ");
@@ -116,7 +107,7 @@ void MessageOfTheDay::finalization(char *_data, unsigned int length, bool good)
 }
 
 
-void MessageOfTheDay::getURL(const std::string URL)
+void MessageOfTheDay::getURL(const std::string &URL)
 {
   // get all up on the internet and go get the thing
   setURL(URL);
