@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -26,7 +26,7 @@ class MessageOfTheDay : cURLManager {
 public:
 
   virtual void finalization(char *data, unsigned int length, bool good);
-  void	 getURL(const std::string URL);
+  void	 getURL(const std::string &URL);
 };
 
 #endif //__MOTD_H__
