@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,7 +20,7 @@ class Authentication {
  public:
   Authentication();
 
-  bool isGlobal(void) {return globallyAuthenticated;};
+  bool isGlobal(void) const {return globallyAuthenticated;};
   void global(bool set) {globallyAuthenticated = set;}
 private:
   bool		   globallyAuthenticated;
@@ -29,7 +29,7 @@ private:
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
