@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,8 +30,8 @@ public:
   bool warning(std::string warningMsg, int line);
 
   /* status */
-  bool hasHadError() {return hadError;};
-  bool hasHadWarning() {return hadWarning;};
+  bool hasHadError() const {return hadError;};
+  bool hasHadWarning() const {return hadWarning;};
 
 private:
   /* data */
@@ -46,7 +46,7 @@ private:
 #endif //__BZWERROR_H__
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
