@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -237,14 +237,33 @@ bool MuteCommand::operator() (const char	 *message,
   // mute the player
   GameKeeper::Player *muteData = GameKeeper::Player::getPlayerByIndex(i);
   if (muteData) {
+
+    // don't mute players who are already muted
+    if (!muteData->accessInfo.hasPerm(PlayerAccessInfo::talk)) {
+      snprintf(msg, MessageLen, "player %s is already muted!",
+	     muteData->player.getCallSign());
+      sendMessage(ServerPlayer, t, msg);
+      return true;
+    }
+
     muteData->accessInfo.revokePerm(PlayerAccessInfo::talk);
-    snprintf(msg, MessageLen, "You have been muted by %s.",
-	     playerData->player.getCallSign());
+    snprintf(msg, MessageLen, "You have been muted");
     sendMessage(ServerPlayer, i, msg);
     // confirm player is muted
-    snprintf(msg, MessageLen, "player id #%d \"%s\" is now muted.", i,
-	     muteData->player.getCallSign());
-    sendMessage(ServerPlayer, t, msg);
+    snprintf(msg, MessageLen, "player id #%d \"%s\" has been muted by %s.", i,
+	     muteData->player.getCallSign(), playerData->player.getCallSign());
+    sendMessage(ServerPlayer, AdminPlayers, msg);
+    if (!playerData->accessInfo.hasPerm(PlayerAccessInfo::adminMessageReceive)) {
+      snprintf(msg, MessageLen, "player id #%d \"%s\" is now muted.", i,
+	       muteData->player.getCallSign());
+      sendMessage(ServerPlayer, t, msg);
+    }
+
+    bz_MuteEventData_V1 muteEventData;
+    muteEventData.victimID = i;
+    muteEventData.muterID = t;
+
+    worldEventManager.callEvents(bz_eMuteEvent, &muteEventData);
   }
   return true;
 }
@@ -281,14 +300,34 @@ bool UnmuteCommand::operator() (const char	 *message,
   // unmute the player
   GameKeeper::Player *unmuteData = GameKeeper::Player::getPlayerByIndex(i);
   if (unmuteData) {
+
+    // don't unmute players who can talk
+    if (unmuteData->accessInfo.hasPerm(PlayerAccessInfo::talk)) {
+      snprintf(msg, MessageLen, "player %s is not muted!",
+	     unmuteData->player.getCallSign());
+      sendMessage(ServerPlayer, t, msg);
+      return true;
+    }
+
     unmuteData->accessInfo.grantPerm(PlayerAccessInfo::talk);
-    snprintf(msg, MessageLen, "You have been unmuted by %s.",
-	     playerData->player.getCallSign());
+    snprintf(msg, MessageLen, "You have been unmuted");
     sendMessage(ServerPlayer, i, msg);
     // confirm player is unmuted
-    snprintf(msg, MessageLen, "player id #%d \"%s\" is now unmuted.", i,
-	     unmuteData->player.getCallSign());
-    sendMessage(ServerPlayer, t, msg);
+    snprintf(msg, MessageLen, "player id #%d \"%s\" has been unmuted by %s.", i,
+	    unmuteData->player.getCallSign(), playerData->player.getCallSign());
+    sendMessage(ServerPlayer, AdminPlayers, msg);
+    if (!playerData->accessInfo.hasPerm(PlayerAccessInfo::adminMessageReceive)) {
+      snprintf(msg, MessageLen, "player id #%d \"%s\" is now unmuted.", i,
+	       unmuteData->player.getCallSign());
+      sendMessage(ServerPlayer, t, msg);
+    }
+
+    bz_MuteEventData_V1 unmuteEventData;
+    unmuteEventData.eventType = bz_eUnmuteEvent;
+    unmuteEventData.victimID = i;
+    unmuteEventData.muterID = t;
+
+    worldEventManager.callEvents(bz_eUnmuteEvent, &unmuteEventData);
   }
   return true;
 }
@@ -375,11 +414,10 @@ bool KickCommand::operator() (const char	 *message,
       }
     }
 
-    snprintf(kickmessage, MessageLen, "You were kicked off the server by %s",
-	     playerData->player.getCallSign());
+    snprintf(kickmessage, MessageLen, "You were kicked off the server");
     sendMessage(ServerPlayer, kickEvent.kickedID, kickmessage);
     if (kickEvent.reason.size() > 0) {
-      snprintf(kickmessage, MessageLen, " reason given : %s",
+      snprintf(kickmessage, MessageLen, "Reason given: %s",
 	       kickEvent.reason.c_str());
       sendMessage(ServerPlayer, kickEvent.kickedID, kickmessage);
     }
@@ -462,11 +500,10 @@ bool KillCommand::operator() (const char	 *message,
       }
     }
 
-    snprintf(killmessage, MessageLen, "You were killed by %s",
-	     playerData->player.getCallSign());
+    snprintf(killmessage, MessageLen, "You were killed");
     sendMessage(ServerPlayer, killEvent.killedID, killmessage);
     if (killEvent.reason.size() > 0) {
-      snprintf(killmessage, MessageLen, " reason given : %s",
+      snprintf(killmessage, MessageLen, "Reason given : %s",
 	       killEvent.reason.c_str());
       sendMessage(ServerPlayer, killEvent.killedID, killmessage);
     }
@@ -598,9 +635,7 @@ static bool doBanKick(GameKeeper::Player *victim,
   }
 
   // send a notice to the victim
-  snprintf(buffer, MessageLen,
-	   "You were banned from this server by %s",
-	   banner->player.getCallSign());
+  snprintf(buffer, MessageLen, "You were banned from this server");
   sendMessage(ServerPlayer, victimID, buffer);
   if (strlen(reason) > 0) {
     snprintf(buffer, MessageLen, "Reason given: %s", reason);
@@ -662,7 +697,7 @@ bool BanCommand::operator() (const char	 *message,
     // valid slot or callsign
     victimPlayer = GameKeeper::Player::getPlayerByIndex(victim);
     if (victimPlayer) {
-      if (victimPlayer->accessInfo.hasPerm(PlayerAccessInfo::antiban)){
+      if (victimPlayer->accessInfo.hasPerm(PlayerAccessInfo::antiban)) {
 	char buffer[MessageLen];
 	snprintf(buffer, MessageLen,
 		 "%s is protected from being banned (skipped).",
@@ -1131,7 +1166,7 @@ bool MasterBanCommand::operator() (const char	 *message,
 		  TextUtils::format("There are %d bans, only displaying the "
 				    "first 20", bans.size()).c_str());
 
-    } else if (bans.size() == 0) {
+    } else if (bans.empty()) {
       sendMessage(ServerPlayer, t, "There are no master bans loaded.");
 
     } else {
@@ -1148,7 +1183,7 @@ bool MasterBanCommand::operator() (const char	 *message,
     // print out the bans
     int counter = 0;
     for (std::vector<std::pair<std::string, std::string> >::const_iterator j
-	   = bans.begin(); j != bans.end() && counter < 20; j++, counter++) {
+	   = bans.begin(); j != bans.end() && counter < 20; ++j, counter++) {
       sendMessage(ServerPlayer, t,
 		  TextUtils::format("%s: %s", (j->first).c_str(),
 				    (j->second).c_str()).c_str());
