@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
 /* this should be the only header necessary except for headers specific
  * to the class implementation (such as version.h)
  */
@@ -28,6 +24,7 @@
 #include "TextUtils.h"
 #include "BZDBCache.h"
 #include "BzMaterial.h"
+#include "ObstacleMgr.h"
 
 /* FIXME implementation specific header for global that should eventually go away */
 #include <vector>
@@ -145,6 +142,9 @@ const char *usageString =
 "[-tkannounce] "
 "[-tkkr <percent>] "
 "[-ts [micros]] "
+#ifdef HAVE_MINIUPNPC_MINIUPNPC_H
+"[-UPnP] "
+#endif
 "[-userdb <user permissions file>] "
 "[-utc] "
 "[-vars <filename>] "
@@ -255,6 +255,9 @@ const char *extraUsageString =
 "\t-tkkr: team-kills-to-wins percentage (1-100) for kicking tk-ing players\n"
 "\t-ts [micros]: timestamp all console output, [micros] to include\n"
 "\t\tmicroseconds\n"
+#ifdef HAVE_MINIUPNPC_MINIUPNPC_H
+"\t-UPnP: enable UPnP\n"
+#endif
 "\t-userdb: file to read for user access permissions\n"
 "\t-utc: timestamp console output in UTC instead of local time, implies -ts\n"
 "\t-vars: file to read for worlds configuration variables\n"
@@ -282,6 +285,7 @@ const char *extraUsageString =
 static std::vector<std::string> storedFlagDisallows;
 static std::vector<std::string> storedFlagCounts;
 static std::map<std::string, int> storedFlagLimits;
+static std::map<std::string, std::string> bzdbVarQueue;
 
 /* private */
 
@@ -490,12 +494,12 @@ static char **parseConfFile( const char *file, int &ac)
     exit(1);
   }
 
-  const char **av = new const char*[tokens.size()+1];
+  char **av = new char*[tokens.size()+1];
   av[0] = strdup("bzfs");
   ac = 1;
   for (std::vector<std::string>::iterator it = tokens.begin(); it != tokens.end(); ++it)
     av[ac++] = strdup((*it).c_str());
-  return (char **)av;
+  return av;
 }
 
 static char **parseWorldOptions (const char *file, int &ac)
@@ -609,14 +613,17 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       options.randomBoxes = true;
     }
     else if (strcmp(argv[i], "-badwords") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.filterFilename = argv[i];
     }
     else if (strcmp(argv[i], "-ban") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.acl.ban(argv[i]);
     }
     else if (strcmp(argv[i], "-banfile") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.acl.setBanFile(argv[i]);
       if (!options.acl.load()) {
@@ -633,10 +640,12 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       options.gameType = ClassicCTF;
     }
     else if (strcmp(argv[i], "-cache") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.cacheURL = argv[i];
     }
     else if (strcmp(argv[i], "-cacheout") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.cacheOut = argv[i];
     }
@@ -653,16 +662,18 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	free(av[j]);
       delete[] av;
       options.numAllowedFlags = 0;
-    } else if (strcmp(argv[i], "-cr") == 0)  {
+    }
+    else if (strcmp(argv[i], "-cr") == 0) {
       // CTF with random world
       options.randomCTF = true;
       // capture the flag style
-      if (options.gameType == RabbitChase)  {
+      if (options.gameType == RabbitChase) {
 	std::cerr << "Capture the flag incompatible with Rabbit Chase" << std::endl;
 	std::cerr << "Capture the flag assumed" << std::endl;
       }
       options.gameType = ClassicCTF;
-    } else if (strcmp(argv[i], "-density") ==0) {
+    }
+    else if (strcmp(argv[i], "-density") == 0) {
       if (i+1 != argc && isdigit(*argv[i+1])) {
 	options.citySize = atoi(argv[i+1]);
 	i++;
@@ -675,6 +686,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       BZDB.set(StateDatabase::BZDB_DISABLEBOTS, "true");
     }
     else if (strncmp(argv[i], "-d", 2) == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       // increase debug level - this must be the last
       // option beginning with -d so that -dd, -ddd, etc. work
       const char num = argv[i][2];
@@ -710,12 +722,15 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       options.flagsOnBuildings = true;
     }
     else if (strcmp(argv[i], "-filterCallsigns") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       options.filterCallsigns = true;
     }
     else if (strcmp(argv[i], "-filterChat") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       options.filterChat = true;
     }
     else if (strcmp(argv[i], "-filterSimple") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       options.filterSimple = true;
     }
     else if (strcmp(argv[i], "-g") == 0) {
@@ -729,9 +744,10 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       MATERIALMGR.addMaterial(&material);
     }
     else if (strcmp(argv[i], "-groupdb") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       groupsFile = argv[i];
-      std::cerr << "using group file \"" << argv[i] << "\"" << std::endl;
+      logDebugMessage(1,"using group file \"%s\"\n", argv[i]);
     }
     else if (strcmp(argv[i], "-h") == 0) {
       options.randomHeights = true;
@@ -740,14 +756,19 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       extraUsage(argv[0]);
     }
     else if (strcmp(argv[i], "-helpmsg") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(2, i, argc, argv[i]);
-      if (!options.textChunker.parseFile(argv[i], argv[i+1], 50, MessageLen)){
+      std::ifstream helpfile(argv[i]);
+      if (!helpfile)
+	std::cerr << "warning: helpmsg file \"" << argv[i] << "\" does not exist or can't be read" << std::endl;
+      else if (!options.textChunker.parseFile(argv[i], argv[i+1], 50, MessageLen)) {
 	std::cerr << "couldn't read helpmsg file \"" << argv[i] << "\"" << std::endl;
 	usage(argv[0]);
       }
       i++;
     }
     else if (strcmp(argv[i], "-i") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       // use a different interface
       checkArgc(1, i, argc, argv[i]);
       options.pingInterface = argv[i];
@@ -794,7 +815,8 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
     else if (strcmp(argv[i], "-maxidle") == 0) {
       checkArgc(1, i, argc, argv[i]);
       options.idlekickthresh = (float) atoi(argv[i]);
-	} else if (strcmp(argv[i], "-mp") == 0) {
+    }
+    else if (strcmp(argv[i], "-mp") == 0) {
       // set maximum number of players
       checkArgc(1, i, argc, argv[i]);
       if (playerCountArg == 0)
@@ -836,16 +858,18 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	options.maxTeamScore = 0;
       }
     }
-    else if (strcmp(argv[i],"-noMasterBanlist") == 0){
+    else if (strcmp(argv[i],"-noMasterBanlist") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       options.suppressMasterBanList = true;
     }
-    else if (strcmp(argv[i],"-noradar") == 0){
+    else if (strcmp(argv[i],"-noradar") == 0) {
       BZDB.set(StateDatabase::BZDB_RADARLIMIT, "-1.0");
     }
-    else if (strcmp(argv[i],"-masterBanURL") == 0){
+    else if (strcmp(argv[i],"-masterBanURL") == 0) {
       /* if this is the first master ban url, override the default
        * list.  otherwise just keep adding urls.
        */
+      checkFromWorldFile(argv[i], fromWorldFile);
       if (!options.masterBanListOverridden) {
 	options.masterBanListURL.clear();
 	options.masterBanListOverridden = true;
@@ -855,7 +879,10 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
     }
     else if (strcmp(argv[i], "-noTeamKills") == 0) {
       // disable team killing
-      options.gameOptions |= int(NoTeamKillsGameStyle);
+      if (options.gameType == OpenFFA)
+	std::cerr << "noteamkills check WARNING: -noTeamKills is incompatible with -offa, ignoring" << std::endl;
+      else
+	options.gameOptions |= int(NoTeamKillsGameStyle);
     }
     else if (strcmp(argv[i], "-p") == 0) {
       // use a different port
@@ -883,6 +910,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       memset(argv[i], 'X', options.password.size());
     }
     else if (strcmp(argv[i], "-pidfile") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       unsigned int pid = 0;
 	  checkArgc(1, i, argc, argv[i]);
       FILE *fp = fopen(argv[i], "wt");
@@ -895,10 +923,6 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	fprintf(fp, "%d", pid);
 	fclose(fp);
       }
-    }  else if (strcmp(argv[i], "-pf") == 0) {
-      // try wksPort first and if we can't open that port then
-      // let system assign a port for us.
-      options.useFallbackPort = true;
     }
     else if (strcmp(argv[i], "-poll") == 0) {
       // parse the variety of poll system variables
@@ -951,11 +975,11 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       /* if this is the first -publiclist, override the default list
        * server.  otherwise just keep adding urls.
        */
+      checkFromWorldFile(argv[i], fromWorldFile);
       if (!options.listServerOverridden) {
 	options.listServerURL.clear();
 	options.listServerOverridden = true;
       }
-      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.listServerURL.push_back(argv[i]);
     }
@@ -984,7 +1008,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       // rabbit chase style
       if (options.gameType == ClassicCTF) {
 	std::cerr << "Rabbit Chase incompatible with Capture the flag" << std::endl;
-	std::cerr << "Rabbit Chase assumed" << std::endl;;
+	std::cerr << "Rabbit Chase assumed" << std::endl;
       }
       options.gameType = RabbitChase;
       // default selection style
@@ -1006,25 +1030,31 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       }
     }
     else if (strcmp(argv[i], "-recbuf") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       Record::setSize (ServerPlayer, atoi(argv[i]));
       options.startRecording = true;
     }
     else if (strcmp(argv[i], "-recbufonly") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       Record::setAllowFileRecs (false);
     }
     else if (strcmp(argv[i], "-recdir") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       Record::setDirectory (argv[i]);
     }
     else if (strcmp(argv[i], "-replay") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       options.replayServer = true;
     }
     else if (strcmp(argv[i], "-reportfile") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.reportFile = argv[i];
     }
     else if (strcmp(argv[i], "-reportpipe") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       options.reportPipe = argv[i];
     }
@@ -1055,14 +1085,19 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       const char *name, *value;
       checkArgc(2, i, argc, argv[i]);
       name = argv[i];
-      if (!BZDB.isSet(name)) {
-	std::cerr << "Unknown BZDB variable: " << name << std::endl;
-	exit (1);
-      }
       i++;
       value = argv[i];
+
+      // give unknown BZDB variables the benefit of the doubt, allow plug-ins to define them
+      if (!BZDB.isSet(name)) {
+        bzdbVarQueue[name] = value;
+        logDebugMessage(1, "queued variable: %s = %s\n", name, value);
+
+        continue;
+      }
+
       BZDB.set(name, value);
-      logDebugMessage(1,"set variable: %s = %s\n", name, BZDB.get(name).c_str());
+      logDebugMessage(1, "set variable: %s = %s\n", name, BZDB.get(name).c_str());
     }
     else if (strcmp(argv[i], "-setforced") == 0) {
       const char *name, *value;
@@ -1070,17 +1105,18 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       name = argv[i];
       i++;
       value = argv[i];
+
       BZDB.set(name, value);
-      logDebugMessage(1,"set variable: %s = %s\n", name, BZDB.get(name).c_str());
+      logDebugMessage(1, "set variable: %s = %s\n", name, BZDB.get(name).c_str());
     }
     else if (strcmp(argv[i], "-sl") == 0) {
       // shot limits
       checkArgc(2, i, argc, argv[i]);
       i++; // move past the flag descriptor for now (we'll store it in a bit)
       int x = 1;
-      if (isdigit(argv[i][0])){
+      if (isdigit(argv[i][0])) {
 	x = atoi(argv[i]);
-	if (x < 1){
+	if (x < 1) {
 	  std::cerr << "can only limit to 1 or more shots, changing to 1" << std::endl;
 	  x = 1;
 	}
@@ -1089,20 +1125,21 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	usage(argv[0]);
       }
       storedFlagLimits[argv[i-1]] = x;
-    } else if (strcmp(argv[i], "-spamtime") == 0) {
+    }
+    else if (strcmp(argv[i], "-spamtime") == 0) {
       checkArgc(1, i, argc, argv[i]);
       options.msgTimer = atoi(argv[i]);
-      std::cerr << "using spam time of " << options.msgTimer << "\n";
+      logDebugMessage(1,"using spam time of %d seconds\n", options.msgTimer);
     }
     else if (strcmp(argv[i], "-spamwarn") == 0) {
       checkArgc(1, i, argc, argv[i]);
       options.spamWarnMax = atoi(argv[i]);
-      std::cerr << "using spam warn amount of " << options.spamWarnMax << "\n";
+      logDebugMessage(1,"using spam warn threshold of %d\n", options.spamWarnMax);
     }
     else if (strcmp(argv[i], "-speedtol") == 0) {
       checkArgc(1, i, argc, argv[i]);
       speedTolerance = (float) atof(argv[i]);
-      std::cerr << "using speed autokick tolerance of \"" << speedTolerance << "\"" << std::endl;
+      logDebugMessage(1,"using speed autokick tolerance of \"%f\"\n", speedTolerance);
     }
     else if (strcmp(argv[i], "-srvmsg") == 0) {
       checkArgc(1, i, argc, argv[i]);
@@ -1161,6 +1198,10 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	std::cerr << "Open (Teamless) Free-for-all incompatible with other modes" << std::endl;
 	std::cerr << "Open Free-for-all assumed" << std::endl;
       }
+      if ((options.gameOptions & int(NoTeamKillsGameStyle)) != 0) {
+	std::cerr << "offa check WARNING: -noTeamKills is incompatible with -offa, ignoring" << std::endl;
+	options.gameOptions ^= int(NoTeamKillsGameStyle);
+      }
       options.gameType = OpenFFA;
     }
     else if (strcmp(argv[i], "-tftimeout") == 0) {
@@ -1169,7 +1210,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       options.teamFlagTimeout = atoi(argv[i]);
       if (options.teamFlagTimeout < 0)
 	options.teamFlagTimeout = 0;
-      std::cerr << "using team flag timeout of " << options.teamFlagTimeout << " seconds" << std::endl;
+      logDebugMessage(1,"using team flag timeout of %d seconds\n", options.teamFlagTimeout);
     }
     else if (strcmp(argv[i], "-time") == 0) {
       checkArgc(1, i, argc, argv[i]);
@@ -1215,7 +1256,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	// league matches are 30 min
 	options.timeLimit = 1800.0f;
       }
-      std::cerr << "using time limit of " << (int)options.timeLimit << " seconds" << std::endl;
+      logDebugMessage(1,"using time limit of %d seconds\n", (int)options.timeLimit);
     }
     else if (strcmp(argv[i], "-timemanual") == 0) {
       options.timeManualStart = true;
@@ -1233,6 +1274,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
       }
     }
     else if (strcmp(argv[i], "-ts") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       // timestamp output
       options.timestampLog = true;
       // if there is an argument following, see if it is 'micros'
@@ -1243,15 +1285,24 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
 	}
       }
     }
+#ifdef HAVE_MINIUPNPC_MINIUPNPC_H
+    else if (strcmp(argv[i], "-UPnP") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
+      // timestamp output
+      options.UPnP = true;
+    }
+#endif
     else if (strcmp(argv[i], "-utc") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       // timestamp output
       options.timestampLog = true;
       options.timestampUTC = true;
     }
     else if (strcmp(argv[i], "-userdb") == 0) {
+      checkFromWorldFile(argv[i], fromWorldFile);
       checkArgc(1, i, argc, argv[i]);
       userDatabaseFile = argv[i];
-      std::cerr << "using userDB file \"" << argv[i] << "\"" << std::endl;
+      logDebugMessage(1,"using userDB file \"%s\"\n", argv[i]);
     }
     else if (strcmp(argv[i], "-v") == 0 || strcmp(argv[i], "-version") == 0) {
       printVersion();
@@ -1282,7 +1333,7 @@ void parse(int argc, char **argv, CmdLineOptions &options, bool fromWorldFile)
     else if (strcmp(argv[i], "-worldsize") == 0) {
       checkArgc(1, i, argc, argv[i]);
       BZDB.set(StateDatabase::BZDB_WORLDSIZE, TextUtils::format("%d",atoi(argv[i])*2));
-      std::cerr << "using world size of \"" << BZDBCache::worldSize << "\"" << std::endl;
+      logDebugMessage(1,"using world size of \"%f\"\n", (float)BZDBCache::worldSize);
     }
     else if (strcmp(argv[i], "-ws") == 0) {
       checkArgc(1, i, argc, argv[i]);
@@ -1322,7 +1373,7 @@ static int getZoneTeamFlagCount(FlagType* flagType, EntryZones& entryZones,
   for (int z = 0; z < (int)zl.size(); z++) {
     const ZoneFlagMap& zfm = zl[z].getZoneFlagMap();
     ZoneFlagMap::const_iterator zfmIt;
-    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); zfmIt++) {
+    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); ++zfmIt) {
       if (zfmIt->first == flagType) {
 	count += zfmIt->second;
       }
@@ -1344,7 +1395,7 @@ static int addZoneTeamFlags(int startIndex,
   for (int z = 0; z < (int)zl.size(); z++) {
     const ZoneFlagMap& zfm = zl[z].getZoneFlagMap();
     ZoneFlagMap::const_iterator zfmIt;
-    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); zfmIt++) {
+    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); ++zfmIt) {
       if (zfmIt->first == flagType) {
 	const int count = zfmIt->second;
 	for (int c = 0; c < count; c++) {
@@ -1361,12 +1412,24 @@ static int addZoneTeamFlags(int startIndex,
 void finalizeParsing(int UNUSED(argc), char **argv,
 		     CmdLineOptions &options, EntryZones& entryZones)
 {
+  // set queued BZDB variables; allow plugins to define valid BZDB variables
+  for (auto it = bzdbVarQueue.begin(); it != bzdbVarQueue.end(); it++) {
+    if (!BZDB.isSet(it->first)) {
+      std::cerr << "Unknown BZDB variable: " << it->first << std::endl;
+      exit(1);
+    }
+
+    BZDB.set(it->first, it->second);
+    BZDB.setDefault(it->first, it->second);
+    logDebugMessage(1, "queued variable set: %s = %s\n", it->first.c_str(), BZDB.get(it->first).c_str());
+  }
+
   if (options.flagsOnBuildings && !(options.gameOptions & JumpingGameStyle)) {
     std::cerr << "flags on boxes requires jumping" << std::endl;
     usage(argv[0]);
   }
 
-   if (options.gameType == RabbitChase) {
+  if (options.gameType == RabbitChase) {
     for (int j = RedTeam; j <= PurpleTeam; j++) {
       if (options.maxTeam[j] > 0
 	  && options.maxTeam[RogueTeam] != maxRealPlayers)
@@ -1374,6 +1437,11 @@ void finalizeParsing(int UNUSED(argc), char **argv,
 		  << Team::getName((TeamColor) j) << std::endl;
       options.maxTeam[j] = 0;
     }
+    options.maxTeam[RabbitTeam] = 1;
+    options.maxTeam[HunterTeam] = options.maxTeam[RogueTeam];
+  } else {
+    options.maxTeam[RabbitTeam] = 0;
+    options.maxTeam[HunterTeam] = 0;
   }
 
   // disallowed flags
@@ -1381,11 +1449,11 @@ void finalizeParsing(int UNUSED(argc), char **argv,
   for (vsitr = storedFlagDisallows.begin(); vsitr != storedFlagDisallows.end(); ++vsitr) {
     if (strcmp(vsitr->c_str(), "bad") == 0) {
       FlagSet badFlags = Flag::getBadFlags();
-      for (FlagSet::iterator it = badFlags.begin(); it != badFlags.end(); it++)
+      for (FlagSet::iterator it = badFlags.begin(); it != badFlags.end(); ++it)
 	options.flagDisallowed[*it] = true;
     } else if (strcmp(vsitr->c_str(), "good") == 0) {
       FlagSet goodFlags = Flag::getGoodFlags();
-      for (FlagSet::iterator it = goodFlags.begin(); it != goodFlags.end(); it++)
+      for (FlagSet::iterator it = goodFlags.begin(); it != goodFlags.end(); ++it)
 	options.flagDisallowed[*it] = true;
     } else {
       FlagType* fDesc = Flag::getDescFromAbbreviation(vsitr->c_str());
@@ -1410,11 +1478,11 @@ void finalizeParsing(int UNUSED(argc), char **argv,
     }
     if (strcmp(vsitr->c_str(), "good") == 0) {
       FlagSet goodFlags = Flag::getGoodFlags();
-      for (FlagSet::iterator it = goodFlags.begin(); it != goodFlags.end(); it++)
+      for (FlagSet::iterator it = goodFlags.begin(); it != goodFlags.end(); ++it)
 	options.flagCount[*it] += rptCnt;
     } else if (strcmp(vsitr->c_str(), "bad") == 0) {
       FlagSet badFlags = Flag::getBadFlags();
-      for (FlagSet::iterator it = badFlags.begin(); it != badFlags.end(); it++)
+      for (FlagSet::iterator it = badFlags.begin(); it != badFlags.end(); ++it)
 	options.flagCount[*it] += rptCnt;
     } else if (strcmp(vsitr->c_str(), "team") == 0) {
       for (int t = RedTeam; t <= PurpleTeam; t++)
@@ -1466,7 +1534,7 @@ void finalizeParsing(int UNUSED(argc), char **argv,
   if (options.gameOptions & RicochetGameStyle) {
     forbidden.insert(Flags::Ricochet);
   }
-  if (!options.useTeleporters && (options.worldFile == "")) {
+  if (OBSTACLEMGR.getTeles().size() == 0) {
     forbidden.insert(Flags::PhantomZone);
   }
   if (!hasTeam) {
@@ -1495,7 +1563,7 @@ void finalizeParsing(int UNUSED(argc), char **argv,
 
   // void the forbidden flags
   std::set<FlagType*>::const_iterator sit;
-  for (sit = forbidden.begin(); sit != forbidden.end(); sit++) {
+  for (sit = forbidden.begin(); sit != forbidden.end(); ++sit) {
     FlagType* ft = *sit;
     options.flagCount[ft] = 0;
     options.flagDisallowed[ft] = true;
@@ -1572,7 +1640,7 @@ void finalizeParsing(int UNUSED(argc), char **argv,
     const CustomZone& zone = zl[z];
     const ZoneFlagMap& zfm = zone.getZoneFlagMap();
     ZoneFlagMap::const_iterator zfmIt;
-    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); zfmIt++) {
+    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); ++zfmIt) {
       if (forbidden.find(zfmIt->first) == forbidden.end()) {
 	numFlags += zfmIt->second;
       }
@@ -1636,7 +1704,10 @@ void finalizeParsing(int UNUSED(argc), char **argv,
 
     if ((fDesc != Flags::Null) && (fDesc->flagTeam == NoTeam)) {
       for (int j = 0; j < options.flagCount[fDesc]; j++) {
-	FlagInfo::get(f++)->setRequiredFlag(fDesc);
+	FlagInfo *flag = FlagInfo::get(f++);
+        if (!flag)
+           continue;
+	flag->setRequiredFlag(fDesc);
       }
     }
   }
@@ -1645,21 +1716,27 @@ void finalizeParsing(int UNUSED(argc), char **argv,
     const CustomZone& zone = zl[z];
     const ZoneFlagMap& zfm = zone.getZoneFlagMap();
     ZoneFlagMap::const_iterator zfmIt;
-    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); zfmIt++) {
+    for (zfmIt = zfm.begin(); zfmIt != zfm.end(); ++zfmIt) {
       FlagType* ft = zfmIt->first;
       if ((ft->flagTeam == ::NoTeam) && // no team flags here
 	  (forbidden.find(ft) == forbidden.end())) {
 	const int count = zfmIt->second;
-	for (int c = 0; c < count; c++) {
+	for (int c = 0; c < count; c++, f++) {
+	  FlagInfo *flag = FlagInfo::get(f);
+          if (!flag)
+             continue;
 	  entryZones.addZoneFlag(z, f);
-	  FlagInfo::get(f++)->setRequiredFlag(ft);
+	  flag->setRequiredFlag(ft);
 	}
       }
     }
   }
   // add extra flags
   for (; f < numFlags; f++) {
-    FlagInfo::get(f)->required = allFlagsOut;
+    FlagInfo *flag = FlagInfo::get(f);
+    if (!flag)
+       continue;
+    flag->required = allFlagsOut;
   }
 
   // sum the sources of team flags
@@ -1669,7 +1746,6 @@ void finalizeParsing(int UNUSED(argc), char **argv,
     }
   }
 
-
   // debugging
   logDebugMessage(1,"type: %d\n", options.gameType);
   if (options.gameType == ClassicCTF)
@@ -1699,7 +1775,7 @@ void finalizeParsing(int UNUSED(argc), char **argv,
 
 
 // simple syntax check of comma-seperated list of group names (returns true if error)
-bool checkCommaList (const char *list, int maxlen){
+bool checkCommaList (const char *list, int maxlen) {
   int x = strlen (list);
   unsigned char c;
   if (x > maxlen)
