@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -49,7 +49,7 @@ CustomMesh::~CustomMesh()
   }
 
   std::vector<CustomMeshFace*>::iterator face_it;
-  for (face_it = faces.begin(); face_it != faces.end(); face_it++) {
+  for (face_it = faces.begin(); face_it != faces.end(); ++face_it) {
     CustomMeshFace* _face = *face_it;
     delete _face;
   }
@@ -152,7 +152,11 @@ bool CustomMesh::read(const char *cmd, std::istream& input)
       std::cout << "WARNING: multiple drawInfo, using first" << std::endl;
     } else {
       drawInfo = new MeshDrawInfo();
-      if (!drawInfo->parse(input)) {
+
+      bool parseSuccess = drawInfo->parse(input);
+      lines += drawInfo->getLineCount();
+
+      if (!parseSuccess) {
 	std::cout << "WARNING: invalid drawInfo" << std::endl;
 	delete drawInfo;
 	drawInfo = NULL;
@@ -196,14 +200,14 @@ void CustomMesh::writeToGroupDef(GroupDefinition *groupdef) const
     cfvec3 vert;
     if (decorative) {
       vert[0] = vert[1] = vert[2] = (Obstacle::maxExtent * 2.0f);
-      if ((faces.size() > 0) && !(driveThrough && shootThrough)) {
+      if (!faces.empty() && !(driveThrough && shootThrough)) {
 	logDebugMessage(0,"WARNING: mesh is supposed to be decorative, setting to passable\n");
 	forcePassable = true;
       }
     } else {
       vert[0] = vert[1] = vert[2] = 0.0f;
     }
-    ((std::vector<cfvec3>*)&vertices)->push_back(vert);
+    const_cast<std::vector<cfvec3>*>(&vertices)->push_back(vert);
   }
 
   MeshObstacle* mesh =
@@ -218,7 +222,7 @@ void CustomMesh::writeToGroupDef(GroupDefinition *groupdef) const
 
   // add the faces
   std::vector<CustomMeshFace*>::const_iterator face_it;
-  for (face_it = faces.begin(); face_it != faces.end(); face_it++) {
+  for (face_it = faces.begin(); face_it != faces.end(); ++face_it) {
     const CustomMeshFace* customFace = *face_it;
     customFace->write(mesh);
   }
