@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,7 +24,7 @@
 #include "ParseMaterial.h"
 
 
-CustomTetra::CustomTetra()
+CustomTetra::CustomTetra(): vertices(), normals(), texcoords()
 {
   vertexCount = 0; // no vertices have yet been defined
 
