@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,7 +27,7 @@
 #include "TextureMatrix.h"
 
 
-CustomWaterLevel::CustomWaterLevel()
+CustomWaterLevel::CustomWaterLevel(): height(0.0)
 {
   modedMaterial = false;
   return;
