@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,6 +18,7 @@
 
 // system headers
 #include <vector>
+#include <string>
 
 // bzflag library headers
 #include "Flag.h"
@@ -25,9 +26,9 @@
 class FlagHistory {
  public:
   void clear();
-  void get(char message[]);
+  std::string getStr();
   void add(FlagType* type);
-  std::vector<FlagType*> get(void) { return flagHistory;}
+  std::vector<FlagType*> getVec() { return flagHistory;}
  private:
   std::vector<FlagType*> flagHistory;
 };
@@ -35,10 +36,9 @@ class FlagHistory {
 #endif /* __FLAGHISTORY_H__ */
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
