@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -36,11 +36,12 @@
 #include "Authentication.h"
 #include "messages.h"
 #include "bzfsAPI.h"
+#include "FlagInfo.h"
 #include "ShotUpdate.h"
 
 class ShotInfo {
 public:
-  ShotInfo() : present(false) {};
+  ShotInfo() : salt(0), expireTime(0.0), present(false), running(false) {};
 
   FiringInfo firingInfo;
   int	salt;
@@ -69,9 +70,9 @@ public:
     Player(int _playerIndex, bz_ServerSidePlayerHandler *handler);
     ~Player();
 
-    int	    getIndex();
+    int		   getIndex();
     static int     getFreeIndex(int min, int max);
-    static Player *getPlayerByIndex(int _playerIndex);
+    static Player* getPlayerByIndex(int _playerIndex);
     static int     count();
     static void    updateLatency(float &waitTime);
     static void    dumpScore();
@@ -81,13 +82,13 @@ public:
     static int     getPlayerIDByName(const std::string &name);
     static void    reloadAccessDatabase();
 
-    bool	   loadEnterData(uint16_t &rejectCode,
-				 char *rejectMsg);
-    void	  *packAdminInfo(void *buf);
-    void	  *packPlayerInfo(void *buf);
-    void	  *packPlayerUpdate(void *buf);
+    bool	   loadEnterData(uint16_t& rejectCode,
+				 char* rejectMsg);
+    void*	   packAdminInfo(void* buf);
+    void*	   packPlayerInfo(void* buf);
+    void*	   packPlayerUpdate(void* buf);
 
-		void		setPlayerAddMessage ( PlayerAddMessage &msg );
+    void	   setPlayerAddMessage ( PlayerAddMessage &msg );
 
     void	   signingOn(bool ctf);
     void	   close();
@@ -138,7 +139,7 @@ public:
     // players
     PlayerInfo	      player;
     // Net Handler
-    NetHandler       *netHandler;
+    NetHandler	      *netHandler;
     // player lag info
     LagInfo	      lagInfo;
     // player access
@@ -146,7 +147,7 @@ public:
     // Last known position, vel, etc
     PlayerState       lastState;
     float	      stateTimeStamp;
-	float		  serverTimeStamp;
+    float	      serverTimeStamp;
     // GameTime update
     float	      gameTimeRate;
     TimeKeeper	      gameTimeNext;
@@ -160,11 +161,19 @@ public:
     // flag to let us know the player is on it's way out
     bool  isParting;
 
+    bool hasEntered;
+
     // logic class for server side players
     bz_ServerSidePlayerHandler*	playerHandler;
 
+    bool addWasDelayed;
+    bool hadEnter;
+    double addDelayStartTime;
+
+	int lastHeldFlagID;
+
   private:
-    static Player    *playerList[PlayerSlot];
+    static Player*    playerList[PlayerSlot];
     int		      playerIndex;
     bool	      closed;
     tcpCallback       clientCallback;
@@ -189,19 +198,19 @@ inline int GameKeeper::Player::getIndex()
   return playerIndex;
 }
 
-inline GameKeeper::Player *GameKeeper::Player::getPlayerByIndex(int
+inline GameKeeper::Player* GameKeeper::Player::getPlayerByIndex(int
 								_playerIndex)
 {
   if (_playerIndex < 0 || _playerIndex >= PlayerSlot)
-    return NULL;
+    return 0;
   if (!playerList[_playerIndex])
-    return NULL;
+    return 0;
   if (playerList[_playerIndex]->closed)
-    return NULL;
+    return 0;
   return playerList[_playerIndex];
 }
 
-void *PackPlayerInfo(void *buf, int playerIndex, uint8_t properties );
+void* PackPlayerInfo(void* buf, int playerIndex, uint8_t properties );
 
 // For hostban checking, to avoid check and check again
 inline void GameKeeper::Player::setAllNeedHostbanChecked(bool set)
@@ -240,7 +249,7 @@ inline const TimeKeeper& GameKeeper::Player::getNextGameTime() const
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
