@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,7 +18,6 @@
 /* system implementation headers */
 #include <string.h>
 #include <string>
-#include <math.h>
 #include <errno.h>
 #include <set>
 
@@ -38,16 +37,14 @@ const int ListServerLink::NotConnected = -1;
 ListServerLink::ListServerLink(std::string listServerURL,
 			       std::string publicizedAddress,
 			       std::string publicizedTitle,
-			       std::string _advertiseGroups,
-			       float dnsCache)
+			       std::string _advertiseGroups)
 {
 
   std::string bzfsUserAgent = "bzfs ";
   bzfsUserAgent	    += getAppVersion();
 
-  setURL(listServerURL);
+  setURLwithNonce(listServerURL);
   setUserAgent(bzfsUserAgent);
-  setDNSCachingTime((long)ceilf(dnsCache));
   setTimeout(10);
 
   publiclyDisconnected = false;
@@ -66,7 +63,7 @@ ListServerLink::ListServerLink(std::string listServerURL,
   queueMessage(ListServerLink::ADD);
 }
 
-ListServerLink::ListServerLink()
+ListServerLink::ListServerLink(): nextMessageType(), queuedRequest(0)
 {
   // does not create a usable link, so checks should be placed
   // in  all public member functions to ensure that nothing tries
@@ -97,8 +94,8 @@ ListServerLink::~ListServerLink()
 
 void ListServerLink::finalization(char *data, unsigned int length, bool good)
 {
-	publiclyDisconnected = !good;
-
+  publiclyDisconnected = !good;
+  GameKeeper::Player *playerData = NULL;
   queuedRequest = false;
   if (good && (length < 2048)) {
     char buf[2048];
@@ -142,7 +139,7 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
       } else if (!strncmp(base, unknownPlayer, strlen(unknownPlayer))) {
 	callsign = base + strlen(unknownPlayer);
 	authReply  = true;
-      } else if (!strncmp(base, ownerIdentifier, strlen(ownerIdentifier))){
+      } else if (!strncmp(base, ownerIdentifier, strlen(ownerIdentifier))) {
 	setPublicOwner(base + strlen(ownerIdentifier));
       } else if (!strncmp(base, bzIdentifier, strlen(bzIdentifier))) {
 	std::string line = base;
@@ -223,7 +220,7 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
 	    while (*group && (*group == ':')) *group++ = 0;
 	  }
 	}
-	GameKeeper::Player *playerData = NULL;
+	playerData = NULL;
 	int playerIndex;
 	for (playerIndex = 0; playerIndex < curMaxPlayers; playerIndex++) {
 	  playerData = GameKeeper::Player::getPlayerByIndex(playerIndex);
@@ -239,40 +236,30 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
 
 	if (playerIndex < curMaxPlayers) {
 	  if (registered) {
-	    // don't accept the global auth if there's a local account
-	    // of the same name and the local account is not marked as
-	    // being the same as the global account
-	    if (!playerData->accessInfo.hasRealPassword()
-		|| playerData->accessInfo.getUserInfo(callsign)
-		.hasGroup("LOCAL.GLOBAL")) {
-	      if (!playerData->accessInfo.isRegistered())
-		// Create an entry on the user database even if
-		// authentication wenk ko. Make the "isRegistered"
-		// things work
-		playerData->accessInfo.storeInfo(NULL);
-	      if (verified) {
-		playerData->_LSAState = GameKeeper::Player::verified;
-		playerData->accessInfo.setPermissionRights();
-		while (group && *group) {
-		  char *nextgroup = group;
-		  if (nextgroup) {
-		    while (*nextgroup && (*nextgroup != ':')) nextgroup++;
-		    while (*nextgroup && (*nextgroup == ':')) *nextgroup++ = 0;
-		  }
-		  playerData->accessInfo.addGroup(group);
-		  group = nextgroup;
+	    if (!playerData->accessInfo.isRegistered())
+	      // Create an entry on the user database even if
+	      // authentication wenk ko. Make the "isRegistered"
+	      // things work
+	      playerData->accessInfo.storeInfo();
+	    if (verified) {
+	      playerData->_LSAState = GameKeeper::Player::verified;
+	      playerData->accessInfo.setPermissionRights();
+	      while (group && *group) {
+		char *nextgroup = group;
+		if (nextgroup) {
+		  while (*nextgroup && (*nextgroup != ':')) nextgroup++;
+		  while (*nextgroup && (*nextgroup == ':')) *nextgroup++ = 0;
 		}
-		playerData->authentication.global(true);
-		sendMessage(ServerPlayer, playerIndex,
-			    "Global login approved!");
-	      } else {
-		playerData->_LSAState = GameKeeper::Player::failed;
-		sendMessage(ServerPlayer, playerIndex,
-			    "Global login rejected, bad token.");
+		playerData->accessInfo.addGroup(group);
+		group = nextgroup;
 	      }
+	      playerData->authentication.global(true);
+	      sendMessage(ServerPlayer, playerIndex,
+			  "Global login approved!");
 	    } else {
 	      playerData->_LSAState = GameKeeper::Player::failed;
-	      sendMessage(ServerPlayer, playerIndex, "Global login rejected. ");
+	      sendMessage(ServerPlayer, playerIndex,
+			  "Global login rejected, bad token.");
 	    }
 	  } else {
 	    playerData->_LSAState = GameKeeper::Player::notRequired;
@@ -280,7 +267,7 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
 	      sendMessage(ServerPlayer, playerIndex,
 			  "This callsign is not registered.");
 	      sendMessage(ServerPlayer, playerIndex,
-			  "You can register it at http://my.bzflag.org/bb/");
+			  "You can register it at https://forums.bzflag.org/");
 	    }
 	  }
 	  playerData->player.clearToken();
@@ -291,8 +278,16 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
       base = scan;
     }
   }
+
+  if (playerData != NULL) {
+	  // tell the API that auth is complete
+	  bz_AuthenticationCompleteData_V1 eventData;
+	  eventData.player = bz_getPlayerByIndex(playerData->getIndex());
+	  worldEventManager.callEvents(&eventData);
+  }
+
   for (int i = 0; i < curMaxPlayers; i++) {
-    GameKeeper::Player *playerData = GameKeeper::Player::getPlayerByIndex(i);
+    playerData = GameKeeper::Player::getPlayerByIndex(i);
     if (!playerData)
       continue;
     if (playerData->_LSAState != GameKeeper::Player::checking)
@@ -348,7 +343,6 @@ void ListServerLink::addMe(PingPacket pingInfo,
 			   std::string _advertiseGroups)
 {
   std::string msg;
-  std::string hdr;
 
   // encode ping reply as ascii hex digits plus NULL
   char gameInfo[PingPacketHexPackedSize + 1];
@@ -393,7 +387,7 @@ void ListServerLink::addMe(PingPacket pingInfo,
   msg += "&groups=";
   // *groups=GROUP0%0D%0AGROUP1%0D%0A
   PlayerAccessMap::iterator itr = groupAccess.begin();
-  for ( ; itr != groupAccess.end(); itr++) {
+  for ( ; itr != groupAccess.end(); ++itr) {
     if (itr->first.substr(0, 6) != "LOCAL.") {
       msg += itr->first.c_str();
       msg += "%0D%0A";
@@ -425,7 +419,7 @@ void ListServerLink::removeMe(std::string publicizedAddress)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
