@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,14 +10,10 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786)
-#endif
-
 // interface header
 #include "MasterBanList.h"
 
-const std::string& MasterBanList::get ( const std::string URL )
+const std::string &MasterBanList::get(const std::string &URL)
 {
   data = "";
   // get all up on the internet and go get the thing
@@ -33,3 +29,10 @@ void MasterBanList::finalization(char *cURLdata, unsigned int length,
     data = std::string(cURLdata, length);
 }
 
+// Local Variables: ***
+// mode: C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
