@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,7 +18,7 @@
 
 class MasterBanList : cURLManager {
 public:
-const std::string& get ( const std::string URL );
+const std::string &get(const std::string &URL);
 protected:
 	std::string	data;
  private:
@@ -27,10 +27,9 @@ protected:
 #endif //__MASTER_BAN_LIST_H__
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
