@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
 /* interface header */
 #include "Permissions.h"
 
@@ -34,7 +30,6 @@
 
 PlayerAccessMap	groupAccess;
 PlayerAccessMap	userDatabase;
-PasswordMap	passwordDatabase;
 
 uint8_t GetPlayerProperties(bool registered, bool verified, bool admin) {
   uint8_t result = 0;
@@ -47,8 +42,6 @@ uint8_t GetPlayerProperties(bool registered, bool verified, bool admin) {
   return result;
 }
 
-void setUserPassword(const std::string &nick, const std::string &pass);
-
 PlayerAccessInfo::PlayerAccessInfo()
   : verified(false), loginTime(TimeKeeper::getCurrent()), loginAttempts (0),
     serverop(false), passwordAttempts(0)
@@ -62,17 +55,6 @@ void PlayerAccessInfo::setName(const char* callSign) {
   makeupper(regName);
 }
 
-bool PlayerAccessInfo::gotAccessFailure() {
-  bool accessFailure = loginAttempts >= 5;
-  if (accessFailure)
-    logDebugMessage(1,"Too Many Identifys %s\n", getName().c_str());
-  return accessFailure;
-}
-
-void PlayerAccessInfo::setLoginFail() {
-  loginAttempts++;
-}
-
 void PlayerAccessInfo::setPermissionRights() {
   verified = true;
   // get their real info
@@ -110,6 +92,8 @@ bool PlayerAccessInfo::isAdmin() const {
 bool PlayerAccessInfo::showAsAdmin() const {
   if (hasPerm(hideAdmin))
     return false;
+  else if (hasPerm(showAdmin))
+    return true;
   else
     return isAdmin();
 }
@@ -127,14 +111,6 @@ std::string PlayerAccessInfo::getName() {
   return regName;
 }
 
-bool PlayerAccessInfo::hasRealPassword() {
-  return checkPasswordExistence(regName.c_str());
-}
-
-bool PlayerAccessInfo::isPasswordMatching(const char* pwd) {
-  return verifyUserPassword(regName.c_str(), pwd);
-}
-
 bool PlayerAccessInfo::isRegistered() const {
   return userExists(regName);
 }
@@ -147,30 +123,13 @@ bool PlayerAccessInfo::isVerified() const{
   return verified;
 }
 
-void PlayerAccessInfo::storeInfo(const char* pwd) {
+void PlayerAccessInfo::storeInfo() {
   PlayerAccessInfo _info;
   _info.addGroup("VERIFIED");
-
-  if (pwd == NULL) {
-    // automatically give global users permission to use local accounts
-    // since they either already have it, or there's no existing local account.
-    _info.addGroup("LOCAL.GLOBAL");
-    setUserPassword(regName.c_str(), "");
-    logDebugMessage(1,"Global Temp Register %s\n", regName.c_str());
-  } else {
-    std::string pass = pwd;
-    setUserPassword(regName.c_str(), pass.c_str());
-    logDebugMessage(1,"Register %s %s\n", regName.c_str(), pwd);
-  }
   userDatabase[regName] = _info;
   updateDatabases();
 }
 
-void PlayerAccessInfo::setPasswd(const std::string&  pwd) {
-  setUserPassword(regName.c_str(), pwd.c_str());
-  updateDatabases();
-}
-
 uint8_t PlayerAccessInfo::getPlayerProperties() {
   return GetPlayerProperties(isRegistered(), verified, showAsAdmin());
 }
@@ -233,7 +192,7 @@ bool PlayerAccessInfo::hasPerm(PlayerAccessInfo::AccessPerm right) const
   bool isAllowed = false;
   for (std::vector<std::string>::const_iterator itr=groups.begin(); itr!=groups.end(); ++itr) {
     PlayerAccessMap::iterator group = groupAccess.find(*itr);
-    if (group != groupAccess.end()){
+    if (group != groupAccess.end()) {
       if (group->second.explicitDenys.test(right))
       return false;
       else if (group->second.explicitAllows.test(right))
@@ -254,7 +213,7 @@ bool PlayerAccessInfo::hasPerm(PlayerAccessInfo::AccessPerm right) const
   return isAllowed || hasALLPerm;
 }
 
-// grant and revoke perms used with /mute and /unmute
+// grant and revoke perms
 void PlayerAccessInfo::grantPerm(PlayerAccessInfo::AccessPerm right)
 {
   explicitAllows.set(right);
@@ -268,20 +227,20 @@ void PlayerAccessInfo::revokePerm(PlayerAccessInfo::AccessPerm right)
 }
 
 
-// custom perms are ONLY on groups
-bool	PlayerAccessInfo::hasCustomPerm(const char* right) const
+bool PlayerAccessInfo::hasCustomPerm(const char* right) const
 {
 	if (serverop || hasALLPerm)
 		return true;
 
 	std::string perm = TextUtils::toupper(std::string(right));
 
+	// check for custom permissions in groups
 	for (std::vector<std::string>::const_iterator itr=groups.begin(); itr!=groups.end(); ++itr)
 	{
 		PlayerAccessMap::iterator group = groupAccess.find(*itr);
 		if (group != groupAccess.end())
 		{
-			for(unsigned int i = 0; i < group->second.customPerms.size(); i++)
+			for (unsigned int i = 0; i < group->second.customPerms.size(); i++)
 			{
 				if ( perm == TextUtils::toupper(group->second.customPerms[i]) )
 					return true;
@@ -294,24 +253,43 @@ bool	PlayerAccessInfo::hasCustomPerm(const char* right) const
 		PlayerAccessMap::iterator group = groupAccess.find(std::string("DISCONNECTED"));
 		if (group != groupAccess.end())
 		{
-			for(unsigned int i = 0; i < group->second.customPerms.size(); i++)
+			for (unsigned int i = 0; i < group->second.customPerms.size(); i++)
 			{
 				if ( perm == TextUtils::toupper(group->second.customPerms[i]) )
 					return true;
 			}
 		}
 	}
+
+	// check for custom permissions on a per player basis (stored in the customPerms vector)
+	for (unsigned int i = 0; i < customPerms.size(); i++)
+	{
+		if (perm == TextUtils::toupper(customPerms[i]))
+			return true;
+	}
+
 	return false;
 }
 
+void PlayerAccessInfo::grantCustomPerm(const char *right)
+{
+  customPerms.push_back(right);
+}
+
+void PlayerAccessInfo::revokeCustomPerm(const char *right)
+{
+  std::vector<std::string>::iterator position = std::find(customPerms.begin(), customPerms.end(), right);
+
+  if (position != customPerms.end())
+    customPerms.erase(position);
+}
+
 bool userExists(const std::string &nick)
 {
   std::string str = nick;
   makeupper(str);
   PlayerAccessMap::iterator itr = userDatabase.find(str);
-  if (itr == userDatabase.end())
-    return false;
-  return true;
+  return itr != userDatabase.end();
 }
 
 //FIXME - check for non-existing user (throw?)
@@ -327,43 +305,6 @@ PlayerAccessInfo &PlayerAccessInfo::getUserInfo(const std::string &nick)
   return itr->second;
 }
 
-bool checkPasswordExistence(const std::string &nick)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  PasswordMap::iterator itr = passwordDatabase.find(str1);
-  if (itr == passwordDatabase.end())
-    return false;
-  if (itr->second == "*" || itr->second == "")
-    return false;
-  return true;
-}
-
-bool verifyUserPassword(const std::string &nick, const std::string &pass)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  PasswordMap::iterator itr = passwordDatabase.find(str1);
-  if (itr == passwordDatabase.end())
-    return false;
-  return itr->second == MD5(pass).hexdigest();
-}
-
-void setUserPassword(const std::string &nick, const std::string &pass)
-{
-  std::string str1 = nick;
-  makeupper(str1);
-  if (pass.size() == 0) {
-    passwordDatabase[str1] = "*";
-  } else if (pass == "*") {
-    // never encode *, this would change the person's password from NULL to *.
-    passwordDatabase[str1] = "*";
-  } else {
-    // assume it's already a hash when length is 32 (FIXME?)
-    passwordDatabase[str1] = pass.size()==32 ? pass : MD5(pass).hexdigest();
-  }
-}
-
 std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
 {
   switch (perm) {
@@ -379,6 +320,7 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::antipollkill : return "antipollkill";
     case PlayerAccessInfo::ban: return "ban";
     case PlayerAccessInfo::banlist: return "banlist";
+    case PlayerAccessInfo::clientQuery: return "clientQuery";
     case PlayerAccessInfo::countdown: return "countdown";
     case PlayerAccessInfo::date: return "date";
     case PlayerAccessInfo::endGame: return "endGame";
@@ -394,11 +336,13 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::lagwarn: return "lagwarn";
     case PlayerAccessInfo::jitterwarn: return "jitterwarn";
     case PlayerAccessInfo::listPerms: return "listPerms";
+    case PlayerAccessInfo::listPlugins: return "listPlugins";
     case PlayerAccessInfo::masterBan: return "masterban";
     case PlayerAccessInfo::modCount: return "modCount";
     case PlayerAccessInfo::mute: return "mute";
     case PlayerAccessInfo::packetlosswarn: return "packetlosswarn";
     case PlayerAccessInfo::playerList: return "playerList";
+    case PlayerAccessInfo::plugins: return "plugins";
     case PlayerAccessInfo::poll: return "poll";
     case PlayerAccessInfo::pollBan: return "pollBan";
     case PlayerAccessInfo::pollKick: return "pollKick";
@@ -410,12 +354,14 @@ std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm)
     case PlayerAccessInfo::rejoin: return "rejoin";
     case PlayerAccessInfo::removePerms: return "removePerms";
     case PlayerAccessInfo::replay: return "replay";
+    case PlayerAccessInfo::report: return "report";
     case PlayerAccessInfo::say: return "say";
     case PlayerAccessInfo::sendHelp : return "sendHelp";
     case PlayerAccessInfo::setAll: return "setAll";
-    case PlayerAccessInfo::setPassword: return "setPassword";
     case PlayerAccessInfo::setPerms: return "setPerms";
     case PlayerAccessInfo::setVar: return "setVar";
+    case PlayerAccessInfo::showAdmin: return "showAdmin";
+    case PlayerAccessInfo::showMotto: return "showMotto";
     case PlayerAccessInfo::showOthers: return "showOthers";
     case PlayerAccessInfo::shortBan: return "shortBan";
     case PlayerAccessInfo::shutdownServer: return "shutdownServer";
@@ -445,6 +391,7 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "ANTIPOLLKILL") return PlayerAccessInfo::antipollkill;
   if (name == "BAN") return PlayerAccessInfo::ban;
   if (name == "BANLIST") return PlayerAccessInfo::banlist;
+  if (name == "CLIENTQUERY") return PlayerAccessInfo::clientQuery;
   if (name == "COUNTDOWN") return PlayerAccessInfo::countdown;
   if (name == "DATE") return PlayerAccessInfo::date;
   if (name == "ENDGAME") return PlayerAccessInfo::endGame;
@@ -460,11 +407,13 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "LAGWARN") return PlayerAccessInfo::lagwarn;
   if (name == "JITTERWARN") return PlayerAccessInfo::jitterwarn;
   if (name == "LISTPERMS") return PlayerAccessInfo::listPerms;
+  if (name == "LISTPLUGINS") return PlayerAccessInfo::listPlugins;
   if (name == "MASTERBAN") return PlayerAccessInfo::masterBan;
   if (name == "MODCOUNT") return PlayerAccessInfo::modCount;
   if (name == "MUTE") return PlayerAccessInfo::mute;
   if (name == "PACKETLOSSWARN") return PlayerAccessInfo::packetlosswarn;
   if (name == "PLAYERLIST") return PlayerAccessInfo::playerList;
+  if (name == "PLUGINS") return PlayerAccessInfo::plugins;
   if (name == "POLL") return PlayerAccessInfo::poll;
   if (name == "POLLBAN") return PlayerAccessInfo::pollBan;
   if (name == "POLLKICK") return PlayerAccessInfo::pollKick;
@@ -476,13 +425,15 @@ PlayerAccessInfo::AccessPerm permFromName(const std::string &name)
   if (name == "REJOIN") return PlayerAccessInfo::rejoin;
   if (name == "REMOVEPERMS") return PlayerAccessInfo::removePerms;
   if (name == "REPLAY") return PlayerAccessInfo::replay;
+  if (name == "REPORT") return PlayerAccessInfo::report;
   if (name == "SAY") return PlayerAccessInfo::say;
   if (name == "SENDHELP") return PlayerAccessInfo::sendHelp;
   if (name == "SETALL") return PlayerAccessInfo::setAll;
-  if (name == "SETPASSWORD") return PlayerAccessInfo::setPassword;
   if (name == "SETPERMS") return PlayerAccessInfo::setPerms;
   if (name == "SETVAR") return PlayerAccessInfo::setVar;
   if (name == "SHORTBAN") return PlayerAccessInfo::shortBan;
+  if (name == "SHOWADMIN") return PlayerAccessInfo::showAdmin;
+  if (name == "SHOWMOTTO") return PlayerAccessInfo::showMotto;
   if (name == "SHOWOTHERS") return PlayerAccessInfo::showOthers;
   if (name == "SHUTDOWNSERVER") return PlayerAccessInfo::shutdownServer;
   if (name == "SPAWN") return PlayerAccessInfo::spawn;
@@ -519,7 +470,7 @@ bool parsePermissionString(const std::string &permissionString, PlayerAccessInfo
     }
 
     // Operators are not allowed for userdb
-    if (!info.groupState.test(PlayerAccessInfo::isGroup) && first != '\0'){
+    if (!info.groupState.test(PlayerAccessInfo::isGroup) && first != '\0') {
       logDebugMessage(1,"userdb: illegal permission string, operators are not allowed in userdb\n");
       return false;
     }
@@ -597,8 +548,13 @@ bool parsePermissionString(const std::string &permissionString, PlayerAccessInfo
 	info.explicitAllows[PlayerAccessInfo::lastPerm] = false;
 	info.hasALLPerm = true;
       } else {
-	//logDebugMessage(1,"groupdb: Cannot set unknown permission %s\n", word.c_str());
-				info.customPerms.push_back(word);
+	// Easy access
+	std::vector<std::string>& c = info.customPerms;
+
+	// Only store the custom permission if it doesn't exist, in order to prevent duplicates
+	if (std::find(c.begin(), c.end(), word) == c.end()) {
+	  c.push_back(word);
+	}
       }
     }
   }
@@ -608,7 +564,7 @@ bool parsePermissionString(const std::string &permissionString, PlayerAccessInfo
 
 bool PlayerAccessInfo::readGroupsFile(const std::string &filename)
 {
-  std::ifstream in(filename.c_str());
+  std::ifstream in(filename);
   if (!in)
     return false;
 
@@ -627,10 +583,10 @@ bool PlayerAccessInfo::readGroupsFile(const std::string &filename)
       linenum++;
 
       // strip leading whitespace
-      line.erase(0 , line.find_first_not_of(" \t"));
+      line.erase(0, line.find_first_not_of(" \t"));
 
       // check for a comment string or empty line
-      if(line.empty() || line[0] == '#')
+      if (line.empty() || line[0] == '#')
 	continue;
 
       makeupper(line);
@@ -652,7 +608,7 @@ bool PlayerAccessInfo::readGroupsFile(const std::string &filename)
 
 	// Parse the permission string. If it contains a yet undefined group
 	// add a recursion
-	if(parsePermissionString(perm, accessInfo) && initialRun){
+	if (parsePermissionString(perm, accessInfo) && initialRun) {
 	  recursionNeeded++;
 	}
 
@@ -661,14 +617,14 @@ bool PlayerAccessInfo::readGroupsFile(const std::string &filename)
       }
     }
     initialRun = false;
-  } while(recursionNeeded--);
+  } while (recursionNeeded--);
 
   return true;
 }
 
 bool PlayerAccessInfo::readPermsFile(const std::string &filename)
 {
-  std::ifstream in(filename.c_str());
+  std::ifstream in(filename);
   if (!in)
     return false;
 
@@ -710,7 +666,7 @@ bool PlayerAccessInfo::readPermsFile(const std::string &filename)
 bool PlayerAccessInfo::writePermsFile(const std::string &filename)
 {
   int i;
-  std::ofstream out(filename.c_str());
+  std::ofstream out(filename);
   if (!out)
     return false;
   PlayerAccessMap::iterator itr = userDatabase.begin();
@@ -720,7 +676,7 @@ bool PlayerAccessInfo::writePermsFile(const std::string &filename)
     group = itr->second.groups.begin();
     while (group != itr->second.groups.end()) {
       out << (*group) << ' ';
-      group++;
+      ++group;
     }
     out << std::endl;
     // allows
@@ -733,7 +689,7 @@ bool PlayerAccessInfo::writePermsFile(const std::string &filename)
       if (itr->second.explicitDenys.test(i))
 	out << nameFromPerm((PlayerAccessInfo::AccessPerm) i);
     out << std::endl;
-    itr++;
+    ++itr;
   }
   out.close();
   return true;
