@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2012 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -55,6 +55,7 @@ public:
       antipollkill,
       ban,
       banlist,
+      clientQuery,
       countdown,
       date,
       endGame,
@@ -70,11 +71,13 @@ public:
       lagwarn,
       jitterwarn,
       listPerms,
+      listPlugins,
       masterBan,
       modCount,
       mute,
       packetlosswarn,
       playerList,
+      plugins,
       poll,
       pollBan,
       pollKick,
@@ -86,13 +89,15 @@ public:
       rejoin,
       removePerms,
       replay,
+      report,
       say,
       sendHelp,
       setAll,
-      setPassword,
       setPerms,
       setVar,
       shortBan,
+      showAdmin,
+      showMotto,
       showOthers,
       shutdownServer,
       spawn,
@@ -104,7 +109,7 @@ public:
       viewReports,
       vote,
       // just so we know how many rights there
-      // are this dosn't do anything really, just
+      // are this doesn't do anything really, just
       // make sure it's the last real right
       lastPerm
     };
@@ -120,12 +125,8 @@ public:
 
   std::string getName();
 
-  bool	gotAccessFailure();
   void	setLoginFail();
   bool	passwordAttemptsMax();
-  bool	isPasswordMatching(const char* pwd);
-  bool	hasRealPassword();
-  void	setPasswd(const std::string& pwd);
 
   /** have successfully provided server password */
   void  setOperator();
@@ -149,13 +150,15 @@ public:
   void	grantPerm(AccessPerm right);
   void	revokePerm(AccessPerm right);
 
-	bool	hasCustomPerm(const char* right) const;
+  bool	hasCustomPerm(const char* right) const;
+  void  grantCustomPerm(const char* right);
+  void  revokeCustomPerm(const char* right);
 
   bool	isRegistered() const;
   bool	isAllowedToEnter();
   bool	isVerified() const;
   uint8_t     getPlayerProperties();
-  void	storeInfo(const char* pwd);
+  void	storeInfo();
   bool	exists();
   static PlayerAccessInfo &getUserInfo(const std::string &nick);
   static bool readGroupsFile(const std::string &filename);
@@ -185,11 +188,9 @@ private:
 };
 
 typedef std::map<std::string, PlayerAccessInfo> PlayerAccessMap;
-typedef std::map<std::string, std::string> PasswordMap;
 
-extern PlayerAccessMap	groupAccess;
-extern PlayerAccessMap	userDatabase;
-extern PasswordMap	passwordDatabase;
+extern PlayerAccessMap  groupAccess;
+extern PlayerAccessMap  userDatabase;
 
 extern std::string		groupsFile;
 extern std::string		userDatabaseFile;
@@ -200,8 +201,6 @@ inline void makeupper(std::string& str)
 }
 
 bool userExists(const std::string &nick);
-bool checkPasswordExistence(const std::string &nick);
-bool verifyUserPassword(const std::string &nick, const std::string &pass);
 std::string nameFromPerm(PlayerAccessInfo::AccessPerm perm);
 PlayerAccessInfo::AccessPerm permFromName(const std::string &name);
 bool parsePermissionString(const std::string &permissionString, std::bitset<PlayerAccessInfo::lastPerm> &perms);
