@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -14,6 +14,8 @@
 #include "Score.h"
 #include "bzfsAPI.h"
 #include "WorldEventManager.h"
+#include "GameKeeper.h"
+#include "bzfs.h"
 
 // bzflag library headers
 #include "Pack.h"
@@ -27,7 +29,7 @@ bool  Score::randomRanking = false;
 bool Score::KeepPlayerScores = true;
 bool Score::KeepTeamScores = true;
 
-Score::Score(): wins(0), losses(0), tks(0) {
+Score::Score(): wins(0), losses(0), tks(0), handicap(0) {
   playerID = -1;
 }
 
@@ -49,33 +51,46 @@ float Score::ranking() {
   return average * penalty;
 }
 
-bool Score::isTK() {
+bool Score::isTK() const {
   // arbitrary 3
   return (tks >= 3) && (tkKickRatio > 0)
     && ((wins == 0) || (tks * 100 / wins > tkKickRatio));
 }
 
+// Change a score element, then call an event
+void Score::changeScoreElement(bz_eScoreElement element, int *toChange, int newValue) {
+  int oldValue = *toChange;
+  *toChange = newValue;
+  bz_PlayerScoreChangeEventData_V1 eventData = bz_PlayerScoreChangeEventData_V1(playerID, element, oldValue, newValue);
+  worldEventManager.callEvents(&eventData);
+}
+
+
 void Score::tK() {
   if (KeepPlayerScores) {
-    ++tks;
-    worldEventManager.callEvents(bz_PlayerScoreChangeEventData_V1(playerID,bz_eTKs, tks-1, tks));
+    changeScoreElement(bz_eTKs, &tks, tks + 1);
   }
 }
 
 void Score::killedBy() {
   if (KeepPlayerScores) {
-    ++losses;
-    worldEventManager.callEvents(bz_PlayerScoreChangeEventData_V1(playerID,bz_eLosses, losses-1, losses));
+    changeScoreElement(bz_eLosses, &losses, losses + 1);
   }
 }
 
 void Score::kill() {
   if (KeepPlayerScores) {
-    ++wins;
-    worldEventManager.callEvents(bz_PlayerScoreChangeEventData_V1(playerID,bz_eWins, wins-1, wins));
+    changeScoreElement(bz_eWins, &wins, wins + 1);
   }
 }
 
+
+void Score::reset() {
+  changeScoreElement(bz_eWins, &wins, 0);
+  changeScoreElement(bz_eLosses, &losses, 0);
+  changeScoreElement(bz_eTKs, &tks, 0);
+}
+
 void *Score::pack(void *buf) {
   buf = nboPackUShort(buf, wins);
   buf = nboPackUShort(buf, losses);
@@ -83,7 +98,7 @@ void *Score::pack(void *buf) {
   return buf;
 }
 
-bool Score::reached() {
+bool Score::reached() const {
   return wins - losses >= score;
 }
 
@@ -99,12 +114,8 @@ void Score::setRandomRanking() {
   randomRanking = true;
 }
 
-int Score::getHandicap() {
-  return losses - wins;
-}
-
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
