@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,8 +31,8 @@ class ServerCommand {
 
   std::string getHelp();
 
-  virtual bool operator () (const char	 *commandLine,
-			    GameKeeper::Player *playerData);
+  virtual bool operator() (const char	 *commandLine,
+			   GameKeeper::Player *playerData);
 
 
  protected:
@@ -45,7 +45,7 @@ class ServerCommand {
 
   typedef std::map<std::string, ServerCommand *> MapOfCommands;
 
-  static MapOfCommands *getMapRef();
+  static MapOfCommands *mapOfCommands;
 };
 
 #endif
