@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -22,7 +22,7 @@
 SpawnPolicy *SpawnPosition::policy = (SpawnPolicy*)0;
 
 
-SpawnPosition::SpawnPosition(int playerId, bool onGroundOnly, bool notNearEdges)
+SpawnPosition::SpawnPosition(int playerId, bool onGroundOnly, bool notNearEdges): azimuth(0.0), pos()
 {
   /* if a spawn policy hasn't been set yet, just go with the default */
   if (!SpawnPosition::policy) {
@@ -49,7 +49,7 @@ void SpawnPosition::setSpawnPolicy(SpawnPolicy *_policy)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
