@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,7 +24,7 @@
 class TeamBase
 { // This class represents one base
 public:
-  TeamBase() {}
+  TeamBase(): position(), size(), rotation(0.0) {}
   TeamBase(const float *pos, const float *siz, float rot);
   void getRandomPosition( float &x, float &y, float &z ) const;
   float position[3];
