@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786 )
-#endif
-
 #include "common.h"
 
 // interface header
@@ -28,6 +24,7 @@
 WorldFileObject::WorldFileObject()
 {
   name = "";
+  lines = 0;
 }
 
 
@@ -61,6 +58,11 @@ void WorldFileObject::writeToGroupDef(GroupDefinition*) const
   return;
 }
 
+int WorldFileObject::getLineCount() const
+{
+  return lines;
+}
+
 
 /** delete all of the world file objects from a vector list
  */
@@ -76,7 +78,7 @@ void emptyWorldFileObjectList(std::vector<WorldFileObject*>& wlist)
 
 
 // Local variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
