@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,7 +25,7 @@ class GroupDefinition;
 class WorldFileObject {
   public:
     WorldFileObject();
-    virtual ~WorldFileObject() { }
+    virtual ~WorldFileObject() {}
 
     virtual bool read(const char *cmd, std::istream&);
 
@@ -35,17 +35,19 @@ class WorldFileObject {
     virtual void writeToManager() const;
     virtual void writeToGroupDef(GroupDefinition*) const;
 
+    virtual int getLineCount() const;
+
   protected:
     std::string name;
+    int lines;
 };
 
-
 void emptyWorldFileObjectList(std::vector<WorldFileObject*>& wlist);
 
 #endif  /* __WORLDFILEOBJECT_H__ */
 
 // Local variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
