@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -56,14 +56,16 @@
 
 WorldInfo::WorldInfo() :
   maxHeight(0.0f),
-  database(NULL)
+  database(NULL),
+  databaseSize(0),
+  uncompressedSize(0)
 {
   size[0] = 400.0f;
   size[1] = 400.0f;
   gravity = -9.81f;
   waterLevel = -1.0f;
   waterMatRef = NULL;
-	finished = false;
+  finished = false;
 }
 
 WorldInfo::~WorldInfo()
