@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786 )
-#endif
-
 // class-interface header
 #include "WorldWeapons.h"
 
@@ -31,84 +27,98 @@
 
 // bzfs specific headers
 #include "bzfs.h"
+#include "ShotManager.h"
 
-char *getDirectMessageBuffer();
-void broadcastMessage(uint16_t code, int len, const void *msg);
-
-
-static int fireWorldWepReal(FlagType* type, float lifetime, PlayerId player,
-			    TeamColor teamColor, float *pos, float tilt, float dir,
-			    int shotID, float dt)
+uint32_t WorldWeapons::fireShot(FlagType* type, const float origin[3], const float vector[3], int *shotID, TeamColor teamColor, PlayerId targetPlayerID)
 {
+  if (!BZDB.isTrue(StateDatabase::BZDB_WEAPONS)) {
+    return INVALID_SHOT_GUID;
+  }
+
   void *buf, *bufStart = getDirectMessageBuffer();
 
   FiringInfo firingInfo;
   firingInfo.timeSent = (float)TimeKeeper::getCurrent().getSeconds();
   firingInfo.flagType = type;
-  firingInfo.lifetime = lifetime;
-  firingInfo.shot.player = player;
-  memmove(firingInfo.shot.pos, pos, 3 * sizeof(float));
-  const float shotSpeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED);
-  const float tiltFactor = cosf(tilt);
-  firingInfo.shot.vel[0] = shotSpeed * tiltFactor * cosf(dir);
-  firingInfo.shot.vel[1] = shotSpeed * tiltFactor * sinf(dir);
-  firingInfo.shot.vel[2] = shotSpeed * sinf(tilt);
-  firingInfo.shot.id = shotID;
-  firingInfo.shot.dt = dt;
+  firingInfo.lifetime = BZDB.eval(StateDatabase::BZDB_RELOADTIME);
+  firingInfo.shot.player = ServerPlayer;
+  memmove(firingInfo.shot.pos, origin, 3 * sizeof(float));
 
+  const float shotSpeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED);
+
+  for (int i = 0; i < 3; i++)
+    firingInfo.shot.vel[i] = vector[i] * shotSpeed;
+
+  firingInfo.shot.dt = 0;
   firingInfo.shot.team = teamColor;
 
-  buf = firingInfo.pack(bufStart);
-
-  if (BZDB.isTrue(StateDatabase::BZDB_WEAPONS)) {
-    broadcastMessage(MsgShotBegin, (char *)buf - (char *)bufStart, bufStart);
+  if (shotID != nullptr && shotID == 0) {
+    *shotID = getNewWorldShotID();
+    firingInfo.shot.id = *shotID;
+  }
+  else if (shotID == nullptr) {
+    firingInfo.shot.id = getNewWorldShotID();
+  }
+  else {
+    firingInfo.shot.id = *shotID;
   }
-  return shotID;
-}
 
+  bz_AllowServerShotFiredEventData_V1 allowEvent;
+  allowEvent.flagType = type->flagAbbv;
+  allowEvent.speed = shotSpeed;
+  for (int i = 0; i < 3; i++){
+    allowEvent.pos[i] = origin[i];
+    allowEvent.velocity[i] = firingInfo.shot.vel[i];
+  }
+  allowEvent.team = convertTeam(teamColor);
 
-static int fireWorldGMReal ( FlagType* type, PlayerId targetPlayerID, float
-    lifetime, PlayerId player, float *pos, float tilt, float dir, int shotID,
-    float dt)
-{
+  worldEventManager.callEvents(bz_eAllowServerShotFiredEvent, &allowEvent);
 
-  void *buf, *bufStart = getDirectMessageBuffer();
+  if (!allowEvent.allow) {
+    return INVALID_SHOT_GUID;
+  }
 
-  FiringInfo firingInfo;
-  firingInfo.timeSent = (float)TimeKeeper::getCurrent().getSeconds();
-  firingInfo.flagType = type;
-  firingInfo.lifetime = lifetime;
-  firingInfo.shot.player = player;
-  memmove(firingInfo.shot.pos, pos, 3 * sizeof(float));
-  const float shotSpeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED);
-  const float tiltFactor = cosf(tilt);
-  firingInfo.shot.vel[0] = shotSpeed * tiltFactor * cosf(dir);
-  firingInfo.shot.vel[1] = shotSpeed * tiltFactor * sinf(dir);
-  firingInfo.shot.vel[2] = shotSpeed * sinf(tilt);
-  firingInfo.shot.id = shotID;
-  firingInfo.shot.dt = dt;
+  if (allowEvent.changed) {
+    FlagTypeMap &flagMap = FlagType::getFlagMap();
 
-  firingInfo.shot.team = RogueTeam;
+    if (flagMap.find(allowEvent.flagType) == flagMap.end())
+      return INVALID_SHOT_GUID;
+
+    FlagType *flag = flagMap.find(allowEvent.flagType)->second;
+    firingInfo.flagType = flag;
+  }
 
   buf = firingInfo.pack(bufStart);
 
-  if (BZDB.isTrue(StateDatabase::BZDB_WEAPONS)) {
-    broadcastMessage(MsgShotBegin, (char *)buf - (char *)bufStart,
-		     bufStart);
-  }
+  broadcastMessage(MsgShotBegin, (char*)buf - (char*)bufStart, bufStart);
 
-    // Target the gm.
-    // construct and send packet
+  uint32_t shotGUID = ShotManager.AddShot(firingInfo, ServerPlayer);
+
+  // Target the gm, construct it, and send packet
+  if (type->flagAbbv == "GM") {
+    ShotManager.SetShotTarget(shotGUID, targetPlayerID);
+
+    char packet[ShotUpdatePLen + PlayerIdPLen];
+    buf = (void*)packet;
+    buf = firingInfo.shot.pack(buf);
+    buf = nboPackUByte(buf, targetPlayerID);
 
-  char packet[ShotUpdatePLen + PlayerIdPLen];
-  buf = (void*)packet;
-  buf = firingInfo.shot.pack(buf);
-  buf = nboPackUByte(buf, targetPlayerID);
-  if (BZDB.isTrue(StateDatabase::BZDB_WEAPONS)) {
     broadcastMessage(MsgGMUpdate, sizeof(packet), packet);
   }
 
-  return shotID;
+  bz_ServerShotFiredEventData_V1 event;
+  event.guid = shotGUID;
+  event.flagType = allowEvent.flagType;
+  event.speed = shotSpeed;
+  for (int i = 0; i < 3; i++){
+    event.pos[i] = origin[i];
+    event.velocity[i] = firingInfo.shot.vel[i];
+  }
+  event.team = convertTeam(teamColor);
+
+  worldEventManager.callEvents(bz_eServerShotFiredEvent, &event);
+
+  return shotGUID;
 }
 
 WorldWeapons::WorldWeapons()
@@ -156,10 +166,11 @@ void WorldWeapons::fire()
        it != weapons.end(); ++it) {
     Weapon *w = *it;
     if (w->nextTime <= nowTime) {
+      FlagType type = *(w->type);	// non-const copy
 
-      fireWorldWepReal((FlagType*)w->type, BZDB.eval(StateDatabase::BZDB_RELOADTIME),
-		       ServerPlayer, w->teamColor, w->origin, w->tilt, w->direction,
-		       getNewWorldShotID(), 0);
+	  float vec[3] = { 0,0,0 };
+	  bz_vectorFromRotations(w->tilt, w->direction, vec);
+      fireShot(&type, w->origin, vec, nullptr, w->teamColor);
 
       //Set up timer for next shot, and eat any shots that have been missed
       while (w->nextTime <= nowTime) {
@@ -211,7 +222,7 @@ void * WorldWeapons::pack(void *buf) const
     buf = nboPackVector(buf, w->origin);
     buf = nboPackFloat(buf, w->direction);
     buf = nboPackFloat(buf, w->initDelay);
-    buf = nboPackUShort(buf, w->delay.size());
+    buf = nboPackUShort(buf, (uint16_t)w->delay.size());
     for (unsigned int j = 0; j < w->delay.size(); j++) {
       buf = nboPackFloat(buf, w->delay[j]);
     }
@@ -250,6 +261,15 @@ int WorldWeapons::getNewWorldShotID(void)
   return worldShotId++;
 }
 
+bool shotUsedInList(int shotID, Shots::ShotList& list)
+{
+	for (size_t s = 0; s < list.size(); s++)
+	{
+		if (list[s]->GetLocalShotID() == shotID)
+			return true;
+	}
+	return false;
+}
 
 //----------WorldWeaponGlobalEventHandler---------------------
 // where we do the world weapon handling for event based shots since they are not really done by the "world"
@@ -282,31 +302,13 @@ void WorldWeaponGlobalEventHandler::process (bz_EventData *eventData)
 
   bz_CTFCaptureEventData_V1 *capEvent = (bz_CTFCaptureEventData_V1*)eventData;
 
-  if ( capEvent->teamCapped != team )
-	  return;
+  if (capEvent->teamCapped != team)
+    return;
 
-  fireWorldWepReal(type, BZDB.eval(StateDatabase::BZDB_RELOADTIME),
-		   ServerPlayer, RogueTeam, origin, tilt, direction,
-		   world->getWorldWeapons().getNewWorldShotID(),0);
-}
+  float vec[3] = { 0,0,0 };
+  bz_vectorFromRotations(tilt, direction, vec);
 
-
-// for bzfsAPI: it needs to be global
-int fireWorldWep(FlagType* type, float lifetime, PlayerId player,
-			float *pos, float tilt, float direction,
-			int shotID, float dt)
-{
-  return fireWorldWepReal(type, lifetime, player, RogueTeam,
-			  pos, tilt, direction, shotID, dt);
-}
-
-
-int fireWorldGM(FlagType* type, PlayerId targetPlayerID, float lifetime,
-		PlayerId player, float *pos, float tilt, float direction,
-		int shotID, float dt)
-{
-  return fireWorldGMReal(type, targetPlayerID, lifetime, player, pos, tilt,
-			 direction, shotID, dt);
+  world->getWorldWeapons().fireShot(type, origin, vec, NULL);
 }
 
 // Local Variables: ***
