@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,10 +13,6 @@
 #ifndef __WORLDWEAPON_H__
 #define __WORLDWEAPON_H__
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
 /* common header */
 #include "common.h"
 
@@ -28,8 +24,9 @@
 #include "TimeKeeper.h"
 
 #include "WorldEventManager.h"
+#include "PlayerInfo.h"
 
-#define _MAX_WORLD_SHOTS 30
+#define _MAX_WORLD_SHOTS 255
 
 /** WorldWeapons is a container class that holds weapons
  */
@@ -49,7 +46,7 @@ public:
   int packSize() const;
   void *pack(void *buf) const;
 
-  int getNewWorldShotID ( void );
+  uint32_t fireShot(FlagType* type, const float origin[3], const float vector[3], int *shotID, TeamColor teamColor = RogueTeam, PlayerId targetPlayerID = -1);
 
 private:
   struct Weapon
@@ -68,6 +65,8 @@ private:
   std::vector<Weapon*> weapons;
   int worldShotId;
 
+  int getNewWorldShotID(void);
+
   WorldWeapons( const WorldWeapons &w);
   WorldWeapons& operator=(const WorldWeapons &w) const;
 };
@@ -88,13 +87,10 @@ protected:
 	bz_eTeamType	team;
 };
 
-int fireWorldWep ( FlagType* type, float lifetime, PlayerId player, float *pos, float tilt, float direction, int shotID, float dt );
-
-int fireWorldGM(FlagType* type, PlayerId targetPlayerID, float lifetime, PlayerId player, float *pos, float tilt, float direction, int shotID, float dt);
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
