@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,7 @@
 #include <algorithm>
 #include <sstream>
 #include <time.h>
+#include <cstdlib>
 
 // implementation wrapers for all the bzf_ API functions
 #include "bzfsHTTPAPI.h"
@@ -28,8 +29,15 @@
 #include "base64.h"
 #include "Permissions.h"
 
+// only include this if we're going to need plugins
+#ifdef BZ_PLUGINS
+#include "bzfsPlugins.h"
+#endif
+
 std::string ServerVersion;
 std::string ServerHostname;
+std::string ServerPort;
+std::string ServerHostPort;
 std::string BaseURL;
 
 #ifdef _WIN32
@@ -43,7 +51,7 @@ std::string BaseURL;
 std::string trimLeadingWhitespace(const char* t)
 {
   std::string text;
-  while(*t) {
+  while (*t) {
     if (!TextUtils::isWhitespace(*t))
     {
      text = t;
@@ -130,8 +138,8 @@ public:
   }
 };
 
-#define VDIR_SESSION_PTR ((bzhttp_SessionData_Data*)pimple)
-#define VDIR_SESSION(n) bzhttp_SessionData_Data *n = ((bzhttp_SessionData_Data*)pimple)
+#define VDIR_SESSION_PTR (static_cast<bzhttp_SessionData_Data*>(pimple))
+#define VDIR_SESSION(n) bzhttp_SessionData_Data *n = VDIR_SESSION_PTR
 #define VDIR_SESSION_CLASS(c,n) bzhttp_SessionData_Data *n = ((bzhttp_SessionData_Data*)(c))
 
 bzhttp_SessionData::bzhttp_SessionData()
@@ -144,7 +152,7 @@ bzhttp_SessionData::bzhttp_SessionData()
 
 bzhttp_SessionData::~bzhttp_SessionData()
 {
-  delete(VDIR_SESSION_PTR);
+  delete VDIR_SESSION_PTR;
 }
 std::map<std::string,std::string> emptyMap;
 
@@ -365,8 +373,6 @@ BZF_API bool bzhttp_RemoveVDir (bz_Plugin* plugin, bzhttp_VDir *vdir )
     return false;
   VDir dir;
 
-  std::string name =  TextUtils::toupper(vdir->VDirName());
-
   std::map<std::string,VDir>::iterator itr = VDirs.find(dir.name);
   if (itr == VDirs.end())
     return false;
@@ -388,10 +394,10 @@ BZF_API bool bzhttp_RemoveAllVdirs (bz_Plugin* plugin )
       names.push_back(itr->second.name);
   }
 
-  if (names.size() == 0)
+  if (names.empty())
     return false;
 
-  for( size_t i = 0; i < names.size(); i++)
+  for ( size_t i = 0; i < names.size(); i++)
     VDirs.erase(VDirs.find(names[i]));
 
   return true;
@@ -423,7 +429,7 @@ public:
   {
     plugin = NULL;
   }
-  virtual void process ( bz_EventData *eventData )
+  virtual void process (bz_EventData *)
   {
       CheckForZombies();
   }
@@ -432,8 +438,8 @@ public:
 ConnectionEvent *con = NULL;
 TickEvent *tick = NULL;
 
-//---- Responce----
-class bzhttp_Responce_Data
+//---- Response----
+class bzhttp_Response_Data
 {
 public:
   std::map<std::string,std::string> Headers;
@@ -441,53 +447,54 @@ public:
   std::string Body;
 };
 
-#define RESPONCE_DATA_PTR ((bzhttp_Responce_Data*)pimple)
-#define RESPONCE_DATA(n) bzhttp_Responce_Data *n = ((bzhttp_Responce_Data*)pimple)
-#define RESPONCE_DATA_CLASS(c,n) bzhttp_Responce_Data *n = ((bzhttp_Responce_Data*)(c))
+#define RESPONSE_DATA_PTR ((bzhttp_Response_Data*)pimple)
+#define RESPONSE_DATA(n) bzhttp_Response_Data *n = ((bzhttp_Response_Data*)pimple)
+#define RESPONSE_DATA_CLASS(c,n) bzhttp_Response_Data *n = ((bzhttp_Response_Data*)(c))
 
-bzhttp_Responce::bzhttp_Responce()
+bzhttp_Response::bzhttp_Response()
 {
-  pimple = new bzhttp_Responce_Data;
+  Version = 1;
+  pimple = new bzhttp_Response_Data;
   ReturnCode = e404NotFound;
   DocumentType = eHTML;
   ForceNoCache = false;
 }
 
-bzhttp_Responce::~bzhttp_Responce()
+bzhttp_Response::~bzhttp_Response()
 {
-  delete(RESPONCE_DATA_PTR);
+  delete(RESPONSE_DATA_PTR);
 }
 
-void bzhttp_Responce::AddHeader ( const char* n, const char* v)
+void bzhttp_Response::AddHeader ( const char* n, const char* v)
 {
-  RESPONCE_DATA(data);
+  RESPONSE_DATA(data);
 
   std::string name = n;
   data->Headers[name] = std::string(v);
 }
 
-void bzhttp_Responce::AddCookies ( const char* n, const char* v)
+void bzhttp_Response::AddCookies ( const char* n, const char* v)
 {
-  RESPONCE_DATA(data);
+  RESPONSE_DATA(data);
 
   std::string name = n;
    data->Cookies[name] = std::string(v);
 }
 
-void bzhttp_Responce::AddBodyData ( const char* v)
+void bzhttp_Response::AddBodyData ( const char* v)
 {
-  RESPONCE_DATA(data);
+  RESPONSE_DATA(data);
 
   if (v)
     data->Body += v;
 }
 
-void bzhttp_Responce::AddBodyData ( const void* v, size_t size)
+void bzhttp_Response::AddBodyData ( const void* v, size_t size)
 {
-  RESPONCE_DATA(data);
+  RESPONSE_DATA(data);
 
   if (v && size)
-    data->Body += std::string((char*)v,size);
+    data->Body += std::string((const char*)v,size);
 }
 
 //---- Request----
@@ -504,6 +511,7 @@ public:
 
 bzhttp_Request::bzhttp_Request(): Session(NULL)
 {
+  Version = 1;
   pimple = new bzhttp_Request_Data;
 }
 
@@ -520,7 +528,7 @@ bool bzhttp_Request::UserHasPerm ( const char* perm ) const
   std::string permName = TextUtils::toupper(perm);
   PlayerAccessInfo::AccessPerm realPerm =  permFromName(permName);
 
-  for( size_t i = 0; i < BZIDGroups.size(); i++ )
+  for ( size_t i = 0; i < BZIDGroups.size(); i++ )
   {
     std::string groupName = BZIDGroups.get(i).c_str();
     groupName = TextUtils::toupper(groupName);
@@ -531,7 +539,7 @@ bool bzhttp_Request::UserHasPerm ( const char* perm ) const
     if (itr->second.explicitAllows.test(realPerm) && !itr->second.explicitDenys.test(realPerm) )
       return true;
 
-    for(unsigned int c = 0; c < itr->second.customPerms.size(); c++)
+    for (unsigned int c = 0; c < itr->second.customPerms.size(); c++)
     {
       if (permName == TextUtils::toupper(itr->second.customPerms[c]))
 	return true;
@@ -574,7 +582,7 @@ const char* bzhttp_Request::GetHeader ( size_t index ) const
     if (index == i)
       return itr->second.c_str();
     i++;
-    itr++;
+    ++itr;
   }
   return NULL;
 }
@@ -618,7 +626,7 @@ const char* bzhttp_Request::GetCookie ( size_t index ) const
     if (index == i)
       return itr->second.c_str();
     i++;
-    itr++;
+    ++itr;
   }
   return NULL;
 }
@@ -662,7 +670,7 @@ const char* bzhttp_Request::GetParamater ( size_t index ) const
     if (index == i)
       return itr->second.c_str();
     i++;
-    itr++;
+    ++itr;
   }
   return NULL;
 }
@@ -673,7 +681,7 @@ size_t bzhttp_Request::GetParamaterCount () const
   return data->Paramaters.size();
 }
 
-class HTTPConnectedPeer : public bz_NonPlayerConnectionHandler , public bz_BaseURLHandler
+class HTTPConnectedPeer : public bz_NonPlayerConnectionHandler, public bz_BaseURLHandler
 {
 public:
   static HTTPConnectedPeer* Current;
@@ -689,7 +697,7 @@ public:
   bool RequestComplete;
 
   bzhttp_Request  Request;
-  bzhttp_Responce Responce;
+  bzhttp_Response Response;
 
   bool Authenticated;
 
@@ -702,10 +710,14 @@ public:
   std::string bzAuthReturnData;
 
   bool bzIDAuthFailed;
+  bool bzIDAuthComplete;
+  bool firedOffBZIDTokenCheck;
 
-  HTTPConnectedPeer() : bz_NonPlayerConnectionHandler() ,bz_BaseURLHandler()
+  HTTPConnectedPeer() : bz_NonPlayerConnectionHandler(), bz_BaseURLHandler()
   {
+    firedOffBZIDTokenCheck = false;
     bzIDAuthFailed = false;
+	bzIDAuthComplete = false;
     Authenticated = false;
     RequestComplete = false;
     Killme = false;
@@ -748,13 +760,14 @@ public:
       list[n] = std::string(d);
   }
 
-  virtual void URLDone ( const char* URL, void * data, unsigned int size, bool complete )
+  virtual void URLDone (const char*, const void *data, unsigned int size, bool complete)
   {
     if (data && size)
       bzAuthReturnData += std::string((const char*)data,size);
 
     if (complete)
     {
+      bzIDAuthComplete = true;
       bzIDAuthURL.clear();
 
       bzAuthReturnData = TextUtils::replace_all(bzAuthReturnData,"\r","");
@@ -804,25 +817,23 @@ public:
 
   virtual void URLTimeout ( const char* UNUSED(URL), int UNUSED(errorCode) )
   {
+    bzIDAuthComplete = true;
     bzIDAuthFailed = true;
   }
 
   virtual void URLError ( const char* UNUSED(URL), int UNUSED(errorCode), const char * UNUSED(errorString) )
   {
+    bzIDAuthComplete = true;
     bzIDAuthFailed = true;
   }
 
   virtual void pending(int connectionID, void *data, unsigned int size)
   {
-    char *d = (char*)malloc(size+1);
-    memcpy(d,data,size);
-    d[size] = 0;
-    RequestData += d;
-    free(d);
+    RequestData.append(static_cast<char const*>(data), size);
 
     // know our limits
-    size_t maxContentSize = 1024*1536;
-    size_t maxBufferSize = 1024*2048;
+    size_t maxContentSize( 1024*1536 );
+    size_t maxBufferSize( 1024*2048 );
 
     if (bz_BZDBItemHasValue("_MaxHTTPContentSize"))
       maxBufferSize = bz_getBZDBInt("_MaxHTTPContentSize");
@@ -884,34 +895,21 @@ public:
       std::string headerSubStir = RequestData.substr(0,HeaderSize);
       std::vector<std::string> headers = TextUtils::tokenize(headerSubStir,"\r\n");
 
-      if (headers.size() > 0)
-      {
-	std::string browserInfo = headers[0];
-      }
-
       for ( size_t i = 1; i < headers.size(); i++ )
       {
-	std::vector<std::string> headerParts = TextUtils::tokenize(headers[i],":",2);
+	std::vector<std::string> headerParts = TextUtils::tokenize(headers[i],": ",2);
 	if (headerParts.size() > 1)
 	{
 	  Request.AddHeader(headerParts[0].c_str(),headerParts[1].c_str());
 	  std::string name = TextUtils::toupper(headerParts[0]);
-	  if (name == "CONTENT-LENGTH")
-	  {
-	    int size = atoi(headerParts[1].c_str());
-	    if (size > 0)
-	    {
-	      ContentSize = (unsigned int)size;
-
-	      if (ContentSize > maxContentSize)
-	      {
-		send501Error(connectionID);
-		return;
+	  if (name == "CONTENT-LENGTH") {
+	    int size1 = strtol(headerParts[1].c_str(), NULL, 0);
+	    ContentSize = (unsigned int)size1;
+	    if (ContentSize > maxContentSize) {
+	      send501Error(connectionID);
+	      return;
 	      }
 	    }
-	    else
-	      ContentSize = 0;
-	  }
 	  if (name == "COOKIE")
 	  {
 	    std::vector<std::string> cookieParts = TextUtils::tokenize(headerParts[1],"=",2);
@@ -950,10 +948,15 @@ public:
 	parseParams(Resource.substr(question+1,Resource.length()-(question+1)));
 	resource = Resource.substr(0,question);
       }
+      std::string IP = bz_getNonPlayerConnectionIP(connectionID);
 
       Request.URL = Resource;
       Request.Resource = resource;
 
+      Request.RequesterIP = IP.c_str();
+      if (bz_getNonPlayerConnectionHost(connectionID))
+	Request.RequesterHost = bz_getNonPlayerConnectionHost(connectionID);
+
       if (Request.RequestType == eHTTPPost)
       {
 	std::string body = RequestData.substr(HeaderSize,ContentSize);
@@ -965,7 +968,6 @@ public:
       else if (Request.RequestType == eHTTPPut)
 	Request.Body = RequestData.substr(HeaderSize,ContentSize);
 
-      std::string IP = bz_getNonPlayerConnectionIP(connectionID);
 
       if (sessionID == 0 && Request.GetParamater("SSID") != NULL)
 	Request.Session = &GetSessionByID(Request.GetParamater("SSID"),IP.c_str());
@@ -1025,7 +1027,7 @@ public:
 		token = t;
 		callsign = c;
 
-		bzIDAuthURL = "http://my.bzflag.org/db/";
+		bzIDAuthURL = "https://my.bzflag.org/db/";
 		if (bz_BZDBItemHasValue("_WebAuthCheckURL"))
 		  bzIDAuthURL = bz_getBZDBString("_WebAuthCheckURL").c_str();
 
@@ -1040,7 +1042,7 @@ public:
 		while (itr != groupAccess.end())
 		{
 		  groups += TextUtils::url_encode(itr->first) + "%0D%0A";
-		  itr++;
+		  ++itr;
 		}
 
 		for (size_t i = 0; i < vDir->BZIDAuthenicationGroups.size(); i++)
@@ -1051,7 +1053,13 @@ public:
 		  groups.erase(groups.size()-6,6);
 		  bzIDAuthURL += "&groups=" + groups;
 		}
-
+		firedOffBZIDTokenCheck = true;
+		bzIDAuthComplete = false;
+#ifdef BZ_PLUGINS
+		PushPendingHTTPWait();
+#endif
+		bz_setNonPlayerDisconnectOnSend(connectionID,false);
+		bz_setNonPlayerInactivityTimeout(connectionID,120);
 		bzAuthReturnData = "";
 		bz_addURLJob(bzIDAuthURL.c_str(),this);
 
@@ -1061,34 +1069,35 @@ public:
 	    }
 	    else
 	    {
-	     std::string authURL = "http://my.bzflag.org/weblogin.php";
-	     if (bz_BZDBItemHasValue("_WebAuthURL"))
-	       authURL = bz_getBZDBString("_WebAuthURL").c_str();
+	      std::string authURL = "https://my.bzflag.org/weblogin.php";
+	      if (bz_BZDBItemHasValue("_WebAuthURL"))
+		authURL = bz_getBZDBString("_WebAuthURL").c_str();
 
-	     authURL += "?action=weblogin&url=";
-	     std::string redirURL = vDir->BaseURL.c_str();
+	      authURL += "?action=weblogin&url=";
+	      std::string redirURL = vDir->BaseURL.c_str();
 
-	     std::string vname = "/";
-	     vname += vDir->VDirName();
-	     vname += "/";
+	      std::string vname = "/";
+	      vname += vDir->VDirName();
+	      vname += "/";
 
-	     if (Resource.size() > vname.size())
-	      redirURL += Resource.c_str()+vname.size();
+	      if (Resource.size() > vname.size())
+		redirURL += Resource.c_str()+vname.size();
 
-	     if (redirURL.find_last_of('?') == std::string::npos)
-	       redirURL += "?";
+	      if (redirURL.find_last_of('?') == std::string::npos)
+		redirURL += "?";
 
-	     redirURL += TextUtils::format("bzauthtoken=%%TOKEN%%&bzauthcallsign=%%USERNAME%%&SSID=%d",Request.Session->SessionID);
+	      redirURL += TextUtils::format("bzauthtoken=%%TOKEN%%&bzauthcallsign=%%USERNAME%%&SSID=%d",Request.Session->SessionID);
 
-	     authURL += TextUtils::url_encode(redirURL);
+	      authURL += TextUtils::url_encode(redirURL);
 
-	     Responce.ReturnCode = e302Found;
-	     Responce.RedirectLocation = authURL.c_str();
-	     SetAuthSessionData("bzidauthstatus","redired");
+	      // authStatus = eNotAuthedYet;
+	      Response.ReturnCode = e302Found;
+	      Response.RedirectLocation = authURL.c_str();
+	      SetAuthSessionData("bzidauthstatus","redired");
 	    }
 
 	    if (Authenticated && vDir->CacheAuthentication)
-	       SetAuthSessionData("bzid", Request.BZID.c_str());
+	      SetAuthSessionData("bzid", Request.BZID.c_str());
 	  }
 	  else
 	  {
@@ -1114,21 +1123,21 @@ public:
 
 	      if (!Authenticated)
 	      {
-		if (!vDir->GenerateNoAuthPage(Request,Responce) && authStatus == eAuthFail)
-		  Responce.ReturnCode = e403Forbiden;
+		if (!vDir->GenerateNoAuthPage(Request,Response) && authStatus == eAuthFail)
+		  Response.ReturnCode = e403Forbiden;
 	      }
 
 	      if (Authenticated && vDir->CacheAuthentication)
 		SetAuthSessionData("authstatus", "complete");
 	    }
 	    else
-	      Responce.ReturnCode = e401Unauthorized;
+	      Response.ReturnCode = e401Unauthorized;
 	  }
 	}
 
 	if (!Authenticated && authStatus == eAuthFail)
 	{
-	  GenerateResponce(connectionID);
+	  GenerateResponse(connectionID);
 	  Killme = true;
 	  return;
 	}
@@ -1147,7 +1156,7 @@ public:
 
   virtual bzhttp_ePageGenStatus GetPage ()
   {
-    if(!vDir)
+    if (!vDir)
       return eNoPage;
 
     VDIR_SESSION_CLASS(Request.Session->pimple,session);
@@ -1160,7 +1169,7 @@ public:
     for (size_t i =0; i < bzGroups.size(); i++)
       Request.BZIDGroups.push_back(bzGroups[i]);
 
-    bzhttp_ePageGenStatus status = vDir->GeneratePage(Request,Responce);
+    bzhttp_ePageGenStatus status = vDir->GeneratePage(Request,Response);
 
     session->CurrentVdir = "";
 
@@ -1185,27 +1194,35 @@ public:
 	  }
 	  else
 	  {
-	    if (!vDir->GenerateNoAuthPage(Request,Responce) && authStatus == eAuthFail)
+	    if (!vDir->GenerateNoAuthPage(Request,Response) && authStatus == eAuthFail)
 	    {
-	      Responce.ReturnCode = e403Forbiden;
-	      GenerateResponce(connectionID);
+	      Response.ReturnCode = e403Forbiden;
+	      GenerateResponse(connectionID);
 	      Killme = true;
 	    }
 	  }
 	}
-	else if (vDir->RequiredAuthentiction == eBZID)
+	else if (vDir->RequiredAuthentiction == eBZID && bzIDAuthComplete) // check to see if we have authed yet or not
 	{
-	  // check and see if that url job is done or not
+	  // if we failed then we suck
 	  if (bzIDAuthFailed)
 	  {
-	    if (!vDir->GenerateNoAuthPage(Request,Responce))
-	      Responce.ReturnCode = e403Forbiden;
-	    GenerateResponce(connectionID);
+	    if (!vDir->GenerateNoAuthPage(Request,Response))
+	      Response.ReturnCode = e403Forbiden;
+	    GenerateResponse(connectionID);
 	    Killme = true;
 	  }
 	}
       }
 
+      if (firedOffBZIDTokenCheck && bzIDAuthComplete)
+      {
+#ifdef BZ_PLUGINS
+	PopPendingHTTPWait();
+#endif
+	firedOffBZIDTokenCheck = false;
+      }
+
       if (!vDir || Authenticated)
       {
 	bzhttp_ePageGenStatus status = GetPage();
@@ -1213,7 +1230,7 @@ public:
 	if (status == eNoPage)
 	  send404Error(connectionID);
 	else if (status == ePageDone)
-	  GenerateResponce(connectionID);
+	  GenerateResponse(connectionID);
       }
     }
     HTTPConnectedPeer::Current = NULL;
@@ -1222,7 +1239,7 @@ public:
 
   const char* getMimeType(bzhttp_eDocumentType docType)
   {
-    switch(docType) {
+    switch (docType) {
       case eOctetStream:
 	return "application/octet-stream";
 
@@ -1250,7 +1267,7 @@ public:
 
   void appendTime(std::string & text, bz_Time *ts, const char* _zoneofTime)
   {
-    switch(ts->dayofweek) {
+    switch (ts->dayofweek) {
   case 1:
     text += "Mon";
     break;
@@ -1276,7 +1293,7 @@ public:
 
     text += TextUtils::format(", %d ",ts->day);
 
-    switch(ts->month) {
+    switch (ts->month) {
   case 0:
     text += "Jan";
     break;
@@ -1329,46 +1346,54 @@ public:
     return time;
   }
 
-  void GenerateResponce (int connectionID)
+  void GenerateResponse (int connectionID)
   {
-    RESPONCE_DATA_CLASS(Responce.pimple,data);
+    RESPONSE_DATA_CLASS(Response.pimple,data);
 
     // set the session cookie
-    Responce.AddCookies(SESSION_COOKIE,TextUtils::format("%d",Request.Session->SessionID).c_str());
+    Response.AddCookies(SESSION_COOKIE,TextUtils::format("%d",Request.Session->SessionID).c_str());
 
     std::string pageBuffer = "HTTP/1.1";
 
-    switch (Responce.ReturnCode)
+    bool redirected = false;
+
+    switch (Response.ReturnCode)
     {
       case e200OK:
 	pageBuffer += " 200 OK\n";
 	break;
       case e301Redirect:
-	if (Responce.RedirectLocation.size())
+	if (Response.RedirectLocation.size())
 	{
+	  redirected = true;
 	  pageBuffer += " 301 Moved Permanently\n";
-	  pageBuffer += "Location: " + std::string(Responce.RedirectLocation.c_str()) + "\n";
+	  pageBuffer += "Location: " + std::string(Response.RedirectLocation.c_str()) + "\n";
 	}
-	else
+	else {
 	  pageBuffer += " 500 Server Error\n";
-	pageBuffer += "Host: " + ServerHostname + "\n";
+	}
+
+	pageBuffer += "Host: " + ServerHostPort + "\n";
 	break;
 
       case e302Found:
-	if (Responce.RedirectLocation.size())
+	if (Response.RedirectLocation.size())
 	{
+	  redirected = true;
 	  pageBuffer += " 302 Found\n";
-	  pageBuffer += "Location: " + std::string(Responce.RedirectLocation.c_str()) + "\n";
+	  pageBuffer += "Location: " + std::string(Response.RedirectLocation.c_str()) + "\n";
 	}
-	else
+	else {
 	  pageBuffer += " 500 Server Error\n";
+	}
 
-	pageBuffer += "Host: " + ServerHostname + "\n";
+	pageBuffer += "Host: " + ServerHostPort + "\n";
 	break;
 
       case e401Unauthorized:
-	if (!vDir || vDir->RequiredAuthentiction == eBZID)
+	if (!vDir || vDir->RequiredAuthentiction == eBZID) {
 	  pageBuffer += " 403 Forbidden\n";
+	}
 	else
 	{
 	  pageBuffer += " 401 Unauthorized\n";
@@ -1383,7 +1408,7 @@ public:
 	  if (vDir->HTTPAuthenicationRelalm.size())
 	    pageBuffer += vDir->HTTPAuthenicationRelalm.c_str();
 	  else
-	    pageBuffer += ServerHostname;
+	    pageBuffer += ServerHostPort;
 	  pageBuffer += "\"\n";
 	}
 	break;
@@ -1412,12 +1437,12 @@ public:
       pageBuffer += TextUtils::format("Content-Length: %d\n", data->Body.size());
 
       pageBuffer += "Content-Type: ";
-      if (Responce.ReturnCode == e200OK)
+      if (Response.ReturnCode == e200OK)
       {
-	if (Responce.DocumentType == eOther && Responce.MimeType.size())
-	  pageBuffer += Responce.MimeType.c_str();
+	if (Response.DocumentType == eOther && Response.MimeType.size())
+	  pageBuffer += Response.MimeType.c_str();
 	else
-	  pageBuffer += getMimeType(Responce.DocumentType);
+	  pageBuffer += getMimeType(Response.DocumentType);
       }
       else
 	pageBuffer += getMimeType(eHTML);
@@ -1425,11 +1450,11 @@ public:
       pageBuffer += "\n";
     }
 
-    if (Responce.ForceNoCache)
+    if (Response.ForceNoCache)
       pageBuffer += "Cache-Control: no-cache\n";
 
-    if (Responce.MD5Hash.size())
-      pageBuffer += "Content-MD5: " + std::string(Responce.MD5Hash.c_str()) + "\n";
+    if (Response.MD5Hash.size())
+      pageBuffer += "Content-MD5: " + std::string(Response.MD5Hash.c_str()) + "\n";
 
     pageBuffer += "Server: " + ServerVersion + "\n";
 
@@ -1441,7 +1466,7 @@ public:
       pageBuffer += itr->first + ":" + itr->second + "\n";
       if (itr->first == "Date")
 	didDate = true;
-      itr++;
+      ++itr;
     }
 
     if (!didDate)
@@ -1456,13 +1481,13 @@ public:
     std::string cookieDomain;
     std::string cookiePath;
 
-    if (Responce.CookieDomain.size())
-      cookieDomain = Responce.CookieDomain.c_str();
+    if (Response.CookieDomain.size())
+      cookieDomain = Response.CookieDomain.c_str();
     else
       cookieDomain = ServerHostname;
 
-    if (Responce.CookiePath.size())
-      cookiePath = Responce.CookiePath.c_str();
+    if (Response.CookiePath.size())
+      cookiePath = Response.CookiePath.c_str();
     else
     {
       if (vDir)
@@ -1472,7 +1497,7 @@ public:
     }
 
 
-  //  if (Responce.ReturnCode == e200OK)
+  //  if (Response.ReturnCode == e200OK)
     {
       itr = data->Cookies.begin();
       while (itr != data->Cookies.end())
@@ -1492,7 +1517,7 @@ public:
 	}
 
 	pageBuffer +=  TextUtils::format("Set-Cookie: %s=%s; Domain=%s; Path=%s; Max-Age=3600; HttpOnly\n",itr->first.c_str(),itr->second.c_str(),d.c_str(),p.c_str());
-	itr++;
+	++itr;
       }
     }
 
@@ -1501,6 +1526,9 @@ public:
      if (Request.RequestType != eHTTPHead && data->Body.size())
       pageBuffer += data->Body;
 
+     pageBuffer += "\n\n";
+
+     bz_setNonPlayerDisconnectOnSend(connectionID,redirected);
 
      // build up the buffers
      size_t i = 0;
@@ -1527,7 +1555,7 @@ public:
       if (v[i].size())
       {
 	std::vector<std::string> t = TextUtils::tokenize(v[i],"=");
-	if (t.size())
+	if (!t.empty())
 	  Request.AddParamater(TextUtils::url_decode(t[0]).c_str(), t.size() > 1 ? TextUtils::url_decode(t[1]).c_str() : "");
       }
     }
@@ -1610,17 +1638,21 @@ public:
     size = ftell(fp);
     fseek(fp,0,SEEK_SET);
     void *p = malloc(size);
-    fread(p,size,1,fp);
-
-    Responce.MD5Hash = bz_MD5(p,size);
+    size_t item_read = fread(p,size,1,fp);
     fclose(fp);
 
+    Response.MD5Hash = bz_MD5(p,size);
+
     if (Request.RequestType != eHTTPHead)
-      Responce.AddBodyData(p,size);
+      Response.AddBodyData(p,size);
     free(p);
-    Responce.ReturnCode = e200OK;
-    Responce.DocumentType = eOther;
-    Responce.MimeType = Mime.c_str();
+
+    if (item_read != 1)
+      return eNoPage;
+
+    Response.ReturnCode = e200OK;
+    Response.DocumentType = eOther;
+    Response.MimeType = Mime.c_str();
 
     return ePageDone;
   }
@@ -1651,31 +1683,32 @@ public:
     AddStandardTypes();
   }
 
-  virtual const char* VDirName(){return "INDEX";}
+  virtual const char* VDirName() {return "INDEX";}
 
-  virtual bzhttp_ePageGenStatus GeneratePage ( const bzhttp_Request& request, bzhttp_Responce &responce )
+  virtual bzhttp_ePageGenStatus GeneratePage (const bzhttp_Request &, bzhttp_Response &response)
   {
-    responce.ReturnCode = e200OK;
-    responce.DocumentType = eHTML;
-    responce.AddBodyData("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\"><html><head>");
-    responce.AddBodyData("<title>Index page for ");
-    responce.AddBodyData(ServerHostname.c_str());
-    responce.AddBodyData("</title></head><body>");
+    response.ReturnCode = e200OK;
+    response.DocumentType = eHTML;
+    response.AddBodyData("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\"><html><head>");
+    response.AddBodyData("<title>Index page for ");
+    response.AddBodyData(ServerHostPort.c_str());
+    response.AddBodyData("</title></head><body>");
 
-    if (VDirs.size() == 0)
-     responce.AddBodyData("No HTTP Services are running on this server");
-    else
-    {
+    if (VDirs.empty()) {
+     response.AddBodyData("No HTTP Services are running on this server");
+    } else {
       std::map<std::string,VDir>::iterator itr = VDirs.begin();
+      while (itr != VDirs.end())
       {
 	std::string vdirName = itr->second.vdir->VDirName();
 	std::string vDirDescription = itr->second.vdir->VDirDescription();
 	std::string line =  "<a href=\"/" + vdirName + "/\">" + vdirName +"</a>&nbsp;" +vDirDescription +"<br/>";
-	responce.AddBodyData(line.c_str());
+	response.AddBodyData(line.c_str());
+	itr++;
       }
     }
 
-    responce.AddBodyData("</body></html>");
+    response.AddBodyData("</body></html>");
 
     return ePageDone;
   }
@@ -1694,7 +1727,7 @@ void InitHTTP()
 {
   indexHandler = new HTTPIndexHandler();
   VDirs.clear();
-  if (con || tick){  
+  if (con || tick) {
     worldEventManager.removeEvent(bz_eTickEvent,tick);
     worldEventManager.removeEvent(bz_eNewNonPlayerConnection,con);
     delete(con);
@@ -1711,13 +1744,17 @@ void InitHTTP()
     ServerHostname = bz_getPublicAddr().c_str();
 
   // make sure it has the port
-  if (strrchr(ServerHostname.c_str(),':') == NULL)
-    ServerHostname += TextUtils::format(":%d",bz_getPublicPort());
+  size_t pos;
+  if ((pos = ServerHostname.find(':')) != std::string::npos)
+    ServerHostname = ServerHostname.substr(0, pos);
+  ServerPort = TextUtils::format("%d",bz_getPublicPort());
+
+  ServerHostPort = ServerHostname + ":" + ServerPort;
 
   ServerVersion = bz_getServerVersion();
 
   BaseURL = "http://";
-  BaseURL += ServerHostname +"/";
+  BaseURL += ServerHostPort + "/";
 
   indexHandler->BaseURL = BaseURL.c_str();
 }
@@ -1729,26 +1766,30 @@ void KillHTTP()
   {
     bz_disconnectNonPlayerConnection(itr->first);
     delete(itr->second);
-    itr++;
+    ++itr;
   }
 
   HTTPPeers.clear();
-  if (con || tick)
-  {
-    worldEventManager.removeEvent(bz_eTickEvent,tick);
-    worldEventManager.removeEvent(bz_eNewNonPlayerConnection,con);
-    delete(con);
-    con = NULL;
+
+  if (tick) {
+    worldEventManager.removeHandler(tick);
     delete(tick);
     tick = NULL;
- }
+  }
+
+  if (con) {
+    worldEventManager.removeHandler(con);
+    delete(con);
+    con = NULL;
+  }
+
   VDirs.clear();
   delete(indexHandler);
 }
 
 void NewHTTPConnection ( bz_EventData *eventData )
 {
-  if (VDirs.size() == 0)
+  if (VDirs.empty())
     return;
 
   bz_NewNonPlayerConnectionEventData_V1 *connData = (bz_NewNonPlayerConnectionEventData_V1*)eventData;
@@ -1855,7 +1896,7 @@ void NewHTTPConnection ( bz_EventData *eventData )
 
 void CheckForZombies ( void )
 {
-  std::map<int,HTTPConnectedPeer*>::iterator itr = HTTPPeers.end();
+  std::map<int,HTTPConnectedPeer*>::iterator itr = HTTPPeers.begin();
   std::vector<int> toKill;
 
   while (itr != HTTPPeers.end())
@@ -1871,6 +1912,8 @@ void CheckForZombies ( void )
     }
     else
       itr->second->Think(itr->first);
+
+	itr++;
   }
 
   for (size_t i = 0; i < toKill.size(); i++)
@@ -1881,7 +1924,7 @@ void CheckForZombies ( void )
   double sessionTimeOut = 10*60;
   double rightNow = TimeKeeper::getCurrent().getSeconds();
   std::map<int,bzhttp_SessionData*>::iterator sessionItr = Sessions.begin();
-  while(sessionItr != Sessions.end())
+  while (sessionItr != Sessions.end())
   {
     VDIR_SESSION_CLASS(sessionItr->second->pimple,data);
     if (data->LastUpdateTime + sessionTimeOut < rightNow)
@@ -1889,7 +1932,7 @@ void CheckForZombies ( void )
       delete (sessionItr->second);
       toKill.push_back(sessionItr->first);
     }
-    sessionItr++;
+    ++sessionItr;
   }
 
   for (size_t i = 0; i < toKill.size(); i++)
@@ -2002,13 +2045,16 @@ std::string readFileText ( const char* file )
   fseek(fp,0,SEEK_SET);
 
   char* m = (char*)malloc(s+1);
-  fread(m,s,1,fp);
+  size_t item_read = fread(m, s, 1, fp);
   m[s] = 0;
   fclose(fp);
 
-  std::string ret = m;
+  std::string ret(m);
   free(m);
 
+  if (item_read != 1)
+    return std::string();
+
   if (ret.find_first_of('\n') != std::string::npos)
     return ret;
 
@@ -2061,10 +2107,10 @@ std::string::const_iterator readKey ( std::string &key, std::string::const_itera
   while ( itr != str.end() ) {
     if (*itr != ']') {
       key += *itr;
-      itr++;
+      ++itr;
     } else {
       // go past the code
-      itr++;
+      ++itr;
       key = TextUtils::tolower(key);
       return itr;
     }
@@ -2075,7 +2121,7 @@ std::string::const_iterator readKey ( std::string &key, std::string::const_itera
 
 std::string::const_iterator findNextTag ( const std::vector<std::string> &keys, std::string &endKey, std::string &code, std::string::const_iterator inItr, const std::string &str )
 {
-  if (!keys.size())
+  if (keys.empty())
     return inItr;
 
   std::string::const_iterator itr = inItr;
@@ -2088,7 +2134,7 @@ std::string::const_iterator findNextTag ( const std::vector<std::string> &keys,
     // save off the itr in case this is the one, so we can copy to this point
     std::string::const_iterator keyStartItr = itr;
 
-    itr++;
+    ++itr;
     if (itr == str.end())
       return itr;
 
@@ -2109,7 +2155,7 @@ std::string::const_iterator findNextTag ( const std::vector<std::string> &keys,
 
 double startTime;
 
-const char* CallKey ( std::string& key, bzhttp_TemplateCallback* callback)
+std::string CallKey ( std::string& key, bzhttp_TemplateCallback* callback)
 {
   if (key == "date") {
     bz_Time time;
@@ -2120,9 +2166,10 @@ const char* CallKey ( std::string& key, bzhttp_TemplateCallback* callback)
     bz_getLocaltime(&time);
     TextUtils::format("%d:%d:%d",time.hour,time.minute,time.second);
   } else if (key == "hostname") {
-    std::string data = bz_getPublicAddr().c_str();
+    std::string data = bz_getPublicAddr();
     if (!data.size())
-     return TextUtils::format("localhost:%d",bz_getPublicPort()).c_str();
+      data = TextUtils::format("localhost:%d",bz_getPublicPort());
+    return data;
   } else if (key == "pagetime") {
     return TextUtils::format("%.3f",bz_getCurrentTime()-startTime).c_str();
   } else if (key == "baseurl") {
@@ -2130,8 +2177,9 @@ const char* CallKey ( std::string& key, bzhttp_TemplateCallback* callback)
   } else if (key == "pluginname") {
     return VDirs[HTTPConnectedPeer::Current->vDir->VDirName()].plugin ? VDirs[HTTPConnectedPeer::Current->vDir->VDirName()].plugin->Name() : "";
   }
-  else if (callback)
+  else if (callback) {
     return callback->GetTemplateKey(key.c_str());
+  }
 
   return "";
 }
@@ -2144,11 +2192,7 @@ void replaceVar ( std::string &code, std::string::const_iterator &itr, const std
   itr = readKey(key,itr,str);
 
   if (itr != str.end()) {
-    std::string lowerKey;
-    std::string val;
-
-    lowerKey = TextUtils::tolower(key);
-
+    std::string lowerKey(TextUtils::tolower(key));
     code += CallKey(lowerKey,info.Callback);
   }
 }
@@ -2202,7 +2246,7 @@ void processLoop ( std::string &code, std::string::const_iterator &inItr, const
   {
     code += processTemplate(loopSection,info);
 
-    while(info.Callback && info.Callback->GetTemplateLoop(commandParts[1].c_str(),param.c_str()))
+    while (info.Callback && info.Callback->GetTemplateLoop(commandParts[1].c_str(),param.c_str()))
       code += processTemplate(loopSection,info);
   }
   else
@@ -2344,14 +2388,14 @@ std::string processTemplate ( const std::string &templateText, TemplateInfo& inf
   while ( templateItr != templateText.end() ) {
     if ( *templateItr != '[' ) {
       code += *templateItr;
-      templateItr++;
+      ++templateItr;
     } else {
-      templateItr++;
+      ++templateItr;
 
       if (templateItr == templateText.end()) {
 	code += '[';
       } else {
-	switch(*templateItr) {
+	switch (*templateItr) {
 	default: // it's not a code, so just let the next loop hit it and output it
 	  break;
 
@@ -2416,7 +2460,8 @@ BZF_API bz_ApiString bzhttp_RenderTemplateFromText ( const char* text, bzhttp_Te
 
   TemplateInfo info;
   info.Callback = callback;
-  info.PathSet = pathSet;
+  if (pathSet)
+	info.PathSet = pathSet;
 
   startTime = TimeKeeper::getCurrent().getSeconds();
 
@@ -2472,7 +2517,7 @@ BZF_API const char* bzhttp_FindFile ( const char* pathSet, const char* filename
   std::vector<std::string> &list = PathSets[name];
   for ( size_t i = 0; i < list.size(); i++)
   {
-    std::string path = concatPaths(list[i].c_str(),filename);
+    static const std::string path = concatPaths(list[i].c_str(),filename);
     if (fileExits(path.c_str()))
       return path.c_str();
   }
@@ -2480,7 +2525,7 @@ BZF_API const char* bzhttp_FindFile ( const char* pathSet, const char* filename
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
