@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2012 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -29,6 +29,9 @@ std::vector<std::string> getPluginList ( void );
 
 float getPluginMinWaitTime ( void );
 
+void PushPendingHTTPWait ();
+void PopPendingHTTPWait ();
+
 bz_Plugin* getPlugin( const char* name );
 
 extern std::string lastPluginDir;
@@ -37,7 +40,7 @@ extern std::string lastPluginDir;
 #endif //_BZFS_PLUGINS_H_
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
