@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786)
-#endif
-
 #include "common.h"
 
 // implementation header
@@ -110,7 +106,7 @@ std::string AutoCompleter::complete(const std::string& str, std::string* matches
     *matches = "";
     if (first != last) {
       std::vector<WordRecord>::iterator it = first;
-      for (it = first; it != (last + 1); it++) {
+      for (it = first; it != (last + 1); ++it) {
 	std::string tmp2 = it->word;
 	// strip the trailing whitespace
 	while ((tmp2.size() > 0) && isspace(tmp2[tmp2.size() - 1])) {
@@ -176,9 +172,9 @@ void DefaultCompleter::setDefaults()
   registerWord("show");
   registerWord("/flaghistory");
   registerWord("/gameover");
-  registerWord("/ghost ");
   registerWord("/grouplist");
   registerWord("/groupperms");
+  registerWord("/handicap");
   registerWord("/help");
   registerWord("/highlight ");
   registerWord("/hostban ");
@@ -189,13 +185,20 @@ void DefaultCompleter::setDefaults()
   registerWord("/idbanlist");
   registerWord("/idlist");
   registerWord("/idlestats");
+  registerWord("/idletime");
+  registerWord("/jitterdrop");
+  registerWord("/jitterwarn");
   registerWord("/kick ");
   registerWord("/kill ");
   registerWord("/lagdrop");
   registerWord("/lagstats");
   registerWord("/lagwarn ");
   registerWord("/localset ");
+  registerWord("/modcount ");
   registerWord("/mute ");
+  registerWord("/owner");
+  registerWord("/packetlossdrop");
+  registerWord("/packetlosswarn");
   registerWord("/password ");
   registerWord("/playerlist");
   registerWord("/poll ");
@@ -226,6 +229,8 @@ void DefaultCompleter::setDefaults()
   registerWord("/retexture");
   registerWord("/roampos ");
   registerWord("/saveworld ");
+  registerWord("/say ");
+  registerWord("/sendhelp ");
   registerWord("/serverdebug");
   registerWord("/serverquery");
   registerWord("/set");
@@ -249,7 +254,7 @@ void DefaultCompleter::setDefaults()
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
