@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -102,6 +102,60 @@ const char*		KeyManager::buttonNames[] = {
   "Joystick Button 8",
   "Joystick Button 9",
   "Joystick Button 10",
+  "Joystick Button 11",
+  "Joystick Button 12",
+  "Joystick Button 13",
+  "Joystick Button 14",
+  "Joystick Button 15",
+  "Joystick Button 16",
+  "Joystick Button 17",
+  "Joystick Button 18",
+  "Joystick Button 19",
+  "Joystick Button 20",
+  "Joystick Button 21",
+  "Joystick Button 22",
+  "Joystick Button 23",
+  "Joystick Button 24",
+  "Joystick Button 25",
+  "Joystick Button 26",
+  "Joystick Button 27",
+  "Joystick Button 28",
+  "Joystick Button 29",
+  "Joystick Button 30",
+  "Joystick Button 31",
+  "Joystick Button 32",
+  "Joystick Hat Up Left",
+  "Joystick Hat Up",
+  "Joystick Hat Up Right",
+  "Joystick Hat Right",
+  "Joystick Hat Down Right",
+  "Joystick Hat Down",
+  "Joystick Hat Down Left",
+  "Joystick Hat Left",
+  "Joystick Hat 2 Up Left",
+  "Joystick Hat 2 Up",
+  "Joystick Hat 2 Up Right",
+  "Joystick Hat 2 Right",
+  "Joystick Hat 2 Down Right",
+  "Joystick Hat 2 Down",
+  "Joystick Hat 2 Down Left",
+  "Joystick Hat 2 Left",
+  "Joystick Hat 3 Up Left",
+  "Joystick Hat 3 Up",
+  "Joystick Hat 3 Up Right",
+  "Joystick Hat 3 Right",
+  "Joystick Hat 3 Down Right",
+  "Joystick Hat 3 Down",
+  "Joystick Hat 3 Down Left",
+  "Joystick Hat 3 Left",
+  "Joystick Hat 4 Up Left",
+  "Joystick Hat 4 Up",
+  "Joystick Hat 4 Up Right",
+  "Joystick Hat 4 Right",
+  "Joystick Hat 4 Down Right",
+  "Joystick Hat 4 Down",
+  "Joystick Hat 4 Down Left",
+  "Joystick Hat 4 Left",
   "LastButton"  // should always be last item listed
 };
 const char*		KeyManager::asciiNames[][2] = {
@@ -172,10 +226,10 @@ void			KeyManager::unbindCommand(const char* command)
   while (index != pressEventToCommand.end()) {
     if (index->second == command) {
       deleteme = index;
-      index++;
+      ++index;
       unbind(deleteme->first, true);
     } else {
-      index++;
+      ++index;
     }
   }
 
@@ -183,10 +237,10 @@ void			KeyManager::unbindCommand(const char* command)
   while (index != releaseEventToCommand.end()) {
     if (index->second == command) {
       deleteme = index;
-      index++;
+      ++index;
       unbind(deleteme->first, false);
     } else {
-      index++;
+      ++index;
     }
   }
 }
@@ -196,11 +250,21 @@ std::string		KeyManager::get(const BzfKeyEvent& key,
 {
   const EventToCommandMap* map = press ? &pressEventToCommand :
     &releaseEventToCommand;
-  EventToCommandMap::const_iterator index = map->find(key);
-  if (index == map->end())
-    return "";
-  else
-    return index->second;
+  // If this key has both a button and an ascii value, search the hard way
+  if (key.ascii != '\0' && key.button != BzfKeyEvent::NoButton) {
+    for (EventToCommandMap::const_iterator index = map->begin(); index != map->end(); ++index) {
+      // If either the ascii or button match, return it
+      if ((index->first.ascii == key.ascii || index->first.button == key.button) && index->first.shift == key.shift)
+        return index->second;
+    }
+  } else {
+    // Otherwise just look for an exact match
+    EventToCommandMap::const_iterator index = map->find(key);
+    if (index != map->end())
+      return index->second;
+  }
+
+  return "";
 }
 
 
@@ -235,9 +299,9 @@ std::string		KeyManager::keyEventToString(
     name += "Ctrl+";
   if (key.shift & BzfKeyEvent::AltKey)
     name += "Alt+";
+  if (key.button != BzfKeyEvent::NoButton)
+    return name + buttonNames[key.button];
   switch (key.ascii) {
-    case 0:
-      return name + buttonNames[key.button];
     case '\b':
       return name + "Backspace";
     case '\t':
@@ -337,7 +401,7 @@ bool			KeyManager::onCallback(
   return true;
 }
 
-bool			KeyManager::KeyEventLess::operator()(
+bool			KeyManager::KeyEventLess::operator() (
 				const BzfKeyEvent& a,
 				const BzfKeyEvent& b) const
 {
@@ -369,10 +433,9 @@ bool			KeyManager::KeyEventLess::operator()(
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
