@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-  #pragma warning( disable : 4786 )  // Disable warning message
-#endif
-
 // interface header
 #include "OSFile.h"
 
@@ -192,10 +188,12 @@ bool OSFile::open(const char *mode)
 
   char  modeToUse[32];
 
-  if (!mode)
+  if (!mode) {
     sprintf(modeToUse, "rb");
-  else
-    strcpy(modeToUse, mode);
+  } else {
+    strncpy(modeToUse, mode, sizeof(modeToUse) - 1);
+    modeToUse[31] = '\0';
+  }
 
   std::string fileName;
 
@@ -203,13 +201,13 @@ bool OSFile::open(const char *mode)
     fileName = osBaseDir;
   fileName += info->osName;
 
-  info->fp = fopen(fileName.c_str(),mode);
+  info->fp = fopen(fileName.c_str(),modeToUse);
 
   // we may need to make the file path to the file, if we are writing then lets get on with it.
-  if (!info->fp && strchr(mode,'w'))
+  if (!info->fp && strchr(modeToUse,'w'))
   {
     osMakePath(fileName);
-    info->fp = fopen(fileName.c_str(),mode);
+    info->fp = fopen(fileName.c_str(),modeToUse);
   }
 
   return isOpen();
@@ -299,7 +297,7 @@ int OSFile::seek(teFilePos ePos, int iOffset)
     return 0;
 
   long iMode;
-  switch(ePos)
+  switch (ePos)
   {
     case eFileStart:
       iMode = SEEK_SET;
@@ -547,7 +545,6 @@ bool OSDir::getNextFile(OSFile &oFile, const char* fileMask, bool bRecursive)
 
   realMask = TextUtils::toupper(realMask);
 
-  std::string theFileExt;
   if (info->namePos == -1)
   {
     info->nameList.clear();
@@ -750,9 +747,12 @@ bool OSDir::linuxAddFileStack(std::string pathName, std::string fileMask, bool b
   char   searchstr[1024];
   std::string  FilePath;
 
-  strcpy(searchstr, pathName.c_str());
-  if (searchstr[strlen(searchstr) - 1] != '/')
-    strcat(searchstr, "/");
+  strncpy(searchstr, pathName.c_str(), sizeof(searchstr) - 1);
+  searchstr[1023] = '\0';
+  size_t pathLen = strlen(searchstr);
+  if ((pathLen < 1022) && searchstr[pathLen - 1] != '/') {
+    searchstr[pathLen] = '/';
+  }
   directory = opendir(searchstr);
   if (!directory)
     return false;
@@ -778,3 +778,11 @@ bool OSDir::linuxAddFileStack(std::string pathName, std::string fileMask, bool b
   return true;
 #endif// !Win32
 }
+
+// Local Variables: ***
+// mode: C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
