@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -144,7 +144,7 @@ void*	PlayerState::pack(void* buf, uint16_t& code)
 }
 
 
-void*	PlayerState::unpack(void* buf, uint16_t code)
+const void*	PlayerState::unpack(const void* buf, uint16_t code)
 {
   int32_t inOrder;
   int16_t inStatus;
@@ -217,7 +217,7 @@ void*	PlayerState::unpack(void* buf, uint16_t code)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
