@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,7 +33,7 @@ void*			ShotUpdate::pack(void* buf) const
   return buf;
 }
 
-void*			ShotUpdate::unpack(void* buf)
+const void*		ShotUpdate::unpack(const void* buf)
 {
   buf = nboUnpackUByte(buf, player);
   buf = nboUnpackUShort(buf, id);
@@ -64,7 +64,7 @@ void*			FiringInfo::pack(void* buf) const
   return buf;
 }
 
-void*			FiringInfo::unpack(void* buf)
+const void*		FiringInfo::unpack(const void* buf)
 {
   buf = nboUnpackFloat(buf, timeSent);
   buf = shot.unpack(buf);
@@ -74,7 +74,7 @@ void*			FiringInfo::unpack(void* buf)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
