@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -85,35 +85,35 @@ const std::string StateDatabase::BZDB_AGILITYADVEL	   = std::string("_agilityAdV
 const std::string StateDatabase::BZDB_AGILITYTIMEWINDOW	   = std::string("_agilityTimeWindow");
 const std::string StateDatabase::BZDB_AGILITYVELDELTA	   = std::string("_agilityVelDelta");
 const std::string StateDatabase::BZDB_AMBIENTLIGHT	   = std::string("_ambientLight");
-const std::string StateDatabase::BZDB_ANGLETOLERANCE       = std::string("_angleTolerance");
+const std::string StateDatabase::BZDB_ANGLETOLERANCE	   = std::string("_angleTolerance");
 const std::string StateDatabase::BZDB_ANGULARAD		   = std::string("_angularAd");
 const std::string StateDatabase::BZDB_AVENUESIZE	   = std::string("_avenueSize");
 const std::string StateDatabase::BZDB_BASESIZE		   = std::string("_baseSize");
 const std::string StateDatabase::BZDB_BOXBASE		   = std::string("_boxBase");
 const std::string StateDatabase::BZDB_BOXHEIGHT		   = std::string("_boxHeight");
-const std::string StateDatabase::BZDB_BURROWDEPTH	  = std::string("_burrowDepth");
-const std::string StateDatabase::BZDB_BURROWSPEEDAD	= std::string("_burrowSpeedAd");
-const std::string StateDatabase::BZDB_BURROWANGULARAD      = std::string("_burrowAngularAd");
-const std::string StateDatabase::BZDB_COLDETDEPTH	  = std::string("_coldetDepth");
-const std::string StateDatabase::BZDB_COLDETELEMENTS       = std::string("_coldetElements");
+const std::string StateDatabase::BZDB_BURROWDEPTH	   = std::string("_burrowDepth");
+const std::string StateDatabase::BZDB_BURROWSPEEDAD	   = std::string("_burrowSpeedAd");
+const std::string StateDatabase::BZDB_BURROWANGULARAD	   = std::string("_burrowAngularAd");
+const std::string StateDatabase::BZDB_COLDETDEPTH	   = std::string("_coldetDepth");
+const std::string StateDatabase::BZDB_COLDETELEMENTS	   = std::string("_coldetElements");
 const std::string StateDatabase::BZDB_COUNTDOWNRESDELAY	   = std::string("_countdownResumeDelay");
 const std::string StateDatabase::BZDB_CULLDEPTH		   = std::string("_cullDepth");
-const std::string StateDatabase::BZDB_CULLELEMENTS	 = std::string("_cullElements");
-const std::string StateDatabase::BZDB_CULLOCCLUDERS	= std::string("_cullOccluders");
-const std::string StateDatabase::BZDB_DISABLEBOTS	  = std::string("_disableBots");
+const std::string StateDatabase::BZDB_CULLELEMENTS	   = std::string("_cullElements");
+const std::string StateDatabase::BZDB_CULLOCCLUDERS	   = std::string("_cullOccluders");
+const std::string StateDatabase::BZDB_DISABLEBOTS	   = std::string("_disableBots");
 const std::string StateDatabase::BZDB_DRAWCELESTIAL	   = std::string("_drawCelestial");
 const std::string StateDatabase::BZDB_DRAWCLOUDS	   = std::string("_drawClouds");
 const std::string StateDatabase::BZDB_DRAWGROUND	   = std::string("_drawGround");
 const std::string StateDatabase::BZDB_DRAWGROUNDLIGHTS	   = std::string("_drawGroundLights");
 const std::string StateDatabase::BZDB_DRAWMOUNTAINS	   = std::string("_drawMountains");
 const std::string StateDatabase::BZDB_DRAWSKY		   = std::string("_drawSky");
-const std::string StateDatabase::BZDB_ENDSHOTDETECTION     = std::string("_endShotDetection");
-const std::string StateDatabase::BZDB_EXPLODETIME	  = std::string("_explodeTime");
-const std::string StateDatabase::BZDB_FLAGALTITUDE	 = std::string("_flagAltitude");
-const std::string StateDatabase::BZDB_FLAGEFFECTTIME       = std::string("_flagEffectTime");
+const std::string StateDatabase::BZDB_ENDSHOTDETECTION	   = std::string("_endShotDetection");
+const std::string StateDatabase::BZDB_EXPLODETIME	   = std::string("_explodeTime");
+const std::string StateDatabase::BZDB_FLAGALTITUDE	   = std::string("_flagAltitude");
+const std::string StateDatabase::BZDB_FLAGEFFECTTIME	   = std::string("_flagEffectTime");
 const std::string StateDatabase::BZDB_FLAGHEIGHT	   = std::string("_flagHeight");
-const std::string StateDatabase::BZDB_FLAGPOLEWIDTH	= std::string("_flagPoleWidth");
-const std::string StateDatabase::BZDB_FLAGPOLESIZE	 = std::string("_flagPoleSize");
+const std::string StateDatabase::BZDB_FLAGPOLEWIDTH	   = std::string("_flagPoleWidth");
+const std::string StateDatabase::BZDB_FLAGPOLESIZE	   = std::string("_flagPoleSize");
 const std::string StateDatabase::BZDB_FLAGRADIUS	   = std::string("_flagRadius");
 const std::string StateDatabase::BZDB_FOGMODE		   = std::string("_fogMode");
 const std::string StateDatabase::BZDB_FOGDENSITY	   = std::string("_fogDensity");
@@ -126,11 +126,11 @@ const std::string StateDatabase::BZDB_GMADLIFE		   = std::string("_gmAdLife");
 const std::string StateDatabase::BZDB_GMSIZE		   = std::string("_gmSize");
 const std::string StateDatabase::BZDB_GMTURNANGLE	   = std::string("_gmTurnAngle");
 const std::string StateDatabase::BZDB_GRAVITY		   = std::string("_gravity");
-const std::string StateDatabase::BZDB_HANDICAPSCOREDIFF    = std::string("_handicapScoreDiff");
+const std::string StateDatabase::BZDB_HANDICAPSCOREDIFF	   = std::string("_handicapScoreDiff");
 const std::string StateDatabase::BZDB_HANDICAPVELAD	   = std::string("_handicapVelAd");
 const std::string StateDatabase::BZDB_HANDICAPANGAD	   = std::string("_handicapAngAd");
 const std::string StateDatabase::BZDB_HANDICAPSHOTAD	   = std::string("_handicapShotAd");
-const std::string StateDatabase::BZDB_HIDEFLAGSONRADAR     = std::string("_hideFlagsOnRadar");
+const std::string StateDatabase::BZDB_HIDEFLAGSONRADAR	   = std::string("_hideFlagsOnRadar");
 const std::string StateDatabase::BZDB_HIDETEAMFLAGSONRADAR = std::string("_hideTeamFlagsOnRadar");
 const std::string StateDatabase::BZDB_IDENTIFYRANGE	   = std::string("_identifyRange");
 const std::string StateDatabase::BZDB_JUMPVELOCITY	   = std::string("_jumpVelocity");
@@ -141,8 +141,8 @@ const std::string StateDatabase::BZDB_LATITUDE		   = std::string("_latitude");
 const std::string StateDatabase::BZDB_LOCKONANGLE	   = std::string("_lockOnAngle");
 const std::string StateDatabase::BZDB_LONGITUDE		   = std::string("_longitude");
 const std::string StateDatabase::BZDB_LRADRATE		   = std::string("_lRAdRate");
-const std::string StateDatabase::BZDB_MAXBUMPHEIGHT	= std::string("_maxBumpHeight");
-const std::string StateDatabase::BZDB_MAXFLAGGRABS	 = std::string("_maxFlagGrabs");
+const std::string StateDatabase::BZDB_MAXBUMPHEIGHT	   = std::string("_maxBumpHeight");
+const std::string StateDatabase::BZDB_MAXFLAGGRABS	   = std::string("_maxFlagGrabs");
 const std::string StateDatabase::BZDB_MAXLOD		   = std::string("_maxLOD");
 const std::string StateDatabase::BZDB_MIRROR		   = std::string("_mirror");
 const std::string StateDatabase::BZDB_MOMENTUMLINACC	   = std::string("_momentumLinAcc");
@@ -155,23 +155,23 @@ const std::string StateDatabase::BZDB_MUZZLEFRONT	   = std::string("_muzzleFront
 const std::string StateDatabase::BZDB_MUZZLEHEIGHT	   = std::string("_muzzleHeight");
 const std::string StateDatabase::BZDB_NOCLIMB		   = std::string("_noClimb");
 const std::string StateDatabase::BZDB_NOSHADOWS		   = std::string("_noShadows");
-const std::string StateDatabase::BZDB_NOSMALLPACKETS       = std::string("_noSmallPackets");
-const std::string StateDatabase::BZDB_NOTRESPONDINGTIME    = std::string("_notRespondingTime");
-const std::string StateDatabase::BZDB_OBESEFACTOR	  = std::string("_obeseFactor");
+const std::string StateDatabase::BZDB_NOSMALLPACKETS	   = std::string("_noSmallPackets");
+const std::string StateDatabase::BZDB_NOTRESPONDINGTIME	   = std::string("_notRespondingTime");
+const std::string StateDatabase::BZDB_OBESEFACTOR	   = std::string("_obeseFactor");
 const std::string StateDatabase::BZDB_PAUSEDROPTIME	   = std::string("_pauseDropTime");
-const std::string StateDatabase::BZDB_POSITIONTOLERANCE    = std::string("_positionTolerance");
+const std::string StateDatabase::BZDB_POSITIONTOLERANCE	   = std::string("_positionTolerance");
 const std::string StateDatabase::BZDB_PYRBASE		   = std::string("_pyrBase");
 const std::string StateDatabase::BZDB_PYRHEIGHT		   = std::string("_pyrHeight");
 const std::string StateDatabase::BZDB_RADARLIMIT	   = std::string("_radarLimit");
 const std::string StateDatabase::BZDB_REJOINTIME	   = std::string("_rejoinTime");
 const std::string StateDatabase::BZDB_RELOADTIME	   = std::string("_reloadTime");
 const std::string StateDatabase::BZDB_RFIREADVEL	   = std::string("_rFireAdVel");
-const std::string StateDatabase::BZDB_RFIREADRATE	  = std::string("_rFireAdRate");
-const std::string StateDatabase::BZDB_RFIREADLIFE	  = std::string("_rFireAdLife");
-const std::string StateDatabase::BZDB_SHIELDFLIGHT	 = std::string("_shieldFlight");
-const std::string StateDatabase::BZDB_SHOCKADLIFE	  = std::string("_shockAdLife");
-const std::string StateDatabase::BZDB_SHOCKINRADIUS	= std::string("_shockInRadius");
-const std::string StateDatabase::BZDB_SHOCKOUTRADIUS       = std::string("_shockOutRadius");
+const std::string StateDatabase::BZDB_RFIREADRATE	   = std::string("_rFireAdRate");
+const std::string StateDatabase::BZDB_RFIREADLIFE	   = std::string("_rFireAdLife");
+const std::string StateDatabase::BZDB_SHIELDFLIGHT	   = std::string("_shieldFlight");
+const std::string StateDatabase::BZDB_SHOCKADLIFE	   = std::string("_shockAdLife");
+const std::string StateDatabase::BZDB_SHOCKINRADIUS	   = std::string("_shockInRadius");
+const std::string StateDatabase::BZDB_SHOCKOUTRADIUS	   = std::string("_shockOutRadius");
 const std::string StateDatabase::BZDB_SHOTRADIUS	   = std::string("_shotRadius");
 const std::string StateDatabase::BZDB_SHOTRANGE		   = std::string("_shotRange");
 const std::string StateDatabase::BZDB_SHOTSPEED		   = std::string("_shotSpeed");
@@ -182,9 +182,9 @@ const std::string StateDatabase::BZDB_SRRADIUSMULT	   = std::string("_srRadiusMu
 const std::string StateDatabase::BZDB_SQUISHFACTOR	   = std::string("_squishFactor");
 const std::string StateDatabase::BZDB_SQUISHTIME	   = std::string("_squishTime");
 const std::string StateDatabase::BZDB_SYNCTIME		   = std::string("_syncTime");
-const std::string StateDatabase::BZDB_SYNCLOCATION	 = std::string("_syncLocation");
+const std::string StateDatabase::BZDB_SYNCLOCATION	   = std::string("_syncLocation");
 const std::string StateDatabase::BZDB_TANKANGVEL	   = std::string("_tankAngVel");
-const std::string StateDatabase::BZDB_TANKEXPLOSIONSIZE    = std::string("_tankExplosionSize");
+const std::string StateDatabase::BZDB_TANKEXPLOSIONSIZE	   = std::string("_tankExplosionSize");
 const std::string StateDatabase::BZDB_TANKHEIGHT	   = std::string("_tankHeight");
 const std::string StateDatabase::BZDB_TANKLENGTH	   = std::string("_tankLength");
 const std::string StateDatabase::BZDB_TANKRADIUS	   = std::string("_tankRadius");
@@ -192,27 +192,27 @@ const std::string StateDatabase::BZDB_TANKSPEED		   = std::string("_tankSpeed");
 const std::string StateDatabase::BZDB_TANKWIDTH		   = std::string("_tankWidth");
 const std::string StateDatabase::BZDB_TARGETINGANGLE	   = std::string("_targetingAngle");
 const std::string StateDatabase::BZDB_TARGETINGDISTANCE	   = std::string("_targetingDistance");
-const std::string StateDatabase::BZDB_TELEBREADTH	  = std::string("_teleportBreadth");
+const std::string StateDatabase::BZDB_TELEBREADTH	   = std::string("_teleportBreadth");
 const std::string StateDatabase::BZDB_TELEHEIGHT	   = std::string("_teleportHeight");
-const std::string StateDatabase::BZDB_TELEPORTTIME	 = std::string("_teleportTime");
+const std::string StateDatabase::BZDB_TELEPORTTIME	   = std::string("_teleportTime");
 const std::string StateDatabase::BZDB_TELEWIDTH		   = std::string("_teleportWidth");
 const std::string StateDatabase::BZDB_THIEFADLIFE	   = std::string("_thiefAdLife");
-const std::string StateDatabase::BZDB_THIEFADRATE	  = std::string("_thiefAdRate");
-const std::string StateDatabase::BZDB_THIEFADSHOTVEL       = std::string("_thiefAdShotVel");
-const std::string StateDatabase::BZDB_THIEFTINYFACTOR      = std::string("_thiefTinyFactor");
+const std::string StateDatabase::BZDB_THIEFADRATE	   = std::string("_thiefAdRate");
+const std::string StateDatabase::BZDB_THIEFADSHOTVEL	   = std::string("_thiefAdShotVel");
+const std::string StateDatabase::BZDB_THIEFTINYFACTOR	   = std::string("_thiefTinyFactor");
 const std::string StateDatabase::BZDB_THIEFVELAD	   = std::string("_thiefVelAd");
-const std::string StateDatabase::BZDB_THIEFDROPTIME	= std::string("_thiefDropTime");
+const std::string StateDatabase::BZDB_THIEFDROPTIME	   = std::string("_thiefDropTime");
 const std::string StateDatabase::BZDB_TINYFACTOR	   = std::string("_tinyFactor");
 const std::string StateDatabase::BZDB_TRACKFADE		   = std::string("_trackFade");
 const std::string StateDatabase::BZDB_UPDATETHROTTLERATE   = std::string("_updateThrottleRate");
 const std::string StateDatabase::BZDB_VELOCITYAD	   = std::string("_velocityAd");
 const std::string StateDatabase::BZDB_WALLHEIGHT	   = std::string("_wallHeight");
 const std::string StateDatabase::BZDB_WEAPONS		   = std::string("_weapons");
-const std::string StateDatabase::BZDB_WIDEANGLEANG	 = std::string("_wideAngleAng");
-const std::string StateDatabase::BZDB_WINGSGRAVITY	 = std::string("_wingsGravity");
-const std::string StateDatabase::BZDB_WINGSJUMPCOUNT       = std::string("_wingsJumpCount");
-const std::string StateDatabase::BZDB_WINGSJUMPVELOCITY    = std::string("_wingsJumpVelocity");
-const std::string StateDatabase::BZDB_WINGSSLIDETIME       = std::string("_wingsSlideTime");
+const std::string StateDatabase::BZDB_WIDEANGLEANG	   = std::string("_wideAngleAng");
+const std::string StateDatabase::BZDB_WINGSGRAVITY	   = std::string("_wingsGravity");
+const std::string StateDatabase::BZDB_WINGSJUMPCOUNT	   = std::string("_wingsJumpCount");
+const std::string StateDatabase::BZDB_WINGSJUMPVELOCITY	   = std::string("_wingsJumpVelocity");
+const std::string StateDatabase::BZDB_WINGSSLIDETIME	   = std::string("_wingsSlideTime");
 const std::string StateDatabase::BZDB_WORLDSIZE		   = std::string("_worldSize");
 
 //
@@ -578,25 +578,25 @@ void		     StateDatabase::setDebug(bool print) {
 }
 
 void		     StateDatabase::setSaveDefault(bool save) {
-	saveDefault = save;
+  saveDefault = save;
 }
 
 StateDatabase::ExpressionToken::ExpressionToken()
 {
-  tokenType = number;
+  tokenType = Number;
   tokenContents.number = 0;
 }
 
 StateDatabase::ExpressionToken::ExpressionToken(Type _tokenType)
 {
   tokenType = _tokenType;
-  switch(tokenType) {
-    case number:
+  switch (tokenType) {
+    case Number:
       tokenContents.number = 0;
       break;
-    case variable:
+    case Variable:
       break;
-    case oper:
+    case Oper:
       tokenContents.oper = none;
       break;
   }
@@ -611,13 +611,13 @@ StateDatabase::ExpressionToken::ExpressionToken(Type _tokenType, Contents _token
 void StateDatabase::ExpressionToken::setType(Type _tokenType)
 {
   tokenType = _tokenType;
-  switch(tokenType) {
-    case number:
+  switch (tokenType) {
+    case Number:
       tokenContents.number = 0;
       break;
-    case variable:
+    case Variable:
       break;
-    case oper:
+    case Oper:
       tokenContents.oper = none;
       break;
   }
@@ -630,19 +630,19 @@ void StateDatabase::ExpressionToken::setContents(Contents _tokenContents)
 
 void StateDatabase::ExpressionToken::setNumber(double num)
 {
-  tokenType = number;
+  tokenType = Number;
   tokenContents.number = num;
 }
 
 void StateDatabase::ExpressionToken::setVariable(std::string var)
 {
-  tokenType = variable;
+  tokenType = Variable;
   tokenContents.variable = var;
 }
 
 void StateDatabase::ExpressionToken::setOper(Operator op)
 {
-  tokenType = oper;
+  tokenType = Oper;
   tokenContents.oper = op;
 }
 
@@ -711,7 +711,7 @@ std::istream&operator >> (std::istream& src, StateDatabase::ExpressionToken& dst
     dst.setNumber(atof(tempname.c_str()));
   } else if (temp == '+' || temp == '-' || temp == '*' || temp == '/' || temp == '^' || temp == '(' || temp == ')') {
     // operator
-    switch(temp) {
+    switch (temp) {
       case '+':
 	dst.setOper(StateDatabase::ExpressionToken::add);
 	break;
@@ -755,15 +755,20 @@ std::string& operator >> (std::string& src, StateDatabase::ExpressionToken& dst)
   char temp;
   std::string tempname;
 
+  if (src.size() == 0)
+    return src;
+
   temp = src[0]; src = src.substr(1);
   if ((temp >= '0' && temp <= '9') || temp == '.') {
     // number
     tempname += temp;
-    temp = src[0];
+    if (!src.empty())
+      temp = src[0];
     while (((temp >= '0' && temp <= '9') || temp == '.') && (src.length() != 0)) {
       src = src.substr(1);
       tempname += temp;
-      temp = src[0];
+      if (!src.empty())
+	temp = src[0];
     }
     dst.setNumber(atof(tempname.c_str()));
   } else if (temp == '+' || temp == '-' || temp == '*' || temp == '/' || temp == '^' || temp == '(' || temp == ')') {
@@ -793,11 +798,13 @@ std::string& operator >> (std::string& src, StateDatabase::ExpressionToken& dst)
     }
   } else if ((temp >= 'a' && temp <= 'z') || (temp >= 'A' && temp <= 'Z') || temp == '_') {
     tempname += temp;
-    temp = src[0];
+    if (!src.empty())
+      temp = src[0];
     while (((temp >= 'a' && temp <= 'z') || (temp >= 'A' && temp <= 'Z') || temp == '_') && (src.length() != 0)) {
       src = src.substr(1);
       tempname += temp;
-      temp = src[0];
+      if (!src.empty())
+	temp = src[0];
     }
     dst.setVariable(tempname);
   } else {
@@ -809,10 +816,10 @@ std::string& operator >> (std::string& src, StateDatabase::ExpressionToken& dst)
 std::ostream& operator << (std::ostream& dst, const StateDatabase::ExpressionToken& src)
 {
   switch (src.getTokenType()) {
-    case StateDatabase::ExpressionToken::number:
+    case StateDatabase::ExpressionToken::Number:
       dst << src.getNumber();
       break;
-    case StateDatabase::ExpressionToken::oper:
+    case StateDatabase::ExpressionToken::Oper:
       switch (src.getOperator()) {
 	case StateDatabase::ExpressionToken::add:
 	  dst << '+';
@@ -839,7 +846,7 @@ std::ostream& operator << (std::ostream& dst, const StateDatabase::ExpressionTok
 	  break;
       }
       break;
-    case StateDatabase::ExpressionToken::variable:
+    case StateDatabase::ExpressionToken::Variable:
       dst << src.getVariable();
       break;
   }
@@ -897,33 +904,33 @@ StateDatabase::Expression StateDatabase::infixToPrefix(const Expression &infix)
   Expression postfix, prefix;
   std::stack<ExpressionToken> operators;
 
-  for (Expression::const_iterator i = infix.begin(); i != infix.end(); i++) {
-    if (i->getTokenType() == ExpressionToken::variable || i->getTokenType() == ExpressionToken::number) {
+  for (Expression::const_iterator i = infix.begin(); i != infix.end(); ++i) {
+    if (i->getTokenType() == ExpressionToken::Variable || i->getTokenType() == ExpressionToken::Number) {
       postfix.push_back(*i);
-    } else if (i->getTokenType() == ExpressionToken::oper) {
+    } else if (i->getTokenType() == ExpressionToken::Oper) {
       if (i->getOperator() == ExpressionToken::lparen) {
 	operators.push(*i);
       } else if (i->getOperator() == ExpressionToken::rparen) {
 	// unstack operators until a matching ( is found
-	while((operators.size() > 0) && (operators.top().getOperator() != ExpressionToken::lparen)) {
+	while (!operators.empty() && (operators.top().getOperator() != ExpressionToken::lparen)) {
 	  postfix.push_back(operators.top()); operators.pop();
 	}
 	// discard (
-	if (operators.size() > 0) // handle extra-rparen case
+	if (!operators.empty()) // handle extra-rparen case
 	  operators.pop();
       } else {
-	while((operators.size() > 0) && (operators.top().getPrecedence() < i->getPrecedence()) && (operators.top().getOperator() != ExpressionToken::lparen)) {
+	while (!operators.empty() && (operators.top().getPrecedence() < i->getPrecedence()) && (operators.top().getOperator() != ExpressionToken::lparen)) {
 	  postfix.push_back(operators.top()); operators.pop();
 	}
 	operators.push(*i);
       }
     }
   }
-  while (operators.size() > 0) {
+  while (!operators.empty()) {
     postfix.push_back(operators.top()); operators.pop();
   }
 
-  for (Expression::reverse_iterator ri = postfix.rbegin(); ri != postfix.rend(); ri++)
+  for (Expression::reverse_iterator ri = postfix.rbegin(); ri != postfix.rend(); ++ri)
     prefix.push_back(*ri);
   return prefix;
 }
@@ -934,23 +941,23 @@ float StateDatabase::evaluate(Expression e) const
   ExpressionToken tok, lvalue, rvalue;
   bool unary;
 
-  for (Expression::reverse_iterator i = e.rbegin(); i != e.rend(); i++) {
+  for (Expression::reverse_iterator i = e.rbegin(); i != e.rend(); ++i) {
     unary = false;
-    switch(i->getTokenType()) {
-      case ExpressionToken::number:
+    switch (i->getTokenType()) {
+      case ExpressionToken::Number:
 	evaluationStack.push(*i);
 	break;
-      case ExpressionToken::variable:
+      case ExpressionToken::Variable:
 	// strip off '$'?
 	tok.setNumber(BZDB.eval(i->getVariable()));
 	evaluationStack.push(tok);
 	break;
-      case ExpressionToken::oper:
+      case ExpressionToken::Oper:
 	if ((i->getOperator() == ExpressionToken::lparen) ||
 	    (i->getOperator() == ExpressionToken::rparen)) {
 	    break;  // should not have any parens here, skip them
 	}
-	if (evaluationStack.size() == 0) {
+	if (evaluationStack.empty()) {
 	  // syntax error
 	  // ugly hack, since gcc 2.95 doesn't have <limits>
 	  float NaN;
@@ -959,13 +966,13 @@ float StateDatabase::evaluate(Expression e) const
 	}
 	// rvalue and lvalue are switched, since we're reversed
 	rvalue = evaluationStack.top(); evaluationStack.pop();
-	if (evaluationStack.size() == 0) {
+	if (evaluationStack.empty()) {
 	  unary = true; // syntax error or unary operator
 	}
 	if (!unary) {
 	  lvalue = evaluationStack.top(); evaluationStack.pop();
 	}
-	switch(i->getOperator()) {
+	switch (i->getOperator()) {
 	  case ExpressionToken::add:
 	    tok.setNumber(lvalue.getNumber() + rvalue.getNumber());
 	    evaluationStack.push(tok);
@@ -997,7 +1004,7 @@ float StateDatabase::evaluate(Expression e) const
 	break;
     }
   }
-  if (!evaluationStack.size())
+  if (evaluationStack.empty())
     return 0; // yeah we are screwed. TODO, don't let us get this far
 
   return (float)evaluationStack.top().getNumber();
@@ -1005,7 +1012,7 @@ float StateDatabase::evaluate(Expression e) const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
