@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2012 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,16 +12,18 @@
 
 #include "common.h"
 #include "Team.h"
+#include "AnsiCodes.h"
+#include "BZDBCache.h"
 #include "Pack.h"
 
 float			Team::tankColor[NumTeams][3] = {
-				{ 0.0f, 0.0f, 0.0f },   // rogue
+				{ 1.0f, 1.0f, 0.0f },   // rogue
 				{ 1.0f, 0.0f, 0.0f },   // red
 				{ 0.0f, 1.0f, 0.0f },   // green
-				{ 0.2f, 0.2f, 1.0f },   // blue
+				{ 0.1f, 0.2f, 1.0f },   // blue
 				{ 1.0f, 0.0f, 1.0f },   // purple
-				{ 0.0f, 1.0f, 1.0f },   // observer
-				{ 1.0f, 1.0f, 1.0f },   // rabbit
+				{ 1.0f, 1.0f, 1.0f },   // observer
+				{ 0.8f, 0.8f, 0.8f },   // rabbit
 				{ 1.0f, 0.5f, 0.0f }	// hunter orange
 			};
 float			Team::radarColor[NumTeams][3] = {
@@ -30,10 +32,12 @@ float			Team::radarColor[NumTeams][3] = {
 				{ 0.2f, 0.9f, 0.2f },	// green
 				{ 0.08f, 0.25, 1.0f},	// blue
 				{ 1.0f, 0.4f, 1.0f },	// purple
-				{ 0.0f, 1.0f, 1.0f },	// observer
+				{ 1.0f, 1.0f, 1.0f },	// observer
 				{ 1.0f, 1.0f, 1.0f },   // rabbit
 				{ 1.0f, 0.5f, 0.0f }	// hunter orange
 			};
+float			Team::shotColor[NumTeams][3];
+
 
 Team::Team()
 {
@@ -50,7 +54,7 @@ void*			Team::pack(void* buf) const
   return buf;
 }
 
-void*			Team::unpack(void* buf)
+const void*		Team::unpack(const void* buf)
 {
   uint16_t inSize, inWon, inLost;
   buf = nboUnpackUShort(buf, inSize);
@@ -122,6 +126,19 @@ const float*		Team::getRadarColor(TeamColor team) // const
   return radarColor[int(team)];
 }
 
+const float*		Team::getShotColor(TeamColor team) // const
+{
+  if (int(team) < 0) {
+    return shotColor[0];
+  }
+  return shotColor[int(team)];
+}
+
+const std::string	Team::getAnsiCode(TeamColor team) // const
+{
+  return rgbToAnsi(getTankColor(team));
+}
+
 bool		Team::isColorTeam(TeamColor team) // const
 {
   return team >= RedTeam  && team <= PurpleTeam;
@@ -136,19 +153,50 @@ void			Team::setColors(TeamColor team,
   if (teamIndex < 0)
     return;
 
-  tankColor[teamIndex][0] = tank[0];
-  tankColor[teamIndex][1] = tank[1];
-  tankColor[teamIndex][2] = tank[2];
-  radarColor[teamIndex][0] = radar[0];
-  radarColor[teamIndex][1] = radar[1];
-  radarColor[teamIndex][2] = radar[2];
+  for (int i = 0; i <= 2; i++) {
+    tankColor[teamIndex][i] = tank[i];
+    radarColor[teamIndex][i] = radar[i];
+    shotColor[teamIndex][i] = addBrightness(tank[i]);
+  }
+}
+
+void			Team::updateShotColors()
+{
+  for (int teamIndex = 0; teamIndex < NumTeams; teamIndex++) {
+    for (int i = 0; i <= 2; i++) {
+      shotColor[teamIndex][i] = addBrightness(tankColor[teamIndex][i]);
+    }
+  }
+}
+
+float Team::addBrightness(const float color)
+{
+  if (BZDBCache::shotBrightness == 0.0f) {
+    return color;
+  }
+
+  float brightness = BZDBCache::shotBrightness;
+
+  if (brightness > 0.0f) {
+    brightness *= pow(1.0f - color, 4.0f);
+  } else {
+    brightness *= color;
+  }
+
+  // Make sure that the resulting color doesn't get below 0 or above 1
+  if (brightness + color > 1.0f) {
+    return 1.0f;
+  } else if (brightness + color < 0.0f) {
+    return 0.0f;
+  }
+
+  return brightness + color;
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
