@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4: 4786)
-#endif
-
 /* interface header */
 #include "TextChunkManager.h"
 
@@ -144,7 +140,7 @@ const StringVector* TextChunkManager::getTextChunk(const std::string &chunkName)
 {
   TextChunkMap::const_iterator it;
   it = theChunks.find(chunkName);
-  if (it != theChunks.end()){
+  if (it != theChunks.end()) {
     return &it->second.getVector();
   } else {
     return NULL;
@@ -161,7 +157,7 @@ const StringVector& TextChunkManager::getChunkNames() const
 void TextChunkManager::reload()
 {
   TextChunkMap::iterator it;
-  for (it = theChunks.begin(); it != theChunks.end(); it++) {
+  for (it = theChunks.begin(); it != theChunks.end(); ++it) {
     it->second.reload();
   }
   return;
@@ -172,10 +168,9 @@ void TextChunkManager::reload()
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
