@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -72,12 +72,12 @@ bool WordFilter::simpleFilter(char *input) const
 
 bool WordFilter::aggressiveFilter(char *input) const
 {
-#if !defined(BUILD_REGEX) && !defined(HAVE_REGEX_H)
+#if  !defined(HAVE_REGEX_H)
 
   std::cerr << "Regular expressions are not available (using the simple filter)" << std::endl;
   return simpleFilter(input);
 
-#else /* BUILD_REGEX || HAVE_REGEX_H */
+#else /* HAVE_REGEX_H */
 
   bool filtered = false;
   regmatch_t match[1];
@@ -318,17 +318,17 @@ bool WordFilter::aggressiveFilter(char *input) const
 
   return filtered;
 
-#endif /* BUILD_REGEX || HAVE_REGEX_H */
+#endif /* HAVE_REGEX_H */
 } // end aggressiveFilter
 
 
 // provides a pointer to a fresh compiled expression for some given expression
-#if !defined(BUILD_REGEX) && !defined(HAVE_REGEX_H)
+#if !defined(HAVE_REGEX_H)
 regex_t *WordFilter::getCompiledExpression(const std::string &) const
 {
   return (regex_t *)NULL;
 }
-#else /* BUILD_REGEX || HAVE_REGEX_H */
+#else /* HAVE_REGEX_H */
 regex_t *WordFilter::getCompiledExpression(const std::string &word) const
 {
   regex_t *compiledReg;
@@ -350,7 +350,7 @@ regex_t *WordFilter::getCompiledExpression(const std::string &word) const
   return compiledReg;
 
 }
-#endif /* BUILD_REGEX || HAVE_REGEX_H */
+#endif /* HAVE_REGEX_H */
 
 
 std::string WordFilter::l33tspeakSetFromCharacter(const char c) const
@@ -369,7 +369,7 @@ std::string WordFilter::l33tspeakSetFromCharacter(const char c) const
     return set;
   }
 
-  switch(c) {
+  switch (c) {
     case 'a':
       set = "a4@";
       break;
@@ -427,7 +427,7 @@ std::string WordFilter::alphabeticSetFromCharacter(const char c) const
   /* for most punctuation, we include the actual punctuation
    * last just in case it was really intended
    */
-  switch(c) {
+  switch (c) {
     case '!':
       set = "il";
       break;
@@ -651,7 +651,7 @@ WordFilter::~WordFilter(void)
   for (int j = 0; j < MAX_FILTER_SETS; j++) {
     for (i = filters[j].begin();
 	 i != filters[j].end();
-	 i++) {
+	 ++i) {
       if (i->compiled) {
 	regfree(i->compiled);
 	free(i->compiled);
@@ -661,7 +661,7 @@ WordFilter::~WordFilter(void)
   // delete compiled prefixes
   for (i = prefixes.begin();
        i != prefixes.end();
-       i++) {
+       ++i) {
     if (i->compiled) {
       regfree(i->compiled);
       free(i->compiled);
@@ -670,7 +670,7 @@ WordFilter::~WordFilter(void)
   // delete compiled suffixes
   for (i = suffixes.begin();
        i != suffixes.end();
-       i++) {
+       ++i) {
     if (i->compiled) {
       regfree(i->compiled);
       free(i->compiled);
@@ -795,7 +795,6 @@ unsigned int WordFilter::loadFromFile(const std::string &fileName, bool verbose)
   return totalAdded;
 } // end loadFromFile
 
-
 /** filters an input message either a complex regular expression-based
  * pattern match (default) catching hundreds of variations per filter
  * word or using a simple exact word match technique (original).
@@ -820,7 +819,7 @@ bool WordFilter::filter(char *input, const bool simple) const
 
 bool WordFilter::filter(std::string &input, const bool simple) const
 {
-  char input2[512] = {0};
+  char input2[512];
   bool filtered = false;
   std::string resultString = "";
 
@@ -828,8 +827,9 @@ bool WordFilter::filter(std::string &input, const bool simple) const
    * but it works.  just means words that span the boundary might be
    * wrong.
    */
-  for (unsigned int i = 0; i < input.size(); i+=512) {
-    strncpy(input2, input.c_str() + i, 512);
+  for (unsigned int i = 0; i < input.size(); i+=511) {
+    strncpy(input2, input.c_str() + i, 511);
+    input2[511] = '\0';
     bool filteredChunk = filter(input2, simple);
     if (filteredChunk) {
       filtered = true;
@@ -882,12 +882,19 @@ unsigned long int WordFilter::wordCount(void) const
   return count;
 }
 
+void WordFilter::clear(void)
+{
+	for (int i = 0; i < MAX_FILTER_SETS; i++)
+		filters[i].clear();
+
+	suffixes.clear();
+	prefixes.clear();
+}
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
