@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -11,6 +11,7 @@
  */
 
 #include "common.h"
+#include "version.h"
 
 /* system headers */
 #include <sstream>
@@ -24,17 +25,18 @@
 //  misc/bzfquery.php
 //  misc/bzfquery.pl
 //  misc/bzfquery.py
+//  misc/bzls.lua
 #ifndef BZ_PROTO_VERSION
 #  define BZ_PROTO_VERSION	"0221"
 #endif
 
 // version numbers - also update as needed:
 //  ChangeLog
+//  MSVC/bzflag.rc
 //  README
 //  configure.ac
 //  include/version.h
 //  package/win32/nsis/BZFlag.nsi
-//  tools/TextTool-W32/TextTool.rc
 #ifndef BZ_MAJOR_VERSION
 #  define BZ_MAJOR_VERSION	2
 #endif
@@ -44,44 +46,26 @@
 #endif
 
 #ifndef BZ_REV
-#  define BZ_REV		0
+#  define BZ_REV		14
 #endif
 
 // DEVEL | RC# | STABLE | MAINT
 #ifndef BZ_BUILD_TYPE
-#  define BZ_BUILD_TYPE		"STABLE"
+#  define BZ_BUILD_TYPE		"MAINT"
 #endif
 
-const char *bzfcopyright = "Copyright (c) 1993-2011 Tim Riker";
+const char *bzfcopyright = "Copyright (c) 1993-2018 Tim Riker";
 
-
-//
-//  Although the ./configure process will generate
-//  -DBZ_BUILD_DATE for the build, here it's voided.
-//
-//  Could someone explain the reason for the
-//  inconvenience caused by the ./configure method? This
-//  way is simple, touch the *.cxx to get a new time
-//  stamp (no big recompiles). If this file is updated,
-//  you are also forced to get a new timestamp.
-//
-//  Using __DATE__ for all OSes is more consistent.
-//
-#undef BZ_BUILD_DATE
-
-
-#ifndef BZ_BUILD_DATE
-/* to get the version in the right format YYYYMMDD */
-/* yes this is horrible but it needs to be done to get it right */
-/* windows should pull from a resource */
-/* *nix gets this from the passed from my the Makefile */
-char buildDate[] = {__DATE__};
-
-int getBuildDate()
+static int getBuildDate()
 {
   int year = 1900, month = 0, day = 0;
+#ifdef BUILD_DATE
+  // the BUILD_DATE define looks like "YYYY-MM-DD"
+  sscanf(BUILD_DATE, "%d-%d-%d", &year, &month, &day);
+#else
   char monthStr[512];
-  sscanf(buildDate, "%s %d %d", monthStr, &day, &year);
+  // the __DATE__ macro looks like "Jun 15 2013" (*with* the quotes)
+  sscanf(__DATE__, "%s %d %d", monthStr, &day, &year);
 
   // we want it not as a name but a number
   if (strcmp(monthStr, "Jan") == 0)
@@ -108,12 +92,10 @@ int getBuildDate()
     month = 11;
   else if (strcmp(monthStr, "Dec") == 0)
     month = 12;
-
-  return (year*10000) + (month*100)+ day;
-}
 #endif
-// down here so above gets created
-#include "version.h"
+
+  return (year*10000) + (month*100) + day;
+}
 
 const char*		getProtocolVersion()
 {
@@ -130,7 +112,7 @@ const char*		getServerVersion()
 const char*		getMajorMinorVersion()
 {
   static std::string	version = "";
-  if (!version.size()){
+  if (!version.size()) {
     std::ostringstream	versionStream;
     versionStream << BZ_MAJOR_VERSION << "." << BZ_MINOR_VERSION;
     version = versionStream.str();
@@ -141,7 +123,7 @@ const char*		getMajorMinorVersion()
 const char*		getMajorMinorRevVersion()
 {
   static std::string	version = "";
-  if (!version.size()){
+  if (!version.size()) {
     std::ostringstream	versionStream;
     versionStream << BZ_MAJOR_VERSION << "." << BZ_MINOR_VERSION << "." << BZ_REV;
     version = versionStream.str();
@@ -152,13 +134,16 @@ const char*		getMajorMinorRevVersion()
 const char*		getAppVersion()
 {
   static std::string	appVersion = "";
-  if (!appVersion.size()){
+  if (!appVersion.size()) {
     std::ostringstream	appVersionStream;
     // TODO add current platform, release, cpu, etc
-    appVersionStream << getMajorMinorRevVersion() << "." << BZ_BUILD_DATE
+    appVersionStream << getMajorMinorRevVersion() << "." << getBuildDate()
 	<< "-" << BZ_BUILD_TYPE << "-" << BZ_BUILD_OS;
 #ifdef HAVE_SDL
     appVersionStream << "-SDL";
+#ifdef HAVE_SDL2
+    appVersionStream << "2";
+#endif
 #endif
     appVersion = appVersionStream.str();
   }
@@ -166,7 +151,7 @@ const char*		getAppVersion()
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
