@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -74,7 +74,7 @@ inline static void addToFullPadList (Obstacle* obs)
   return;
 }
 
-inline static void addToRayList (ColDetNode* node)
+inline static void addToRayList (const ColDetNode* node)
 {
   RayList.list[RayList.count] = node;
   RayList.count++;
@@ -136,8 +136,8 @@ static int compareObstacles (const void* a, const void* b)
   // - normal object come first (from lowest to highest)
   // - then come the mesh face (highest to lowest)
   // - and finally, the mesh objects (checkpoints really)
-  const Obstacle* obsA = *((const Obstacle**)a);
-  const Obstacle* obsB = *((const Obstacle**)b);
+  const Obstacle* obsA = *((const Obstacle* const *)a);
+  const Obstacle* obsB = *((const Obstacle* const *)b);
 
   bool isMeshA = (obsA->getType() == MeshObstacle::getClassName());
   bool isMeshB = (obsB->getType() == MeshObstacle::getClassName());
@@ -350,8 +350,8 @@ const ObsList* CollisionManager::rayTest (const Ray* ray, float timeLeft) const
 
 static int compareRayNodes (const void *a, const void *b)
 {
-  const ColDetNode* nodeA = *((ColDetNode**)a);
-  const ColDetNode* nodeB = *((ColDetNode**)b);
+  const ColDetNode* nodeA = *((ColDetNode* const *)a);
+  const ColDetNode* nodeB = *((ColDetNode* const *)b);
   return (nodeA->getInTime() > nodeB->getInTime());
 }
 
@@ -419,7 +419,7 @@ void CollisionManager::load ()
     MeshObstacle* mesh = (MeshObstacle*) meshes[i];
     if (!mesh->isPassable()) {
       for (int f = 0; f < mesh->getFaceCount(); f++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(f);
+	const MeshFace* face = mesh->getFace(f);
 	if (!face->isPassable()) fullCount++;
       }
       fullCount++; // one for the mesh itself
@@ -458,7 +458,7 @@ void CollisionManager::load ()
     if (!mesh->isPassable()) {
       const int meshFaceCount = mesh->getFaceCount();
       for (int f = 0; f < meshFaceCount; f++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(f);
+	MeshFace* face = mesh->getFace(f);
 	if (!face->isPassable()) addToFullList((Obstacle*) face);
       }
     }
@@ -481,7 +481,7 @@ void CollisionManager::load ()
   root->tallyStats();
 
   // setup the ray list
-  RayList.list = new ColDetNode*[leafNodes];
+  RayList.list = new const ColDetNode*[leafNodes];
   RayList.count = 0;
 
   // print some statistics
@@ -868,7 +868,7 @@ void ColDetNode::rayTestNodes (const Ray* ray, float timeLeft) const
   }
 
   if (childCount == 0) {
-    addToRayList((ColDetNode*)this);
+    addToRayList(this);
   }
   else {
     for (int i = 0; i < childCount; i++) {
@@ -960,6 +960,7 @@ void ColDetNode::draw(DrawLinesFunc drawLinesFunc)
 }
 
 
+// Local Variables: ***
 // mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
