@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -63,14 +63,20 @@ std::string		getConfigDirName( const char* versionName )
 {
   std::string customConfigDir = configDir(0, NULL);
 
-  if (customConfigDir.size() > 0)
-    return customConfigDir;
+  if (customConfigDir.size() > 0) {
+    std::string customName = customConfigDir + DirectorySeparator;
+    if (versionName) {
+      customName += versionName;
+      customName += DirectorySeparator;
+    }
+    return customName;
+  }
 
 #if defined(_WIN32)
   std::string name("C:");
   char dir[MAX_PATH];
   ITEMIDLIST* idl;
-  if (SUCCEEDED(SHGetSpecialFolderLocation(NULL, CSIDL_LOCAL_APPDATA , &idl))) {
+  if (SUCCEEDED(SHGetSpecialFolderLocation(NULL, CSIDL_LOCAL_APPDATA, &idl))) {
     if (SHGetPathFromIDList(idl, dir)) {
       struct stat statbuf;
       if (stat(dir, &statbuf) == 0 && (statbuf.st_mode & _S_IFDIR) != 0)
@@ -89,7 +95,6 @@ std::string		getConfigDirName( const char* versionName )
     name += versionName;
     name += "\\";
   }
-  customConfigDir = name;
   return name;
 
 #elif defined(__APPLE__)
@@ -97,19 +102,18 @@ std::string		getConfigDirName( const char* versionName )
   ::FSRef libraryFolder;
   ::OSErr err;
   err = ::FSFindFolder(::kUserDomain, ::kApplicationSupportFolderType, true, &libraryFolder);
-  if(err == ::noErr) {
+  if (err == ::noErr) {
     char buff[1024];
     err = ::FSRefMakePath(&libraryFolder, (UInt8*)buff, sizeof(buff));
-    if(err == ::noErr) {
-      std::strcat(buff, "/BZFlag/");
+    if (err == ::noErr) {
+      name = buff;
+      name += "/BZFlag/";
       if (versionName) {
-	std::strcat(buff, versionName);
-	std::strcat(buff, "/");
+	name += versionName;
+	name += "/";
       }
-     name = buff;
     }
   }
-  customConfigDir = name;
   return name;
 #else
   std::string name;
@@ -123,7 +127,6 @@ std::string		getConfigDirName( const char* versionName )
     name += versionName;
     name += "/";
   }
-  customConfigDir = name;
   return name;
 #endif
 }
@@ -138,17 +141,7 @@ static std::string		setupString(std::string dir)
 
 std::string getCacheDirName()
 {
-  std::string name = getConfigDirName();
-  name += "cache";
-#if !defined (_WIN32) && !defined (__APPLE__)
-  // add in hostname on UNIX
-  // FIXME should be able to share the cache
-  if (getenv("HOST")) {
-    name += ".";
-    name += getenv("HOST");
-  }
-#endif
-  name += DirectorySeparator;
+  std::string name = getConfigDirName() + "cache" + DirectorySeparator;
   return name;
 }
 
