@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,6 +24,7 @@
 #include <string>
 #include <vector>
 #include <iostream>
+#include <sstream>
 
 // common headers
 #include "bzglob.h"
@@ -57,9 +58,11 @@ void LinkManager::clear()
 void LinkManager::makeLinkName(int number, std::string& name)
 {
   name = "/t";
-  char buffer[8];
-  sprintf(buffer, "%i", (number / 2));
-  name += buffer;
+
+  std::stringstream buffer;
+  buffer << (number / 2);
+
+  name += buffer.str();
   name += ":";
   if ((number % 2) == 0) {
     name += "f";
@@ -131,11 +134,11 @@ void LinkManager::doLinking()
     findTelesByName(link.dst, dstNumbers);
 
     bool broken = false;
-    if (srcNumbers.size() <= 0) {
+    if (srcNumbers.empty()) {
       broken = true;
       logDebugMessage(1,"broken link src: %s\n", link.src.c_str());
     }
-    if (dstNumbers.size() <= 0) {
+    if (dstNumbers.empty()) {
       broken = true;
       logDebugMessage(1,"broken link dst: %s\n", link.dst.c_str());
     }
@@ -156,7 +159,7 @@ void LinkManager::doLinking()
   // fill in the blanks (passthru linkage)
   for (i = 0; i < linkNumbers.size(); i++) {
     std::vector<int>& dstsList = linkNumbers[i].dsts;
-    if (dstsList.size() <= 0) {
+    if (dstsList.empty()) {
       const int t = (i / 2) * 2; // tele number
       const int f = 1 - (i % 2); // opposite link
       dstsList.push_back(t + f);
@@ -286,7 +289,7 @@ void* LinkManager::pack(void* buf) const
 }
 
 
-void* LinkManager::unpack(void* buf)
+const void* LinkManager::unpack(const void* buf)
 {
   clear(); // just in case
   unsigned int i;
@@ -330,7 +333,7 @@ int LinkManager::packSize() const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
