@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -62,7 +62,7 @@ static std::string strFlag (u16 id);
 static std::string strFlagStatus (FlagStatus status);
 static std::string strTeam (u16 id);
 static std::string strPlayer (u16 id);
-static std::string strVector (float *vector);
+static std::string strVector (const float *vector);
 static std::string strKillReason (int16_t reason);
 static std::string strAddress (Address& address);
 
@@ -109,7 +109,6 @@ static MsgStringList handleMsgWantWHash(PacketInfo *pi);
 static MsgStringList handleMsgWantSettings(PacketInfo *pi);
 static MsgStringList handleMsgUDPLinkRequest(PacketInfo *pi);
 static MsgStringList handleMsgUDPLinkEstablished(PacketInfo *pi);
-static MsgStringList handleMsgServerControl(PacketInfo *pi);
 static MsgStringList handleMsgLagPing(PacketInfo *pi);
 static MsgStringList handleMsgPingCodeReply(PacketInfo *pi);
 static MsgStringList handleMsgPingCodeRequest(PacketInfo *pi);
@@ -167,7 +166,6 @@ static PacketListEntry PacketList[] = {
   PACKET_LIST_ENTRY (MsgWantSettings),
   PACKET_LIST_ENTRY (MsgUDPLinkRequest),
   PACKET_LIST_ENTRY (MsgUDPLinkEstablished),
-  PACKET_LIST_ENTRY (MsgServerControl),
   PACKET_LIST_ENTRY (MsgLagPing),
   PACKET_LIST_ENTRY (MsgPingCodeReply),
   PACKET_LIST_ENTRY (MsgPingCodeRequest)
@@ -274,6 +272,10 @@ const char * MsgStrings::strMsgCode (uint16_t code)
 }
 
 
+// a simple example of how to use this:
+// MsgStringList details = MsgStrings::msgFromServer(len, code, msg);
+// for (MsgStringList::iterator i = details.begin(); i != details.end(); i++)
+//   std::cerr << i->text << std::endl;
 MsgStringList MsgStrings::msgFromServer (u16 len, u16 code, const void *data)
 {
   int i;
@@ -413,7 +415,7 @@ static std::string strPlayer (u16 id)
 }
 
 
-static std::string strVector (float *vector)
+static std::string strVector (const float *vector)
 {
   std::string str = TextUtils::format ("(%8.3f, %8.3f, %8.3f)",
     vector[0], vector[1], vector[2]);
@@ -469,7 +471,7 @@ static MsgStringList handleMsgAlive (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player;
   float pos[3], azimuth;
   d = nboUnpackUByte (d, player);
@@ -488,7 +490,7 @@ static MsgStringList handleMsgAdminInfo (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 count, ipsize, player;
   Address address;
   u16 i;
@@ -512,7 +514,7 @@ static MsgStringList handleMsgAddPlayer (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 index;
   u16 type, team, wins, losses, tks;
   char callsign[CallSignLen];
@@ -546,7 +548,7 @@ static MsgStringList handleMsgCaptureFlag (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u16 team;
   d = nboUnpackUShort (d, team);
   listPush (list, 1, "team: %s", strTeam (team).c_str());
@@ -559,7 +561,7 @@ static MsgStringList handleMsgDropFlag (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   Flag flag;
   u8 player;
   u16 flagid;
@@ -593,7 +595,7 @@ static MsgStringList handleMsgFlagUpdate (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u16 count, index;
   int i;
   d = nboUnpackUShort (d, count);
@@ -619,7 +621,7 @@ static MsgStringList handleMsgGrabFlag (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   Flag flag;
   u8 player;
   u16 flagid;
@@ -637,7 +639,7 @@ static MsgStringList handleMsgGMUpdate (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 target;
   ShotUpdate shot;
   d = shot.unpack (d);
@@ -673,7 +675,7 @@ static MsgStringList handleMsgKilled (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 victim, killer;
   int16_t reason, shot;
   FlagType* flagType;
@@ -708,13 +710,13 @@ static MsgStringList handleMsgMessage (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 src, dst;
   d = nboUnpackUByte (d, src);
   d = nboUnpackUByte (d, dst);
   listPush (list, 1, "src: %s", strPlayer(src).c_str());
   listPush (list, 1, "dst: %s", strPlayer(dst).c_str());
-  listPush (list, 1, "message: \"%s\"", (char*) d);
+  listPush (list, 1, "message: \"%s\"", (const char*) d);
 
   return list;
 }
@@ -732,7 +734,7 @@ static MsgStringList handleMsgNewRabbit (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player, paused;
   d = nboUnpackUByte (d, player);
   d = nboUnpackUByte (d, paused);
@@ -753,7 +755,7 @@ static MsgStringList handleMsgPause (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player, paused;
   d = nboUnpackUByte (d, player);
   d = nboUnpackUByte (d, paused);
@@ -768,7 +770,7 @@ static MsgStringList handleMsgPlayerInfo (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 count, player, properties;
   Address address;
   u16 i;
@@ -801,7 +803,7 @@ static MsgStringList handleMsgPlayerUpdate (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   float timestamp;
   u8 index;
   PlayerState state;
@@ -865,7 +867,7 @@ static MsgStringList handleMsgRemovePlayer (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 index;
   d = nboUnpackUByte (d, index);
   listPush (list, 1, "player: %s", strPlayer(index).c_str());
@@ -881,7 +883,7 @@ static MsgStringList handleMsgShotBegin (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   FiringInfo finfo;
   d = finfo.unpack (d);
   const ShotUpdate& shot = finfo.shot;
@@ -889,8 +891,8 @@ static MsgStringList handleMsgShotBegin (PacketInfo *pi)
   listPush (list, 1, "type:     %.2s", finfo.flagType->flagAbbv.c_str()); // FIXME ?
   listPush (list, 2, "id:       %i", shot.id);
   listPush (list, 2, "team:     %s", strTeam(shot.team).c_str());
-  listPush (list, 2, "pos:      %s", strVector((float*)shot.pos).c_str());
-  listPush (list, 2, "vel:      %s", strVector((float*)shot.vel).c_str());
+  listPush (list, 2, "pos:      %s", strVector(shot.pos).c_str());
+  listPush (list, 2, "vel:      %s", strVector(shot.vel).c_str());
   listPush (list, 2, "lifetime: %-8.3f", finfo.lifetime);
 
   return list;
@@ -901,7 +903,7 @@ static MsgStringList handleMsgScore (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 count, player;
   u16 wins, losses, tks, i;
   d = nboUnpackUByte (d, count);
@@ -923,7 +925,7 @@ static MsgStringList handleMsgScoreOver (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player;
   u16 team;
   d = nboUnpackUByte(d, player);
@@ -939,7 +941,7 @@ static MsgStringList handleMsgShotEnd (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player;
   u16 shotid;
   int16_t reason;
@@ -967,7 +969,7 @@ static MsgStringList handleMsgSetVar (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u16 i;
   u16 count;
   u8 nameLen, valueLen;
@@ -998,7 +1000,7 @@ static MsgStringList handleMsgSetVar (PacketInfo *pi)
 static MsgStringList handleMsgTimeUpdate (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   int32_t timeLeft;
   d = nboUnpackInt(d, timeLeft);
   listPush (list, 1, "timeLeft: %i", timeLeft);
@@ -1011,7 +1013,7 @@ static MsgStringList handleMsgTeleport (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 player;
   u16 to, from;
   d = nboUnpackUByte(d, player);
@@ -1029,7 +1031,7 @@ static MsgStringList handleMsgTransferFlag (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 to, from;
   u16 flagid;
   Flag flag;
@@ -1049,7 +1051,7 @@ static MsgStringList handleMsgTeamUpdate (PacketInfo *pi)
 {
   MsgStringList list = listMsgBasics (pi);
 
-  void *d = (void*)pi->data;
+  const void *d = pi->data;
   u8 count;
   u16 i, team, size, won, lost;
   d = nboUnpackUByte(d, count);
@@ -1099,14 +1101,6 @@ static MsgStringList handleMsgUDPLinkEstablished (PacketInfo *pi)
 }
 
 
-static MsgStringList handleMsgServerControl (PacketInfo *pi)
-{
-  // packet type hasn't not been implemented
-  MsgStringList list = listMsgBasics (pi);
-  return list;
-}
-
-
 static MsgStringList handleMsgLagPing (PacketInfo *pi)
 {
   // not recorded
@@ -1142,7 +1136,7 @@ static MsgStringList handleMsgPingCodeRequest (PacketInfo *pi)
 /******************************************************************************/
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
