@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -50,11 +50,10 @@ PhysicsDriverManager::~PhysicsDriverManager()
 void PhysicsDriverManager::clear()
 {
   std::vector<PhysicsDriver*>::iterator it;
-  for (it = drivers.begin(); it != drivers.end(); it++) {
+  for (it = drivers.begin(); it != drivers.end(); ++it) {
     delete *it;
   }
   drivers.clear();
-  return;
 }
 
 
@@ -62,11 +61,10 @@ void PhysicsDriverManager::update()
 {
   float t = (float)(TimeKeeper::getCurrent() - TimeKeeper::getStartTime());
   std::vector<PhysicsDriver*>::iterator it;
-  for (it = drivers.begin(); it != drivers.end(); it++) {
+  for (it = drivers.begin(); it != drivers.end(); ++it) {
     PhysicsDriver* driver = *it;
     driver->update(t);
   }
-  return;
 }
 
 
@@ -105,7 +103,7 @@ void * PhysicsDriverManager::pack(void *buf) const
 {
   std::vector<PhysicsDriver*>::const_iterator it;
   buf = nboPackUInt(buf, (int)drivers.size());
-  for (it = drivers.begin(); it != drivers.end(); it++) {
+  for (it = drivers.begin(); it != drivers.end(); ++it) {
     PhysicsDriver* driver = *it;
     buf = driver->pack(buf);
   }
@@ -113,7 +111,7 @@ void * PhysicsDriverManager::pack(void *buf) const
 }
 
 
-void * PhysicsDriverManager::unpack(void *buf)
+const void * PhysicsDriverManager::unpack(const void *buf)
 {
   unsigned int i;
   uint32_t count;
@@ -131,7 +129,7 @@ int PhysicsDriverManager::packSize() const
 {
   int fullSize = sizeof (uint32_t);
   std::vector<PhysicsDriver*>::const_iterator it;
-  for (it = drivers.begin(); it != drivers.end(); it++) {
+  for (it = drivers.begin(); it != drivers.end(); ++it) {
     PhysicsDriver* driver = *it;
     fullSize = fullSize + driver->packSize();
   }
@@ -143,11 +141,10 @@ void PhysicsDriverManager::print(std::ostream& out,
 				 const std::string& indent) const
 {
   std::vector<PhysicsDriver*>::const_iterator it;
-  for (it = drivers.begin(); it != drivers.end(); it++) {
+  for (it = drivers.begin(); it != drivers.end(); ++it) {
     const PhysicsDriver* driver = *it;
     driver->print(out, indent);
   }
-  return;
 }
 
 
@@ -295,7 +292,7 @@ void * PhysicsDriver::pack(void *buf) const
 }
 
 
-void * PhysicsDriver::unpack(void *buf)
+const void * PhysicsDriver::unpack(const void *buf)
 {
   buf = nboUnpackStdString(buf, name);
 
@@ -374,10 +371,9 @@ void PhysicsDriver::print(std::ostream& out, const std::string& indent) const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
