@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,9 +30,18 @@ WordFilter *PlayerInfo::filterData	= NULL;
 bool	PlayerInfo::simpleFiltering   = true;
 
 PlayerInfo::PlayerInfo(int _playerIndex) :
-  playerIndex(_playerIndex), state(PlayerInLimbo), team(NoTeam),
-  hasDoneEntering(false), flag(-1), spamWarns(0), lastMsgTime(now),
-  paused(false), pausedSince(TimeKeeper::getNullTime()), autopilot(false),
+  playerIndex(_playerIndex),
+  state(PlayerInLimbo),
+  hasDoneEntering(false),
+  team(NoTeam),
+  flag(-1),
+  allowedToSpawn(true),
+  notifiedSpawn(false),
+  spamWarns(0),
+  lastMsgTime(now),
+  paused(false),
+  pausedSince(TimeKeeper::getNullTime()),
+  autopilot(false),
   tracker(0)
 {
   notResponding = false;
@@ -46,6 +55,8 @@ PlayerInfo::PlayerInfo(int _playerIndex) :
   completelyAdded = false;
   nextSpawnTime = TimeKeeper::getSunGenesisTime();
   wantsToSpawn = false;
+  neverSpawned = true;
+  type = TankPlayer;
 }
 
 void PlayerInfo::setFilterParameters(bool	_callSignFiltering,
@@ -86,6 +97,7 @@ void PlayerInfo::setAlive() {
   state = PlayerAlive;
   paused = false;
   wantsToSpawn = false;
+  neverSpawned = false;
   flag = -1;
 }
 
@@ -105,7 +117,7 @@ void *PlayerInfo::packId(void *buf) {
   return buf;
 }
 
-bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
+bool PlayerInfo::unpackEnter(const void *buf, uint16_t &rejectCode, char *rejectMsg)
 {
   // data: type, team, name, motto
   uint16_t _type;
@@ -119,7 +131,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
   buf = nboUnpackString(buf, token, TokenLen);
   buf = nboUnpackString(buf, clientVersion, VersionLen);
 
-  return processEnter(rejectCode, rejectMsg);;
+  return processEnter(rejectCode, rejectMsg);
 }
 
 bool PlayerInfo::processEnter ( uint16_t &rejectCode, char *rejectMsg )
@@ -147,6 +159,13 @@ bool PlayerInfo::processEnter ( uint16_t &rejectCode, char *rejectMsg )
     serverSpoofingFilter.addToFilter("SERVER", "");
   }
 
+  if (isBot() && BZDB.isTrue(StateDatabase::BZDB_DISABLEBOTS)) {
+    logDebugMessage(2,"rejecting robot tank: %s\n", callSign);
+    rejectCode   = RejectBadType;
+    strcpy(rejectMsg, "Robot tanks are not allowed on this server.");
+    return false;
+  }
+
   if (!isCallSignReadable()) {
     logDebugMessage(2,"rejecting unreadable callsign: %s\n", callSign);
     rejectCode   = RejectBadCallsign;
@@ -377,6 +396,10 @@ bool PlayerInfo::isFlagTransitSafe() {
   return now - lastFlagDropTime >= 2.0f;
 }
 
+double PlayerInfo::timeSinceLastFlagDrop() {
+	return now - lastFlagDropTime;
+}
+
 const char *PlayerInfo::getClientVersion() {
   return clientVersion;
 }
@@ -397,6 +420,27 @@ void PlayerInfo::getClientVersionNumbers(int& major, int& minor, int& rev)
   return;
 }
 
+double PlayerInfo::getPausedTime()
+{
+  if ((state > PlayerInLimbo) && (team != ObserverTeam) && (paused)) {
+    return (now - pausedSince);
+  }
+
+  return 0;
+}
+
+double PlayerInfo::getIdleTime()
+{
+  if ((state > PlayerInLimbo) && (team != ObserverTeam)) {
+    return (now - lastupdate);
+  }
+  else if (team == ObserverTeam) {
+    return -1;
+  }
+
+  return 0;
+}
+
 std::string PlayerInfo::getIdleStat() {
   std::string reply;
   if ((state > PlayerInLimbo) && (team != ObserverTeam)) {
@@ -495,8 +539,38 @@ void PlayerInfo::setCurrentTime(TimeKeeper tm)
   now = tm;
 }
 
+void PlayerInfo::killedBy(PlayerId killer)
+{
+	if (deathCountMap.find(killer) == deathCountMap.end())
+		deathCountMap[killer] = 0;
+	deathCountMap[killer]++;
+}
+
+void PlayerInfo::flushKiller(PlayerId killer)
+{
+	if (deathCountMap.find(killer) != deathCountMap.end())
+		deathCountMap.erase(killer);
+}
+
+int PlayerInfo::howManyTimesKilledBy(PlayerId killer)
+{
+	if (deathCountMap.find(killer) == deathCountMap.end())
+		return 0;
+	return deathCountMap[killer];
+}
+
+void PlayerInfo::setAllowedToSpawn(bool canSpawn)
+{
+  allowedToSpawn = canSpawn;
+}
+
+void PlayerInfo::setNotifiedOfSpawnable(bool notified)
+{
+  notifiedSpawn = notified;
+}
+
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
