@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -427,8 +427,7 @@ void MeshSceneNode::updateMaterial(MeshSceneNode::MeshMaterial* mat)
   OpenGLGStateBuilder builder;
   TextureManager &tm = TextureManager::instance();
 
-  // cheat a little
-  ((BzMaterial*)bzmat)->setReference();
+  bzmat->setReference();
 
   // ways of requiring blending
   bool colorAlpha = false;
@@ -438,9 +437,9 @@ void MeshSceneNode::updateMaterial(MeshSceneNode::MeshMaterial* mat)
 
   // texturing
   if (BZDBCache::texture) {
-    int faceTexture = -1;
     bool userTexture = (bzmat->getTextureCount() > 0);
     if (userTexture) {
+      int faceTexture = -1;
       const std::string& texname = bzmat->getTextureLocal(0);
       if (texname.size() > 0) {
 	faceTexture = tm.getTextureID(texname.c_str());
@@ -661,7 +660,7 @@ void MeshSceneNode::setRadarLodScale(float lengthPerPixel)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
