@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -126,20 +126,20 @@ static GLuint buildSphereList(GLdouble radius, GLint slices, GLint stacks)
 {
   GLuint list;
 
-  GLUquadric* quad = gluNewQuadric();
-  gluQuadricDrawStyle(quad, GLU_FILL);
-  gluQuadricTexture(quad, GL_TRUE);
-  gluQuadricNormals(quad, GL_SMOOTH);
-  gluQuadricOrientation(quad, GLU_OUTSIDE);
+  GLUquadric* quadric = gluNewQuadric();
+  gluQuadricDrawStyle(quadric, GLU_FILL);
+  gluQuadricTexture(quadric, GL_TRUE);
+  gluQuadricNormals(quadric, GL_SMOOTH);
+  gluQuadricOrientation(quadric, GLU_OUTSIDE);
 
   list = glGenLists(1);
   glNewList(list, GL_COMPILE);
   {
-    gluSphere(quad, radius, slices, stacks);
+    gluSphere(quadric, radius, slices, stacks);
   }
   glEndList();
 
-  gluDeleteQuadric(quad);
+  gluDeleteQuadric(quadric);
 
   return list;
 }
@@ -826,10 +826,9 @@ void			SphereFragmentSceneNode::FragmentRenderNode::render()
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
