@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,16 +41,15 @@ static const float vertExplosionRatio = 0.5f;
 
 // parts: body, turret, barrel, left tread, right tread
 
-const int		TankSceneNode::numLOD = 3;
-int			TankSceneNode::maxLevel = numLOD;
+const int TankSceneNode::numLOD = 3;
+int       TankSceneNode::maxLevel = numLOD;
 
 TankSceneNode::TankSceneNode(const GLfloat pos[3], const GLfloat forward[3]) :
 				leftTreadOffset(0.0f), rightTreadOffset(0.0f),
 				leftWheelOffset(0.0f), rightWheelOffset(0.0f),
-				useDimensions(false), useOverride(false),
-				onlyShadows(false), clip(false),
-				inTheCockpit(false), tankRenderNode(this), treadsRenderNode(this),
-				shadowRenderNode(this),
+				useDimensions(false), onlyShadows(false),
+				clip(false), inTheCockpit(false), tankRenderNode(this),
+				treadsRenderNode(this), shadowRenderNode(this),
 				tankSize(TankGeometryEnums::Normal)
 {
   // setup style factors (BZDB isn't set up at global init time
@@ -219,13 +218,6 @@ void TankSceneNode::notifyStyleChange()
 
 void TankSceneNode::addRenderNodes(SceneRenderer& renderer)
 {
-  // don't draw onlyShadows tanks.  this is mainly to avoid drawing player's
-  // tank when player is using view from tank.  can't simply not include
-  // player, though, cos then we wouldn't get the tank's shadow.
-  if (onlyShadows) {
-    return;
-  }
-
   // pick level of detail
   const GLfloat* mySphere = getSphere();
   const ViewFrustum& view = renderer.getViewFrustum();
@@ -280,6 +272,17 @@ void TankSceneNode::addRenderNodes(SceneRenderer& renderer)
   }
 
   treadsRenderNode.setTreads(true);
+
+  // don't draw onlyShadows tanks.  this is mainly to avoid drawing player's
+  // tank when player is using view from tank.  can't simply not include
+  // player, though, cos then we wouldn't get the tank's shadow.
+  //
+  // Also don't return without doing anything,
+  // fancy radar tanks need TankLOD set.
+  if (onlyShadows) {
+    return;
+  }
+
   renderer.addRenderNode(&tankRenderNode, &gstate);
   renderer.addRenderNode(&treadsRenderNode, &treadState);
 
@@ -512,14 +515,14 @@ void TankSceneNode::renderRadar()
 	  color[3] = 0.15f;
   }
 
+  if (BZDBCache::animatedTreads) {
+    treadState.setState();
+    treadsRenderNode.setRadar(true);
+    treadsRenderNode.sortOrder(true /* above */, false, false);
+    treadsRenderNode.render();
+    treadsRenderNode.setRadar(false);
+  }
   gstate.setState();
-//   if (BZDBCache::animatedTreads) {
-// //	  treadState.setState();
-// 	  treadsRenderNode.setRadar(true);
-// 	  treadsRenderNode.sortOrder(true /* above */, false, false);
-// 	  treadsRenderNode.render();
-// 	  treadsRenderNode.setRadar(false);
-//   }
 
   tankRenderNode.setRadar(true);
   tankRenderNode.sortOrder(true /* above */, false, false);
@@ -731,19 +734,19 @@ void TankIDLSceneNode::IDLRenderNode::render()
   const GLfloat azimuth = sceneNode->tank->azimuth;
   const GLfloat ca = cosf(-azimuth * (float)M_PI / 180.0f);
   const GLfloat sa = sinf(-azimuth * (float)M_PI / 180.0f);
-  GLfloat plane[4];
-  plane[0] = ca * _plane[0] - sa * _plane[1];
-  plane[1] = sa * _plane[0] + ca * _plane[1];
-  plane[2] = _plane[2];
-  plane[3] = (sphere[0] * _plane[0] + sphere[1] * _plane[1] +
-	      sphere[2] * _plane[2] + _plane[3]);
+  GLfloat tankPlane[4];
+  tankPlane[0] = ca * _plane[0] - sa * _plane[1];
+  tankPlane[1] = sa * _plane[0] + ca * _plane[1];
+  tankPlane[2] = _plane[2];
+  tankPlane[3] = (sphere[0] * _plane[0] + sphere[1] * _plane[1] +
+		  sphere[2] * _plane[2] + _plane[3]);
 
-  // compute projection point -- one TankLength in from plane
-  const GLfloat pd = -1.0f * BZDBCache::tankLength - plane[3];
+  // compute projection point -- one TankLength in from tankPlane
+  const GLfloat pd = -1.0f * BZDBCache::tankLength - tankPlane[3];
   GLfloat origin[3];
-  origin[0] = pd * plane[0];
-  origin[1] = pd * plane[1];
-  origin[2] = pd * plane[2];
+  origin[0] = pd * tankPlane[0];
+  origin[1] = pd * tankPlane[1];
+  origin[2] = pd * tankPlane[2];
 
   glPushMatrix();
     glTranslatef(sphere[0], sphere[1], sphere[2]);
@@ -752,16 +755,16 @@ void TankIDLSceneNode::IDLRenderNode::render()
     glBegin(GL_QUADS);
     const int numFaces = countof(idlFaces);
     for (int i = 0; i < numFaces; i++) {
-      // get distances from plane
+      // get distances from tankPlane
       const int* face = idlFaces[i] + 1;
       const int numVertices = idlFaces[i][0];
       GLfloat d[4];
       int j;
       for (j = 0; j < numVertices; j++)
-	d[j] = idlVertex[face[j]][0] * plane[0] +
-	       idlVertex[face[j]][1] * plane[1] +
-	       idlVertex[face[j]][2] * plane[2] +
-	       plane[3];
+	d[j] = idlVertex[face[j]][0] * tankPlane[0] +
+	       idlVertex[face[j]][1] * tankPlane[1] +
+	       idlVertex[face[j]][2] * tankPlane[2] +
+	       tankPlane[3];
 
       // get crossing points
       GLfloat cross[2][3];
@@ -833,7 +836,7 @@ const GLfloat  // FIXME: setup so these come from TANKGEOMMGR
 
 TankSceneNode::TankRenderNode::TankRenderNode(const TankSceneNode* _sceneNode) :
 				sceneNode(_sceneNode), isShadow(false),
-				above(false), towards(false)
+				left(false), above(false), towards(false)
 {
   narrowWithDepth = false;
   drawLOD = LowTankLOD;
@@ -1198,12 +1201,12 @@ void TankSceneNode::TankRenderNode::renderPart(TankPart part)
 		sceneNode->deathOverride->SetDeathRenderParams(params);
 	if (!overide)
 	{
-		const float* vel = sceneNode->vel[part];
-		const float* spin = sceneNode->spin[part];
-		glTranslatef(cog[0] + (explodeFraction * vel[0]),
-			 cog[1] + (explodeFraction * vel[1]),
-			 cog[2] + (explodeFraction * vel[2]));
-		glRotatef(spin[3] * explodeFraction, spin[0], spin[1], spin[2]);
+		const float* velocity = sceneNode->vel[part];
+		const float* rotation = sceneNode->spin[part];
+		glTranslatef(cog[0] + (explodeFraction * velocity[0]),
+			 cog[1] + (explodeFraction * velocity[1]),
+			 cog[2] + (explodeFraction * velocity[2]));
+		glRotatef(rotation[3] * explodeFraction, rotation[0], rotation[1], rotation[2]);
 		glTranslatef(-cog[0], -cog[1], -cog[2]);
 	}
 	else
@@ -1444,8 +1447,8 @@ void TankSceneNode::TankRenderNode::renderJumpJets()
   myColor4f(1.0f, 1.0f, 1.0f, 0.5f);
 
   // use a clip plane, because the ground has no depth
-  const GLdouble clipPlane[4] = {0.0f, 0.0f, 1.0f, 0.0f};
-  glClipPlane(GL_CLIP_PLANE1, clipPlane);
+  const GLdouble clip_plane[4] = {0.0, 0.0, 1.0, 0.0};
+  glClipPlane(GL_CLIP_PLANE1, clip_plane);
   glEnable(GL_CLIP_PLANE1);
 
   sceneNode->jumpJetsGState.setState();
@@ -1482,10 +1485,9 @@ void TankSceneNode::TankRenderNode::renderJumpJets()
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
