@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,7 +16,8 @@
 // AudioFile
 //
 
-AudioFile::AudioFile(std::istream* _stream) : MediaFile(_stream), open(false)
+AudioFile::AudioFile(std::istream* _stream) : MediaFile(_stream), open(false),
+  framesPerSecond(), numChannels(), numFrames(), sampWidth()
 {
   // do nothing
 }
@@ -62,10 +63,9 @@ int		AudioFile::getSampleWidth() const
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
