@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2012 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,6 +37,17 @@
   extern "C" int inet_aton(const char *, struct in_addr *);
 #endif
 
+// RFC 1035 limits the length of a fully qualified domain name to 255
+// octets, so calling sysconf(_SC_HOST_NAME_MAX) to find some other
+// limit and/or dynamically expanding the gethostname() buffer on
+// demand are complex solutions to a problem that does not exist in
+// the environments for which BZFlag is designed.  The value chosen
+// here provides a substantial margin in case the RFC 1035 limit is
+// raised in the future.
+#ifndef MAXHOSTNAMELEN
+#define	MAXHOSTNAMELEN	511
+#endif
+
 //
 // Address
 //
@@ -98,6 +109,10 @@ bool			Address::operator!=(const Address& address) const
   return addr[0].s_addr != address.addr[0].s_addr;
 }
 
+bool			Address::operator<(Address const& address) const
+{
+  return addr[0].s_addr < address.addr[0].s_addr;
+}
 bool			Address::isAny() const
 {
   return addr[0].s_addr == htonl(INADDR_ANY);
@@ -129,34 +144,45 @@ uint8_t			Address::getIPVersion() const {
   return 4;
 }
 
+static const struct hostent* bz_gethostbyname(const std::string &name)
+{
+  const struct hostent* hent = NULL;
+
+  if (name.length() > 0)
+    hent = gethostbyname(name.c_str());
+  else {
+    // use our own host name if none is specified
+    char hostname[MAXHOSTNAMELEN+1];
+    if (gethostname(hostname, MAXHOSTNAMELEN) >= 0) {
+      // ensure null termination regardless of
+      // gethostname() implementation details
+      hostname[MAXHOSTNAMELEN] = '\0';
+      hent = gethostbyname(hostname);
+    }
+  }
+  return hent;
+}
+
 Address	Address::getHostAddress(const std::string &hname)
 {
   Address a;
   InAddr tempAddr;
   int j;
 
-  struct hostent* hent;
-  if (hname == "") {				// local address
-    char hostname[MAXHOSTNAMELEN+1];
-    if (gethostname(hostname, sizeof(hostname)) >= 0)
-      hent = gethostbyname(hostname);
-    else
-      return a;
-  } else if (inet_aton(hname.c_str(), &tempAddr) != 0) {
+  if (hname.length() > 0 && inet_aton(hname.c_str(), &tempAddr) != 0) {
     a.addr.clear();
     a.addr.push_back(tempAddr);
     return a;
-  } else {				// non-local address
-    hent = gethostbyname(hname.c_str());
   }
 
+  const struct hostent* hent = bz_gethostbyname(hname);
   if (!hent) {
     herror("Looking up host name");
     return a;
   }
 
   a.addr.clear();
-  for (j=0; hent->h_addr_list[j] != NULL; j++){
+  for (j=0; hent->h_addr_list[j] != NULL; j++) {
     ::memcpy(&tempAddr, hent->h_addr_list[j], sizeof(tempAddr));
     a.addr.push_back(tempAddr);
   }
@@ -177,16 +203,7 @@ std::string		Address::getHostByAddress(InAddr addr)
 
 const std::string Address::getHostName(const std::string &hostname) // const
 {
-  char myname[MAXHOSTNAMELEN+1];
-  std::string name = hostname;
-  if (name.length() <= 0) {
-    if (gethostname(myname, sizeof(myname)) >= 0)
-      name = std::string(myname);
-  }
-  if (name.length() <= 0) {
-    return std::string();
-  }
-  struct hostent* hent = gethostbyname(name.c_str());
+  const struct hostent* hent = bz_gethostbyname(hostname);
   if (!hent) {
     return std::string();
   }
@@ -203,9 +220,9 @@ void*			Address::pack(void* _buf) const
   return (void*)buf;
 }
 
-void*			Address::unpack(void* _buf)
+const void*		Address::unpack(const void* _buf)
 {
-  unsigned char* buf = (unsigned char*)_buf;
+  const unsigned char* buf = (const unsigned char*)_buf;
   InAddr tempAddr;
   // FIXME - should actually parse the first byte to see if it's IPv4 or
   // IPv6
@@ -216,7 +233,7 @@ void*			Address::unpack(void* _buf)
   tempAddr.s_addr = u_long(hostaddr);
   addr.clear();
   addr.push_back(tempAddr);
-  return (void*)buf;
+  return buf;
 }
 
 //
@@ -234,16 +251,16 @@ void*			ServerId::pack(void* _buf) const
   return (void*)buf;
 }
 
-void*			ServerId::unpack(void* _buf)
+const void*		ServerId::unpack(const void* _buf)
 {
   // everything in ServerId should be stored in network byte order
-  unsigned char* buf = (unsigned char*)_buf;
+  const unsigned char* buf = (const unsigned char*)_buf;
   int32_t hostaddr;
   ::memcpy(&hostaddr, buf, sizeof(int32_t));	buf += sizeof(int32_t);
   ::memcpy(&port, buf, sizeof(int16_t));	buf += sizeof(int16_t);
   ::memcpy(&number, buf, sizeof(int16_t));	buf += sizeof(int16_t);
   serverHost.s_addr = u_long(hostaddr);
-  return (void*)buf;
+  return buf;
 }
 
 bool			ServerId::operator==(const ServerId& id) const
@@ -259,10 +276,9 @@ bool			ServerId::operator!=(const ServerId& id) const
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
