@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,6 +12,7 @@
 
 /* interface header */
 #include "AresHandler.h"
+#include "Address.h"
 
 /* system implementation headers */
 #include <errno.h>
@@ -20,15 +21,15 @@
 bool AresHandler::globallyInited = false;
 
 AresHandler::AresHandler(int _index)
-  : index(_index), hostname(NULL), status(None)
+  : index(_index), status(None)
 {
   // clear the host address
   memset(&hostAddress, 0, sizeof(hostAddress));
 
   /* ask for local "hosts" lookups too */
-  static const char* lookups = "fb";
+  static char lookups[] = "fb";
   struct ares_options opts;
-  opts.lookups = (char*)lookups; // we cheat, libares uses strdup
+  opts.lookups = lookups;
 
   /* start up our resolver */
   if (!globallyInited) {
@@ -53,10 +54,6 @@ AresHandler::~AresHandler()
   if (aresFailed)
     return;
   ares_destroy(aresChannel);
-  if (hostname) {
-    free(hostname);
-    hostname = NULL;
-  }
 }
 
 bool AresHandler::globalInit()
@@ -79,44 +76,37 @@ void AresHandler::globalShutdown()
 #endif
 }
 
-
-void AresHandler::queryHostname(struct sockaddr *clientAddr)
+void AresHandler::queryHostname(const struct sockaddr *clientAddr)
 {
   if (aresFailed)
     return;
+
   status = HbAPending;
   // launch the asynchronous query to look up this hostname
-  ares_gethostbyaddr(aresChannel, &((sockaddr_in *)clientAddr)->sin_addr,
+  ares_gethostbyaddr(aresChannel, &((const sockaddr_in *)clientAddr)->sin_addr,
 		     sizeof(in_addr), AF_INET, staticCallback, (void *)this);
   logDebugMessage(2,"Player [%d] submitted reverse resolve query\n", index);
 }
 
-void AresHandler::queryHost(char *hostName)
+void AresHandler::queryHost(const char *name)
 {
   if (aresFailed)
     return;
   ares_cancel(aresChannel);
 
-  if (inet_aton(hostName, &hostAddress) != 0) {
+  if (!name) {
+    status = Failed;
+    return;
+  }
+
+  if (inet_aton(name, &hostAddress) != 0) {
     status = HbNSucceeded;
     return;
   }
 
-  char *queryHostName = hostName;
-
-  char myHost[MAXHOSTNAMELEN+1];
-  if (hostName == NULL || *hostName == '\0') {
-    // local address
-    if (gethostname(hostname, sizeof(hostname)) < 0) {
-      status = Failed;
-      return;
-    }
-    queryHostName = myHost;
-  }
-
   // launch the asynchronous query to look up this hostname
   status = HbNPending;
-  ares_gethostbyname(aresChannel, queryHostName, AF_INET, staticCallback,
+  ares_gethostbyname(aresChannel, name, AF_INET, staticCallback,
 		     (void *)this);
 }
 
@@ -140,11 +130,9 @@ void AresHandler::callback(int callbackStatus, struct hostent *hostent)
 	     callbackStatus);
       status = Failed;
   } else if (status == HbAPending) {
-    if (hostname)
-      free(hostname); // shouldn't happen, but just in case
-    hostname = strdup(hostent->h_name);
+    hostName = strdup(hostent->h_name);
     status = HbASucceeded;
-    logDebugMessage(2,"Player [%d] resolved to %s\n", index, hostname);
+    logDebugMessage(2,"Player [%d] resolved to %s\n", index, hostName.c_str());
   } else if (status == HbNPending) {
     memcpy(&hostAddress, hostent->h_addr_list[0], sizeof(hostAddress));
     status = HbNSucceeded;
@@ -153,7 +141,7 @@ void AresHandler::callback(int callbackStatus, struct hostent *hostent)
 
 const char *AresHandler::getHostname()
 {
-  return hostname;
+  return hostName.c_str();
 }
 
 AresHandler::ResolutionStatus AresHandler::getHostAddress(struct in_addr
@@ -181,7 +169,7 @@ void AresHandler::process(fd_set *read_set, fd_set *write_set)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
