@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -79,7 +79,7 @@ Obstacle* ArcObstacle::copyWithTransform(const MeshTransform& xform) const
   ArcObstacle* copy =
     new ArcObstacle(tmpXform, pos, size, angle, sweepAngle, ratio,
 		    texsize, useNormals, divisions,
-		    (const BzMaterial**)materials, phydrv,
+		    const_cast<const BzMaterial**>(materials), phydrv,
 		    smoothBounce, driveThrough, shootThrough, ricochet);
   return copy;
 }
@@ -616,7 +616,7 @@ bool ArcObstacle::inMovingBox(const float*, float, const float*, float,
 }
 
 
-bool ArcObstacle::isCrossing(const float* UNUSED(p), float UNUSED(angle),
+bool ArcObstacle::isCrossing(const float* UNUSED(p), float UNUSED(_angle),
 			     float UNUSED(dx), float UNUSED(dy), float UNUSED(height),
 			     float* UNUSED(_plane)) const
 {
@@ -658,7 +658,7 @@ void* ArcObstacle::pack(void* buf) const
 }
 
 
-void* ArcObstacle::unpack(void* buf)
+const void* ArcObstacle::unpack(const void* buf)
 {
   int32_t inTmp;
   buf = transform.unpack(buf);
@@ -778,10 +778,9 @@ void ArcObstacle::print(std::ostream& out, const std::string& indent) const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
