@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -236,7 +236,7 @@ void* BoxBuilding::pack(void* buf) const
 }
 
 
-void* BoxBuilding::unpack(void* buf)
+const void* BoxBuilding::unpack(const void* buf)
 {
   buf = nboUnpackVector(buf, pos);
   buf = nboUnpackFloat(buf, angle);
@@ -381,10 +381,9 @@ void BoxBuilding::printOBJ(std::ostream& out, const std::string& UNUSED(indent))
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
