@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -165,6 +165,7 @@ void MeshDrawInfo::clear()
 void MeshDrawInfo::init()
 {
   name = "";
+  lines = 0;
 
   valid = true;
   serverSide = true;
@@ -466,7 +467,7 @@ bool MeshDrawInfo::clientSetup(const MeshObstacle* mesh)
       for (int cmd = 0; cmd < drawSet.count; cmd++) {
 	DrawCmd& drawCmd = drawSet.cmds[cmd];
 	const int points = drawCmd.count;
-	switch(drawCmd.drawMode) {
+	switch (drawCmd.drawMode) {
 	  // NOTE: points and lines are each counted as a triangle
 	  case DrawCmd::DrawPoints:	   tris += points;	break;
 	  case DrawCmd::DrawLines:	   tris += points / 2;	break;
@@ -685,7 +686,7 @@ static bool parseDrawCmd(std::istream& input, const std::string& mode,
 }
 
 
-static bool parseDrawSet(std::istream& input, DrawSet& set)
+static bool parseDrawSet(std::istream& input, DrawSet& set, int& lines)
 {
   bool success = true;
 
@@ -693,6 +694,8 @@ static bool parseDrawSet(std::istream& input, DrawSet& set)
   std::string line, label;
 
   while (std::getline(input, line)) {
+    ++lines;
+
     std::istringstream parms(line);
     if (!(parms >> label)) {
       continue;
@@ -743,7 +746,7 @@ static bool parseDrawSet(std::istream& input, DrawSet& set)
 }
 
 
-static bool parseDrawLod(std::istream& input, DrawLod& lod)
+static bool parseDrawLod(std::istream& input, DrawLod& lod, int& lines)
 {
   bool success = true;
 
@@ -751,6 +754,8 @@ static bool parseDrawLod(std::istream& input, DrawLod& lod)
   std::string line, cmd;
 
   while (std::getline(input, line)) {
+    ++lines;
+
     std::istringstream parms(line);
     if (!(parms >> cmd)) {
       continue;
@@ -777,7 +782,7 @@ static bool parseDrawLod(std::istream& input, DrawLod& lod)
       if (parms >> matName) {
 	DrawSet set;
 	set.material = MATERIALMGR.findMaterial(matName);
-	if (parseDrawSet(input, set)) {
+	if (parseDrawSet(input, set, lines)) {
 	  pSets.push_back(set);
 	} else {
 	  success = false;
@@ -824,6 +829,8 @@ bool MeshDrawInfo::parse(std::istream& input)
   std::string line, cmd;
 
   while (std::getline(input, line)) {
+    ++lines;
+
     std::istringstream parms(line);
     if (!(parms >> cmd)) {
       continue;
@@ -918,7 +925,7 @@ bool MeshDrawInfo::parse(std::istream& input)
       }
     }
     else if (strcasecmp(cmd.c_str(), "lod") == 0) {
-      if (parseDrawLod(input, lod)) {
+      if (parseDrawLod(input, lod, lines)) {
 	pLods.push_back(lod);
       } else {
 	success = false;
@@ -926,7 +933,7 @@ bool MeshDrawInfo::parse(std::istream& input)
       }
     }
     else if (strcasecmp(cmd.c_str(), "radarlod") == 0) {
-      if (parseDrawLod(input, lod)) {
+      if (parseDrawLod(input, lod, lines)) {
 	pRadarLods.push_back(lod);
       } else {
 	success = false;
@@ -959,7 +966,7 @@ bool MeshDrawInfo::parse(std::istream& input)
   }
 
   // make raw verts
-  if (pVerts.size() > 0) {
+  if (!pVerts.empty()) {
     rawVertCount = pVerts.size();
     rawVerts = new afvec3[rawVertCount];
     for (i = 0; i < rawVertCount; i++) {
@@ -967,7 +974,7 @@ bool MeshDrawInfo::parse(std::istream& input)
     }
   }
   // make raw norms
-  if (pNorms.size() > 0) {
+  if (!pNorms.empty()) {
     rawNormCount = pNorms.size();
     rawNorms = new afvec3[rawNormCount];
     for (i = 0; i < rawNormCount; i++) {
@@ -975,7 +982,7 @@ bool MeshDrawInfo::parse(std::istream& input)
     }
   }
   // make raw texcoords
-  if (pTxcds.size() > 0) {
+  if (!pTxcds.empty()) {
     rawTxcdCount = pTxcds.size();
     rawTxcds = new afvec2[rawTxcdCount];
     for (i = 0; i < rawTxcdCount; i++) {
@@ -1284,7 +1291,7 @@ void* MeshDrawInfo::pack(void* buf) const
 }
 
 
-void* MeshDrawInfo::unpack(void* buf)
+const void* MeshDrawInfo::unpack(const void* buf)
 {
   int i;
   int32_t s32;
@@ -1416,7 +1423,7 @@ void* Corner::pack(void* buf) const
 }
 
 
-void* Corner::unpack(void* buf)
+const void* Corner::unpack(const void* buf)
 {
   uint8_t u8;
   buf = nboUnpackUByte(buf, u8);
@@ -1541,7 +1548,7 @@ void* DrawCmd::pack(void* buf) const
 }
 
 
-void* DrawCmd::unpack(void* buf)
+const void* DrawCmd::unpack(const void* buf)
 {
   uint16_t u16;
   int32_t s32;
@@ -1632,7 +1639,7 @@ void* DrawSet::pack(void* buf) const
 }
 
 
-void* DrawSet::unpack(void* buf)
+const void* DrawSet::unpack(const void* buf)
 {
   int32_t s32;
   buf = nboUnpackInt(buf, s32);
@@ -1703,7 +1710,7 @@ void* DrawLod::pack(void* buf) const
 }
 
 
-void* DrawLod::unpack(void* buf)
+const void* DrawLod::unpack(const void* buf)
 {
   int32_t s32;
   buf = nboUnpackInt(buf, s32);
@@ -1746,7 +1753,7 @@ void* AnimationInfo::pack(void* buf) const
 }
 
 
-void* AnimationInfo::unpack(void* buf)
+const void* AnimationInfo::unpack(const void* buf)
 {
   buf = nboUnpackFloat(buf, angvel);
   buf= nboUnpackStdString(buf, dummy);
@@ -1757,7 +1764,7 @@ void* AnimationInfo::unpack(void* buf)
 /******************************************************************************/
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
