@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -349,7 +349,6 @@ void MeshFace::get3DNormal(const float* p, float* n) const
     // normal smoothing to fake curved surfaces
     int i;
     // calculate the triangle ares
-    float totalArea = 0.0f;
     float* areas = new float[vertexCount];
     for (i = 0; i < vertexCount; i++) {
       int next = (i + 1) % vertexCount;
@@ -358,7 +357,6 @@ void MeshFace::get3DNormal(const float* p, float* n) const
       vec3sub(eb, vertices[next], vertices[i]);
       vec3cross(cross, ea, eb);
       areas[i] = sqrtf(vec3dot(cross, cross));
-      totalArea = totalArea + areas[i];
     }
     float smallestArea = MAXFLOAT;
     float* twinAreas = new float[vertexCount];
@@ -543,7 +541,7 @@ bool MeshFace::inMovingBox(const float* oldPos, float UNUSED(oldAngle),
 }
 
 
-bool MeshFace::isCrossing(const float* UNUSED(p), float UNUSED(angle),
+bool MeshFace::isCrossing(const float* UNUSED(p), float UNUSED(_angle),
 			  float UNUSED(dx), float UNUSED(dy), float UNUSED(height),
 			  float* _plane) const
 {
@@ -601,7 +599,7 @@ void *MeshFace::pack(void *buf) const
 }
 
 
-void *MeshFace::unpack(void *buf)
+const void *MeshFace::unpack(const void *buf)
 {
   int32_t inTmp;
   driveThrough = shootThrough = smoothBounce = false;
@@ -624,7 +622,7 @@ void *MeshFace::unpack(void *buf)
   for (int i = 0; i < vertexCount; i++) {
     int32_t index;
     buf = nboUnpackInt(buf, index);
-    vertices[i] = (float*)mesh->getVertices()[index];
+    vertices[i] = mesh->getVertices()[index];
   }
 
   // normals
@@ -633,7 +631,7 @@ void *MeshFace::unpack(void *buf)
     for (int i = 0; i < vertexCount; i++) {
       int32_t index;
       buf = nboUnpackInt(buf, index);
-      normals[i] = (float*)mesh->getNormals()[index];
+      normals[i] = mesh->getNormals()[index];
     }
   }
 
@@ -643,7 +641,7 @@ void *MeshFace::unpack(void *buf)
     for (int i = 0; i < vertexCount; i++) {
       int32_t index;
       buf = nboUnpackInt(buf, index);
-      texcoords[i] = (float*)mesh->getTexcoords()[index];
+      texcoords[i] = mesh->getTexcoords()[index];
     }
   }
 
@@ -780,10 +778,9 @@ void MeshFace::print(std::ostream& out, const std::string& indent) const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
