@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -209,14 +209,13 @@ bool MeshObstacle::addFace(const std::vector<int>& _vertices,
   if (face->isValid()) {
     faces[faceCount] = face;
     faceCount++;
-  }
-  else if (triangulate) {
+  } else if (triangulate) {
     // triangulate
     std::vector<TriIndices> triIndices;
     triangulateFace(count, v, triIndices);
     delete face; // delete the old face
     const unsigned int triSize = triIndices.size();
-    if (triSize <= 0) {
+    if (triSize == 0) {
       return false;
     } else {
       // prepare array for extra faces
@@ -250,8 +249,7 @@ bool MeshObstacle::addFace(const std::vector<int>& _vertices,
 	}
       }
     }
-  }
-  else {
+  } else {
     // just nuke it
     delete face;
     return false;
@@ -313,7 +311,6 @@ MeshObstacle::~MeshObstacle()
 
 Obstacle* MeshObstacle::copyWithTransform(const MeshTransform& xform) const
 {
-  int i;
   MeshObstacle* copy;
   std::vector<char> ctlist;
   std::vector<cfvec3> clist;
@@ -329,6 +326,7 @@ Obstacle* MeshObstacle::copyWithTransform(const MeshTransform& xform) const
 			    vlist, nlist, tlist, 0, noclusters,
 			    smoothBounce, driveThrough, shootThrough, ricochet);
   } else {
+    int i;
     for (i = 0; i < checkCount; i++) {
       ctlist.push_back(checkTypes[i]);
     }
@@ -340,8 +338,8 @@ Obstacle* MeshObstacle::copyWithTransform(const MeshTransform& xform) const
     }
 
     copy = new MeshObstacle(xform, ctlist, clist,
-			    vlist, nlist, tlist, faceCount, noclusters,
-			    smoothBounce, driveThrough, shootThrough, ricochet);
+	vlist, nlist, tlist, faceCount, noclusters,
+	smoothBounce, driveThrough, shootThrough, ricochet);
 
     for (i = 0; i < faceCount; i++) {
       copyFace(i, copy);
@@ -364,15 +362,15 @@ void MeshObstacle::copyFace(int f, MeshObstacle* mesh) const
   const int vcount = face->getVertexCount();
   for (int i = 0; i < vcount; i++) {
     int index;
-    index = ((afvec3*) face->getVertex(i)) - vertices;
+    index = ((const afvec3*) face->getVertex(i)) - vertices;
     vlist.push_back(index);
 
     if (face->useNormals()) {
-      index = ((afvec3*) face->getNormal(i)) - normals;
+      index = ((const afvec3*) face->getNormal(i)) - normals;
       nlist.push_back(index);
     }
     if (face->useTexcoords()) {
-      index = ((afvec2*) face->getTexcoord(i)) - texcoords;
+      index = ((const afvec2*) face->getTexcoord(i)) - texcoords;
       tlist.push_back(index);
     }
   }
@@ -562,7 +560,7 @@ void MeshObstacle::getNormal(const float* p, float* n) const
 
 
 bool MeshObstacle::getHitNormal(const float* UNUSED(oldPos), float UNUSED(oldAngle),
-				 const float* p, float UNUSED(angle),
+				 const float* p, float UNUSED(_angle),
 				 float, float, float UNUSED(height),
 				 float* n) const
 {
@@ -581,7 +579,7 @@ bool MeshObstacle::inCylinder(const float* p,
 }
 
 
-bool MeshObstacle::inBox(const float* p, float UNUSED(angle),
+bool MeshObstacle::inBox(const float* p, float UNUSED(_angle),
 			 float UNUSED(dx), float UNUSED(dy), float height) const
 {
   const float mid[3] = { p[0], p[1], p[2] + (0.5f * height) };
@@ -590,7 +588,7 @@ bool MeshObstacle::inBox(const float* p, float UNUSED(angle),
 
 
 bool MeshObstacle::inMovingBox(const float*, float,
-			       const float* p, float UNUSED(angle),
+			       const float* p, float UNUSED(_angle),
 			       float UNUSED(dx), float UNUSED(dy), float height) const
 {
   const float mid[3] = { p[0], p[1], p[2] + (0.5f * height) };
@@ -598,7 +596,7 @@ bool MeshObstacle::inMovingBox(const float*, float,
 }
 
 
-bool MeshObstacle::isCrossing(const float* UNUSED(p), float UNUSED(angle),
+bool MeshObstacle::isCrossing(const float* UNUSED(p), float UNUSED(_angle),
 			       float UNUSED(dx), float UNUSED(dy), float UNUSED(height),
 			       float* UNUSED(plane)) const
 {
@@ -709,7 +707,7 @@ void *MeshObstacle::pack(void *buf) const
 }
 
 
-void *MeshObstacle::unpack(void *buf)
+const void *MeshObstacle::unpack(const void *buf)
 {
   int i;
   int32_t inTmp;
@@ -742,11 +740,10 @@ void *MeshObstacle::unpack(void *buf)
   buf = nboUnpackInt(buf, inTmp);
   texcoordCount = int(inTmp);
   texcoords = new afvec2[texcoordCount];
-  for (i = 0; i < texcoordCount; i++) {
-    buf = nboUnpackFloat(buf, texcoords[i][0]);
-    buf = nboUnpackFloat(buf, texcoords[i][1]);
-  }
-  void* texcoordEnd = buf; // for locating hidden drawInfo data
+  // note where the texture coordinates begin; skip past them
+  const void* texCoordPtr = buf;
+  buf = (const char*)buf + sizeof(float) * 2 * texcoordCount;
+  const char* texcoordEnd = (const char*)buf;	// for locating hidden drawInfo data
 
   buf = nboUnpackInt(buf, inTmp);
   faceSize = int(inTmp);
@@ -782,7 +779,7 @@ void *MeshObstacle::unpack(void *buf)
   if (drawInfoOwner &&  (texcoordCount >= 2)) {
     nboUseErrorChecking(false);
     {
-      void* drawInfoSize = (char*)texcoordEnd - sizeof(afvec2);
+      const void* drawInfoSize = texcoordEnd - sizeof(afvec2);
       int32_t rewindLen;
       nboUnpackInt(drawInfoSize, rewindLen);
 
@@ -791,20 +788,25 @@ void *MeshObstacle::unpack(void *buf)
       if (rewindLen <= (int)(texcoordCount * sizeof(afvec2))) {
 	// unpack the drawInfo
 	if (useDrawInfo) {
-	  void* drawInfoData = (char*)texcoordEnd - rewindLen;
+	  const void* drawInfoData = texcoordEnd - rewindLen;
 	  drawInfo = new MeshDrawInfo();
 	  drawInfo->unpack(drawInfoData);
 	  name = drawInfo->getName(); // get the proxied name
 	}
 
 	// free the bogus texcoords
+	// FIXME - don't allocate storage we won't use
 	const int fakeTxcds = rewindLen / sizeof(afvec2);
 	texcoordCount = texcoordCount - fakeTxcds;
 	afvec2* tmpTxcds = new afvec2[texcoordCount];
-	memcpy(tmpTxcds, texcoords, texcoordCount * sizeof(afvec2));
 	delete[] texcoords;
 	int ptrDiff = (char*)tmpTxcds - (char*)texcoords;
 	texcoords = tmpTxcds;
+	// unpack actual texcoords
+	for (i = 0; i < texcoordCount; i++) {
+	  texCoordPtr = nboUnpackFloat(texCoordPtr, texcoords[i][0]);
+	  texCoordPtr = nboUnpackFloat(texCoordPtr, texcoords[i][1]);
+	}
 
 	// setup the drawInfo arrays
 	if (useDrawInfo) {
@@ -831,6 +833,12 @@ void *MeshObstacle::unpack(void *buf)
       }
     }
     nboUseErrorChecking(true);
+  } else {
+    // no "hidden" drawInfo data; just unpack the texcoords
+    for (i = 0; i < texcoordCount; i++) {
+      texCoordPtr = nboUnpackFloat(texCoordPtr, texcoords[i][0]);
+      texCoordPtr = nboUnpackFloat(texCoordPtr, texcoords[i][1]);
+    }
   }
 
   finalize();
@@ -997,11 +1005,11 @@ void MeshObstacle::printOBJ(std::ostream& out, const std::string& UNUSED(indent)
     const bool useTexcoords = face->useTexcoords();
     out << "f";
     for (i = 0; i < vCount; i++) {
-      int vIndex = (afvec3*)face->getVertex(i) - vertices;
+      int vIndex = (const afvec3*)face->getVertex(i) - vertices;
       vIndex = vIndex - vertexCount;
       out << " " << vIndex;
       if (useTexcoords) {
-	int tIndex = (afvec2*)face->getTexcoord(i) - texcoords;
+	int tIndex = (const afvec2*)face->getTexcoord(i) - texcoords;
 	tIndex = tIndex - texcoordCount;
 	out << "/" << tIndex;
       }
@@ -1009,7 +1017,7 @@ void MeshObstacle::printOBJ(std::ostream& out, const std::string& UNUSED(indent)
 	if (!useTexcoords) {
 	  out << "/";
 	}
-	int nIndex = (afvec3*)face->getNormal(i) - normals;
+	int nIndex = (const afvec3*)face->getNormal(i) - normals;
 	nIndex = nIndex - normalCount;
 	out << "/" << nIndex;
       }
@@ -1026,10 +1034,9 @@ void MeshObstacle::printOBJ(std::ostream& out, const std::string& UNUSED(indent)
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
