@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -135,8 +135,8 @@ static bool groundClippedFace(const MeshFace* face)
 
 static int sortByMaterial(const void* a, const void *b)
 {
-  const MeshFace* faceA = *((const MeshFace**)a);
-  const MeshFace* faceB = *((const MeshFace**)b);
+  const MeshFace* faceA = *((const MeshFace* const *)a);
+  const MeshFace* faceB = *((const MeshFace* const *)b);
   const bool noClusterA = faceA->noClusters();
   const bool noClusterB = faceB->noClusters();
 
@@ -382,8 +382,7 @@ MeshPolySceneNode* MeshSceneNodeGenerator::getMeshPolySceneNode(const MeshFace*
 void MeshSceneNodeGenerator::setupNodeMaterial(WallSceneNode* node,
 					       const BzMaterial* mat)
 {
-  // cheat a little
-  ((BzMaterial*)mat)->setReference();
+  mat->setReference();
 
   TextureManager &tm = TextureManager::instance();
   OpenGLMaterial oglMaterial(mat->getSpecular(),
@@ -515,7 +514,7 @@ bool MeshSceneNodeGenerator::makeTexcoords(const float* plane,
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
