@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,7 @@
 // system headers
 #include <string.h>
 #include <string>
+#include <sstream>
 #include <vector>
 #include <map>
 #include <iostream>
@@ -203,7 +204,7 @@ void* GroupInstance::pack(void* buf)
     p = nboPackUByte(buffer, 0); // terminate
     p = nboPackInt(p, count);
     MaterialMap::const_iterator it;
-    for (it = matMap.begin(); it != matMap.end(); it++) {
+    for (it = matMap.begin(); it != matMap.end(); ++it) {
       int srcIndex = MATERIALMGR.getIndex(it->first);
       int dstIndex = MATERIALMGR.getIndex(it->second);
       p = nboPackInt(p, srcIndex);
@@ -247,14 +248,14 @@ void* GroupInstance::pack(void* buf)
 }
 
 
-void* GroupInstance::unpack(void* buf)
+const void* GroupInstance::unpack(const void* buf)
 {
   buf = nboUnpackStdString(buf, groupdef);
 
   buf = nboUnpackStdStringRaw(buf, name);
   if (strlen(name.c_str()) != name.size()) {
     // hack to extract material map data
-    void* p = (void*)(name.c_str() + strlen(name.c_str()) + 1);
+    const void* p = name.c_str() + strlen(name.c_str()) + 1;
     nboUseErrorChecking(false);
     {
       int32_t count;
@@ -374,7 +375,7 @@ void GroupInstance::print(std::ostream& out, const std::string& indent) const
   }
   else if (matMap.size() > 0) {
     MaterialMap::const_iterator it;
-    for (it = matMap.begin(); it != matMap.end(); it++) {
+    for (it = matMap.begin(); it != matMap.end(); ++it) {
       out << indent << "  matswap ";
       MATERIALMGR.printReference(out, it->first);
       out << " ";
@@ -538,9 +539,9 @@ void GroupDefinition::appendGroupName(const GroupInstance* group) const
     newName = "/";
     newName += group->getGroupDef();
     newName += "/";
-    char buffer[8];
-    sprintf (buffer, "%i", count);
-    newName += buffer;
+	std::stringstream buffer;
+	buffer << count;
+    newName += buffer.str();
   }
   depthName += newName;
   depthName += ":";
@@ -548,7 +549,7 @@ void GroupDefinition::appendGroupName(const GroupInstance* group) const
 }
 
 
-static MeshObstacle* makeContainedMesh(int type, const Obstacle* obs)
+static MeshObstacle* makeContainedMesh(int type, Obstacle* obs)
 {
   MeshObstacle* mesh = NULL;
   switch (type) {
@@ -816,7 +817,7 @@ void* GroupDefinition::pack(void* buf) const
 }
 
 
-void* GroupDefinition::unpack(void* buf)
+const void* GroupDefinition::unpack(const void* buf)
 {
   buf = nboUnpackStdString(buf, name);
 
@@ -887,7 +888,7 @@ void GroupDefinition::printGrouped(std::ostream& out,
   for (int type = 0; type < ObstacleTypeCount; type++) {
     const ObstacleList& list = getList(type);
     for (unsigned int i = 0; i < list.size(); i++) {
-      const Obstacle* obs = list[i];
+      Obstacle* obs = list[i];
 
       if (!obs->isFromGroupDef() && !obs->isFromContainer()) {
 	if (!saveAsMeshes) {
@@ -1010,8 +1011,8 @@ void GroupDefinitionMgr::tighten()
 
 static int compareHeights(const void* a, const void* b)
 {
-  const Obstacle* obsA = *((const Obstacle**)a);
-  const Obstacle* obsB = *((const Obstacle**)b);
+  const Obstacle* obsA = *((const Obstacle* const *)a);
+  const Obstacle* obsB = *((const Obstacle* const *)b);
   const Extents& eA = obsA->getExtents();
   const Extents& eB = obsB->getExtents();
 
@@ -1102,7 +1103,7 @@ void* GroupDefinitionMgr::pack(void* buf) const
 }
 
 
-void* GroupDefinitionMgr::unpack(void* buf)
+const void* GroupDefinitionMgr::unpack(const void* buf)
 {
   buf = world.unpack(buf);
   uint32_t i, count;
@@ -1166,10 +1167,9 @@ void GroupDefinitionMgr::print(std::ostream& out,
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
