@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -118,7 +118,7 @@ ObstacleModifier::ObstacleModifier(const ObstacleModifier& obsMod,
     } else {
       matMap = obsMod.matMap;
       MaterialMap::const_iterator it;
-      for (it = grpinst.matMap.begin(); it != grpinst.matMap.end(); it++) {
+      for (it = grpinst.matMap.begin(); it != grpinst.matMap.end(); ++it) {
 	MaterialMap::const_iterator find_it;
 	find_it = obsMod.matMap.find(it->second);
 	if (find_it != obsMod.matMap.end()) {
@@ -184,7 +184,7 @@ void ObstacleModifier::execute(Obstacle* obstacle) const
     if (obstacle->getType() == MeshObstacle::getClassName()) {
       const MeshObstacle* mesh = (MeshObstacle*) obstacle;
       for (int i = 0; i < mesh->getFaceCount(); i++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(i);
+	MeshFace* face = mesh->getFace(i);
 	if (modifyMaterial) {
 	  face->bzMaterial = material;
 	} else if (matMap.size() > 0) {
@@ -203,7 +203,7 @@ void ObstacleModifier::execute(Obstacle* obstacle) const
     if (obstacle->getType() == MeshObstacle::getClassName()) {
       const MeshObstacle* mesh = (MeshObstacle*) obstacle;
       for (int i = 0; i < mesh->getFaceCount(); i++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(i);
+	MeshFace* face = mesh->getFace(i);
 	// only modify faces that already have a physics driver
 	if (face->phydrv >= 0) {
 	  face->phydrv = phydrv;
@@ -216,7 +216,7 @@ void ObstacleModifier::execute(Obstacle* obstacle) const
     if (obstacle->getType() == MeshObstacle::getClassName()) {
       const MeshObstacle* mesh = (MeshObstacle*) obstacle;
       for (int i = 0; i < mesh->getFaceCount(); i++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(i);
+	MeshFace* face = mesh->getFace(i);
 	face->driveThrough = true;
       }
     }
@@ -226,7 +226,7 @@ void ObstacleModifier::execute(Obstacle* obstacle) const
     if (obstacle->getType() == MeshObstacle::getClassName()) {
       const MeshObstacle* mesh = (MeshObstacle*) obstacle;
       for (int i = 0; i < mesh->getFaceCount(); i++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(i);
+	MeshFace* face = mesh->getFace(i);
 	face->shootThrough = true;
       }
     }
@@ -236,7 +236,7 @@ void ObstacleModifier::execute(Obstacle* obstacle) const
     if (obstacle->getType() == MeshObstacle::getClassName()) {
       const MeshObstacle* mesh = (MeshObstacle*) obstacle;
       for (int i = 0; i < mesh->getFaceCount(); i++) {
-	MeshFace* face = (MeshFace*) mesh->getFace(i);
+	MeshFace* face = mesh->getFace(i);
 	face->ricochet = true;
       }
     }
@@ -253,7 +253,7 @@ void ObstacleModifier::getMaterialMap(const MaterialSet& matSet,
 
   if (modifyColor || modifyMaterial || (matMap.size() > 0)) {
     MaterialSet::const_iterator it;
-    for (it = matSet.begin(); it != matSet.end(); it++) {
+    for (it = matSet.begin(); it != matSet.end(); ++it) {
       const BzMaterial* origMat = *it;
       const BzMaterial* convMat = *it;
       if (modifyMaterial) {
@@ -277,10 +277,9 @@ void ObstacleModifier::getMaterialMap(const MaterialSet& matSet,
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
