@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -79,7 +79,7 @@ Obstacle* TetraBuilding::copyWithTransform(const MeshTransform& xform) const
 
   TetraBuilding* copy =
     new TetraBuilding(tmpXform, vertices, normals, texcoords,
-		      useNormals, useTexcoords, (const BzMaterial**)materials,
+		      useNormals, useTexcoords, const_cast<const BzMaterial**>(materials),
 		      driveThrough, shootThrough, ricochet);
   return copy;
 }
@@ -269,7 +269,7 @@ bool TetraBuilding::inMovingBox(const float*, float, const float*, float,
 }
 
 
-bool TetraBuilding::isCrossing(const float* UNUSED(p), float UNUSED(angle),
+bool TetraBuilding::isCrossing(const float* UNUSED(p), float UNUSED(_angle),
 			  float UNUSED(dx), float UNUSED(dy), float UNUSED(height),
 			  float* UNUSED(_plane)) const
 {
@@ -363,7 +363,7 @@ void *TetraBuilding::pack(void* buf) const
 }
 
 
-void *TetraBuilding::unpack(void* buf)
+const void *TetraBuilding::unpack(const void* buf)
 {
   int v;
 
@@ -503,10 +503,9 @@ void TetraBuilding::print(std::ostream& out, const std::string& indent) const
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
