@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -144,7 +144,7 @@ void* WallObstacle::pack(void* buf) const
 }
 
 
-void* WallObstacle::unpack(void* buf)
+const void* WallObstacle::unpack(const void* buf)
 {
   buf = nboUnpackVector(buf, pos);
   buf = nboUnpackFloat(buf, angle);
@@ -181,10 +181,9 @@ void WallObstacle::print(std::ostream& UNUSED(out),
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
