@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,6 +18,7 @@
 /* system headers */
 #include <stdio.h>
 #include <string.h>
+#include <sstream>
 #include <assert.h>
 
 /* common implementation headers */
@@ -931,8 +932,10 @@ OpenGLGState::ContextInitializer*
 			OpenGLGState::ContextInitializer::head = NULL;
 OpenGLGState::ContextInitializer*
 			OpenGLGState::ContextInitializer::tail = NULL;
+int OpenGLGState::maxSamples = 1;
 bool OpenGLGState::executingFreeFuncs = false;
 bool OpenGLGState::executingInitFuncs = false;
+bool OpenGLGState::hasAnisotropicFiltering = false;
 
 OpenGLGState::ContextInitializer::ContextInitializer(
 				OpenGLContextFunction _freeCallback,
@@ -1115,6 +1118,11 @@ int OpenGLGState::getOpaqueStippleIndex()
 }
 
 
+int OpenGLGState::getMaxSamples() {
+  return maxSamples;
+}
+
+
 void OpenGLGState::initStipple(void*)
 {
   stipples = glGenLists(NumStipples);
@@ -1168,13 +1176,6 @@ void OpenGLGState::init()
     return;
   }
 
-  // setup the GLEW library
-#ifdef HAVE_GLEW
-  if (glewInit() != GLEW_OK) {
-    logDebugMessage(0,"GLEW initialization failed");
-  }
-#endif
-
   // initialize GL state to what we expect
   initGLState();
 
@@ -1220,13 +1221,6 @@ void OpenGLGState::initContext()
     return;
   }
 
-  // setup the GLEW library
-#ifdef HAVE_GLEW
-  if (glewInit() != GLEW_OK) {
-    logDebugMessage(0,"GLEW initialization failed");
-  }
-#endif
-
   // call all of the freeing functions first
   logDebugMessage(3,"ContextInitializer::executeFreeFuncs() start\n");
   ContextInitializer::executeFreeFuncs();
@@ -1235,6 +1229,9 @@ void OpenGLGState::initContext()
   // initialize GL state
   initGLState();
 
+  // check GL extensions
+  initGLExtensions();
+
   // reset our idea of the state
   resetState();
 
@@ -1257,7 +1254,6 @@ void OpenGLGState::initContext()
   glLoadIdentity();
   glEnable(GL_SCISSOR_TEST);
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
-
 }
 
 
@@ -1284,6 +1280,69 @@ void OpenGLGState::initGLState()
   glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 }
 
+// utility to check if an OpenGL extension is supported on this system
+bool OpenGLGState::initGLExtensions()
+{
+  const char * extensions = (const char*) glGetString(GL_EXTENSIONS);
+  if (!extensions)
+    return false;
+
+  std::stringstream extensionsStream;
+  extensionsStream.str(extensions);
+
+  hasAnisotropicFiltering = false;
+
+  while (!extensionsStream.eof()) {
+    std::string thisExtension;
+    extensionsStream >> thisExtension;
+
+    if (thisExtension == "GL_EXT_texture_filter_anisotropic")
+      hasAnisotropicFiltering = true;
+  }
+
+  extensionsStream.clear();
+  extensionsStream.str(extensions);
+
+  while (!extensionsStream.eof()) {
+    std::string thisExtension;
+    extensionsStream >> thisExtension;
+
+    if (thisExtension == "GL_ARB_framebuffer_object") {
+      GLint sampleCount = 1;
+      glGetIntegerv(GL_MAX_SAMPLES, &sampleCount);
+      maxSamples = sampleCount;
+
+      // make sure all the functions are good (macOS should have them built-in)
+#ifndef __APPLE__
+      if(glIsRenderbuffer == NULL ||
+	 glIsRenderbuffer == NULL ||
+	 glBindRenderbuffer == NULL ||
+	 glDeleteRenderbuffers == NULL ||
+	 glGenRenderbuffers == NULL ||
+	 glRenderbufferStorage == NULL ||
+	 glRenderbufferStorageMultisample == NULL ||
+	 glGetRenderbufferParameteriv == NULL ||
+	 glIsFramebuffer == NULL ||
+	 glBindFramebuffer == NULL ||
+	 glDeleteFramebuffers == NULL ||
+	 glGenFramebuffers == NULL ||
+	 glCheckFramebufferStatus == NULL ||
+	 glFramebufferTexture1D == NULL ||
+	 glFramebufferTexture2D == NULL ||
+	 glFramebufferTexture3D == NULL ||
+	 glFramebufferTextureLayer == NULL ||
+	 glFramebufferRenderbuffer == NULL ||
+	 glGetFramebufferAttachmentParameteriv == NULL ||
+	 glBlitFramebuffer == NULL ||
+	 glGenerateMipmap == NULL)
+	maxSamples = 1;
+#endif
+    }
+  }
+
+  return false;
+}
+
 
 //
 // OpenGLGStateBuilder
@@ -1564,24 +1623,25 @@ void bzMatrixMode(GLenum mode)
   }
   matrixMode = mode;
   glMatrixMode(mode);
-  logDebugMessage(3, ("MatrixMode: %i %i %i\n", matrixDepth[0], matrixDepth[1], matrixDepth[2]);
+  logDebugMessage(3, "MatrixMode: %i %i %i\n", matrixDepth[0], matrixDepth[1], matrixDepth[2]);
 }
 
 #endif // DEBUG_GL_MATRIX_STACKS
 
 
-#ifdef _WIN32
+#if defined(_WIN32)
 #  define GET_CURRENT_CONTEXT wglGetCurrentContext
+#elif defined(__BEOS__)
+   // no way to do that, and you shouldn't have to anyway!
+#  define GET_CURRENT_CONTEXT() 1
+#elif defined(HAVE_SDL2)
+#  include "bzfSDL.h"
+#  define GET_CURRENT_CONTEXT SDL_GL_GetCurrentContext
+#elif defined(HAVE_CGLGETCURRENTCONTEXT)
+#  define GET_CURRENT_CONTEXT CGLGetCurrentContext
 #else
-#  ifdef HAVE_CGLGETCURRENTCONTEXT
-#    define GET_CURRENT_CONTEXT CGLGetCurrentContext
-#  elif defined(__BEOS__)
-// no way to do that, and you shouldn't have to anyway!
-#    define GET_CURRENT_CONTEXT() 1
-#  else
-#    include <GL/glx.h>
-#    define GET_CURRENT_CONTEXT glXGetCurrentContext
-#  endif
+#  include <GL/glx.h>
+#  define GET_CURRENT_CONTEXT glXGetCurrentContext
 #endif
 
 // NOTE: if you're compiler croaks here, then you might want
