@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,9 +16,6 @@
 /* interface header */
 #include "DXJoystick.h"
 
-// Don't try compile this if we don't have an up-to-date, working DX
-#if defined(USE_DINPUT)
-
 #pragma comment(lib, "dinput8.lib")
 #pragma comment(lib, "dxguid.lib")
 
@@ -29,7 +26,11 @@
 #include <stdlib.h>
 
 /* local impl. headers */
-#include "WinWindow.h"
+#ifdef HAVE_SDL
+#  include "SDL2Window.h"
+#else
+#  include "WinWindow.h"
+#endif
 #include "ErrorHandler.h"
 #include "TextUtils.h"
 
@@ -46,7 +47,7 @@ DXJoystick::DXJoystick() : device(NULL)
     DXError("Could not initialize DirectInput", success);
     return;
   }
-
+  numberOfHats = 0;
   enumerateDevices();
 }
 
@@ -67,6 +68,18 @@ DXJoystick::~DXJoystick()
   }
 }
 
+BOOL CALLBACK EnumObjectsCallback( const DIDEVICEOBJECTINSTANCE* pdidoi, VOID* pContext )
+{
+	DXJoystick *stick = ( DXJoystick * )pContext;
+
+	 if ( pdidoi->guidType == GUID_POV )
+	 {
+		stick->numberOfHats++;
+	 }
+
+	 return DIENUM_CONTINUE;
+}
+
 void	      DXJoystick::initJoystick(const char* joystickName)
 {
   // turn it off
@@ -96,9 +109,13 @@ void	      DXJoystick::initJoystick(const char* joystickName)
    * Set device cooperation level - all input on this device goes to BZFlag,
    * because we're greedy.
    */
-
+#ifdef HAVE_SDL
+  success = device->SetCooperativeLevel(SDLWindow::getHandle(),
+					DISCL_BACKGROUND | DISCL_EXCLUSIVE);
+#else
   success = device->SetCooperativeLevel(WinWindow::getHandle(),
 					DISCL_BACKGROUND | DISCL_EXCLUSIVE);
+#endif
 
   if (success != DI_OK) {
     // couldn't grab device, what to do now?
@@ -107,6 +124,17 @@ void	      DXJoystick::initJoystick(const char* joystickName)
     return;
   }
 
+
+  // enumerate the axes and stuff
+  success = device->EnumObjects(EnumObjectsCallback,(VOID*)this, DIDFT_POV);
+
+  if (success != DI_OK) {
+	  // couldn't grab device, what to do now?
+	  DXError("Could not enumerate options", success);
+	  device = NULL;
+	  return;
+  }
+
   /*
    * Set the device data format.  We want buttons and axis, so we'll use a
    * predefined Joystick structure.
@@ -202,6 +230,8 @@ void	      DXJoystick::initJoystick(const char* joystickName)
   if (success == DI_OK)
     axes["Slider 2"] = true;
 
+  hataxes.assign(numberOfHats * 2, 0); // two axes each
+
   /*
    * Acquire the device so that we can get input from it.
    */
@@ -261,6 +291,43 @@ unsigned long DXJoystick::getJoyButtons()
   return buttons;
 }
 
+int	   DXJoystick::getNumHats()
+{
+  return numberOfHats;
+}
+
+void	  DXJoystick::getJoyHat(int hat, float &hatX, float &hatY)
+{
+	DIJOYSTATE state = pollDevice();
+
+	for (int i = 0; i < numberOfHats; i++)
+	{
+		DWORD hatPos = state.rgdwPOV[i];
+
+		float hatX = 0;
+		float hatY = 0;
+		BOOL hatCentered = (LOWORD(hatPos) == 0xFFFF);
+		if (hatCentered)
+		{
+		    hataxes[i * 2]     = hatX = 0;
+		    hataxes[i * 2 + 1] = hatY = 0;
+		} else {
+		    // hatPos is indicated clockwise from north, we transform it so it
+		    // can be fed into sinf() and cosf() which start counting from east
+			float angle = (float)hatPos/100.0f - 90;
+
+			hataxes[i * 2]     = hatX = cosf(angle * ((float)M_PI/180.0f));
+			hataxes[i * 2 + 1] = hatY = sinf(angle * ((float)M_PI/180.0f));
+		}
+	}
+
+  hatX = hatY = 0;
+  if (!device) return;
+  if (hat >= numberOfHats) return;
+  hatX = hataxes[hat * 2];
+  hatY = hataxes[hat * 2 + 1];
+}
+
 DIJOYSTATE    DXJoystick::pollDevice()
 {
   DIJOYSTATE state;
@@ -295,13 +362,13 @@ void	      DXJoystick::getJoyDeviceAxes(std::vector<std::string> &list) const
   }
 }
 
-void	      DXJoystick::setXAxis(std::string axis)
+void	      DXJoystick::setXAxis(const std::string &axis)
 {
   if (axes[axis] == false) return;
   xAxis = axis;
 }
 
-void	      DXJoystick::setYAxis(std::string axis)
+void	      DXJoystick::setYAxis(const std::string &axis)
 {
   if (axes[axis] == false) return;
   yAxis = axis;
@@ -812,11 +879,9 @@ BOOL CALLBACK DXJoystick::deviceEnumCallback(LPCDIDEVICEINSTANCE device, void* U
   return DIENUM_CONTINUE;
 }
 
-#endif
-
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
