@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -218,7 +218,7 @@ void			EvdevJoystick::initJoystick(const char* joystickName)
   } else {
     joystickfd = open(info->filename.c_str(), O_RDONLY | O_NONBLOCK);
     if (joystickfd > 0) {
-      /* Got it in read only */
+      /* Got it in read-only */
       currentJoystick = info;
       currentJoystick->readonly = true;
       printError("No write access to joystick device, force feedback disabled.");
@@ -230,6 +230,8 @@ void			EvdevJoystick::initJoystick(const char* joystickName)
   useaxis[0] = ABS_X;
   useaxis[1] = ABS_Y;
   buttons = 0;
+  //for some reason, I can't put this in getJoyHats
+  hataxes.assign(4 * 2, 0);
 }
 
 bool			EvdevJoystick::joystick() const
@@ -246,9 +248,12 @@ void		    EvdevJoystick::poll()
     switch (ev.type) {
 
     case EV_ABS:
-      if (ev.code - ABS_X > 8)
+      if (ev.code > ABS_WHEEL) {
+	if (ABS_HAT0X <= ev.code && ev.code <= ABS_HAT3Y)
+	  hataxes[ev.code - ABS_HAT0X] = ev.value;
 	break;
-      currentJoystick->axis_info[ev.code - ABS_X].value = ev.value; break;
+      }
+      currentJoystick->axis_info[ev.code - ABS_X].value = ev.value;
       break;
 
     case EV_KEY:
@@ -336,6 +341,33 @@ void			EvdevJoystick::getJoy(int& x, int& y)
   }
 }
 
+int		     EvdevJoystick::getNumHats()
+{
+  numHats = 0;
+  if (currentJoystick) {
+    for (int i = 0; i < 4; ++i) {
+      if (test_bit(ABS_HAT0X + i * 2, currentJoystick->absbit)) {
+	numHats++;
+      }
+    }
+  }
+  //for some reason, I can't move this from initJoystick
+  //hataxes.assign(numHats * 2, 0);
+  return numHats;
+}
+
+void		    EvdevJoystick::getJoyHat(int hat, float &hatX, float &hatY)
+{
+  hatX = hatY = 0;
+  if (currentJoystick) {
+    if (hat < 4) {
+      poll();
+      hatX = hataxes[hat * 2];
+      hatY = hataxes[hat * 2 + 1];
+    }
+  }
+}
+
 unsigned long		EvdevJoystick::getJoyButtons()
 {
   if (currentJoystick) {
@@ -370,14 +402,14 @@ void		EvdevJoystick::getJoyDeviceAxes(std::vector<std::string>
       list.push_back(anames[i]);
 }
 
-void		    EvdevJoystick::setXAxis(const std::string axis)
+void		    EvdevJoystick::setXAxis(const std::string &axis)
 {
   for (int i = 0; i < 9; ++i)
     if (anames[i] == axis)
       useaxis[0] = ABS_X + i;
 }
 
-void		    EvdevJoystick::setYAxis(const std::string axis)
+void		    EvdevJoystick::setYAxis(const std::string &axis)
 {
   for (int i = 0; i < 9; ++i)
     if (anames[i] == axis)
@@ -647,7 +679,7 @@ void EvdevJoystick::ffDirectionalResistance(float, float, float, ResistanceType)
 #endif /* HAVE_LINUX_INPUT_H */
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
