@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,10 +23,7 @@ PlatformFactory::PlatformFactory()
 {
 #ifdef HAVE_SDL
   Uint32 flags = 0;
-#ifdef DEBUG
-  flags |= SDL_INIT_NOPARACHUTE;
-#endif
-  if (SDL_Init(flags) == -1) {
+  if (SDL_Init(flags) < 0) {
     printFatalError("Could not initialize SDL: %s.\n", SDL_GetError());
     exit(-1);
   };
@@ -56,10 +53,9 @@ BzfMedia*		PlatformFactory::getMedia()
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
