@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,7 +23,7 @@ static int mx = 0;
 static int my = 0;
 
 SDLDisplay::SDLDisplay() : fullScreen(false), base_width(640),
-			   base_height(480), canGrabMouse(true),
+			   base_height(480), min_width(), min_height(),  x(), y(), canGrabMouse(true),
 			   oldFullScreen(false),
 			   oldWidth(0), oldHeight(0)
 {
@@ -528,6 +528,52 @@ bool SDLDisplay::createWindow() {
     printf("Could not set Video Mode: %s.\n", SDL_GetError());
     return false;
   } else {
+#ifndef __APPLE__
+    // initialize opengl extension functions
+    glIsRenderbuffer = (PFNGLISRENDERBUFFERPROC)
+      SDL_GL_GetProcAddress("glIsRenderbuffer");
+    glBindRenderbuffer = (PFNGLBINDRENDERBUFFERPROC)
+      SDL_GL_GetProcAddress("glBindRenderbuffer");
+    glDeleteRenderbuffers = (PFNGLDELETERENDERBUFFERSPROC)
+      SDL_GL_GetProcAddress("glDeleteRenderbuffers");
+    glGenRenderbuffers = (PFNGLGENRENDERBUFFERSPROC)
+      SDL_GL_GetProcAddress("glGenRenderbuffers");
+    glRenderbufferStorage = (PFNGLRENDERBUFFERSTORAGEPROC)
+      SDL_GL_GetProcAddress("glRenderbufferStorage");
+    glRenderbufferStorageMultisample =
+      (PFNGLRENDERBUFFERSTORAGEMULTISAMPLEPROC)
+      SDL_GL_GetProcAddress("glRenderbufferStorageMultisample");
+    glGetRenderbufferParameteriv = (PFNGLGETRENDERBUFFERPARAMETERIVPROC)
+      SDL_GL_GetProcAddress("glGetRenderbufferParameteriv");
+    glIsFramebuffer = (PFNGLISFRAMEBUFFERPROC)
+      SDL_GL_GetProcAddress("glIsFramebuffer");
+    glBindFramebuffer = (PFNGLBINDFRAMEBUFFERPROC)
+      SDL_GL_GetProcAddress("glBindFramebuffer");
+    glDeleteFramebuffers = (PFNGLDELETEFRAMEBUFFERSPROC)
+      SDL_GL_GetProcAddress("glDeleteFramebuffers");
+    glGenFramebuffers = (PFNGLGENFRAMEBUFFERSPROC)
+      SDL_GL_GetProcAddress("glGenFramebuffers");
+    glCheckFramebufferStatus = (PFNGLCHECKFRAMEBUFFERSTATUSPROC)
+      SDL_GL_GetProcAddress("glCheckFramebufferStatus");
+    glFramebufferTexture1D = (PFNGLFRAMEBUFFERTEXTURE1DPROC)
+      SDL_GL_GetProcAddress("glFramebufferTexture1D");
+    glFramebufferTexture2D = (PFNGLFRAMEBUFFERTEXTURE2DPROC)
+      SDL_GL_GetProcAddress("glFramebufferTexture2D");
+    glFramebufferTexture3D = (PFNGLFRAMEBUFFERTEXTURE3DPROC)
+      SDL_GL_GetProcAddress("glFramebufferTexture3D");
+    glFramebufferTextureLayer = (PFNGLFRAMEBUFFERTEXTURELAYERPROC)
+      SDL_GL_GetProcAddress("glFramebufferTextureLayer");
+    glFramebufferRenderbuffer = (PFNGLFRAMEBUFFERRENDERBUFFERPROC)
+      SDL_GL_GetProcAddress("glFramebufferRenderbuffer");
+    glGetFramebufferAttachmentParameteriv =
+      (PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVPROC)
+      SDL_GL_GetProcAddress("glGetFramebufferAttachmentParameteriv");
+    glBlitFramebuffer = (PFNGLBLITFRAMEBUFFERPROC)
+      SDL_GL_GetProcAddress("glBlitFramebuffer");
+    glGenerateMipmap = (PFNGLGENERATEMIPMAPPROC)
+      SDL_GL_GetProcAddress("glGenerateMipmap");
+#endif // __APPLE__
+
     // init opengl context
     OpenGLGState::initContext();
     return true;
@@ -598,8 +644,12 @@ void SDLVisual::setStereo(bool on) {
   SDL_GL_SetAttribute(SDL_GL_STEREO, on ? 1 : 0);
 }
 
+void SDLVisual::setVerticalSync(bool on) {
+  SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, on ? 1 : 0);
+}
+
 SDLWindow::SDLWindow(const SDLDisplay* _display, SDLVisual*)
-  : BzfWindow(_display), x(-1), y(-1), hasGamma(true)
+  : BzfWindow(_display), hasGamma(true)
 {
 }
 
@@ -608,7 +658,7 @@ void SDLWindow::setTitle(const char * title) {
 }
 
 void SDLWindow::setFullscreen(bool on) {
-  ((SDLDisplay *)getDisplay())->setFullscreen(on);
+  const_cast<SDLDisplay *>((const SDLDisplay *)getDisplay())->setFullscreen(on);
 }
 
 void SDLWindow::iconify(void) {
@@ -625,11 +675,11 @@ void SDLWindow::getMouse(int& _x, int& _y) const {
 }
 
 void SDLWindow::setSize(int width, int height) {
-  ((SDLDisplay *)getDisplay())->setWindowSize(width, height);
+  const_cast<SDLDisplay *>((const SDLDisplay *)getDisplay())->setWindowSize(width, height);
 }
 
 void SDLWindow::getSize(int& width, int& height) const {
-  ((SDLDisplay *)getDisplay())->getWindowSize(width, height);
+  const_cast<SDLDisplay *>((const SDLDisplay *)getDisplay())->getWindowSize(width, height);
 }
 
 void SDLWindow::setGamma(float gamma) {
@@ -689,20 +739,20 @@ void SDLWindow::swapBuffers() {
 }
 
 bool SDLWindow::create(void) {
-  if (!((SDLDisplay *)getDisplay())->createWindow()) {
+  if (!const_cast<SDLDisplay *>((const SDLDisplay *)getDisplay())->createWindow()) {
     return false;
   }
   return true;
 }
 
 void SDLWindow::enableGrabMouse(bool on) {
-  ((SDLDisplay *)getDisplay())->enableGrabMouse(on);
+  const_cast<SDLDisplay *>((const SDLDisplay *)getDisplay())->enableGrabMouse(on);
 }
 
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
