@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -69,7 +69,7 @@ class SDLVisual : public BzfVisual {
   void setStencil(int minDepth);
   void setAccum(int, int, int, int) {;};
   void setStereo(bool);
-  void setMultisample(int) {;};
+  void setVerticalSync(bool);
   bool build() {return true;};
 };
 
@@ -96,21 +96,20 @@ class SDLWindow : public BzfWindow {
   void  setGamma(float newGamma);
   float getGamma() const;
   bool  hasGammaControl() const;
+  virtual bool hasVerticalSync() const {return true;};
   void  makeCurrent() {;};
   void  swapBuffers();
   void  makeContext() {;};
   void  freeContext() {;};
   bool  create(void);
  private:
-  int	  x;
-  int	  y;
   bool	 hasGamma;
 };
 
 #endif // BZF_SDLDISPLAY_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
