@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -161,11 +161,11 @@ bool			Resolution::setFormat(Display* dpy, int screen) const
 
 static int		resolutionCompare(const void* _a, const void* _b)
 {
-  const Resolution* a = *((const Resolution**)_a);
+  const Resolution* a = *((const Resolution* const *)_a);
   const int aNumChannels = a->getNumChannels();
   const Resolution::Config* aConfig = a->getConfigs();
 
-  const Resolution* b = *((const Resolution**)_b);
+  const Resolution* b = *((const Resolution* const *)_b);
   const int bNumChannels = b->getNumChannels();
   const Resolution::Config* bConfig = b->getConfigs();
 
@@ -451,10 +451,9 @@ bool			SGIDisplayMode::set(int index)
 #endif
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
