@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,11 +33,9 @@ short tmp_buf[512];
 // SolarisMedia
 //
 
-SolarisMedia::SolarisMedia() : BzfMedia(), audio_fd(-1),
-				queueIn(-1), queueOut(-1),
-				childProcID(0),
-				written(0), eof_written(0),
-				eof_counter(0),audio_ready(0)
+SolarisMedia::SolarisMedia() : BzfMedia(), audio_fd(-1), audio_ready(0),
+			       queueIn(-1), queueOut(-1), written(0),
+			       eof_written(0), eof_counter(0), childProcID(0)
 
 {
   // do nothing
@@ -66,23 +64,23 @@ bool			SolarisMedia::openAudio()
 {
   int fd[2];
 
-  if(audio_ready)
+  if (audio_ready)
     return false;
 
   audio_fd = open("/dev/audio", O_WRONLY  | O_NDELAY);
 
-  if(audio_fd < 0)
+  if (audio_fd < 0)
     return false;
 
-  if(DEBUG_SOLARIS)
+  if (DEBUG_SOLARIS)
     fprintf(stderr, "Audio device '/dev/audio' opened\n");
 
   audioctl_fd = open("/dev/audioctl", O_RDWR);
 
-  if(audioctl_fd < 0)
+  if (audioctl_fd < 0)
     return false;
 
-  if(DEBUG_SOLARIS)
+  if (DEBUG_SOLARIS)
     fprintf(stderr, "Opened audio control device '/dev/audioctl'\n");
 
 // removing these avoids a kernel crash on solaris 8 - bzFrank
@@ -93,22 +91,22 @@ bool			SolarisMedia::openAudio()
   ioctl(audioctl_fd, I_FLUSH, FLUSHRW);
 #endif
 
-  if(ioctl(audio_fd, AUDIO_GETDEV, &a_dev) < 0)
+  if (ioctl(audio_fd, AUDIO_GETDEV, &a_dev) < 0)
   {
-    if(DEBUG_SOLARIS)
+    if (DEBUG_SOLARIS)
       fprintf(stderr, "Cannot get audio information.\n");
     close(audio_fd);
     close(audioctl_fd);
     return false;
   }
 
-  if(DEBUG_SOLARIS)
+  if (DEBUG_SOLARIS)
     fprintf(stderr, "Sound device is a %s %s version %s\n", a_dev.config, a_dev.name, a_dev.version);
 
   // Get audio parameters
-  if(ioctl(audioctl_fd, AUDIO_GETINFO, &a_info) < 0)
+  if (ioctl(audioctl_fd, AUDIO_GETINFO, &a_info) < 0)
   {
-    if(DEBUG_SOLARIS)
+    if (DEBUG_SOLARIS)
       fprintf(stderr, "Cannot get audio information.\n");
     close(audio_fd);
     close(audioctl_fd);
@@ -126,15 +124,15 @@ bool			SolarisMedia::openAudio()
   audioBufferSize	  = AUDIO_BUFFER_SIZE;
   audioLowWaterMark	  = 2;
 
-  if(ioctl(audio_fd, AUDIO_SETINFO, &a_info) == -1)
+  if (ioctl(audio_fd, AUDIO_SETINFO, &a_info) == -1)
   {
-    if(DEBUG_SOLARIS)
+    if (DEBUG_SOLARIS)
       fprintf(stderr, "Warning: Cannot set audio parameters.\n");
 
     return false;
   }
 
-  if(DEBUG_SOLARIS)
+  if (DEBUG_SOLARIS)
     fprintf(stderr, "Audio initialised. Setting up queues...\n");
 
   if (pipe(fd)<0) {
@@ -158,7 +156,7 @@ bool			SolarisMedia::openAudio()
   // ready to go
   audio_ready = true;
 
-  if(DEBUG_SOLARIS)
+  if (DEBUG_SOLARIS)
     fprintf(stderr, "Audio ready.\n");
 
   return true;
@@ -304,10 +302,9 @@ void			SolarisMedia::audioSleep(
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
