@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,15 +18,13 @@
 #define	BZF_WINMEDIA_H
 
 #include "BzfMedia.h"
-#ifdef HAVE_DSOUND_H
 #include <dsound.h>
-#endif
 
 class WinWindow;
 
 class WinMedia : public BzfMedia {
   public:
-			WinMedia(WinWindow*);
+			WinMedia();
 			~WinMedia();
 
     bool		openAudio();
@@ -47,14 +45,11 @@ class WinMedia : public BzfMedia {
     static DWORD WINAPI	audioThreadInit(void*);
 
   private:
-    HWND		window;
     bool		audioReady;
     bool		audioPlaying;
-#ifdef HAVE_DSOUND_H
     IDirectSound*	audioInterface;
     IDirectSoundBuffer*	audioPrimaryPort;
     IDirectSoundBuffer*	audioPort;
-#endif
     int			audioNumChannels;
     int			audioOutputRate;
     int			audioBufferSize;
@@ -78,10 +73,9 @@ class WinMedia : public BzfMedia {
 #endif // BZF_WINMEDIA_H
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
