@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -213,7 +213,7 @@ bool XDisplay::setupEvent(BzfEvent& event, const XEvent& xevent) const
       break;
 
     case ClientMessage: {
-      XClientMessageEvent* cme = (XClientMessageEvent*)&xevent;
+      const XClientMessageEvent* cme = (const XClientMessageEvent*)&xevent;
       if (cme->format == 32) {
 	if ((Atom)cme->data.l[0] == XInternAtom(rep->getDisplay(),
 					"WM_DELETE_WINDOW", true)) {
@@ -234,7 +234,8 @@ bool			XDisplay::getKey(const XEvent& xevent,
 {
   char buf[3];
   KeySym keysym;
-  if (XLookupString((XKeyEvent*)&xevent.xkey, buf, 1, &keysym, NULL) == 1) {
+  XKeyEvent xkey = xevent.xkey;		// non-const copy
+  if (XLookupString(&xkey, buf, 1, &keysym, NULL) == 1) {
     key.ascii = buf[0];
     key.button = BzfKeyEvent::NoButton;
 
@@ -322,10 +323,9 @@ bool			XDisplayMode::setDefault(int mode)
 }
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
