@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -232,8 +232,8 @@ void OccluderManager::select(const SceneNode* const* list, int listCount)
 
 static int compareOccluders (const void* a, const void* b)
 {
-  Occluder** ptrA = (Occluder**)a;
-  Occluder** ptrB = (Occluder**)b;
+  const Occluder* const * ptrA = (const Occluder* const *)a;
+  const Occluder* const * ptrB = (const Occluder* const *)b;
   int scoreA = (*ptrA)->getScore();
   int scoreB = (*ptrB)->getScore();
 
@@ -316,14 +316,6 @@ IntersectLevel Occluder::doCullAxisBox(const Extents& exts)
 }
 
 
-bool Occluder::doCullSceneNode(SceneNode* node)
-{
-  // FIXME - not yet implemented
-  node = node;
-  return false;
-}
-
-
 static bool makePlane (const float* p1, const float* p2, const float* pc,
 		       float* r)
 {
@@ -471,7 +463,7 @@ void Occluder::draw() const
 void Occluder::print(const char* string) const
 {
   // FIXME - debugging
-  printf ("%s: %p, V = %i, P = %i\n", string, (void *)sceneNode, vertexCount, planeCount);
+  printf ("%s: %p, V = %i, P = %i\n", string, (const void *)sceneNode, vertexCount, planeCount);
   for (int v = 0; v < vertexCount; v++) {
     printf ("  v%i: %f, %f, %f\n", v, vertices[v][0], vertices[v][1],vertices[v][2]);
   }
@@ -481,3 +473,11 @@ void Occluder::print(const char* string) const
 
   return;
 }
+
+// Local Variables: ***
+// mode: C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
