@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2011 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -376,6 +376,7 @@ OctreeNode::OctreeNode(unsigned char _depth, const Extents& exts,
   count = listSize;
 
   // resize the list to save space
+  // FIXME: Correctly handle the situation of the realloc failing (which would return a NULL pointer)
   list = (SceneNode**) realloc (list, count * sizeof (SceneNode*));
 
   // return if this is a leaf node
@@ -443,7 +444,7 @@ void OctreeNode::makeChildren ()
 	else {
 	  childCount++;
 	}
-	children[kid] = squeezed[kid];;
+	children[kid] = squeezed[kid];
       }
     }
   }
@@ -877,7 +878,7 @@ void OctreeNode::draw ()
 
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
